@@ -66,6 +66,8 @@
 class CMakeGenerator
 {
     size_t m_counter;
+    wxString m_userBlock01;
+    wxString m_userBlock02;
     wxString m_userBlock1;
     wxString m_userBlock2;
     wxString m_userBlock3;
@@ -105,10 +107,21 @@ protected:
     void ReadUntilEndOfUserBlock(wxArrayString& lines, wxString& content);
 
     void AddUserCodeSection(wxString& content, const wxString& sectionPrefix, const wxString& sectionCode = "");
+    
+    /**
+     * @brief add pre|post build commands to the generated CMakeLists.txt file
+     * @param buildType can be POST_BUILD, PRE_BUILD or PRE_LINK string
+     * @param commands list of commands to run
+     * @param content the CMakeLists.txt file content [output]
+     */
+    void AddBuildCommands(const wxString& buildType,
+                          const BuildCommandList& commands,
+                          ProjectPtr project,
+                          wxString& content);
 
 public:
     CMakeGenerator();
-    ~CMakeGenerator();
+    ~CMakeGenerator() = default;
 
     /**
      * @brief Generate CMakeLists.txt for workspace.
