@@ -51,13 +51,12 @@ DotWriter::DotWriter()
     dwce = 0;
     dwtn = 0;
     dwte = 0;
+    m_writedotfileFlag = false;
     dwhideparams = false;
     dwhidenamespaces = false;
     dwstripparams = false;
 }
 
-DotWriter::~DotWriter() {}
-
 void DotWriter::SetLineParser(LineParserList* pLines) //, int numOfLines)
 {
     mlines = pLines;
@@ -193,7 +192,7 @@ void DotWriter::WriteToDotLanguage()
     if(!is_node) { // if the call graph is empty create new graph with label node
         m_OutputString = wxT("digraph e {0 [label=");
         m_OutputString +=
-            _(wxString::Format("\"The call-graph is empty; the node threshold ceiling is %d !\"", wxRound(max_time)));
+            wxString::Format(_("\"The call-graph is empty; the node threshold ceiling is %d !\""), wxRound(max_time));
         m_OutputString += wxT(", shape=none, height=2, width=2, fontname=Arial, fontsize=14.00];}");
     }
 }
@@ -216,7 +215,7 @@ wxString DotWriter::OptionsShortNameAndParameters(const wxString& name)
             wxRegEx re;
             // remove STL
             int start, end;
-            while(GetOuterTempleate(out, &start, &end)) {
+            while(GetOuterTemplate(out, &start, &end)) {
                 out.Replace(out.Mid(start, end - start + 1), wxT("%STL%"));
             }
             out.Replace(wxT("%STL%"), wxT("<...>"));
@@ -343,16 +342,16 @@ wxString DotWriter::DefineColorForLabel(int index)
     }
 }
 
-bool DotWriter::GetOuterTempleate(const wxString& txt, int* start, int* end)
+bool DotWriter::GetOuterTemplate(const wxString& txt, int* start, int* end)
 {
     int cnt = 0;
     int pos = 0;
 
-    for(wxString::const_iterator it = txt.begin(); it != txt.end(); ++it) {
-        if(*it == wxT('<')) {
+    for (auto c : txt) {
+        if (c == wxT('<')) {
             if(cnt == 0) *start = pos;
             cnt++;
-        } else if(*it == wxT('>')) {
+        } else if (c == wxT('>')) {
             cnt--;
             if(cnt == 0) *end = pos;
             return true;
