@@ -36,11 +36,11 @@
 #ifndef __uisettingsdlg__
 #define __uisettingsdlg__
 
-#include "wx/wx.h"
-#include "wx/string.h"
-#include "uisettings.h"
 #include "confcallgraph.h"
+#include "uisettings.h"
 
+#include <wx/wx.h>
+#include <wx/string.h>
 
 class IManager;
 //class CallGraph;
@@ -64,7 +64,7 @@ protected:
 public:
 	/** Constructor */
 	uisettingsdlg( wxWindow* parent, IManager *mgr);//, CallGraph *plugin );
-	virtual ~uisettingsdlg();
+    virtual ~uisettingsdlg() = default;
 };
 
 #endif
