@@ -4,10 +4,22 @@
 #include "IPathConverter.hpp"
 #include "JSON.h"
 #include "JSONObject.h"
+#include "clModuleLogger.hpp"
 #include "codelite_exports.h"
+#include "fileutils.h"
+
 #include <vector>
 #include <wx/sharedptr.h>
 
+// Helper macros to be used outside of this library
+#define LSP_LOG (LSP::GetLogHandle())
+
+#define LSP_DEBUG() LOG_DEBUG(LSP_LOG)
+#define LSP_TRACE() LOG_TRACE(LSP_LOG)
+#define LSP_ERROR() LOG_ERROR(LSP_LOG)
+#define LSP_WARNING() LOG_WARNING(LSP_LOG)
+#define LSP_SYSTEM() LOG_SYSTEM(LSP_LOG)
+
 namespace LSP
 {
 enum eSymbolKind {
@@ -39,75 +51,23 @@ enum eSymbolKind {
     kSK_TypeParameter = 26,
 };
 
-//===----------------------------------------------------------------------------------
-// TextDocumentContentChangeEvent
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL TextDocumentContentChangeEvent : public Serializable
+class WXDLLIMPEXP_CL URI
 {
-    std::string m_text;
+    wxString m_path;
+    wxString m_uri;
+
+private:
+    URI(const wxString& str) = delete;
+    URI& operator=(const wxString& str) = delete;
 
 public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
+    URI() = default;
+    ~URI() = default;
 
-    TextDocumentContentChangeEvent() {}
-    TextDocumentContentChangeEvent(const wxString& text)
-        : m_text(text)
-    {
-    }
-    virtual ~TextDocumentContentChangeEvent() {}
-    TextDocumentContentChangeEvent& SetText(const std::string& text);
-    const std::string& GetText() const { return m_text; }
-};
+    static void FromString(const wxString& str, URI* o);
 
-//===----------------------------------------------------------------------------------
-// TextDocumentIdentifier
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL TextDocumentIdentifier : public Serializable
-{
-    wxString m_filename;
-
-public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-
-    TextDocumentIdentifier() {}
-    TextDocumentIdentifier(const wxString& filename)
-        : m_filename(filename)
-    {
-    }
-    virtual ~TextDocumentIdentifier() {}
-    TextDocumentIdentifier& SetFilename(const wxString& filename)
-    {
-        this->m_filename = filename;
-        return *this;
-    }
-    const wxString& GetFilename() const { return m_filename; }
-};
-
-//===----------------------------------------------------------------------------------
-// VersionedTextDocumentIdentifier
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL VersionedTextDocumentIdentifier : public TextDocumentIdentifier
-{
-    int m_version = 1;
-
-public:
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-
-    VersionedTextDocumentIdentifier() {}
-    VersionedTextDocumentIdentifier(int version)
-        : m_version(version)
-    {
-    }
-    virtual ~VersionedTextDocumentIdentifier() {}
-    VersionedTextDocumentIdentifier& SetVersion(int version)
-    {
-        this->m_version = version;
-        return *this;
-    }
-    int GetVersion() const { return m_version; }
+    const wxString& GetPath() const;
+    const wxString& GetUrl() const;
 };
 
 //===----------------------------------------------------------------------------------
@@ -119,16 +79,32 @@ class WXDLLIMPEXP_CL Position : public Serializable
     int m_character = wxNOT_FOUND;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Position(int line, int col)
         : m_line(line)
         , m_character(col)
     {
     }
-    Position() {}
-    virtual ~Position() {}
+    Position() = default;
+    virtual ~Position() = default;
+    bool operator==(const Position& rhs) const
+    {
+        return this->m_line == rhs.m_line && this->m_character == rhs.m_character;
+    }
+    bool operator!=(const Position& rhs) const { return !(*this == rhs); }
+    bool operator<(const Position& rhs) const
+    {
+        if (this->m_line == rhs.m_line) {
+            return this->m_character < rhs.m_character;
+        } else {
+            return this->m_line < rhs.m_line;
+        }
+    }
+    bool operator>(const Position& rhs) const { return rhs < *this; }
+    bool operator<=(const Position& rhs) const { return !(*this > rhs); }
+    bool operator>=(const Position& rhs) const { return !(*this < rhs); }
     Position& SetCharacter(int character)
     {
         this->m_character = character;
@@ -153,16 +129,16 @@ class WXDLLIMPEXP_CL Range : public Serializable
     Position m_end;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Range(const Position& start, const Position& end)
         : m_start(start)
         , m_end(end)
     {
     }
-    Range() {}
-    virtual ~Range() {}
+    Range() = default;
+    virtual ~Range() = default;
     Range& SetEnd(const Position& end)
     {
         this->m_end = end;
@@ -178,6 +154,79 @@ public:
     bool IsOk() const { return m_start.IsOk() && m_end.IsOk(); }
 };
 
+//===----------------------------------------------------------------------------------
+// TextDocumentContentChangeEvent
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL TextDocumentContentChangeEvent : public Serializable
+{
+    wxString m_text;
+    Range m_range; // Optional
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    TextDocumentContentChangeEvent() = default;
+    TextDocumentContentChangeEvent(const wxString& text)
+        : m_text(text)
+    {
+    }
+    virtual ~TextDocumentContentChangeEvent() = default;
+    TextDocumentContentChangeEvent& SetText(const wxString& text);
+    const wxString& GetText() const { return m_text; }
+    const Range& GetRange() const { return m_range; }
+    void SetRange(const Range& range) { m_range = range; }
+};
+
+//===----------------------------------------------------------------------------------
+// TextDocumentIdentifier
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL TextDocumentIdentifier : public Serializable
+{
+    URI m_filename;
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    TextDocumentIdentifier() = default;
+    TextDocumentIdentifier(const wxString& filename) { URI::FromString(filename, &m_filename); }
+
+    virtual ~TextDocumentIdentifier() = default;
+    TextDocumentIdentifier& SetFilename(const wxString& filename)
+    {
+        URI::FromString(filename, &m_filename);
+        return *this;
+    }
+    const wxString& GetPath() const { return m_filename.GetPath(); }
+    const wxString& GetPathAsURI() const { return m_filename.GetUrl(); }
+};
+
+//===----------------------------------------------------------------------------------
+// VersionedTextDocumentIdentifier
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL VersionedTextDocumentIdentifier : public TextDocumentIdentifier
+{
+    int m_version = 1;
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    VersionedTextDocumentIdentifier() = default;
+    VersionedTextDocumentIdentifier(int version)
+        : m_version(version)
+    {
+    }
+    virtual ~VersionedTextDocumentIdentifier() = default;
+    VersionedTextDocumentIdentifier& SetVersion(int version)
+    {
+        this->m_version = version;
+        return *this;
+    }
+    int GetVersion() const { return m_version; }
+};
+
 //===----------------------------------------------------------------------------------
 // TextEdit
 //===----------------------------------------------------------------------------------
@@ -188,10 +237,10 @@ class WXDLLIMPEXP_CL TextEdit : public LSP::Serializable
     wxString m_newText;
 
 public:
-    TextEdit() {}
-    virtual ~TextEdit() {}
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    TextEdit() = default;
+    virtual ~TextEdit() = default;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
     void SetNewText(const wxString& newText) { this->m_newText = newText; }
     void SetRange(const Range& range) { this->m_range = range; }
     const wxString& GetNewText() const { return m_newText; }
@@ -201,36 +250,41 @@ public:
 
 class WXDLLIMPEXP_CL Location : public Serializable
 {
-    wxString m_uri;
+    URI m_uri;
     Range m_range;
-    bool m_trySSH = false;
+    wxString m_pattern;
+    wxString m_name;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Location(const wxString& uri, const Range& range)
-        : m_uri(uri)
-        , m_range(range)
+        : m_range(range)
     {
+        URI::FromString(uri, &m_uri);
     }
-    Location() {}
-    virtual ~Location() {}
+
+    Location() = default;
+    virtual ~Location() = default;
     Location& SetRange(const Range& range)
     {
         this->m_range = range;
         return *this;
     }
-    Location& SetUri(const wxString& uri)
+    Location& SetPath(const wxString& path)
     {
-        this->m_uri = uri;
+        URI::FromString(path, &m_uri);
         return *this;
     }
-    const Range& GetRange() const { return m_range; }
-    const wxString& GetUri() const { return m_uri; }
 
-    void SetTrySSH(bool trySSH) { this->m_trySSH = trySSH; }
-    bool IsTrySSH() const { return m_trySSH; }
+    const Range& GetRange() const { return m_range; }
+    const wxString& GetPathAsURI() const { return m_uri.GetUrl(); }
+    const wxString& GetPath() const { return m_uri.GetPath(); }
+    void SetPattern(const wxString& pattern) { this->m_pattern = pattern; }
+    const wxString& GetPattern() const { return m_pattern; }
+    void SetName(const wxString& name) { this->m_name = name; }
+    const wxString& GetName() const { return m_name; }
 };
 
 //===----------------------------------------------------------------------------------
@@ -238,24 +292,25 @@ public:
 //===----------------------------------------------------------------------------------
 class WXDLLIMPEXP_CL TextDocumentItem : public Serializable
 {
-    wxString m_uri;
+    URI m_uri;
     wxString m_languageId;
-    std::string m_text;
+    wxString m_text;
     int m_version = 1;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
-    TextDocumentItem(const wxString& uri, const wxString& langId, const std::string& text, int version = 1)
-        : m_uri(uri)
-        , m_languageId(langId)
+    TextDocumentItem(const wxString& uri, const wxString& langId, const wxString& text, int version = 1)
+        : m_languageId(langId)
         , m_text(text)
         , m_version(version)
     {
+        URI::FromString(uri, &m_uri);
     }
-    TextDocumentItem() {}
-    virtual ~TextDocumentItem() {}
+
+    TextDocumentItem() = default;
+    virtual ~TextDocumentItem() = default;
     TextDocumentItem& SetLanguageId(const wxString& languageId)
     {
         this->m_languageId = languageId;
@@ -268,17 +323,19 @@ public:
     }
     TextDocumentItem& SetUri(const wxString& uri)
     {
-        this->m_uri = uri;
+        URI::FromString(uri, &m_uri);
         return *this;
     }
+
     TextDocumentItem& SetVersion(int version)
     {
         this->m_version = version;
         return *this;
     }
     const wxString& GetLanguageId() const { return m_languageId; }
-    const std::string& GetText() const { return m_text; }
-    const wxString& GetUri() const { return m_uri; }
+    const wxString& GetText() const { return m_text; }
+    const wxString& GetPathAsURI() const { return m_uri.GetUrl(); }
+    const wxString& GetPath() const { return m_uri.GetPath(); }
     int GetVersion() const { return m_version; }
 };
 
@@ -288,8 +345,8 @@ class WXDLLIMPEXP_CL ParameterInformation : public LSP::Serializable
     wxString m_documentation;
 
 public:
-    ParameterInformation() {}
-    virtual ~ParameterInformation() {}
+    ParameterInformation() = default;
+    virtual ~ParameterInformation() = default;
     ParameterInformation& SetDocumentation(const wxString& documentation)
     {
         this->m_documentation = documentation;
@@ -302,8 +359,8 @@ public:
     }
     const wxString& GetDocumentation() const { return m_documentation; }
     const wxString& GetLabel() const { return m_label; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     typedef std::vector<ParameterInformation> Vec_t;
 };
@@ -318,8 +375,8 @@ public:
     typedef std::vector<LSP::SignatureInformation> Vec_t;
 
 public:
-    SignatureInformation() {}
-    virtual ~SignatureInformation() {}
+    SignatureInformation() = default;
+    virtual ~SignatureInformation() = default;
     SignatureInformation& SetParameters(const ParameterInformation::Vec_t& parameters)
     {
         this->m_parameters = parameters;
@@ -338,8 +395,8 @@ public:
     }
     const wxString& GetDocumentation() const { return m_documentation; }
     const wxString& GetLabel() const { return m_label; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 };
 
 class WXDLLIMPEXP_CL SignatureHelp : public LSP::Serializable
@@ -349,8 +406,8 @@ class WXDLLIMPEXP_CL SignatureHelp : public LSP::Serializable
     int m_activeParameter = 0;
 
 public:
-    SignatureHelp() {}
-    virtual ~SignatureHelp() {}
+    SignatureHelp() = default;
+    virtual ~SignatureHelp() = default;
 
     SignatureHelp& SetActiveParameter(int activeParameter)
     {
@@ -370,26 +427,94 @@ public:
     int GetActiveParameter() const { return m_activeParameter; }
     int GetActiveSignature() const { return m_activeSignature; }
     const SignatureInformation::Vec_t& GetSignatures() const { return m_signatures; }
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+};
+
+class WXDLLIMPEXP_CL MarkupContent : public LSP::Serializable
+{
+    wxString m_kind;
+    wxString m_value;
+
+public:
+    MarkupContent() = default;
+    virtual ~MarkupContent() = default;
+    MarkupContent& SetKind(const wxString& kind)
+    {
+        this->m_kind = kind;
+        return *this;
+    }
+    const wxString& GetKind() const { return m_kind; }
+    MarkupContent& SetValue(const wxString& value)
+    {
+        this->m_value = value;
+        return *this;
+    }
+    const wxString& GetValue() const { return m_value; }
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+};
+
+class WXDLLIMPEXP_CL Hover : public LSP::Serializable
+{
+    MarkupContent m_contents;
+    Range m_range;
+
+public:
+    Hover() = default;
+    virtual ~Hover() = default;
+    Hover& SetContents(const MarkupContent& contents)
+    {
+        this->m_contents = contents;
+        return *this;
+    }
+    const MarkupContent& GetContents() const { return m_contents; }
+    Hover& SetRange(const Range& range)
+    {
+        this->m_range = range;
+        return *this;
+    }
+    const Range& GetRange() const { return m_range; }
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
+};
+
+enum DiagnosticSeverity {
+    /**
+     * Reports an error.
+     */
+    Error = 1,
+    /**
+     * Reports a warning.
+     */
+    Warning = 2,
+    /**
+     * Reports an information.
+     */
+    Information = 3,
+    /**
+     * Reports a hint.
+     */
+    Hint = 4,
 };
 
 class WXDLLIMPEXP_CL Diagnostic : public Serializable
 {
     Range m_range;
     wxString m_message;
+    DiagnosticSeverity m_severity = DiagnosticSeverity::Error;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
     Diagnostic(const Range& range, const wxString& message)
         : m_range(range)
         , m_message(message)
     {
     }
-    Diagnostic() {}
-    virtual ~Diagnostic() {}
+    Diagnostic() = default;
+    virtual ~Diagnostic() = default;
     Diagnostic& SetRange(const Range& range)
     {
         this->m_range = range;
@@ -402,6 +527,30 @@ public:
         return *this;
     }
     const wxString& GetMessage() const { return m_message; }
+    void SetSeverity(const DiagnosticSeverity& severity) { this->m_severity = severity; }
+    const DiagnosticSeverity& GetSeverity() const { return m_severity; }
+};
+
+class WXDLLIMPEXP_CL Command : public Serializable
+{
+    wxString m_title;
+    wxString m_command;
+    wxString m_arguments;
+
+public:
+    void FromJSON(const JSONItem& json) override;
+    JSONItem ToJSON(const wxString& name) const override;
+
+    Command() = default;
+    virtual ~Command() = default;
+
+    void SetTitle(const wxString& title) { this->m_title = title; }
+    void SetCommand(const wxString& command) { this->m_command = command; }
+    void SetArguments(const wxString& arguments) { this->m_arguments = arguments; }
+
+    const wxString& GetTitle() const { return m_title; }
+    const wxString& GetCommand() const { return m_command; }
+    const wxString& GetArguments() const { return m_arguments; }
 };
 
 class WXDLLIMPEXP_CL DocumentSymbol : public Serializable
@@ -441,11 +590,11 @@ class WXDLLIMPEXP_CL DocumentSymbol : public Serializable
     std::vector<DocumentSymbol> children;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
-    DocumentSymbol() {}
-    virtual ~DocumentSymbol() {}
+    DocumentSymbol() = default;
+    virtual ~DocumentSymbol() = default;
 
     void SetChildren(const std::vector<DocumentSymbol>& children) { this->children = children; }
     void SetDetail(const wxString& detail) { this->detail = detail; }
@@ -495,11 +644,11 @@ class WXDLLIMPEXP_CL SymbolInformation : public Serializable
     wxString containerName;
 
 public:
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON(const wxString& name) const;
 
-    SymbolInformation() {}
-    virtual ~SymbolInformation() {}
+    SymbolInformation() = default;
+    virtual ~SymbolInformation() = default;
 
     void SetContainerName(const wxString& containerName) { this->containerName = containerName; }
     void SetKind(const eSymbolKind& kind) { this->kind = kind; }
@@ -511,5 +660,17 @@ public:
     const wxString& GetName() const { return name; }
 };
 
-};     // namespace LSP
+/// Initialise the library
+WXDLLIMPEXP_CL void Initialise();
+
+/// convert native file path to URI
+WXDLLIMPEXP_CL wxString FileNameToURI(const wxString& filename);
+
+/// Return the log handle of this library
+WXDLLIMPEXP_CL clModuleLogger& GetLogHandle();
+
+/// Parse the text edit from a response "result" field
+WXDLLIMPEXP_CL std::unordered_map<wxString, std::vector<LSP::TextEdit>> ParseWorkspaceEdit(const JSONItem& result);
+
+}; // namespace LSP
 #endif // JSONRPC_BASICTYPES_H
