@@ -32,17 +32,35 @@
 class WXDLLIMPEXP_CL clSocketServer : public clSocketBase
 {
 public:
-    clSocketServer();
+    clSocketServer() = default;
     virtual ~clSocketServer();
 
+protected:
     /**
      * @brief On Windows, the 'pipePath' is a string containing the port number.
      * LocalSocket is implemented under Windows with TCP/IP with IP always set to 127.0.0.1
      * @param pipePath
+     * @throw clSocketException
      */
-    void CreateServer(const std::string &pipePath) throw (clSocketException);
-    void CreateServer(const std::string &address, int port) throw (clSocketException);
-    clSocketBase::Ptr_t WaitForNewConnection( long timeout = -1 ) throw (clSocketException);
+    int CreateServer(const std::string& pipePath);
+    /**
+     * @throw clSocketException
+     * @return port number
+     */
+    int CreateServer(const std::string& address, int port);
+
+public:
+    /**
+     * @brief Create server using connection string
+     * @return port number on success
+     * @throw clSocketException
+     */
+    int Start(const wxString& connectionString);
+    clSocketBase::Ptr_t WaitForNewConnection(long timeout = -1);
+    /**
+     * @brief same as above, however, return a pointer to the connection that should be freed by the caller
+     */
+    clSocketBase* WaitForNewConnectionRaw(long timeout = -1);
 };
 
 #endif // CLSOCKETSERVER_H
