@@ -23,91 +23,26 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "archive.h"
+
+#include "clFontHelper.h"
+#include "serialized_object.h"
+#include "xmlutils.h"
+
 #include <wx/colour.h>
 #include <wx/xml/xml.h>
-#include "serialized_object.h"
-
-#include <memory>
-#include "wx_xml_compatibility.h"
-#include "clFontHelper.h"
 
 namespace
 {
 const wxChar breakpointName[] = wxT("Breakpoint");
 const wxChar breakpointArrayName[] = wxT("BreakpointArray");
-}
-
-// helper functions
-static wxXmlNode* FindNodeByName(const wxXmlNode* parent, const wxString& tagName, const wxString& name)
-{
-    if(!parent) {
-        return NULL;
-    }
-
-    wxXmlNode* child = parent->GetChildren();
-    while(child) {
-        if(child->GetName() == tagName) {
-            if(child->GetPropVal(wxT("Name"), wxEmptyString) == name) {
-                return child;
-            }
-        }
-        child = child->GetNext();
-    }
-    return NULL;
-}
-
-static void SetNodeContent(wxXmlNode* node, const wxString& text)
-{
-    wxXmlNode* n = node->GetChildren();
-    wxXmlNode* contentNode = NULL;
-    while(n) {
-        if(n->GetType() == wxXML_TEXT_NODE || n->GetType() == wxXML_CDATA_SECTION_NODE) {
-            contentNode = n;
-            break;
-        }
-        n = n->GetNext();
-    }
-
-    if(contentNode) {
-        // remove old node
-        node->RemoveChild(contentNode);
-        delete contentNode;
-    }
-
-    if(!text.IsEmpty()) {
-        contentNode = new wxXmlNode(wxXML_TEXT_NODE, wxEmptyString, text);
-        node->AddChild(contentNode);
-    }
-}
-
-static void SetCDATANodeContent(wxXmlNode* node, const wxString& text)
-{
-    wxXmlNode* n = node->GetChildren();
-    wxXmlNode* contentNode = NULL;
-    while(n) {
-        if(n->GetType() == wxXML_TEXT_NODE || n->GetType() == wxXML_CDATA_SECTION_NODE) {
-            contentNode = n;
-            break;
-        }
-        n = n->GetNext();
-    }
-
-    if(contentNode) {
-        // remove old node
-        node->RemoveChild(contentNode);
-        delete contentNode;
-    }
-
-    if(!text.IsEmpty()) {
-        contentNode = new wxXmlNode(wxXML_CDATA_SECTION_NODE, wxEmptyString, text);
-        node->AddChild(contentNode);
-    }
-}
+} // namespace
 
 // class Tab info
-TabInfo::TabInfo() {}
-
-TabInfo::~TabInfo() {}
+TabInfo::TabInfo()
+    : m_firstVisibleLine(0)
+    , m_currentLine(0)
+{
+}
 
 void TabInfo::DeSerialize(Archive& arch)
 {
@@ -133,12 +68,10 @@ Archive::Archive()
 {
 }
 
-Archive::~Archive() {}
-
 bool Archive::Write(const wxString& name, SerializedObject* obj)
 {
     Archive arch;
-    wxXmlNode* node = FindNodeByName(m_root, wxT("SerializedObject"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("SerializedObject"), name);
     if(node) {
         m_root->RemoveChild(node);
         delete node;
@@ -146,7 +79,7 @@ bool Archive::Write(const wxString& name, SerializedObject* obj)
 
     node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("SerializedObject"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     arch.SetXmlNode(node);
     obj->Serialize(arch);
@@ -156,7 +89,7 @@ bool Archive::Write(const wxString& name, SerializedObject* obj)
 bool Archive::Read(const wxString& name, SerializedObject* obj)
 {
     Archive arch;
-    wxXmlNode* node = FindNodeByName(m_root, wxT("SerializedObject"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("SerializedObject"), name);
     if(node) {
         arch.SetXmlNode(node);
         obj->DeSerialize(arch);
@@ -172,13 +105,13 @@ bool Archive::Write(const wxString& name, const wxArrayString& arr)
     }
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxArrayString"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each wxString in the array
     for(size_t i = 0; i < arr.GetCount(); i++) {
         wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxString"));
         node->AddChild(child);
-        child->AddProperty(wxT("Value"), arr.Item(i));
+        child->AddAttribute(wxT("Value"), arr.Item(i));
     }
     return true;
 }
@@ -190,7 +123,7 @@ bool Archive::Write(const wxString& name, std::vector<TabInfo>& _vTabInfoArr)
     }
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("TabInfoArray"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each wxString in the array
     for(size_t i = 0; i < _vTabInfoArr.size(); i++) {
@@ -210,13 +143,13 @@ bool Archive::Write(const wxString& name, std::vector<int>& _vInt)
     }
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("IntVector"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each int in the vector
     for(size_t i = 0; i < _vInt.size(); ++i) {
         wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("IntVectorItem"));
         node->AddChild(child);
-        child->AddProperty(wxT("Value"), wxString::Format(wxT("%i"), _vInt.at(i)));
+        child->AddAttribute(wxT("Value"), wxString::Format(wxT("%i"), _vInt.at(i)));
     }
     return true;
 }
@@ -229,19 +162,19 @@ bool Archive::Write(const wxString& name, const StringMap& str_map)
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("StringMap"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each wxString in the array
-    StringMap::const_iterator iter = str_map.begin();
-    for(; iter != str_map.end(); iter++) {
+    for (const auto& [key, value] : str_map) {
         wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("MapEntry"));
         node->AddChild(child);
-        child->AddProperty(wxT("Key"), iter->first);
-        child->AddProperty(wxT("Value"), iter->second);
+        child->AddAttribute(wxT("Key"), key);
+        child->AddAttribute(wxT("Value"), value);
     }
     return true;
 }
 
+#if wxUSE_GUI
 bool Archive::Write(const wxString& name, wxSize size)
 {
     if(!m_root) {
@@ -250,17 +183,16 @@ bool Archive::Write(const wxString& name, wxSize size)
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxSize"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     wxString xstr, ystr;
     xstr << size.x;
     ystr << size.y;
 
-    node->AddProperty(wxT("x"), xstr);
-    node->AddProperty(wxT("y"), ystr);
+    node->AddAttribute(wxT("x"), xstr);
+    node->AddAttribute(wxT("y"), ystr);
     return true;
 }
-
 bool Archive::Write(const wxString& name, wxPoint pt)
 {
     if(!m_root) {
@@ -269,16 +201,17 @@ bool Archive::Write(const wxString& name, wxPoint pt)
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxPoint"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     wxString xstr, ystr;
     xstr << pt.x;
     ystr << pt.y;
 
-    node->AddProperty(wxT("x"), xstr);
-    node->AddProperty(wxT("y"), ystr);
+    node->AddAttribute(wxT("x"), xstr);
+    node->AddAttribute(wxT("y"), ystr);
     return true;
 }
+#endif
 
 bool Archive::Read(const wxString& name, wxArrayString& arr)
 {
@@ -286,7 +219,7 @@ bool Archive::Read(const wxString& name, wxArrayString& arr)
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("wxArrayString"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("wxArrayString"), name);
     if(node) {
         // fill the output array with the values
         arr.Clear();
@@ -294,7 +227,7 @@ bool Archive::Read(const wxString& name, wxArrayString& arr)
         while(child) {
             if(child->GetName() == wxT("wxString")) {
                 wxString value;
-                value = child->GetPropVal(wxT("Value"), wxEmptyString);
+                value = child->GetAttribute(wxT("Value"), wxEmptyString);
                 arr.Add(value);
             }
             child = child->GetNext();
@@ -311,7 +244,7 @@ bool Archive::Read(const wxString& name, std::vector<TabInfo>& _vTabInfoArr)
     }
 
     Archive arch;
-    wxXmlNode* node = FindNodeByName(m_root, wxT("TabInfoArray"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("TabInfoArray"), name);
     if(node) {
         // fill the output array with the values
         _vTabInfoArr.clear();
@@ -336,7 +269,7 @@ bool Archive::Read(const wxString& name, std::vector<int>& _vInt)
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("IntVector"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("IntVector"), name);
     if(node) {
         // fill the output array with the values
         _vInt.clear();
@@ -344,7 +277,7 @@ bool Archive::Read(const wxString& name, std::vector<int>& _vInt)
         while(child) {
             if(child->GetName() == wxT("IntVectorItem")) {
                 long value;
-                wxString stringvalue = child->GetPropVal(wxT("Value"), wxEmptyString);
+                wxString stringvalue = child->GetAttribute(wxT("Value"), wxEmptyString);
                 if(stringvalue.ToLong(&value)) {
                     _vInt.push_back(value);
                 }
@@ -362,7 +295,7 @@ bool Archive::Read(const wxString& name, StringMap& str_map)
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("StringMap"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("StringMap"), name);
     if(node) {
         // fill the output array with the values
         str_map.clear();
@@ -371,8 +304,8 @@ bool Archive::Read(const wxString& name, StringMap& str_map)
             if(child->GetName() == wxT("MapEntry")) {
                 wxString value;
                 wxString key;
-                key = child->GetPropVal(wxT("Key"), wxEmptyString);
-                value = child->GetPropVal(wxT("Value"), wxEmptyString);
+                key = child->GetAttribute(wxT("Key"), wxEmptyString);
+                value = child->GetAttribute(wxT("Value"), wxEmptyString);
                 str_map[key] = value;
             }
             child = child->GetNext();
@@ -381,22 +314,22 @@ bool Archive::Read(const wxString& name, StringMap& str_map)
     }
     return false;
 }
-
+#if wxUSE_GUI
 bool Archive::Read(const wxString& name, wxSize& size)
 {
     if(!m_root) {
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("wxSize"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("wxSize"), name);
     if(node) {
         long v;
         wxString value;
-        value = node->GetPropVal(wxT("x"), wxEmptyString);
+        value = node->GetAttribute(wxT("x"), wxEmptyString);
         value.ToLong(&v);
         size.x = v;
 
-        value = node->GetPropVal(wxT("y"), wxEmptyString);
+        value = node->GetAttribute(wxT("y"), wxEmptyString);
         value.ToLong(&v);
         size.y = v;
         return true;
@@ -410,21 +343,22 @@ bool Archive::Read(const wxString& name, wxPoint& pt)
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("wxPoint"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("wxPoint"), name);
     if(node) {
         long v;
         wxString value;
-        value = node->GetPropVal(wxT("x"), wxEmptyString);
+        value = node->GetAttribute(wxT("x"), wxEmptyString);
         value.ToLong(&v);
         pt.x = v;
 
-        value = node->GetPropVal(wxT("y"), wxEmptyString);
+        value = node->GetAttribute(wxT("y"), wxEmptyString);
         value.ToLong(&v);
         pt.y = v;
         return true;
     }
     return false;
 }
+#endif
 
 bool Archive::Write(const wxString& name, int value) { return WriteSimple(value, wxT("int"), name); }
 
@@ -465,8 +399,8 @@ bool Archive::Write(const wxString& name, const wxString& str)
     }
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxString"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Value"), str);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Value"), str);
+    node->AddAttribute(wxT("Name"), name);
     return true;
 }
 
@@ -479,8 +413,8 @@ bool Archive::WriteCData(const wxString& name, const wxString& str)
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("CData"));
     m_root->AddChild(node);
 
-    SetCDATANodeContent(node, str);
-    node->AddProperty(wxT("Name"), name);
+    XmlUtils::SetCDATANodeContent(node, str);
+    node->AddAttribute(wxT("Name"), name);
     return true;
 }
 
@@ -490,7 +424,7 @@ bool Archive::ReadCData(const wxString& name, wxString& value)
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("CData"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("CData"), name);
     if(node) {
         // get the content node
         value = node->GetNodeContent();
@@ -505,9 +439,9 @@ bool Archive::Read(const wxString& name, wxString& value)
     if(!m_root) {
         return false;
     }
-    wxXmlNode* node = FindNodeByName(m_root, wxT("wxString"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("wxString"), name);
     if(node) {
-        value = node->GetPropVal(wxT("Value"), value);
+        value = node->GetAttribute(wxT("Value"), value);
         return true;
     }
     return false;
@@ -541,42 +475,45 @@ void Archive::SetXmlNode(wxXmlNode* node) { m_root = node; }
 
 bool Archive::WriteSimple(long value, const wxString& typeName, const wxString& name)
 {
-    if(!m_root) return false;
+    if(!m_root)
+        return false;
 
     wxString propValue;
     propValue << value;
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, typeName);
     m_root->AddChild(node);
-    node->AddProperty(wxT("Value"), propValue);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Value"), propValue);
+    node->AddAttribute(wxT("Name"), name);
     return true;
 }
 
 bool Archive::ReadSimple(long& value, const wxString& typeName, const wxString& name)
 {
-    if(!m_root) return false;
+    if(!m_root)
+        return false;
 
     value = 0;
-    wxXmlNode* node = FindNodeByName(m_root, typeName, name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, typeName, name);
     if(node) {
-        wxString val = node->GetPropVal(wxT("Value"), wxEmptyString);
+        wxString val = node->GetAttribute(wxT("Value"), wxEmptyString);
         val.ToLong(&value);
         return true;
     }
     return false;
 }
 
+#if wxUSE_GUI
 bool Archive::Read(const wxString& name, wxColour& colour)
 {
     if(!m_root) {
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("wxColour"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("wxColour"), name);
     wxString value;
     if(node) {
-        value = node->GetPropVal(wxT("Value"), wxEmptyString);
+        value = node->GetAttribute(wxT("Value"), wxEmptyString);
     }
 
     if(value.IsEmpty()) {
@@ -586,7 +523,6 @@ bool Archive::Read(const wxString& name, wxColour& colour)
     colour = wxColour(value);
     return true;
 }
-
 bool Archive::Write(const wxString& name, const wxColour& colour)
 {
     if(!m_root) {
@@ -594,12 +530,13 @@ bool Archive::Write(const wxString& name, const wxColour& colour)
     }
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("wxColour"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Value"), colour.GetAsString());
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Value"), colour.GetAsString());
+    node->AddAttribute(wxT("Name"), name);
     return true;
 }
+#endif
 
-bool Archive::Write(const wxString& name, const std::map<wxString, wxString>& strinMap)
+bool Archive::Write(const wxString& name, const wxStringMap_t& stringMap)
 {
     if(!m_root) {
         return false;
@@ -607,37 +544,36 @@ bool Archive::Write(const wxString& name, const std::map<wxString, wxString>& st
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("std_string_map"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each wxString in the array
-    std::map<wxString, wxString>::const_iterator iter = strinMap.begin();
-    for(; iter != strinMap.end(); iter++) {
+    for (const auto& [key, value] : stringMap) {
         wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("MapEntry"));
         node->AddChild(child);
-        child->AddProperty(wxT("Key"), iter->first);
-        SetNodeContent(child, iter->second);
+        child->AddAttribute(wxT("Key"), key);
+        XmlUtils::SetNodeContent(child, value);
     }
     return true;
 }
 
-bool Archive::Read(const wxString& name, std::map<wxString, wxString>& strinMap)
+bool Archive::Read(const wxString& name, wxStringMap_t& stringMap)
 {
     if(!m_root) {
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("std_string_map"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("std_string_map"), name);
     if(node) {
         // fill the output array with the values
-        strinMap.clear();
+        stringMap.clear();
         wxXmlNode* child = node->GetChildren();
         while(child) {
             if(child->GetName() == wxT("MapEntry")) {
                 wxString value;
                 wxString key;
-                key = child->GetPropVal(wxT("Key"), wxEmptyString);
+                key = child->GetAttribute(wxT("Key"), wxEmptyString);
                 value = child->GetNodeContent();
-                strinMap[key] = value;
+                stringMap[key] = value;
             }
             child = child->GetNext();
         }
@@ -646,13 +582,13 @@ bool Archive::Read(const wxString& name, std::map<wxString, wxString>& strinMap)
     return false;
 }
 
-bool Archive::Read(const wxString& name, std::set<wxString>& s)
+bool Archive::Read(const wxString& name, wxStringSet_t& s)
 {
     if(!m_root) {
         return false;
     }
 
-    wxXmlNode* node = FindNodeByName(m_root, wxT("std_string_set"), name);
+    wxXmlNode* node = XmlUtils::FindNodeByName(m_root, wxT("std_string_set"), name);
     if(node) {
         // fill the output array with the values
         s.clear();
@@ -670,7 +606,7 @@ bool Archive::Read(const wxString& name, std::set<wxString>& s)
     return false;
 }
 
-bool Archive::Write(const wxString& name, const std::set<wxString>& s)
+bool Archive::Write(const wxString& name, const wxStringSet_t& s)
 {
     if(!m_root) {
         return false;
@@ -678,19 +614,18 @@ bool Archive::Write(const wxString& name, const std::set<wxString>& s)
 
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("std_string_set"));
     m_root->AddChild(node);
-    node->AddProperty(wxT("Name"), name);
+    node->AddAttribute(wxT("Name"), name);
 
     // add an entry for each wxString in the array
-    std::set<wxString>::const_iterator iter = s.begin();
-    for(; iter != s.end(); iter++) {
+    for (const auto& text : s) {
         wxXmlNode* child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("SetEntry"));
         node->AddChild(child);
-        SetNodeContent(child, *iter);
+        XmlUtils::SetNodeContent(child, text);
     }
     return true;
 }
-
-bool Archive::Read(const wxString& name, wxFont& font, const wxFont& defaultFont) 
+#if wxUSE_GUI
+bool Archive::Read(const wxString& name, wxFont& font, const wxFont& defaultFont)
 {
     wxString strFont;
     bool res = Read(name, strFont);
@@ -702,7 +637,5 @@ bool Archive::Read(const wxString& name, wxFont& font, const wxFont& defaultFont
     return true;
 }
 
-bool Archive::Write(const wxString& name, const wxFont& font) 
-{
-    return Write(name, clFontHelper::ToString(font));
-}
+bool Archive::Write(const wxString& name, const wxFont& font) { return Write(name, clFontHelper::ToString(font)); }
+#endif
