@@ -23,17 +23,18 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#ifndef CLCOMMANDEVENT_H
-#define CLCOMMANDEVENT_H
+#pragma once
 
+#include "AsyncProcess/asyncprocess.h"
 #include "LSP/CompletionItem.h"
 #include "clDebuggerBreakpoint.hpp"
 #include "clEditorConfig.h"
 #include "clGotoEntry.h"
 #include "codelite_exports.h"
-#include "entry.h"
-#include "ssh_account_info.h"
+#include "database/entry.h"
+#include "ssh/ssh_account_info.h"
 #include "wxCodeCompletionBoxEntry.hpp"
+
 #include <vector>
 #include <wx/arrstr.h>
 #include <wx/event.h>
@@ -52,8 +53,6 @@ public:
     wxCommandEvent(wxEventType commandType = wxEVT_NULL, int winid = 0)
         : wxEvent(winid, commandType)
     {
-        m_clientData = NULL;
-        m_clientObject = NULL;
         m_isCommandEvent = true;
 
         // the command events are propagated upwards by default
@@ -68,11 +67,11 @@ public:
     {
         // Because GetString() can retrieve the string text only on demand, we
         // need to copy it explicitly.
-        if(m_cmdString.empty())
+        if (m_cmdString.empty())
             m_cmdString = event.GetString();
     }
 
-    virtual ~wxCommandEvent() {}
+    virtual ~wxCommandEvent() wxOVERRIDE {}
 
     // Set/Get client data from controls
     void SetClientData(void* clientData) { m_clientData = clientData; }
@@ -99,8 +98,8 @@ public:
     virtual wxEventCategory GetEventCategory() const wxOVERRIDE { return wxEVT_CATEGORY_USER_INPUT; }
 
 protected:
-    void* m_clientData;           // Arbitrary client data
-    wxClientData* m_clientObject; // Arbitrary client object
+    void* m_clientData = nullptr;           // Arbitrary client data
+    wxClientData* m_clientObject = nullptr; // Arbitrary client object
 };
 
 // this class adds a possibility to react (from the user) code to a control
@@ -111,14 +110,9 @@ public:
     wxNotifyEvent(wxEventType commandType = wxEVT_NULL, int winid = 0)
         : wxCommandEvent(commandType, winid)
     {
-        m_bAllow = true;
     }
 
-    wxNotifyEvent(const wxNotifyEvent& event)
-        : wxCommandEvent(event)
-    {
-        m_bAllow = event.m_bAllow;
-    }
+    wxNotifyEvent(const wxNotifyEvent& event) = default;
 
     // veto the operation (usually it's allowed by default)
     void Veto() { m_bAllow = false; }
@@ -132,7 +126,7 @@ public:
     virtual wxEvent* Clone() const wxOVERRIDE { return new wxNotifyEvent(*this); }
 
 private:
-    bool m_bAllow;
+    bool m_bAllow = true;
 };
 
 #endif // !wxUSE_GUI
@@ -145,16 +139,18 @@ protected:
     wxArrayString m_strings;
     wxString m_fileName;
     wxString m_oldName;
-    bool m_answer;
-    bool m_allowed;
-    int m_lineNumber;
-    bool m_selected;
+    bool m_answer = false;
+    bool m_allowed = true;
+    int m_lineNumber = 0;
+    bool m_selected = false;
+    std::string m_stringRaw;
+    wxString m_sshAccount;
 
 public:
     clCommandEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clCommandEvent(const clCommandEvent& event);
-    clCommandEvent& operator=(const clCommandEvent& src);
-    virtual ~clCommandEvent();
+    clCommandEvent(const clCommandEvent&) = default;
+    clCommandEvent& operator=(const clCommandEvent&) = delete;
+    ~clCommandEvent() override = default;
 
     clCommandEvent& SetSelected(bool selected)
     {
@@ -171,7 +167,7 @@ public:
     void SetClientObject(wxClientData* clientObject);
 
     wxClientData* GetClientObject() const;
-    virtual wxEvent* Clone() const;
+    wxEvent* Clone() const override;
 
     clCommandEvent& SetLineNumber(int lineNumber)
     {
@@ -216,9 +212,13 @@ public:
     const wxSharedPtr<wxClientData>& GetPtr() const { return m_ptr; }
     const wxArrayString& GetStrings() const { return m_strings; }
     wxArrayString& GetStrings() { return m_strings; }
+    const std::string& GetStringRaw() const { return m_stringRaw; }
+    void SetStringRaw(const std::string& str) { m_stringRaw = str; }
+    void SetSshAccount(const wxString& sshAccount) { this->m_sshAccount = sshAccount; }
+    const wxString& GetSshAccount() const { return m_sshAccount; }
 };
 
-typedef void (wxEvtHandler::*clCommandEventFunction)(clCommandEvent&);
+using clCommandEventFunction = void (wxEvtHandler::*)(clCommandEvent&);
 #define clCommandEventHandler(func) wxEVENT_HANDLER_CAST(clCommandEventFunction, func)
 
 /// Source control event
@@ -229,36 +229,67 @@ protected:
 
 public:
     clSourceControlEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clSourceControlEvent(const clSourceControlEvent& event);
-    clSourceControlEvent& operator=(const clSourceControlEvent& src);
-    virtual ~clSourceControlEvent();
-    virtual wxEvent* Clone() const;
+    clSourceControlEvent(const clSourceControlEvent& event) = default;
+    clSourceControlEvent& operator=(const clSourceControlEvent&) = delete;
+    ~clSourceControlEvent() override = default;
+    wxEvent* Clone() const override;
     void SetSourceControlName(const wxString& sourceControlName) { this->m_sourceControlName = sourceControlName; }
     const wxString& GetSourceControlName() const { return m_sourceControlName; }
 };
 
-typedef void (wxEvtHandler::*clSourceControlEventFunction)(clSourceControlEvent&);
+using clSourceControlEventFunction = void (wxEvtHandler::*)(clSourceControlEvent&);
 #define clSourceControlEventHandler(func) wxEVENT_HANDLER_CAST(clSourceControlEventFunction, func)
 
+/// Source control event
+struct WXDLLIMPEXP_CL RecentWorkspace {
+    wxString m_category;
+    wxString m_account; // for remote workspaces, which account does this workspace belongs to
+    wxString m_name;
+    wxString path;
+};
+
+class WXDLLIMPEXP_CL clRecentWorkspaceEvent : public clCommandEvent
+{
+protected:
+    std::vector<RecentWorkspace> m_workspaces;
+
+public:
+    clRecentWorkspaceEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clRecentWorkspaceEvent(const clRecentWorkspaceEvent&) = default;
+    clRecentWorkspaceEvent& operator=(const clRecentWorkspaceEvent&) = delete;
+    ~clRecentWorkspaceEvent() override = default;
+    wxEvent* Clone() const override;
+
+    void SetWorkspaces(const std::vector<RecentWorkspace>& workspaces) { this->m_workspaces = workspaces; }
+    const std::vector<RecentWorkspace>& GetWorkspaces() const { return m_workspaces; }
+    std::vector<RecentWorkspace>& GetWorkspaces() { return m_workspaces; }
+};
+
+using clRecentWorkspaceEventFunction = void (wxEvtHandler::*)(clRecentWorkspaceEvent&);
+#define clRecentWorkspaceEventHandler(func) wxEVENT_HANDLER_CAST(clRecentWorkspaceEventFunction, func)
+
 /// a clCodeCompletionEvent
 class WXDLLIMPEXP_CL clCodeCompletionEvent : public clCommandEvent
 {
-    wxObject* m_editor;
     wxString m_word;
-    int m_position;
+    int m_position = wxNOT_FOUND;
     wxString m_tooltip;
-    bool m_insideCommentOrString;
+    bool m_insideCommentOrString = false;
     wxCodeCompletionBoxEntry::Ptr_t m_entry;
     wxArrayString m_definitions;
     wxCodeCompletionBoxEntry::Vec_t m_entries;
     LSP::CompletionItem::eTriggerKind m_triggerKind = LSP::CompletionItem::kTriggerUnknown;
 
+    // semantic highlights. We support 2 types variables and classes
+    wxString m_variables;
+    wxString m_classes;
+
 public:
     clCodeCompletionEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clCodeCompletionEvent(const clCodeCompletionEvent& event);
-    clCodeCompletionEvent& operator=(const clCodeCompletionEvent& src);
-    virtual ~clCodeCompletionEvent();
-    virtual wxEvent* Clone() const;
+    clCodeCompletionEvent(const clCodeCompletionEvent& event) = default;
+    clCodeCompletionEvent& operator=(const clCodeCompletionEvent&) = delete;
+    ~clCodeCompletionEvent() override = default;
+    wxEvent* Clone() const override;
 
     void SetDefinitions(const wxArrayString& definitions) { this->m_definitions = definitions; }
     const wxArrayString& GetDefinitions() const { return m_definitions; }
@@ -268,7 +299,6 @@ public:
     void SetInsideCommentOrString(bool insideCommentOrString) { this->m_insideCommentOrString = insideCommentOrString; }
 
     bool IsInsideCommentOrString() const { return m_insideCommentOrString; }
-    void SetEditor(wxObject* editor) { this->m_editor = editor; }
     void SetEntries(const wxCodeCompletionBoxEntry::Vec_t& entries) { this->m_entries = entries; }
     const wxCodeCompletionBoxEntry::Vec_t& GetEntries() const { return m_entries; }
     wxCodeCompletionBoxEntry::Vec_t& GetEntries() { return m_entries; }
@@ -276,12 +306,13 @@ public:
     const LSP::CompletionItem::eTriggerKind& GetTriggerKind() const { return m_triggerKind; }
     void SetTriggerKind(const LSP::CompletionItem::eTriggerKind& triggerKind) { this->m_triggerKind = triggerKind; }
 
-    /**
-     * @brief return the Editor object
-     */
-    wxObject* GetEditor() { return m_editor; }
     void SetWord(const wxString& word) { this->m_word = word; }
 
+    void SetClasses(const wxString& classes) { this->m_classes = classes; }
+    void SetVariables(const wxString& variables) { this->m_variables = variables; }
+    const wxString& GetClasses() const { return m_classes; }
+    const wxString& GetVariables() const { return m_variables; }
+
     /**
      * @brief return the user typed word up to the caret position
      */
@@ -295,7 +326,7 @@ public:
     const wxString& GetTooltip() const { return m_tooltip; }
 };
 
-typedef void (wxEvtHandler::*clCodeCompletionEventFunction)(clCodeCompletionEvent&);
+using clCodeCompletionEventFunction = void (wxEvtHandler::*)(clCodeCompletionEvent&);
 #define clCodeCompletionEventHandler(func) wxEVENT_HANDLER_CAST(clCodeCompletionEventFunction, func)
 
 class WXDLLIMPEXP_CL clColourEvent : public clCommandEvent
@@ -304,16 +335,16 @@ class WXDLLIMPEXP_CL clColourEvent : public clCommandEvent
     wxColour m_bgColour;
     wxColour m_fgColour;
     wxColour m_borderColour;
-    wxWindow* m_page;
+    wxWindow* m_page = nullptr;
 #endif
-    bool m_isActiveTab;
+    bool m_isActiveTab = false;
 
 public:
     clColourEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clColourEvent(const clColourEvent& event);
-    clColourEvent& operator=(const clColourEvent& src);
-    virtual ~clColourEvent();
-    virtual wxEvent* Clone() const { return new clColourEvent(*this); };
+    clColourEvent(const clColourEvent&) = default;
+    clColourEvent& operator=(const clColourEvent&) = delete;
+    ~clColourEvent() override = default;
+    wxEvent* Clone() const override { return new clColourEvent(*this); };
 
 #if wxUSE_GUI
     void SetBorderColour(const wxColour& borderColour) { this->m_borderColour = borderColour; }
@@ -329,32 +360,60 @@ public:
     bool IsActiveTab() const { return m_isActiveTab; }
 };
 
-typedef void (wxEvtHandler::*clColourEventFunction)(clColourEvent&);
+using clColourEventFunction = void (wxEvtHandler::*)(clColourEvent&);
 #define clColourEventHandler(func) wxEVENT_HANDLER_CAST(clColourEventFunction, func)
 
 // -------------------------------------------------------------------------
 // -------------------------------------------------------------------------
 class WXDLLIMPEXP_CL clBuildEvent : public clCommandEvent
 {
+public:
+    enum eFlags {
+        kClean = (1 << 0),
+        kBuild = (1 << 1),
+        kCustomProject = (1 << 2),
+    };
+
+protected:
     wxString m_projectName;
     wxString m_configurationName;
     wxString m_command;
-    bool m_projectOnly;
-    size_t m_warningCount;
-    size_t m_errorCount;
+    bool m_projectOnly = false;
+    size_t m_warningCount = 0;
+    size_t m_errorCount = 0;
     wxString m_kind;
-    bool m_isRunning;
+    bool m_isRunning = false;
+    bool m_cleanLog = true;
+    size_t m_flags = 0;
+    wxString m_toolchain;
+    wxString m_buildDir;
 
 public:
     clBuildEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clBuildEvent(const clBuildEvent& event);
-    clBuildEvent& operator=(const clBuildEvent& src);
-    virtual ~clBuildEvent();
-    virtual wxEvent* Clone() const { return new clBuildEvent(*this); };
+    clBuildEvent(const clBuildEvent&) = default;
+    clBuildEvent& operator=(const clBuildEvent&) = delete;
+    ~clBuildEvent() override = default;
+    wxEvent* Clone() const override { return new clBuildEvent(*this); };
 
+    void SetFlag(eFlags f, bool b)
+    {
+        if (b) {
+            m_flags |= f;
+        } else {
+            m_flags &= ~f;
+        }
+    }
+
+    void SetBuildDir(const wxString& buildDir) { this->m_buildDir = buildDir; }
+    const wxString& GetBuildDir() const { return m_buildDir; }
+
+    void SetToolchain(const wxString& toolchain) { this->m_toolchain = toolchain; }
+    const wxString& GetToolchain() const { return m_toolchain; }
+    bool HasFlag(eFlags f) const { return m_flags & f; }
     void SetIsRunning(bool isRunning) { this->m_isRunning = isRunning; }
     bool IsRunning() const { return m_isRunning; }
-
+    void SetCleanLog(bool cleanLog) { this->m_cleanLog = cleanLog; }
+    bool IsCleanLog() const { return m_cleanLog; }
     void SetKind(const wxString& kind) { this->m_kind = kind; }
     const wxString& GetKind() const { return this->m_kind; }
 
@@ -373,7 +432,7 @@ public:
     size_t GetWarningCount() const { return m_warningCount; }
 };
 
-typedef void (wxEvtHandler::*clBuildEventFunction)(clBuildEvent&);
+using clBuildEventFunction = void (wxEvtHandler::*)(clBuildEvent&);
 #define clBuildEventHandler(func) wxEVENT_HANDLER_CAST(clBuildEventFunction, func)
 
 // -------------------------------------------------------------------------
@@ -390,20 +449,19 @@ class WXDLLIMPEXP_CL clDebugEvent : public clCommandEvent
     wxString m_workingDirectory; // wxEVT_DBG_UI_CORE_FILE, wxEVT_DBG_UI_QUICK_DEBUG
     wxString m_arguments;        // wxEVT_DBG_UI_QUICK_DEBUG
     wxString m_startupCommands;  // wxEVT_DBG_UI_QUICK_DEBUG
-    size_t m_features;
-    wxString m_memoryAddress;    // wxEVT_DEBUGGER_SET_MEMORY
-    wxString m_memoryBlockValue; // wxEVT_DEBUGGER_SET_MEMORY
-    size_t m_memoryBlockSize;    // wxEVT_DEBUGGER_SET_MEMORY
+    size_t m_features = kAllFeatures;
+    wxString m_memoryAddress;      // wxEVT_DEBUGGER_SET_MEMORY
+    wxString m_memoryBlockValue;   // wxEVT_DEBUGGER_SET_MEMORY
+    size_t m_memoryBlockSize = 32; // wxEVT_DEBUGGER_SET_MEMORY
     clDebuggerBreakpoint::Vec_t m_breakpoints;
     bool m_isSSHDebugging = false;
-    SSHAccountInfo m_sshAccount;
     wxString m_alternateDebuggerPath; // Holds the path to an alternate debugger executable
 
 public:
     // Special features not available by all the debuggers
     enum eFeatures {
         kStepInst = (1 << 0),         // single step instruction
-        kInterrupt = (1 << 1),        // interrup the running process
+        kInterrupt = (1 << 1),        // interrupt the running process
         kShowCursor = (1 << 2),       // show the current active line
         kJumpToCursor = (1 << 3),     // Jump to the caret line, without executing the code in between
         kRunToCursor = (1 << 4),      // execute all the code until reaching the caret
@@ -413,19 +471,17 @@ public:
 
 public:
     clDebugEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clDebugEvent(const clDebugEvent& event);
-    clDebugEvent& operator=(const clDebugEvent& other);
+    clDebugEvent(const clDebugEvent&) = default;
+    clDebugEvent& operator=(const clDebugEvent&) = delete;
 
-    virtual ~clDebugEvent();
-    virtual wxEvent* Clone() const { return new clDebugEvent(*this); };
+    ~clDebugEvent() override = default;
+    wxEvent* Clone() const override { return new clDebugEvent(*this); };
 
     void SetAlternateDebuggerPath(const wxString& alternateDebuggerPath)
     {
         this->m_alternateDebuggerPath = alternateDebuggerPath;
     }
     const wxString& GetAlternateDebuggerPath() const { return m_alternateDebuggerPath; }
-    void SetSshAccount(const SSHAccountInfo& sshAccount) { this->m_sshAccount = sshAccount; }
-    const SSHAccountInfo& GetSshAccount() const { return m_sshAccount; }
     void SetIsSSHDebugging(bool isSSHDebugging) { this->m_isSSHDebugging = isSSHDebugging; }
     bool IsSSHDebugging() const { return m_isSSHDebugging; }
     void SetFeatures(size_t features) { m_features = features; }
@@ -457,7 +513,7 @@ public:
     clDebuggerBreakpoint::Vec_t& GetBreakpoints() { return m_breakpoints; }
 };
 
-typedef void (wxEvtHandler::*clDebugEventFunction)(clDebugEvent&);
+using clDebugEventFunction = void (wxEvtHandler::*)(clDebugEvent&);
 #define clDebugEventHandler(func) wxEVENT_HANDLER_CAST(clDebugEventFunction, func)
 
 // ------------------------------------------------------------------
@@ -473,12 +529,10 @@ public:
         wxString m_templatePng;
         wxString m_toolchain;
         wxString m_debugger;
-        bool m_allowSeparateFolder;
-        Template()
-            : m_allowSeparateFolder(true)
-        {
-        }
-        typedef std::vector<clNewProjectEvent::Template> Vec_t;
+        bool m_allowSeparateFolder = true;
+        Template() = default;
+
+        using Vec_t = std::vector<clNewProjectEvent::Template>;
     };
 
 protected:
@@ -491,10 +545,10 @@ protected:
 
 public:
     clNewProjectEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clNewProjectEvent(const clNewProjectEvent& event);
-    clNewProjectEvent& operator=(const clNewProjectEvent& src);
-    virtual ~clNewProjectEvent();
-    virtual wxEvent* Clone() const { return new clNewProjectEvent(*this); };
+    clNewProjectEvent(const clNewProjectEvent&) = default;
+    clNewProjectEvent& operator=(const clNewProjectEvent&) = delete;
+    ~clNewProjectEvent() override = default;
+    wxEvent* Clone() const override { return new clNewProjectEvent(*this); };
 
     void SetTemplates(const clNewProjectEvent::Template::Vec_t& templates) { this->m_templates = templates; }
     const clNewProjectEvent::Template::Vec_t& GetTemplates() const { return m_templates; }
@@ -512,7 +566,7 @@ public:
     const wxString& GetTemplateName() const { return m_templateName; }
 };
 
-typedef void (wxEvtHandler::*clNewProjectEventFunction)(clNewProjectEvent&);
+using clNewProjectEventFunction = void (wxEvtHandler::*)(clNewProjectEvent&);
 #define clNewProjectEventHandler(func) wxEVENT_HANDLER_CAST(clNewProjectEventFunction, func)
 
 // --------------------------------------------------------------
@@ -522,13 +576,13 @@ class WXDLLIMPEXP_CL clCompilerEvent : public clCommandEvent
 {
 public:
     clCompilerEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clCompilerEvent(const clCompilerEvent& event);
-    clCompilerEvent& operator=(const clCompilerEvent& src);
-    virtual ~clCompilerEvent();
-    virtual wxEvent* Clone() const { return new clCompilerEvent(*this); }
+    clCompilerEvent(const clCompilerEvent&) = default;
+    clCompilerEvent& operator=(const clCompilerEvent&) = delete;
+    ~clCompilerEvent() override = default;
+    wxEvent* Clone() const override { return new clCompilerEvent(*this); }
 };
 
-typedef void (wxEvtHandler::*clCompilerEventFunction)(clCompilerEvent&);
+using clCompilerEventFunction = void (wxEvtHandler::*)(clCompilerEvent&);
 #define clCompilerEventHandler(func) wxEVENT_HANDLER_CAST(clCompilerEventFunction, func)
 
 // --------------------------------------------------------------
@@ -541,10 +595,10 @@ class WXDLLIMPEXP_CL clGotoEvent : public clCommandEvent
 
 public:
     clGotoEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clGotoEvent(const clGotoEvent& src);
-    clGotoEvent& operator=(const clGotoEvent& src);
-    virtual ~clGotoEvent();
-    virtual wxEvent* Clone() const { return new clGotoEvent(*this); }
+    clGotoEvent(const clGotoEvent&) = default;
+    clGotoEvent& operator=(const clGotoEvent&) = delete;
+    ~clGotoEvent() override = default;
+    wxEvent* Clone() const override { return new clGotoEvent(*this); }
     const clGotoEntry::Vec_t& GetEntries() const { return m_entries; }
     clGotoEntry::Vec_t& GetEntries() { return m_entries; }
     void SetEntries(const clGotoEntry::Vec_t& entries) { m_entries = entries; }
@@ -552,32 +606,34 @@ public:
     const clGotoEntry& GetEntry() const { return m_entry; }
 };
 
-typedef void (wxEvtHandler::*clGotoEventFunction)(clGotoEvent&);
+using clGotoEventFunction = void (wxEvtHandler::*)(clGotoEvent&);
 #define clGotoEventHandler(func) wxEVENT_HANDLER_CAST(clGotoEventFunction, func)
 
 // --------------------------------------------------------------
-// Processs event
+// Process event
 // --------------------------------------------------------------
 class IProcess;
 class WXDLLIMPEXP_CL clProcessEvent : public clCommandEvent
 {
     wxString m_output;
-    IProcess* m_process;
+    IProcess* m_process = nullptr;
 
 public:
     clProcessEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clProcessEvent(const clProcessEvent& event);
-    clProcessEvent& operator=(const clProcessEvent& src);
-    virtual ~clProcessEvent();
-    virtual wxEvent* Clone() const { return new clProcessEvent(*this); }
+    clProcessEvent(const clProcessEvent&) = default;
+    clProcessEvent& operator=(const clProcessEvent&) = delete;
+    ~clProcessEvent() override = default;
+    wxEvent* Clone() const override { return new clProcessEvent(*this); }
 
     void SetOutput(const wxString& output) { this->m_output = output; }
     void SetProcess(IProcess* process) { this->m_process = process; }
     const wxString& GetOutput() const { return m_output; }
+    void SetOutputRaw(const std::string& output) { SetStringRaw(output); }
+    const std::string& GetOutputRaw() const { return GetStringRaw(); }
     IProcess* GetProcess() { return m_process; }
 };
 
-typedef void (wxEvtHandler::*clProcessEventFunction)(clProcessEvent&);
+using clProcessEventFunction = void (wxEvtHandler::*)(clProcessEvent&);
 #define clProcessEventHandler(func) wxEVENT_HANDLER_CAST(clProcessEventFunction, func)
 
 //---------------------------------------------------------------
@@ -590,17 +646,17 @@ class WXDLLIMPEXP_CL clSourceFormatEvent : public clCommandEvent
 
 public:
     clSourceFormatEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clSourceFormatEvent(const clSourceFormatEvent& event);
-    clSourceFormatEvent& operator=(const clSourceFormatEvent& src);
-    virtual ~clSourceFormatEvent();
-    virtual wxEvent* Clone() const { return new clSourceFormatEvent(*this); }
+    clSourceFormatEvent(const clSourceFormatEvent&) = default;
+    clSourceFormatEvent& operator=(const clSourceFormatEvent&) = delete;
+    ~clSourceFormatEvent() override = default;
+    wxEvent* Clone() const override { return new clSourceFormatEvent(*this); }
     void SetFormattedString(const wxString& formattedString) { this->m_formattedString = formattedString; }
     void SetInputString(const wxString& inputString) { this->m_inputString = inputString; }
     const wxString& GetFormattedString() const { return m_formattedString; }
     const wxString& GetInputString() const { return m_inputString; }
 };
 
-typedef void (wxEvtHandler::*clSourceFormatEventFunction)(clSourceFormatEvent&);
+using clSourceFormatEventFunction = void (wxEvtHandler::*)(clSourceFormatEvent&);
 #define clSourceFormatEventHandler(func) wxEVENT_HANDLER_CAST(clSourceFormatEventFunction, func)
 
 //---------------------------------------------------------------
@@ -609,17 +665,17 @@ typedef void (wxEvtHandler::*clSourceFormatEventFunction)(clSourceFormatEvent&);
 class WXDLLIMPEXP_CL clContextMenuEvent : public clCommandEvent
 {
 #if wxUSE_GUI
-    wxMenu* m_menu;
+    wxMenu* m_menu = nullptr;
 #endif
-    wxObject* m_editor;
+    wxObject* m_editor = nullptr;
     wxString m_path;
 
 public:
     clContextMenuEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clContextMenuEvent(const clContextMenuEvent& event);
-    clContextMenuEvent& operator=(const clContextMenuEvent& src);
-    virtual ~clContextMenuEvent();
-    virtual wxEvent* Clone() const { return new clContextMenuEvent(*this); }
+    clContextMenuEvent(const clContextMenuEvent&) = default;
+    clContextMenuEvent& operator=(const clContextMenuEvent&) = delete;
+    ~clContextMenuEvent() override = default;
+    wxEvent* Clone() const override { return new clContextMenuEvent(*this); }
 #if wxUSE_GUI
     void SetMenu(wxMenu* menu) { this->m_menu = menu; }
     wxMenu* GetMenu() { return m_menu; }
@@ -630,7 +686,7 @@ public:
     void SetPath(const wxString& path) { m_path = path; }
 };
 
-typedef void (wxEvtHandler::*clContextMenuEventFunction)(clContextMenuEvent&);
+using clContextMenuEventFunction = void (wxEvtHandler::*)(clContextMenuEvent&);
 #define clContextMenuEventHandler(func) wxEVENT_HANDLER_CAST(clContextMenuEventFunction, func)
 
 //---------------------------------------------------------------
@@ -642,16 +698,16 @@ class WXDLLIMPEXP_CL clExecuteEvent : public clCommandEvent
 
 public:
     clExecuteEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clExecuteEvent(const clExecuteEvent& event);
-    clExecuteEvent& operator=(const clExecuteEvent& src);
-    virtual ~clExecuteEvent();
-    virtual wxEvent* Clone() const { return new clExecuteEvent(*this); }
+    clExecuteEvent(const clExecuteEvent&) = default;
+    clExecuteEvent& operator=(const clExecuteEvent&) = delete;
+    ~clExecuteEvent() override = default;
+    wxEvent* Clone() const override { return new clExecuteEvent(*this); }
 
     void SetTargetName(const wxString& targetName) { this->m_targetName = targetName; }
     const wxString& GetTargetName() const { return m_targetName; }
 };
 
-typedef void (wxEvtHandler::*clExecuteEventFunction)(clExecuteEvent&);
+using clExecuteEventFunction = void (wxEvtHandler::*)(clExecuteEvent&);
 #define clExecuteEventHandler(func) wxEVENT_HANDLER_CAST(clExecuteEventFunction, func)
 
 //---------------------------------------------------------------
@@ -664,17 +720,17 @@ class WXDLLIMPEXP_CL clProjectSettingsEvent : public clCommandEvent
 
 public:
     clProjectSettingsEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clProjectSettingsEvent(const clProjectSettingsEvent& event);
-    clProjectSettingsEvent& operator=(const clProjectSettingsEvent& src);
-    virtual ~clProjectSettingsEvent();
-    virtual wxEvent* Clone() const { return new clProjectSettingsEvent(*this); }
+    clProjectSettingsEvent(const clProjectSettingsEvent&) = default;
+    clProjectSettingsEvent& operator=(const clProjectSettingsEvent&) = delete;
+    ~clProjectSettingsEvent() override = default;
+    wxEvent* Clone() const override { return new clProjectSettingsEvent(*this); }
     void SetConfigName(const wxString& configName) { this->m_configName = configName; }
     void SetProjectName(const wxString& projectName) { this->m_projectName = projectName; }
     const wxString& GetConfigName() const { return m_configName; }
     const wxString& GetProjectName() const { return m_projectName; }
 };
 
-typedef void (wxEvtHandler::*clProjectSettingsEventFunction)(clProjectSettingsEvent&);
+using clProjectSettingsEventFunction = void (wxEvtHandler::*)(clProjectSettingsEvent&);
 #define clProjectSettingsEventHandler(func) wxEVENT_HANDLER_CAST(clProjectSettingsEventFunction, func)
 
 //---------------------------------------------------------------
@@ -682,20 +738,20 @@ typedef void (wxEvtHandler::*clProjectSettingsEventFunction)(clProjectSettingsEv
 //---------------------------------------------------------------
 class WXDLLIMPEXP_CL clFindEvent : public clCommandEvent
 {
-    wxStyledTextCtrl* m_ctrl;
+    wxStyledTextCtrl* m_ctrl = nullptr;
 
 public:
     clFindEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clFindEvent(const clFindEvent& event);
-    clFindEvent& operator=(const clFindEvent& src);
-    virtual ~clFindEvent();
-    virtual wxEvent* Clone() const { return new clFindEvent(*this); }
+    clFindEvent(const clFindEvent&) = default;
+    clFindEvent& operator=(const clFindEvent&) = delete;
+    ~clFindEvent() override = default;
+    wxEvent* Clone() const override { return new clFindEvent(*this); }
 
     void SetCtrl(wxStyledTextCtrl* ctrl) { this->m_ctrl = ctrl; }
     wxStyledTextCtrl* GetCtrl() { return m_ctrl; }
 };
 
-typedef void (wxEvtHandler::*clFindEventFunction)(clFindEvent&);
+using clFindEventFunction = void (wxEvtHandler::*)(clFindEvent&);
 #define clFindEventHandler(func) wxEVENT_HANDLER_CAST(clFindEventFunction, func)
 
 //---------------------------------------------------------------
@@ -703,17 +759,34 @@ typedef void (wxEvtHandler::*clFindEventFunction)(clFindEvent&);
 //---------------------------------------------------------------
 class WXDLLIMPEXP_CL clFindInFilesEvent : public clCommandEvent
 {
+public:
+    struct Location {
+        size_t line = 0;
+        size_t column_start = 0;
+        size_t column_end = 0;
+        wxString pattern;
+        using vec_t = std::vector<Location>;
+    };
+
+    struct Match {
+        wxString file;
+        Location::vec_t locations;
+        using vec_t = std::vector<Match>;
+    };
+
+protected:
     wxString m_paths;
     wxString m_fileMask;
     size_t m_options = 0;
     wxString m_transientPaths;
+    Match::vec_t m_matches;
 
 public:
     clFindInFilesEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clFindInFilesEvent(const clFindInFilesEvent& event);
-    clFindInFilesEvent& operator=(const clFindInFilesEvent& src);
-    virtual ~clFindInFilesEvent();
-    virtual wxEvent* Clone() const { return new clFindInFilesEvent(*this); }
+    clFindInFilesEvent(const clFindInFilesEvent&) = default;
+    clFindInFilesEvent& operator=(const clFindInFilesEvent&) = delete;
+    ~clFindInFilesEvent() override = default;
+    wxEvent* Clone() const override { return new clFindInFilesEvent(*this); }
     void SetFileMask(const wxString& fileMask) { this->m_fileMask = fileMask; }
     void SetOptions(size_t options) { this->m_options = options; }
     const wxString& GetFileMask() const { return m_fileMask; }
@@ -722,9 +795,12 @@ public:
     const wxString& GetPaths() const { return m_paths; }
     void SetTransientPaths(const wxString& transientPaths) { this->m_transientPaths = transientPaths; }
     const wxString& GetTransientPaths() const { return m_transientPaths; }
+    Match::vec_t& GetMatches() { return m_matches; }
+    const Match::vec_t& GetMatches() const { return m_matches; }
+    void SetMatches(const Match::vec_t& matches) { m_matches = matches; }
 };
 
-typedef void (wxEvtHandler::*clFindInFilesEventFunction)(clFindInFilesEvent&);
+using clFindInFilesEventFunction = void (wxEvtHandler::*)(clFindInFilesEvent&);
 #define clFindInFilesEventHandler(func) wxEVENT_HANDLER_CAST(clFindInFilesEventFunction, func)
 
 // --------------------------------------------------------------
@@ -732,22 +808,22 @@ typedef void (wxEvtHandler::*clFindInFilesEventFunction)(clFindInFilesEvent&);
 // --------------------------------------------------------------
 class WXDLLIMPEXP_CL clParseEvent : public clCommandEvent
 {
-    size_t m_curfileIndex;
-    size_t m_totalFiles;
+    size_t m_curfileIndex = 0;
+    size_t m_totalFiles = 0;
 
 public:
     clParseEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clParseEvent(const clParseEvent& event);
-    clParseEvent& operator=(const clParseEvent& src);
-    virtual ~clParseEvent();
-    virtual wxEvent* Clone() const { return new clParseEvent(*this); }
+    clParseEvent(const clParseEvent&) = default;
+    clParseEvent& operator=(const clParseEvent&) = delete;
+    ~clParseEvent() override = default;
+    wxEvent* Clone() const override { return new clParseEvent(*this); }
     void SetCurfileIndex(size_t curfileIndex) { this->m_curfileIndex = curfileIndex; }
     void SetTotalFiles(size_t totalFiles) { this->m_totalFiles = totalFiles; }
     size_t GetCurfileIndex() const { return m_curfileIndex; }
     size_t GetTotalFiles() const { return m_totalFiles; }
 };
 
-typedef void (wxEvtHandler::*clParseEventFunction)(clParseEvent&);
+using clParseEventFunction = void (wxEvtHandler::*)(clParseEvent&);
 #define clParseEventHandler(func) wxEVENT_HANDLER_CAST(clParseEventFunction, func)
 
 // --------------------------------------------------------------
@@ -759,15 +835,125 @@ class WXDLLIMPEXP_CL clEditorConfigEvent : public clCommandEvent
 
 public:
     clEditorConfigEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
-    clEditorConfigEvent(const clEditorConfigEvent& event);
-    clEditorConfigEvent& operator=(const clEditorConfigEvent& src);
-    virtual ~clEditorConfigEvent();
-    virtual wxEvent* Clone() const { return new clEditorConfigEvent(*this); }
+    clEditorConfigEvent(const clEditorConfigEvent&) = default;
+    clEditorConfigEvent& operator=(const clEditorConfigEvent&) = delete;
+    ~clEditorConfigEvent() override = default;
+    wxEvent* Clone() const override { return new clEditorConfigEvent(*this); }
     void SetEditorConfig(const clEditorConfigSection& editorConfig) { this->m_editorConfigSection = editorConfig; }
     const clEditorConfigSection& GetEditorConfig() const { return m_editorConfigSection; }
 };
 
-typedef void (wxEvtHandler::*clEditorConfigEventFunction)(clEditorConfigEvent&);
+using clEditorConfigEventFunction = void (wxEvtHandler::*)(clEditorConfigEvent&);
 #define clEditorConfigEventHandler(func) wxEVENT_HANDLER_CAST(clEditorConfigEventFunction, func)
 
-#endif // CLCOMMANDEVENT_H
+// --------------------------------------------------------------
+// clEditorEvent event
+// --------------------------------------------------------------
+class WXDLLIMPEXP_CL clEditorEvent : public clCommandEvent
+{
+    wxClientData* m_userData = nullptr;
+
+public:
+    clEditorEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clEditorEvent(const clEditorEvent&) = default;
+    clEditorEvent& operator=(const clEditorEvent&) = delete;
+    ~clEditorEvent() override = default;
+    wxEvent* Clone() const override { return new clEditorEvent(*this); }
+    wxClientData* GetUserData() const { return m_userData; }
+    void SetUserData(wxClientData* d) { m_userData = d; }
+};
+
+using clEditorEventFunction = void (wxEvtHandler::*)(clEditorEvent&);
+#define clEditorEventHandler(func) wxEVENT_HANDLER_CAST(clEditorEventFunction, func)
+
+//---------------------------------------------------------------
+// Language Server events
+//---------------------------------------------------------------
+class WXDLLIMPEXP_CL clLanguageServerEvent : public clCommandEvent
+{
+public:
+    enum eFlags {
+        kEnabled = (1 << 0),
+        kDisaplyDiags = (1 << 2),
+    };
+
+    enum eAction {
+        kInvalidAction = 0,
+        kDelete = 1,
+        kConfigure = 2,
+        kRestart = 3,
+        kRestartAll = 4,
+        kOpenSettings = 5,
+        kEnable = 6,
+    };
+
+protected:
+    wxString m_lspName;
+    wxString m_lspCommand;
+    size_t m_flags = 0;
+    size_t m_priority = 50;
+    wxString m_connectionString;
+    clEnvList_t m_enviroment;
+    wxString m_initOptions;
+    wxArrayString m_languages;
+    eAction m_action = kInvalidAction;
+    wxString m_rootUri;
+
+public:
+    clLanguageServerEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clLanguageServerEvent(const clLanguageServerEvent&) = default;
+    clLanguageServerEvent& operator=(const clLanguageServerEvent&) = delete;
+    ~clLanguageServerEvent() override = default;
+    wxEvent* Clone() const override;
+    void SetConnectionString(const wxString& connectionString) { this->m_connectionString = connectionString; }
+    void SetFlags(size_t flags) { this->m_flags = flags; }
+    void SetInitOptions(const wxString& initOptions) { this->m_initOptions = initOptions; }
+    void SetLanguages(const wxArrayString& languages) { this->m_languages = languages; }
+    void SetLspCommand(const wxString& lspCommand) { this->m_lspCommand = lspCommand; }
+    void SetLspName(const wxString& lspName) { this->m_lspName = lspName; }
+    void SetPriority(size_t priority) { this->m_priority = priority; }
+    const wxString& GetConnectionString() const { return m_connectionString; }
+    size_t GetFlags() const { return m_flags; }
+    const wxString& GetInitOptions() const { return m_initOptions; }
+    const wxArrayString& GetLanguages() const { return m_languages; }
+    const wxString& GetLspCommand() const { return m_lspCommand; }
+    const wxString& GetLspName() const { return m_lspName; }
+    size_t GetPriority() const { return m_priority; }
+    void SetAction(const eAction& action) { this->m_action = action; }
+    const eAction& GetAction() const { return m_action; }
+    void SetRootUri(const wxString& rootUri) { this->m_rootUri = rootUri; }
+    const wxString& GetRootUri() const { return m_rootUri; }
+    void SetEnviroment(const clEnvList_t& enviroment) { this->m_enviroment = enviroment; }
+    const clEnvList_t& GetEnviroment() const { return m_enviroment; }
+};
+
+using clLanguageServerEventFunction = void (wxEvtHandler::*)(clLanguageServerEvent&);
+#define clLanguageServerEventHandler(func) wxEVENT_HANDLER_CAST(clLanguageServerEventFunction, func)
+
+// --------------------------------------------------------------
+// clLLMEvent event
+// --------------------------------------------------------------
+class WXDLLIMPEXP_CL clLLMEvent : public clCommandEvent
+{
+public:
+    clLLMEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clLLMEvent(const clLLMEvent&) = default;
+    clLLMEvent& operator=(const clLLMEvent&) = delete;
+    ~clLLMEvent() override = default;
+    wxEvent* Clone() const override { return new clLLMEvent(*this); }
+
+    void SetPrompt(const wxString& prompt) { this->m_prompt = prompt; }
+    const wxString& GetPrompt() const { return m_prompt; }
+    void SetResponseRaw(const std::string& response) { SetStringRaw(response); }
+    const std::string& GetResponseRaw() const { return GetStringRaw(); }
+
+    void SetIsError(bool isError) { this->m_isError = isError; }
+    bool IsError() const { return m_isError; }
+
+protected:
+    wxString m_prompt;
+    bool m_isError{false};
+};
+
+using clLLMEventFunction = void (wxEvtHandler::*)(clLLMEvent&);
+#define clLLMEventHandler(func) wxEVENT_HANDLER_CAST(clLLMEventFunction, func)
