@@ -24,15 +24,37 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "cl_standard_paths.h"
-#include <wx/stdpaths.h>
-#include <wx/filename.h>
 
-clStandardPaths::clStandardPaths()
+#include "fileutils.h"
+
+#include <wx/datetime.h>
+#include <wx/dir.h>
+#include <wx/filefn.h>
+#include <wx/filename.h>
+#include <wx/stdpaths.h>
+#include <wx/utils.h>
+
+static wxString __get_user_name()
 {
-    IgnoreAppSubDir("bin");
+    wxString squashedname, name = wxGetUserId();
+
+    // The wx doc says that 'name' may now be e.g. "Mr. John Smith"
+    // So try to make it more suitable to be an extension
+    name.MakeLower();
+    name.Replace(wxT(" "), wxT("_"));
+    for(size_t i = 0; i < name.Len(); ++i) {
+        wxChar ch = name.GetChar(i);
+        if((ch < wxT('a') || ch > wxT('z')) && ch != wxT('_')) {
+            // Non [a-z_] character: skip it
+        } else {
+            squashedname << ch;
+        }
+    }
+
+    return (squashedname.IsEmpty() ? wxString(wxT("someone")) : squashedname);
 }
 
-clStandardPaths::~clStandardPaths() {}
+clStandardPaths::clStandardPaths() { IgnoreAppSubDir("bin"); }
 
 clStandardPaths& clStandardPaths::Get()
 {
@@ -40,6 +62,44 @@ clStandardPaths& clStandardPaths::Get()
     return codelitePaths;
 }
 
+#ifdef __WXMAC__
+namespace
+{
+void copy_directory(const wxString& from, const wxString& to)
+{
+    if(!wxDirExists(from)) {
+        return;
+    }
+
+    wxString source_dir = from;
+    wxString target_dir = to;
+    if(!source_dir.EndsWith("/")) {
+        source_dir << "/";
+    }
+
+    if(!target_dir.EndsWith("/")) {
+        target_dir << "/";
+    }
+
+    wxDir dir(source_dir);
+    wxString filename;
+    bool bla = dir.GetFirst(&filename);
+    if(bla) {
+        do {
+            if(wxDirExists(source_dir + filename)) {
+                // a directory
+                wxFileName::Mkdir(target_dir + filename, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+                copy_directory(source_dir + filename, target_dir + filename);
+            } else {
+                // a file, copy it
+                wxCopyFile(source_dir + filename, target_dir + filename);
+            }
+        } while(dir.GetNext(&filename));
+    }
+}
+} // namespace
+
+#endif
 wxString clStandardPaths::GetUserDataDir() const
 {
     // If the user has provided an alternative datadir, use it
@@ -48,21 +108,35 @@ wxString clStandardPaths::GetUserDataDir() const
     }
 
 #ifdef __WXGTK__
-
 #ifndef NDEBUG
-
     // Debug mode
     wxFileName fn(wxStandardPaths::Get().GetUserDataDir());
     fn.SetFullName(fn.GetFullName() + "-dbg");
     return fn.GetFullPath();
-
 #else
     // Release mode
     return wxStandardPaths::Get().GetUserDataDir();
-
 #endif
-#else // Windows / OSX
+#elif defined(__WXMSW__) // Windows / OSX
+    // %APPDATA%\CodeLite
     return wxStandardPaths::Get().GetUserDataDir();
+#else
+    // use ~/.codelite on macOS as well
+    wxFileName path{ wxGetHomeDir(), wxEmptyString };
+    path.AppendDir(".codelite");
+
+    // upgrade path
+    static bool upgrade_needed = true;
+    if(upgrade_needed) {
+        upgrade_needed = false;
+
+        if(wxFileName::DirExists(wxStandardPaths::Get().GetUserDataDir()) && !path.DirExists()) {
+            // we have an old setting directory but not a new one
+            // copy the content
+            copy_directory(wxStandardPaths::Get().GetUserDataDir(), path.GetPath());
+        }
+    }
+    return path.GetFullPath();
 #endif
 }
 
@@ -86,6 +160,10 @@ wxString clStandardPaths::GetPluginsDirectory() const
 
 wxString clStandardPaths::GetDataDir() const
 {
+    if(!m_dataDir.IsEmpty()) {
+        return m_dataDir;
+    }
+
 #ifdef USE_POSIX_LAYOUT
     wxFileName path(wxStandardPaths::Get().GetDataDir() + wxT(INSTALL_DIR), "");
     return path.GetPath();
@@ -100,14 +178,19 @@ wxString clStandardPaths::GetBinFolder() const
     return fnExe.GetPath();
 }
 
-wxString clStandardPaths::GetBinaryFullPath(const wxString& toolname) const
+wxString clStandardPaths::GetBinaryFullPath(const wxString& toolname, bool unixStylePath) const
 {
     wxFileName binary(GetBinFolder(), toolname);
     binary.SetExt(wxEmptyString);
 #ifdef __WXMSW__
     binary.SetExt("exe");
 #endif
-    return binary.GetFullPath();
+
+    wxString fullpath = binary.GetFullPath();
+    if(unixStylePath) {
+        fullpath.Replace("\\", "/");
+    }
+    return fullpath;
 }
 
 wxString clStandardPaths::GetLexersDir() const
@@ -142,7 +225,24 @@ wxString clStandardPaths::GetUserProjectTemplatesDir() const
 
 wxString clStandardPaths::GetExecutablePath() const { return wxStandardPaths::Get().GetExecutablePath(); }
 
-wxString clStandardPaths::GetTempDir() const { return wxStandardPaths::Get().GetTempDir(); }
+wxString clStandardPaths::GetTempDir() const
+{
+    static bool once = true;
+    static wxString tmpdir;
+    if(once) {
+        wxString username = __get_user_name();
+#if defined(__WXGTK__) || defined(__WXOSX__)
+        tmpdir << "/tmp/codelite/";
+#else
+        tmpdir << wxStandardPaths::Get().GetTempDir() << "\\CodeLite." << username << "\\.";
+#endif
+        tmpdir << ::wxGetProcessId();
+        // Create the temp folder
+        wxFileName::Mkdir(tmpdir, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+        once = false;
+    }
+    return tmpdir;
+}
 
 wxString clStandardPaths::GetDocumentsDir() const
 {
@@ -173,9 +273,11 @@ wxString clStandardPaths::GetInstallDir() const
 #endif
 }
 
-void clStandardPaths::IgnoreAppSubDir(const wxString & subdirPattern)
+void clStandardPaths::IgnoreAppSubDir(const wxString& subdirPattern)
 {
 #ifdef USE_POSIX_LAYOUT
     wxStandardPaths::Get().IgnoreAppSubDir(subdirPattern);
 #endif
 }
+
+void clStandardPaths::RemoveTempDir() { wxFileName::Rmdir(GetTempDir(), wxPATH_RMDIR_RECURSIVE); }
