@@ -26,22 +26,36 @@
 #ifndef CLSTANDARDPATHS_H
 #define CLSTANDARDPATHS_H
 
-#include <wx/string.h>
-#include "codelite_exports.h"
 #include "cl_defs.h"
+#include "codelite_exports.h"
+
+#include <wx/string.h>
 
 class WXDLLIMPEXP_CL clStandardPaths
 {
 private:
     clStandardPaths();
-    virtual ~clStandardPaths();
-    
+    virtual ~clStandardPaths() = default;
+
     wxString m_path;
-    
+    wxString m_dataDir;
+
 public:
     static clStandardPaths& Get();
+
     /**
-     * @brief return the user local data folder. Usually this is ~/.codelite or %APPDATA%\CodeLite 
+     * @brief remove the temp directory and its content
+     */
+    void RemoveTempDir();
+
+    /**
+     * @brief set an alternative data dir
+     * The default data dir is set to the installation path on Windows or /usr/share/codelite on Linux systems
+     */
+    void SetDataDir(const wxString& dataDir) { this->m_dataDir = dataDir; }
+
+    /**
+     * @brief return the user local data folder. Usually this is ~/.codelite or %APPDATA%\CodeLite
      * However, under Linux, this function will return ~/.codelite-dbg to avoid clobbering the release config
      * settings
      */
@@ -50,17 +64,17 @@ public:
      * @brief Sets an alternative local data folder, to be returned by GetUserDataDir()
      */
     void SetUserDataDir(const wxString& path);
-    
+
     /**
      * @brief return the temp folder for this OS
      */
     wxString GetTempDir() const;
-    
+
     /**
      * @brief return the path to the plugins folder
      */
     wxString GetPluginsDirectory() const;
-    
+
     /**
      * @brief Return the location of the applications global, i.e. not user-specific, data files.
      * Example return values:
@@ -81,15 +95,16 @@ public:
     /**
      * @brief return the full path for an executable. This function
      * usually returns: GetBinFolder() + "/" + toolname + ".exe"
+     * @param unixStylePath the path returned is always using forward slash `/`
      * @note the .exe and "/" are platform dependant
      */
-    wxString GetBinaryFullPath(const wxString &toolname) const;
-    
+    wxString GetBinaryFullPath(const wxString& toolname, bool unixStylePath = false) const;
+
     /**
-     * @brief get CodeLite executale path
+     * @brief get CodeLite executable path
      */
     wxString GetExecutablePath() const;
-    
+
     /**
      * @brief return the user lexers directory
      */
@@ -99,18 +114,18 @@ public:
      * @brief return the default (installation) lexers directory
      */
     wxString GetLexersDir() const;
-    
+
     /**
-     * @brief return the project templates dircectory
+     * @brief return the project templates directory
      */
     wxString GetProjectTemplatesDir() const;
-    
+
     /**
      * @brief return the user templates folder
-     * @return 
+     * @return
      */
     wxString GetUserProjectTemplatesDir() const;
-    
+
     /**
      * @brief return the documents directory.
      * Windows: C:\Users\name\Documents
@@ -118,13 +133,13 @@ public:
      * OSX: /Users/name/Documents
      */
     wxString GetDocumentsDir() const;
-    
+
     /**
      * @brief return the installation directory.
      */
     wxString GetInstallDir() const;
-    
-    void IgnoreAppSubDir(const wxString & subdirPattern);
+
+    void IgnoreAppSubDir(const wxString& subdirPattern);
 };
 
 #endif // CLSTANDARDPATHS_H
