@@ -23,14 +23,15 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "dirtraverser.h"
-#include "wx/tokenzr.h"
-#include "wx/filename.h"
-#include "wx/log.h"
+#include "fileutils.h"
 
-DirTraverser::DirTraverser(const wxString &filespec, bool includeExtLessFiles)
+#include <wx/filename.h>
+#include <wx/log.h>
+#include <wx/tokenzr.h>
+
+DirTraverser::DirTraverser(const wxString &filespec)
     : wxDirTraverser()
     , m_filespec(filespec)
-    , m_extlessFiles(includeExtLessFiles)
 {
     m_specArray = wxStringTokenize(filespec, wxT(";"), wxTOKEN_STRTOK);
 }
@@ -40,19 +41,9 @@ wxDirTraverseResult DirTraverser::OnFile(const wxString& filename)
     // add the file to our array
     wxFileName fn(filename);
 
-    for(size_t i=0; i<m_specArray.GetCount(); i++) {
-        if(wxMatchWild(m_specArray.Item(i), fn.GetFullName())) {
-            m_files.Add(filename);
-            return wxDIR_CONTINUE;
-        }
-    }
-
-    // if we reached this point, no pattern was suitable for our file
-    // test for extensionless file flag
-    if (fn.GetExt().IsEmpty() && m_extlessFiles) {
+    if (FileUtils::WildMatch(m_filespec, fn)) {
         m_files.Add(filename);
     }
-
     return wxDIR_CONTINUE;
 }
 
@@ -75,7 +66,3 @@ wxDirTraverseResult DirTraverser::OnDir(const wxString &dirname)
     }
     return wxDIR_CONTINUE;
 }
-
-DirTraverser::~DirTraverser()
-{
-}
