@@ -25,10 +25,12 @@
 #ifndef CODELITE_TAG_TREE_H
 #define CODELITE_TAG_TREE_H
 
-#include <wx/string.h>
-#include "smart_ptr.h"
+#include "codelite_exports.h"
+#include "database/entry.h"
 #include "tree.h"
-#include "entry.h"
+
+#include <wx/string.h>
+#include <memory>
 
 typedef TreeNode<wxString, TagEntry> TagNode;
 
@@ -40,7 +42,7 @@ typedef TreeNode<wxString, TagEntry> TagNode;
  * \author eran
  *
  */
-class TagTree : public Tree<wxString, TagEntry>
+class WXDLLIMPEXP_CL TagTree : public Tree<wxString, TagEntry>
 {
 public:
 	/**
@@ -54,7 +56,7 @@ public:
 	/**
 	 * Destructor
 	 */
-	virtual ~TagTree();
+	virtual ~TagTree() = default;
 
 	/**
 	 * Add an entry to the tree.
@@ -68,6 +70,6 @@ public:
 
 };
 
-typedef SmartPtr<TagTree> TagTreePtr;
+using TagTreePtr = std::shared_ptr<TagTree>;
 
 #endif // CODELITE_TAG_TREE_H
