@@ -36,20 +36,22 @@ class CodeLiteDiff : public IPlugin
 
 protected:
     void OnNewDiff(wxCommandEvent& e);
+    void OnNewDiffFolder(wxCommandEvent& e);
     void OnTabContextMenu(clContextMenuEvent& event);
     void OnDiff(wxCommandEvent& event);
     void DoClear();
+    wxFileName SaveEditorToTmpfile(IEditor* editor) const;
 
 public:
     CodeLiteDiff(IManager* manager);
-    ~CodeLiteDiff();
+    ~CodeLiteDiff() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void UnPlug() override;
 };
 
 #endif // CodeLiteDiff
