@@ -24,34 +24,32 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "continuousbuild.h"
-#include "event_notifier.h"
-#include "buildmanager.h"
-#include "globals.h"
-#include "builder.h"
-#include "file_logger.h"
-#include "processreaderthread.h"
-#include "fileextmanager.h"
-#include "build_settings_config.h"
-#include "workspace.h"
-#include "custombuildrequest.h"
-#include "compile_request.h"
-#include <wx/app.h>
-#include "environmentconfig.h"
-#include "continousbuildpane.h"
-#include <wx/xrc/xmlres.h>
-#include "continousbuildconf.h"
-#include <wx/log.h>
-#include <wx/imaglist.h>
-#include "cl_command_event.h"
 
-static ContinuousBuild* thePlugin = NULL;
+#include "AsyncProcess/processreaderthread.h"
+#include "build_settings_config.h"
+#include "builder/builder.h"
+#include "buildmanager.h"
+#include "cl_command_event.h"
+#include "compile_request.h"
+#include "continousbuildconf.h"
+#include "continousbuildpane.h"
+#include "custombuildrequest.h"
+#include "environmentconfig.h"
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "fileextmanager.h"
+#include "globals.h"
+#include "workspace.h"
+
+#include <wx/app.h>
+#include <wx/imaglist.h>
+#include <wx/log.h>
+#include <wx/xrc/xmlres.h>
+
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new ContinuousBuild(manager);
-    }
-    return thePlugin;
+    return new ContinuousBuild(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -74,30 +72,26 @@ ContinuousBuild::ContinuousBuild(IManager* manager)
 {
     m_longName = _("Continuous build plugin which compiles files on save and report errors");
     m_shortName = wxT("ContinuousBuild");
-    m_view = new ContinousBuildPane(m_mgr->GetOutputPaneNotebook(), m_mgr, this);
+    m_view = new ContinousBuildPane(m_mgr->BookGet(PaneId::BOTTOM_BAR), m_mgr, this);
 
     // add our page to the output pane notebook
-    m_mgr->GetOutputPaneNotebook()->AddPage(m_view, CONT_BUILD, false, m_mgr->GetStdIcons()->LoadBitmap("execute"));
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_view, CONT_BUILD);
     m_tabHelper.reset(new clTabTogglerHelper(CONT_BUILD, m_view, "", NULL));
-    m_tabHelper->SetOutputTabBmp(m_mgr->GetStdIcons()->LoadBitmap("execute"));
-    
+
     m_topWin = m_mgr->GetTheApp();
     EventNotifier::Get()->Connect(wxEVT_FILE_SAVED, clCommandEventHandler(ContinuousBuild::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_FILE_SAVE_BY_BUILD_START, wxCommandEventHandler(ContinuousBuild::OnIgnoreFileSaved), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_FILE_SAVE_BY_BUILD_END, wxCommandEventHandler(ContinuousBuild::OnStopIgnoreFileSaved), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_FILE_SAVE_BY_BUILD_START,
+                                  wxCommandEventHandler(ContinuousBuild::OnIgnoreFileSaved), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_FILE_SAVE_BY_BUILD_END,
+                                  wxCommandEventHandler(ContinuousBuild::OnStopIgnoreFileSaved), NULL, this);
     Bind(wxEVT_ASYNC_PROCESS_OUTPUT, &ContinuousBuild::OnBuildProcessOutput, this);
     Bind(wxEVT_ASYNC_PROCESS_TERMINATED, &ContinuousBuild::OnBuildProcessEnded, this);
 }
 
-ContinuousBuild::~ContinuousBuild() {}
-
-clToolBar* ContinuousBuild::CreateToolBar(wxWindow* parent)
+void ContinuousBuild::CreateToolBar(clToolBarGeneric* toolbar)
 {
     // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-    return tb;
+    wxUnusedVar(toolbar);
 }
 
 void ContinuousBuild::CreatePluginMenu(wxMenu* pluginsMenu) { wxUnusedVar(pluginsMenu); }
@@ -111,29 +105,25 @@ void ContinuousBuild::HookPopupMenu(wxMenu* menu, MenuType type)
 void ContinuousBuild::UnPlug()
 {
     m_tabHelper.reset(NULL);
-    // before this plugin is un-plugged we must remove the tab we added
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
-        if(m_view == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            break;
-        }
+    if(!m_mgr->BookDeletePage(PaneId::BOTTOM_BAR, m_view)) {
+        m_view->Destroy();
     }
-    m_view->Destroy();
-    
+    m_view = nullptr;
+
     EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(ContinuousBuild::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_FILE_SAVE_BY_BUILD_START, wxCommandEventHandler(ContinuousBuild::OnIgnoreFileSaved), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_FILE_SAVE_BY_BUILD_END, wxCommandEventHandler(ContinuousBuild::OnStopIgnoreFileSaved), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVE_BY_BUILD_START,
+                                     wxCommandEventHandler(ContinuousBuild::OnIgnoreFileSaved), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVE_BY_BUILD_END,
+                                     wxCommandEventHandler(ContinuousBuild::OnStopIgnoreFileSaved), NULL, this);
 }
 
 void ContinuousBuild::OnFileSaved(clCommandEvent& e)
 {
     e.Skip();
-    CL_DEBUG(wxT("ContinuousBuild::OnFileSaved\n"));
-    // Dont build while the main build is in progress
+    clDEBUG1() << "ContinuousBuild::OnFileSaved";
+    // Don't build while the main build is in progress
     if(m_buildInProgress) {
-        CL_DEBUG(wxT("Build already in progress, skipping\n"));
+        clDEBUG() << "Build already in progress, skipping";
         return;
     }
 
@@ -143,16 +133,16 @@ void ContinuousBuild::OnFileSaved(clCommandEvent& e)
     if(conf.GetEnabled()) {
         DoBuild(e.GetString());
     } else {
-        CL_DEBUG(wxT("ContinuousBuild is disabled\n"));
+        clDEBUG1() << "ContinuousBuild is disabled";
     }
 }
 
 void ContinuousBuild::DoBuild(const wxString& fileName)
 {
-    CL_DEBUG(wxT("DoBuild\n"));
+    clDEBUG() << "ContinuousBuild::DoBuild is called";
     // Make sure a workspace is opened
     if(!m_mgr->IsWorkspaceOpen()) {
-        CL_DEBUG(wxT("No workspace opened!\n"));
+        clDEBUG() << "ContinuousBuild::DoBuild: No workspace opened!";
         return;
     }
 
@@ -165,46 +155,46 @@ void ContinuousBuild::DoBuild(const wxString& fileName)
         break;
 
     default: {
-        CL_DEBUG(wxT("Non source file\n"));
+        clDEBUG1() << "ContinuousBuild::DoBuild: Non source file";
         return;
     }
     }
 
     wxString projectName = m_mgr->GetProjectNameByFile(fileName);
     if(projectName.IsEmpty()) {
-        CL_DEBUG(wxT("Project name is empty\n"));
+        clDEBUG() << "ContinuousBuild::DoBuild: project name is empty";
         return;
     }
 
     wxString errMsg;
     ProjectPtr project = m_mgr->GetWorkspace()->FindProjectByName(projectName, errMsg);
     if(!project) {
-        CL_DEBUG(wxT("Could not find project for file\n"));
+        clDEBUG() << "Could not find project for file";
         return;
     }
 
     // get the selected configuration to be build
     BuildConfigPtr bldConf = m_mgr->GetWorkspace()->GetProjBuildConf(project->GetName(), wxEmptyString);
     if(!bldConf) {
-        CL_DEBUG(wxT("Failed to locate build configuration\n"));
+        clDEBUG() << "Failed to locate build configuration\n" << endl;
         return;
     }
 
-    BuilderPtr builder = m_mgr->GetBuildManager()->GetBuilder(wxT("GNU makefile for g++/gcc"));
+    BuilderPtr builder = bldConf->GetBuilder();
     if(!builder) {
-        CL_DEBUG(wxT("Failed to located builder\n"));
+        clDEBUG() << "Failed to located builder\n" << endl;
         return;
     }
 
     // Only normal file builds are supported
     if(bldConf->IsCustomBuild()) {
-        CL_DEBUG(wxT("Build is custom. Skipping\n"));
+        clDEBUG() << "Build is custom. Skipping\n" << endl;
         return;
     }
 
     // get the single file command to use
-    wxString cmd = builder->GetSingleFileCmd(projectName, bldConf->GetName(), fileName);
-    WrapInShell(cmd);
+    wxString cmd =
+        builder->GetSingleFileCmd(projectName, bldConf->GetName(), bldConf->GetBuildSystemArguments(), fileName);
 
     if(m_buildProcess.IsBusy()) {
         // add the build to the queue
@@ -217,22 +207,19 @@ void ContinuousBuild::DoBuild(const wxString& fileName)
         return;
     }
 
-    clCommandEvent event(wxEVT_SHELL_COMMAND_STARTED);
-
-    // Associate the build event details
-    BuildEventDetails* eventData = new BuildEventDetails();
-    eventData->SetProjectName(projectName);
-    eventData->SetConfiguration(bldConf->GetName());
-    eventData->SetIsCustomProject(bldConf->IsCustomBuild());
-    eventData->SetIsClean(false);
-
-    event.SetClientObject(eventData);
     // Fire it up
+    clBuildEvent event(wxEVT_BUILD_PROCESS_STARTED);
+    event.SetProjectName(projectName);
+    event.SetConfigurationName(bldConf->GetName());
+    event.SetFlag(clBuildEvent::kCustomProject, bldConf->IsCustomBuild());
+    event.SetFlag(clBuildEvent::kClean, false);
+    event.SetToolchain(bldConf->GetCompilerType());
     EventNotifier::Get()->AddPendingEvent(event);
 
     EnvSetter env(NULL, NULL, projectName, bldConf->GetName());
-    CL_DEBUG(wxString::Format(wxT("cmd:%s\n"), cmd.c_str()));
-    if(!m_buildProcess.Execute(cmd, fileName, project->GetFileName().GetPath(), this)) return;
+    clDEBUG() << "Continuous build:" << cmd << endl;
+    if(!m_buildProcess.Execute(cmd, fileName, project->GetFileName().GetPath(), this))
+        return;
 
     // Set some messages
     m_mgr->SetStatusMessage(
@@ -248,7 +235,7 @@ void ContinuousBuild::OnBuildProcessEnded(clProcessEvent& e)
     int pid = m_buildProcess.GetPid();
     m_view->RemoveFile(m_buildProcess.GetFileName());
 
-    clCommandEvent event(wxEVT_SHELL_COMMAND_PROCESS_ENDED);
+    clBuildEvent event(wxEVT_BUILD_PROCESS_ENDED);
     EventNotifier::Get()->AddPendingEvent(event);
 
     int exitCode(-1);
@@ -256,7 +243,7 @@ void ContinuousBuild::OnBuildProcessEnded(clProcessEvent& e)
         m_view->AddFailedFile(m_buildProcess.GetFileName());
     }
 
-    // Release the resources allocted for this build
+    // Release the resources allocated for this build
     m_buildProcess.Stop();
 
     // if the queue is not empty, start another build
@@ -264,7 +251,6 @@ void ContinuousBuild::OnBuildProcessEnded(clProcessEvent& e)
 
         wxString fileName = m_files.Item(0);
         m_files.RemoveAt(0);
-
         DoBuild(fileName);
     }
 }
@@ -297,7 +283,7 @@ void ContinuousBuild::OnStopIgnoreFileSaved(wxCommandEvent& e)
 
 void ContinuousBuild::OnBuildProcessOutput(clProcessEvent& e)
 {
-    clCommandEvent event(wxEVT_SHELL_COMMAND_ADDLINE);
+    clBuildEvent event(wxEVT_BUILD_PROCESS_ADDLINE);
     event.SetString(e.GetOutput());
     EventNotifier::Get()->AddPendingEvent(event);
 }
