@@ -1,8 +1,8 @@
 #ifndef EXPRESSION_RESULT_H
 #define EXPRESSION_RESULT_H
 
-#include "string"
-#include <stdio.h>
+#include <cstdio>
+#include <string>
 
 #ifndef WXDLLIMPEXP_CL
 
@@ -33,7 +33,7 @@ public:
 
 public:
 	ExpressionResult();
-	virtual ~ExpressionResult();
+	virtual ~ExpressionResult() = default;
 	void Reset();
 	void Print();
 	std::string ToString() const;
