@@ -1,11 +1,10 @@
 //test the parser
-#include "windows.h"
-#include "stdio.h"
-#include "errno.h"
-#include "string.h"
-#include "vector"
-#include "string"
-#include "map"
+#include <stdio.h>
+#include <errno.h>
+#include <string.h>
+#include <vector>
+#include <string>
+#include <map>
 #include "code_completion_api.h"
 
 void testScopeParser(char *buf);
@@ -17,10 +16,6 @@ void testPureLexer(const char *buf);
 void testIsPrimitive(char *buf);
 
 char *loadFile(const char *fileName);
-void testColorLocals()
-{
-
-}
 
 int main()
 {
@@ -60,16 +55,15 @@ void testFuncParser(char *buf)
     std::map<std::string, std::string> ignoreTokens;
     get_functions(buf, li, ignoreTokens);
 //	time_t end = GetTickCount();
-    for (FunctionList::iterator iter = li.begin(); iter != li.end(); iter++) {
+    for (const clFunction& f : li) {
         //test the var parser on the function argument list:
-        clFunction f = (*iter);
         f.Print();
         //testVarParser((char*)f.m_signature.c_str());
         printf("%s\n", f.m_name.c_str());
     }
 
 //	printf("total time: %d\n", end-start);
-    printf("matches found: %d\n", li.size());
+    printf("matches found: %d\n", (int)li.size());
 }
 
 void testExprParser(char *buf)
@@ -79,10 +73,6 @@ void testExprParser(char *buf)
     res.Print();
 }
 
-void doo(int ii, int value, int stat)
-{
-}
-
 void testScopeParser(char *buf)
 {
     printf("===== Testing Scope parser ======\n");
@@ -111,13 +101,12 @@ void testVarParser(char *buf)
     std::map<std::string, std::string> ignoreTokens;
     get_variables(buf, li, ignoreTokens, true);
 //	time_t end = GetTickCount();
-    for (VariableList::iterator iter = li.begin(); iter != li.end(); iter++) {
-        Variable var = *iter;
+    for (const Variable& var : li) {
         var.Print();
     }
 
 //	printf("total time: %d\n", end-start);
-    printf("matches found: %d\n", li.size());
+    printf("matches found: %d\n", (int)li.size());
 }
 
 void testTypedefParser(char *buf)
@@ -128,11 +117,10 @@ void testTypedefParser(char *buf)
 
     std::map<std::string, std::string> ignoreTokens;
     get_typedefs(buf, li);
-    for (clTypedefList::iterator iter = li.begin(); iter != li.end(); iter++) {
-        clTypedef var = *iter;
+    for (const clTypedef& var : li) {
         var.print();
     }
-    printf("matches found: %d\n", li.size());
+    printf("matches found: %d\n", (int)li.size());
 }
 
 //-------------------------------------------------------
@@ -153,7 +141,7 @@ char *loadFile(const char *fileName)
     //read the whole file
     fseek(fp, 0, SEEK_END); 		//go to end
     len = ftell(fp); 					//get position at end (length)
-    fseek(fp, 0, SEEK_SET); 		//go to begining
+    fseek(fp, 0, SEEK_SET); 		//go to beginning
     buf = (char *)malloc(len+1); 	//malloc buffer
 
     //read into buffer
