@@ -26,21 +26,19 @@
 #ifndef CLASSGENERATEDIALOG_H
 #define CLASSGENERATEDIALOG_H
 
-#include "GUI.h" // Base class: _ClassGenerateDialog
-#include "ErdTable.h"
-#include "ErdView.h"
-#include "table.h"
-#include "IDbAdapter.h"
-#include "wx/wxxmlserializer/XmlSerializer.h"
-#include <wx/textfile.h>
-#include <wx/stdpaths.h>
-#include <wx/init.h>
-#include <wx/hashmap.h>
-
 #include "../Interfaces/imanager.h"
 #include "../Plugin/VirtualDirectorySelectorDlg.h"
 #include "../Plugin/project.h"
 #include "../Plugin/workspace.h"
+#include "GUI.h" // Base class: _ClassGenerateDialog
+#include "IDbAdapter.h"
+#include "table.h"
+
+#include <wx/hashmap.h>
+#include <wx/init.h>
+#include <wx/stdpaths.h>
+#include <wx/textfile.h>
+#include <wx/wxxmlserializer/XmlSerializer.h>
 
 WX_DECLARE_STRING_HASH_MAP(wxString, TemplateMap);
 
@@ -49,8 +47,8 @@ class ClassGenerateDialog : public _ClassGenerateDialog
 {
 
 public:
-    /*! \brief Defautl constructor.  */
-    ClassGenerateDialog(wxWindow *parent, IDbAdapter* dbAdapter, xsSerializable* pItems, IManager* pMgr);
+    /*! \brief Default constructor.  */
+    ClassGenerateDialog(wxWindow* parent, IDbAdapter* dbAdapter, xsSerializable* pItems, IManager* pMgr);
 
     /*! \brief Return string with type name on UNIVERSAL TYPE base */
     wxString GetTypeName(IDbType::UNIVERSAL_TYPE type);
@@ -67,14 +65,16 @@ public:
     /*! \brief Return string with type name in add function format on UNIVERSAL TYPE base */
     wxString GetAddParamFunction(IDbType::UNIVERSAL_TYPE type);
 
-
-    /*! \brief Function for generating classes for selected table. It call GenerateFile function two times. Fist time for generate .h, second time for generate .cpp file. */
+    /*! \brief Function for generating classes for selected table. It call GenerateFile function two times. Fist time
+     * for generate .h, second time for generate .cpp file. */
     bool GenerateClass(Table* pTab, const wxString& path);
 
     /*! \brief Function for generating file for selected table.  */
-    bool GenerateFile(Table* pTab,wxTextFile& htmpFile, wxString& hFile, const wxString& classItemName,const wxString& classItemDef, const wxString& classColName, const wxString& classTableName, const wxString& classUtilName);
+    bool GenerateFile(Table* pTab, wxTextFile& htmpFile, wxString& hFile, const wxString& classItemName,
+        const wxString& classItemDef, const wxString& classColName, const wxString& classTableName,
+        const wxString& classUtilName);
     /*! \brief Format text file */
-    void FormatFile(wxString& content);
+    void FormatFile(wxString& content, const wxFileName& filename);
 
     virtual void OnCancelClick(wxCommandEvent& event);
 
