@@ -51,10 +51,10 @@ public:
 
 public:
     DbConnectionInfo();
-    virtual ~DbConnectionInfo();
+    virtual ~DbConnectionInfo() = default;
 
-    virtual void FromJSON(const JSONElement& json);
-    virtual JSONElement ToJSON() const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON() const;
 
     void SetConnectionName(const wxString& connectionName) {
         this->m_connectionName = connectionName;
@@ -118,7 +118,7 @@ protected:
 
 public:
     DbExplorerSettings();
-    virtual ~DbExplorerSettings();
+    virtual ~DbExplorerSettings() = default;
 
     void SetRecentFiles(const wxArrayString& recentFiles);
     const wxArrayString& GetRecentFiles() const {
@@ -137,8 +137,8 @@ public:
     const wxArrayString& GetSqlHistory() const {
         return m_sqlHistory;
     }
-    virtual void FromJSON(const JSONElement &json);
-    virtual JSONElement ToJSON() const;
+    virtual void FromJSON(const JSONItem &json);
+    virtual JSONItem ToJSON() const;
 };
 
 #endif // DBEXPLORERSETTINGS_H
