@@ -25,10 +25,11 @@
 #ifndef DBGCMD_H
 #define DBGCMD_H
 
-#include "wx/string.h"
-#include "wx/event.h"
-#include "debuggerobserver.h"
 #include "debugger.h"
+#include "debuggerobserver.h"
+
+#include <wx/event.h>
+#include <wx/string.h>
 
 class IDebugger;
 class DbgGdb;
@@ -39,9 +40,9 @@ class DbgGdb;
         currentToken = _U(gdb_result_string.c_str()); \
     }
 
-#define GDB_ABORT(ch)     \
-    if(type != (int)ch) { \
-        break;            \
+#define GDB_ABORT(ch)      \
+    if (type != (int)ch) { \
+        break;             \
     }
 
 class DbgCmdHandler
@@ -54,7 +55,7 @@ public:
         : m_observer(observer)
     {
     }
-    virtual ~DbgCmdHandler() {}
+    virtual ~DbgCmdHandler() = default;
 
     virtual bool WantsErrors() const { return false; }
 
@@ -76,39 +77,37 @@ public:
     {
     }
 
-    virtual ~DbgCmdHandlerGetLine() {}
+    virtual ~DbgCmdHandlerGetLine() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
 
 class DbgCmdHandlerDisasseble : public DbgCmdHandler
 {
-    DbgGdb* m_gdb;
 
 public:
     DbgCmdHandlerDisasseble(IDebuggerObserver* observe, DbgGdb* gdbr)
         : DbgCmdHandler(observe)
-        , m_gdb(gdbr)
+
     {
     }
 
-    virtual ~DbgCmdHandlerDisasseble() {}
+    virtual ~DbgCmdHandlerDisasseble() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
 
 class DbgCmdHandlerDisassebleCurLine : public DbgCmdHandler
 {
-    DbgGdb* m_gdb;
 
 public:
     DbgCmdHandlerDisassebleCurLine(IDebuggerObserver* observe, DbgGdb* gdbr)
         : DbgCmdHandler(observe)
-        , m_gdb(gdbr)
+
     {
     }
 
-    virtual ~DbgCmdHandlerDisassebleCurLine() {}
+    virtual ~DbgCmdHandlerDisassebleCurLine() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -119,16 +118,15 @@ public:
  */
 class DbgCmdHandlerStackDepth : public DbgCmdHandler
 {
-    DbgGdb* m_gdb;
 
 public:
     DbgCmdHandlerStackDepth(IDebuggerObserver* observe, DbgGdb* gdbr)
         : DbgCmdHandler(observe)
-        , m_gdb(gdbr)
+
     {
     }
 
-    virtual ~DbgCmdHandlerStackDepth() {}
+    virtual ~DbgCmdHandlerStackDepth() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -152,7 +150,7 @@ public:
         , m_gdb(gdb)
     {
     }
-    virtual ~DbgCmdHandlerAsyncCmd() {}
+    virtual ~DbgCmdHandlerAsyncCmd() = default;
 
     void UpdateGotControl(DebuggerReasons reason, const wxString& func);
     virtual bool ProcessOutput(const wxString& line);
@@ -166,7 +164,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdHandlerExecRun() {}
+    virtual ~DbgCmdHandlerExecRun() = default;
     virtual bool ProcessOutput(const wxString& line);
     virtual bool WantsErrors() const { return true; }
 };
@@ -182,7 +180,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdHandlerRemoteDebugging() {}
+    virtual ~DbgCmdHandlerRemoteDebugging() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -192,7 +190,6 @@ class DbgCmdHandlerBp : public DbgCmdHandler
     const clDebuggerBreakpoint m_bp;
     std::vector<clDebuggerBreakpoint>* m_bplist;
     int m_bpType; // BP_type_break by default
-    DbgGdb* m_debugger;
 
 public:
     DbgCmdHandlerBp(IDebuggerObserver* observer,
@@ -204,11 +201,10 @@ public:
         , m_bp(bp)
         , m_bplist(bplist)
         , m_bpType(bptype)
-        , m_debugger(debugger)
     {
     }
 
-    virtual ~DbgCmdHandlerBp() {}
+    virtual ~DbgCmdHandlerBp() = default;
     virtual bool ProcessOutput(const wxString& line);
     virtual bool WantsErrors() const { return true; }
 };
@@ -220,18 +216,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdHandlerLocals() {}
-    virtual bool ProcessOutput(const wxString& line);
-};
-
-class DbgCmdHandlerFuncArgs : public DbgCmdHandler
-{
-public:
-    DbgCmdHandlerFuncArgs(IDebuggerObserver* observer)
-        : DbgCmdHandler(observer)
-    {
-    }
-    virtual ~DbgCmdHandlerFuncArgs() {}
+    virtual ~DbgCmdHandlerLocals() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -243,7 +228,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdHandlerVarCreator() {}
+    virtual ~DbgCmdHandlerVarCreator() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -258,7 +243,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdHandlerEvalExpr() {}
+    virtual ~DbgCmdHandlerEvalExpr() = default;
     virtual bool ProcessOutput(const wxString& line);
     virtual const wxString& GetExpression() const { return m_expression; }
 };
@@ -271,7 +256,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdStackList() {}
+    virtual ~DbgCmdStackList() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -283,7 +268,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdSelectFrame() {}
+    virtual ~DbgCmdSelectFrame() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -295,7 +280,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdDisplayOutput() {}
+    virtual ~DbgCmdDisplayOutput() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -308,7 +293,7 @@ class DbgCmdResolveTypeHandler : public DbgCmdHandler
 public:
     DbgCmdResolveTypeHandler(const wxString& expression, DbgGdb* debugger, int userReason);
 
-    virtual ~DbgCmdResolveTypeHandler() {}
+    virtual ~DbgCmdResolveTypeHandler() = default;
     virtual bool ProcessOutput(const wxString& line);
     virtual bool WantsErrors() const { return true; }
 };
@@ -324,7 +309,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdCLIHandler() {}
+    virtual ~DbgCmdCLIHandler() = default;
     virtual bool ProcessOutput(const wxString& line);
 
     const wxString& GetOutput() const { return m_output; }
@@ -348,7 +333,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdGetTipHandler() {}
+    virtual ~DbgCmdGetTipHandler() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -363,7 +348,7 @@ public:
         , m_bp(bp)
     {
     }
-    virtual ~DbgCmdSetConditionHandler() {}
+    virtual ~DbgCmdSetConditionHandler() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -372,12 +357,15 @@ public:
 // the debugger
 class DbgCmdBreakList : public DbgCmdHandler
 {
+    DbgGdb* m_gdb = nullptr;
+
 public:
-    DbgCmdBreakList(IDebuggerObserver* observer)
-        : DbgCmdHandler(observer)
+    DbgCmdBreakList(DbgGdb* gdb)
+        : DbgCmdHandler(nullptr)
+        , m_gdb(gdb)
     {
     }
-    virtual ~DbgCmdBreakList() {}
+    virtual ~DbgCmdBreakList() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -391,7 +379,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdListThreads() {}
+    virtual ~DbgCmdListThreads() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -400,18 +388,14 @@ public:
 class DbgCmdWatchMemory : public DbgCmdHandler
 {
     wxString m_address;
-    size_t m_count;
-    size_t m_columns;
 
 public:
     DbgCmdWatchMemory(IDebuggerObserver* observer, const wxString& address, size_t count, size_t columns)
         : DbgCmdHandler(observer)
         , m_address(address)
-        , m_count(count)
-        , m_columns(columns)
     {
     }
-    virtual ~DbgCmdWatchMemory() {}
+    virtual ~DbgCmdWatchMemory() = default;
     virtual bool ProcessOutput(const wxString& line);
 };
 
@@ -420,14 +404,12 @@ class DbgCmdCreateVarObj : public DbgCmdHandler
 {
     wxString m_expression;
     int m_userReason;
-    DbgGdb* m_debugger;
 
 public:
     DbgCmdCreateVarObj(IDebuggerObserver* observer, DbgGdb* gdb, const wxString& expression, int userReason)
         : DbgCmdHandler(observer)
         , m_expression(expression)
         , m_userReason(userReason)
-        , m_debugger(gdb)
     {
     }
 
@@ -436,7 +418,7 @@ public:
      */
     virtual bool WantsErrors() const { return true; }
 
-    virtual ~DbgCmdCreateVarObj() {}
+    virtual ~DbgCmdCreateVarObj() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -455,7 +437,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdListChildren() {}
+    virtual ~DbgCmdListChildren() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -473,7 +455,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdEvalVarObj() {}
+    virtual ~DbgCmdEvalVarObj() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -489,7 +471,7 @@ public:
     {
     }
 
-    virtual ~DbgFindMainBreakpointIdHandler() {}
+    virtual ~DbgFindMainBreakpointIdHandler() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -497,19 +479,18 @@ public:
 class DbgVarObjUpdate : public DbgCmdHandler
 {
     wxString m_variableName;
-    DbgGdb* m_debugger;
+
     int m_userReason;
 
 public:
     DbgVarObjUpdate(IDebuggerObserver* observer, DbgGdb* debugger, const wxString& name, int userReason)
         : DbgCmdHandler(observer)
         , m_variableName(name)
-        , m_debugger(debugger)
         , m_userReason(userReason)
     {
     }
 
-    virtual ~DbgVarObjUpdate() {}
+    virtual ~DbgVarObjUpdate() = default;
 
     virtual bool ProcessOutput(const wxString& line);
     virtual bool WantsErrors() { return true; }
@@ -524,7 +505,7 @@ public:
         : DbgCmdCLIHandler(observer)
     {
     }
-    virtual ~DbgCmdJumpHandler() {}
+    virtual ~DbgCmdJumpHandler() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -536,7 +517,7 @@ public:
         : DbgCmdHandler(observer)
     {
     }
-    virtual ~DbgCmdStopHandler() {}
+    virtual ~DbgCmdStopHandler() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -551,7 +532,7 @@ public:
         , m_gdb(gdb)
     {
     }
-    virtual ~DbgCmdRecordHandler() {}
+    virtual ~DbgCmdRecordHandler() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -572,7 +553,7 @@ public:
     {
     }
 
-    virtual ~DbgCmdHandlerRegisterNames() {}
+    virtual ~DbgCmdHandlerRegisterNames() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
@@ -582,18 +563,17 @@ public:
 // +++-----------------------------
 class DbgCmdHandlerRegisterValues : public DbgCmdHandler
 {
-    DbgGdb* m_gdb;
+
     std::map<int, wxString> m_numberToName;
 
 public:
     DbgCmdHandlerRegisterValues(IDebuggerObserver* observer, DbgGdb* gdbr, const std::map<int, wxString>& numberToName)
         : DbgCmdHandler(observer)
-        , m_gdb(gdbr)
     {
         m_numberToName = numberToName;
     }
 
-    virtual ~DbgCmdHandlerRegisterValues() {}
+    virtual ~DbgCmdHandlerRegisterValues() = default;
 
     virtual bool ProcessOutput(const wxString& line);
 };
