@@ -25,27 +25,22 @@
 #ifndef DBGINTERFACE_H
 #define DBGINTERFACE_H
 
-#include "wx/string.h"
-#include "wx/event.h"
-#include "list"
-#include "debugger.h"
-#include <wx/hashmap.h>
-#include "consolefinder.h"
+#include "AsyncProcess/asyncprocess.h"
 #include "cl_command_event.h"
+#include "consolefinder.h"
+#include "debugger.h"
+#include "ssh/ssh_account_info.h"
+
+#include <vector>
+#include <wx/event.h>
+#include <wx/hashmap.h>
+#include <wx/string.h>
 
-#ifdef MSVC_VER
-// declare the debugger function creation
-extern "C++" IDebugger* CreateDebuggerGDB();
-// declare the function that will be called by host application
-// to retrieve the debugger initialization function
-extern "C++" DebuggerInfo GetDebuggerInfo();
-#else
 // declare the debugger function creation
 extern "C" IDebugger* CreateDebuggerGDB();
 // declare the function that will be called by host application
 // to retrieve the debugger initialization function
-extern "C" DebuggerInfo GetDebuggerInfo();
-#endif
+extern "C" const DebuggerInfo* GetDebuggerInfo();
 
 class DbgCmdHandler;
 class DbgCmdCLIHandler;
@@ -60,7 +55,7 @@ class DbgGdb : public wxEvtHandler, public IDebugger
     HandlersMap_t m_handlers;
     long m_debuggeePid;
     ConsoleFinder m_consoleFinder;
-    std::vector<BreakpointInfo> m_bpList;
+    std::vector<clDebuggerBreakpoint> m_bpList;
     DbgCmdCLIHandler* m_cliHandler;
     IProcess* m_gdbProcess;
     wxArrayString m_gdbOutputArr;
@@ -83,11 +78,11 @@ protected:
     bool DoGetNextLine(wxString& line);
     void DoCleanup();
 
-    // wrapper for convinience
+    // wrapper for convenience
     void DoProcessAsyncCommand(wxString& line, wxString& id);
 
 protected:
-    bool DoLocateGdbExecutable(const wxString& debuggerPath, wxString& dbgExeName);
+    bool DoLocateGdbExecutable(const wxString& debuggerPath, wxString& dbgExeName, const DebugSessionInfo& sessionInfo);
     bool DoInitializeGdb(const DebugSessionInfo& sessionInfo);
     void SetCliHandler(DbgCmdCLIHandler* handler);
     DbgCmdCLIHandler* GetCliHandler();
@@ -104,7 +99,7 @@ public:
     void SetGoingDown(bool goingDown) { this->m_goingDown = goingDown; }
     bool IsGoingDown() const { return m_goingDown; }
 
-    const std::vector<BreakpointInfo>& GetBpList() const { return m_bpList; }
+    const std::vector<clDebuggerBreakpoint>& GetBpList() const { return m_bpList; }
 
     void SetIsRecording(bool isRecording) { this->m_isRecording = isRecording; }
     bool IsRecording() const { return m_isRecording; }
@@ -114,18 +109,19 @@ public:
     virtual ~DbgGdb();
 
     //------ IDebugger ---------
-    virtual bool Start(const DebugSessionInfo& si);
-    virtual bool Attach(const DebugSessionInfo& si);
+    virtual bool Start(const DebugSessionInfo& si, clEnvList_t* env_list);
+    virtual bool Attach(const DebugSessionInfo& si, clEnvList_t* env_list);
     virtual bool Run(const wxString& args, const wxString& comm);
     virtual bool Stop();
-    virtual bool Break(const BreakpointInfo& bp);
+    virtual bool Break(const clDebuggerBreakpoint& bp);
     virtual bool SetEnabledState(double bid, const bool enable);
     virtual bool SetIgnoreLevel(double bid, const int ignorecount);
-    virtual bool SetCondition(const BreakpointInfo& bp);
-    virtual bool SetCommands(const BreakpointInfo& bp);
+    virtual bool SetCondition(const clDebuggerBreakpoint& bp);
+    virtual bool SetCommands(const clDebuggerBreakpoint& bp);
     virtual bool RemoveBreak(double bid);
     virtual bool RemoveAllBreaks();
     virtual bool StepIn();
+    virtual bool StepInInstruction();
     virtual bool StepOut();
     virtual bool Next();
     virtual bool NextInstruction();
@@ -152,7 +148,7 @@ public:
     virtual bool CreateVariableObject(const wxString& expression, bool persistent, int userReason);
     virtual bool DeleteVariableObject(const wxString& name);
     virtual bool EvaluateVariableObject(const wxString& name, int userReason);
-    virtual bool SetVariableObbjectDisplayFormat(const wxString& name, DisplayFormat displayFormat);
+    virtual bool SetVariableObjectDisplayFormat(const wxString& name, DisplayFormat displayFormat);
     virtual bool UpdateVariableObject(const wxString& name, int userReason);
     virtual void AssignValue(const wxString& expression, const wxString& newValue);
     virtual bool Jump(wxString filename, int line);
@@ -161,7 +157,7 @@ public:
     virtual void EnableReverseDebugging(bool b);
     virtual void EnableRecording(bool b);
     virtual bool IsReverseDebuggingEnabled() const;
-    
+
     /**
      * @brief restart the debugger (execute 'run')
      * @return true on success, false otherwise
