@@ -18,21 +18,21 @@ protected:
 
 public:
     EditorConfigPlugin(IManager* manager);
-    ~EditorConfigPlugin();
+    ~EditorConfigPlugin() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
     /**
      * @brief Add plugin menu to the "Plugins" menu item in the menu bar
      */
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
 
     /**
      * @brief Unplug the plugin. Perform here any cleanup needed (e.g. unbind events, destroy allocated windows)
      */
-    virtual void UnPlug();
+    void UnPlug() override;
 
     void OnEditorConfigLoading(clEditorConfigEvent& event);
     void OnActiveEditorChanged(wxCommandEvent& event);
