@@ -1,16 +1,19 @@
 #include "ExternalToolsProcessManager.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "StringUtils.h"
+#include "dirsaver.h"
+#include "environmentconfig.h"
 #include "event_notifier.h"
+#include "file_logger.h"
 #include "globals.h"
 #include "imanager.h"
-#include "asyncprocess.h"
 #include "macromanager.h"
-#include "environmentconfig.h"
-#include "processreaderthread.h"
-#include <algorithm>
-#include <wx/utils.h>
-#include <wx/process.h>
+
 #include <wx/msgdlg.h>
-#include "file_logger.h"
+#include <wx/process.h>
+#include <wx/utils.h>
 #ifndef __WXMSW__
 #include <signal.h>
 #endif
@@ -22,8 +25,8 @@
 class ExtToolsMyProcess : public wxProcess
 {
 public:
-    ExtToolsMyProcess() {}
-    virtual ~ExtToolsMyProcess() {}
+    ExtToolsMyProcess() = default;
+    virtual ~ExtToolsMyProcess() = default;
     void OnTerminate(int pid, int status)
     {
         ToolsTaskManager::Instance()->ProcessTerminated(pid);
@@ -71,7 +74,7 @@ void ToolsTaskManager::OnProcessEnd(clProcessEvent& event)
     ProcessTerminated(proc->GetPid());
     delete proc;
 
-    // Notify codelite to test for any modified bufferes
+    // Notify CodeLite to test for any modified buffers
     EventNotifier::Get()->PostReloadExternallyModifiedEvent();
 }
 
@@ -80,22 +83,21 @@ void ToolsTaskManager::OnProcessOutput(clProcessEvent& event)
     clGetManager()->AppendOutputTabText(kOutputTab_Output, event.GetOutput());
 }
 
-void ToolsTaskManager::StartTool(const ToolInfo& ti)
+void ToolsTaskManager::StartTool(const ToolInfo& ti, const wxString& filename)
 {
     wxString command, working_dir;
     command << ti.GetPath();
-    ::WrapWithQuotes(command);
-
-    command << " " << ti.GetArguments();
+    //StringUtils::WrapWithQuotes(command);
+    if(!filename.IsEmpty()) {
+        // If an input file was given, append it to the command
+        command << " " << StringUtils::WrapWithDoubleQuotes(filename);
+    }
     working_dir = ti.GetWd();
-
     command = MacroManager::Instance()->Expand(
-        command,
-        clGetManager(),
+        command, clGetManager(),
         (clGetManager()->GetWorkspace() ? clGetManager()->GetWorkspace()->GetActiveProjectName() : ""));
     working_dir = MacroManager::Instance()->Expand(
-        working_dir,
-        clGetManager(),
+        working_dir, clGetManager(),
         (clGetManager()->GetWorkspace() ? clGetManager()->GetWorkspace()->GetActiveProjectName() : ""));
 
     wxString projectName;
@@ -109,17 +111,13 @@ void ToolsTaskManager::StartTool(const ToolInfo& ti)
     }
 
     EnvSetter envGuard(clGetManager()->GetEnv(), NULL, projectName, configName);
-    //::WrapInShell(command);
-    
     clDEBUG() << "Running command:" << command << clEndl;
-    
+
     int pid = wxNOT_FOUND;
     if(ti.GetCaptureOutput()) {
-        IProcess* proc = ::CreateAsyncProcess(this, command, IProcessCreateConsole, working_dir);
+        IProcess* proc = ::CreateAsyncProcess(this, command, IProcessCreateConsole | IProcessWrapInShell, working_dir);
         if(!proc) {
-            ::wxMessageBox(_("Failed to launch tool\n'") + command + "'",
-                           "CodeLite",
-                           wxICON_ERROR | wxOK | wxCENTER,
+            ::wxMessageBox(_("Failed to launch tool\n'") + command + "'", "CodeLite", wxICON_ERROR | wxOK | wxCENTER,
                            EventNotifier::Get()->TopFrame());
             return;
         }
@@ -127,9 +125,12 @@ void ToolsTaskManager::StartTool(const ToolInfo& ti)
         pid = proc->GetPid();
 
     } else {
+        // Set the working directory and launch the process
+        DirSaver ds;
+        ::wxSetWorkingDirectory(working_dir);
         pid = ::wxExecute(command, wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER, new ExtToolsMyProcess());
     }
-    
+
     if(pid > 0) {
         ExternalToolItemData item(command, pid);
         m_tools.insert(std::make_pair(pid, item));
@@ -145,9 +146,9 @@ void ToolsTaskManager::ProcessTerminated(int pid)
 
 void ToolsTaskManager::StopAll()
 {
-    std::for_each(m_tools.begin(), m_tools.end(), [&](const std::pair<int, ExternalToolItemData> &p) {
+    for (const auto& p : m_tools) {
         ::wxKill(p.second.m_pid, wxSIGKILL, NULL, wxKILL_CHILDREN);
-    });
+    }
 }
 
 void ToolsTaskManager::Stop(int pid)
@@ -162,12 +163,12 @@ ExternalToolItemData::Map_t& ToolsTaskManager::GetTools()
 #ifdef __WXOSX__
     // Check that the processes are still alive before we continue
     ExternalToolItemData::Map_t tools;
-    std::for_each(m_tools.begin(), m_tools.end(), [&](const std::pair<int, ExternalToolItemData> &p) {
+    for (const auto& p : m_tools) {
         if(kill(p.first, 0) == 0) {
             // alive
             tools.insert(p);
         }
-    });
+    }
     m_tools.swap(tools);
 #endif
     return m_tools;
