@@ -26,19 +26,16 @@
 #ifndef __ExternalTools__
 #define __ExternalTools__
 
-#include "plugin.h"
-#include "externaltoolsdata.h"
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
 #include "cl_command_event.h"
-
-class wxToolBar;
-class AsyncExeCmd;
+#include "externaltoolsdata.h"
+#include "plugin.h"
 
 class ExternalToolsPlugin : public IPlugin
 {
-    clToolBar* m_tb;
     wxEvtHandler* topWin;
     wxMenu* m_parentMenu;
+    ExternalToolsData m_externalTools;
 
 protected:
     void OnSettings(wxCommandEvent& e);
@@ -52,15 +49,15 @@ protected:
 
 public:
     ExternalToolsPlugin(IManager* manager);
-    ~ExternalToolsPlugin();
+    ~ExternalToolsPlugin() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void HookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void HookPopupMenu(wxMenu* menu, MenuType type) override;
+    void UnPlug() override;
 };
 
 #endif // ExternalTools
