@@ -23,30 +23,30 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include <wx/msgdlg.h>
 #include "externaltooldlg.h"
 #include "externaltoolsdata.h"
+#include "macrosdlg.h"
 #include "newtooldlg.h"
+#include "windowattrmanager.h"
+#include "workspace.h"
 #include <wx/dirdlg.h>
 #include <wx/filedlg.h>
-#include "macrosdlg.h"
-#include "workspace.h"
-#include "windowattrmanager.h"
+#include <wx/msgdlg.h>
 
 NewToolDlg::NewToolDlg(wxWindow* parent, IManager* mgr, ExternalToolData* data)
     : NewToolBase(parent)
     , m_mgr(mgr)
 {
-    const wxString IdChoices[] = { wxT("external_tool_0"), wxT("external_tool_1"), wxT("external_tool_2"),
-                                   wxT("external_tool_3"), wxT("external_tool_4"), wxT("external_tool_5"),
-                                   wxT("external_tool_6"), wxT("external_tool_7"), wxT("external_tool_8"),
-                                   wxT("external_tool_9") };
-    wxArrayString choices(10, IdChoices);
+    wxArrayString choices;
+    for(size_t i = 0; i < MAX_TOOLS; ++i) {
+        wxString toolId;
+        toolId << "external_tool_" << i;
+        choices.Add(toolId);
+    }
     m_choiceId->Clear();
     m_choiceId->Append(choices);
     m_choiceId->SetFocus();
     if(data) {
-        m_textCtrlArguments->ChangeValue(data->m_args);
         m_choiceId->SetStringSelection(data->m_id);
         m_textCtrlPath->ChangeValue(data->m_path);
         m_textCtrlWd->ChangeValue(data->m_workingDirectory);
@@ -55,6 +55,7 @@ NewToolDlg::NewToolDlg(wxWindow* parent, IManager* mgr, ExternalToolData* data)
         m_textCtrlName->ChangeValue(data->m_name);
         m_checkBoxCaptureOutput->SetValue(data->m_captureOutput);
         m_checkBoxSaveAllFilesBefore->SetValue(data->m_saveAllFiles);
+        m_checkBoxCallOnFileSave->SetValue(data->m_callOnFileSave);
         m_choiceId->Enable(false);
     }
     GetSizer()->Fit(this);
@@ -65,11 +66,9 @@ void NewToolDlg::OnButtonBrowsePath(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxString path = m_textCtrlPath->GetValue();
-    wxString new_path = wxFileSelector(
-        _("Select a program:"), path.c_str(), wxT(""), wxT(""), wxFileSelectorDefaultWildcardStr, 0, this);
-    if(new_path.IsEmpty() == false) {
-        m_textCtrlPath->SetValue(new_path);
-    }
+    wxString new_path = wxFileSelector(_("Select a program:"), path.c_str(), wxT(""), wxT(""),
+                                       wxFileSelectorDefaultWildcardStr, 0, this);
+    if(new_path.IsEmpty() == false) { m_textCtrlPath->SetValue(new_path); }
 }
 
 void NewToolDlg::OnButtonBrowseWD(wxCommandEvent& event)
@@ -77,10 +76,8 @@ void NewToolDlg::OnButtonBrowseWD(wxCommandEvent& event)
     wxUnusedVar(event);
     wxString path(m_textCtrlWd->GetValue());
     wxString new_path =
-        wxDirSelector(_("Select working directory:"), path, wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
-    if(new_path.IsEmpty() == false) {
-        m_textCtrlWd->SetValue(new_path);
-    }
+        wxDirSelector(_("Select a working directory:"), path, wxDD_DEFAULT_STYLE, wxDefaultPosition, this);
+    if(new_path.IsEmpty() == false) { m_textCtrlWd->SetValue(new_path); }
 }
 
 void NewToolDlg::OnButtonHelp(wxCommandEvent& event)
@@ -114,9 +111,7 @@ void NewToolDlg::OnButtonBrowseIcon16(wxCommandEvent& event)
     wxString path = m_textCtrlIcon16->GetValue();
     wxString new_path =
         wxFileSelector(_("Select an icon:"), path.c_str(), wxT(""), wxT(""), wxFileSelectorDefaultWildcardStr, 0, this);
-    if(new_path.IsEmpty() == false) {
-        m_textCtrlIcon16->SetValue(new_path);
-    }
+    if(new_path.IsEmpty() == false) { m_textCtrlIcon16->SetValue(new_path); }
 }
 
 void NewToolDlg::OnButtonBrowseIcon24(wxCommandEvent& event)
@@ -125,11 +120,13 @@ void NewToolDlg::OnButtonBrowseIcon24(wxCommandEvent& event)
     wxString path = m_textCtrlIcon24->GetValue();
     wxString new_path =
         wxFileSelector(_("Select an icon:"), path.c_str(), wxT(""), wxT(""), wxFileSelectorDefaultWildcardStr, 0, this);
-    if(new_path.IsEmpty() == false) {
-        m_textCtrlIcon24->SetValue(new_path);
-    }
+    if(new_path.IsEmpty() == false) { m_textCtrlIcon24->SetValue(new_path); }
 }
 
-NewToolDlg::~NewToolDlg() {}
-
 void NewToolDlg::OnIdSelected(wxCommandEvent& event) {}
+
+void NewToolDlg::OnButtonOkUI(wxUpdateUIEvent& event)
+{
+    event.Enable((m_choiceId->GetSelection() != wxNOT_FOUND) && !m_textCtrlName->IsEmpty() &&
+                 !m_textCtrlPath->IsEmpty());
+}
