@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : new_class_dlg_data.cpp
 //
 // -------------------------------------------------------------------------
@@ -26,20 +26,10 @@
 #include "new_class_dlg_data.h"
 
 NewClassDlgData::NewClassDlgData()
-	: m_flags(UseUnderscores )
+    : m_flags(UseUnderscores | HppHeader)
 {
 }
 
-NewClassDlgData::~NewClassDlgData()
-{
-}
+void NewClassDlgData::DeSerialize(Archive& arch) { arch.Read(wxT("m_flags"), m_flags); }
 
-void NewClassDlgData::DeSerialize(Archive& arch)
-{
-	arch.Read(wxT("m_flags"), m_flags);
-}
-
-void NewClassDlgData::Serialize(Archive& arch)
-{
-	arch.Write(wxT("m_flags"), m_flags);
-}
+void NewClassDlgData::Serialize(Archive& arch) { arch.Write(wxT("m_flags"), m_flags); }
