@@ -26,10 +26,15 @@
 #ifndef IWORKSPACE_H
 #define IWORKSPACE_H
 
-#include <wx/string.h>
-#include <wx/filename.h>
+#include "AsyncProcess/asyncprocess.h"
+
 #include <list>
+#include <optional>
 #include <wx/event.h>
+#include <wx/filename.h>
+#include <wx/string.h>
+
+class IEditor;
 
 /**
  * @class IWorkspace
@@ -42,17 +47,27 @@ protected:
     wxString m_workspaceType;
 
 public:
-    typedef std::list<IWorkspace*> List_t;
+    using List_t = std::list<IWorkspace*>;
 
 public:
-    IWorkspace() {}
-    virtual ~IWorkspace() {}
+    IWorkspace() = default;
+    ~IWorkspace() override = default;
 
     /**
-     * @brief return the project file
+     * @brief return the workspace name
      */
-    virtual wxFileName GetFileName() const = 0;
-    
+    virtual wxString GetName() const = 0;
+
+    /**
+     * @brief return the workspace file full path
+     */
+    virtual wxString GetFileName() const = 0;
+
+    /**
+     * @brief return the workspace directory
+     */
+    virtual wxString GetDir() const = 0;
+
     /**
      * @brief set the workspace type
      * For example: "C++ Workspace", "PHP Workspace" etc
@@ -64,6 +79,12 @@ public:
      */
     const wxString& GetWorkspaceType() const { return m_workspaceType; }
 
+    /**
+     * @brief return the currently selected debugger. i.e. if the user hit F7
+     * this debugger will be activated
+     */
+    virtual wxString GetDebuggerName() const = 0;
+
     /**
      * @brief is this workspace support the build concept?
      * e.g. for C++ workspace, the answer is 'true', for PHP workspace, this will be 'false'
@@ -83,7 +104,7 @@ public:
     /**
      * @brief return the project name of a file.
      * If the workspace does not support projects, return an empty string
-     * If the we could not match a project for the given filename, return empty string
+     * If we could not match a project for the given filename, return empty string
      */
     virtual wxString GetProjectFromFile(const wxFileName& filename) const = 0;
 
@@ -93,12 +114,59 @@ public:
      */
     virtual void GetWorkspaceFiles(wxArrayString& files) const = 0;
     /**
-     * @brief return list of files belonged to the prokect. If the workspace does not support
+     * @brief return list of files belonged to the project. If the workspace does not support
      * projects, do not modify 'files'
      * @param projectName the project name
      * @param files [output] list of files in absolute path
      */
     virtual void GetProjectFiles(const wxString& projectName, wxArrayString& files) const = 0;
+
+    /**
+     * @brief return the active project name. For workspace that does not support
+     * projects, return an empty string
+     */
+    virtual wxString GetActiveProjectName() const = 0;
+
+    /**
+     * @brief set the active project
+     */
+    virtual void SetProjectActive(const wxString& project) = 0;
+
+    /**
+     * @brief return the underlying file for a given project name
+     */
+    virtual wxFileName GetProjectFileName(const wxString& projectName) const = 0;
+
+    /**
+     * @brief return list of projects for this workspace
+     */
+    virtual wxArrayString GetWorkspaceProjects() const = 0;
+
+    /**
+     * @brief return true if this workspace is a remote one
+     */
+    virtual bool IsRemote() const { return false; }
+    /**
+     * @brief return the ssh account used by this workspace
+     */
+    virtual wxString GetSshAccount() const { return ""; }
+
+    /**
+     * @brief return the environment for the workspace
+     */
+    virtual clEnvList_t GetEnvironment() const { return {}; }
+
+    /// Return the workspace specific indentation width
+    virtual int GetIndentWidth() { return wxNOT_FOUND; }
+
+    /// Open (or create if missing) `filepath` and load it into an editor.
+    virtual IEditor* OpenFileInEditor(const wxString& filepath, bool createIfMissing = true) = 0;
+
+    /// Open (create if missing) `filename` and load it into an editor. The file is searched (or created)
+    /// inside the workspace private folder (i.e. `.codelite`).
+    /// `filename`: the file name to open or create. It must not contain the path, only name + extension, e.g.
+    /// `codelite-remote.json`
+    virtual IEditor* CreateOrOpenSettingFile(const wxString& filename) = 0;
 };
 
 #endif // IWORKSPACE_H
