@@ -32,20 +32,20 @@
 #endif
 #endif
 
-#include <wx/app.h>
-#include "imanager.h"
-#include "wx/toolbar.h"
-#include <wx/pen.h>
-#include "cl_aui_tb_are.h"
+#include "clAuiToolBarArt.h"
+#include "clToolBar.h"
 #include "cl_defs.h"
-#if USE_AUI_TOOLBAR
-#include <wx/aui/auibar.h>
-#endif
-#include "wx/event.h"
-#include "wx/notebook.h"
-#include "plugindata.h"
-#include "plugin_version.h"
 #include "codelite_events.h"
+#include "imanager.h"
+#include "plugin_version.h"
+#include "plugindata.h"
+
+#include <wx/app.h>
+#include <wx/event.h>
+#include <wx/menu.h>
+#include <wx/notebook.h>
+#include <wx/pen.h>
+#include <wx/toolbar.h>
 
 #ifdef _WIN32
 #define STDCALL __stdcall
@@ -55,12 +55,7 @@
 #define EXPORT
 #endif
 
-#if defined(__WXMSW__) || defined(__WXGTK__)
 #define CL_PLUGIN_API extern "C" EXPORT
-#else 
-// OSX
-#define CL_PLUGIN_API extern "C" EXPORT
-#endif
 
 class IManager;
 
@@ -93,18 +88,37 @@ class IPlugin : public wxEvtHandler
 protected:
     wxString m_shortName;
     wxString m_longName;
-    IManager* m_mgr;
+    IManager* m_mgr = nullptr;
+    wxMenu* m_pluginsMenu = nullptr;
+
+protected:
+    /**
+     * @brief delete plugin's menu from the menu bar
+     */
+    void DeletePluginMenu(wxWindowID id)
+    {
+        if (!GetPluginsMenu()) {
+            return;
+        }
+        if (GetPluginsMenu()->FindItem(id)) {
+            GetPluginsMenu()->Delete(id);
+        }
+    }
 
 public:
     IPlugin(IManager* manager)
         : m_mgr(manager)
     {
     }
-    virtual ~IPlugin() {}
+    ~IPlugin() override = default;
 
     //-----------------------------------------------
     // The interface
     //-----------------------------------------------
+    void SetPluginsMenu(wxMenu* menu) { m_pluginsMenu = menu; }
+    const wxMenu* GetPluginsMenu() const { return m_pluginsMenu; }
+    wxMenu* GetPluginsMenu() { return m_pluginsMenu; }
+
     /**
      * @brief return the plugin's short name
      * @return
@@ -117,13 +131,10 @@ public:
     virtual const wxString& GetLongName() const { return m_longName; }
 
     /**
-     * When LiteEditor loads all the plugins, this function is called. If toolbar
-     * is provided by the plugin, the Plugin Manager will palce it in the appropriate
-     * place on the toolbar pane.
-     * \param parent toolbar parent, usually this is the main frame
-     * \return toolbar or NULL
+     * When CodeLite loads all the plugins, this function is called.
+     * \param toolbar
      */
-    virtual clToolBar* CreateToolBar(wxWindow* parent) = 0;
+    virtual void CreateToolBar(clToolBarGeneric* toolbar) = 0;
 
     /**
      * Every plugin can place a sub menu in the 'Plugins' Menu at the menu bar
@@ -149,33 +160,6 @@ public:
         wxUnusedVar(menu);
     };
 
-    /**
-     * @brief load image file from /path/to/install/plugins/resources/
-     * @param name file name (name+extension)
-     * @return Bitmap of wxNullBitmap if no match was found
-     */
-    virtual wxBitmap LoadBitmapFile(const wxString& name, wxBitmapType type = wxBITMAP_TYPE_PNG)
-    {
-        wxBitmap bmp;
-#ifdef __WXGTK__
-        // /usr/share/codelite
-        wxString pluginsDir = clStandardPaths::Get().GetDataDir();
-#else
-#ifdef USE_POSIX_LAYOUT
-        wxString pluginsDir(clStandardPaths::Get().GetDataDir() + wxT(PLUGINS_DIR));
-#else
-        wxString pluginsDir(m_mgr->GetInstallDirectory() + wxT("/plugins"));
-#endif
-#endif
-        wxString basePath(pluginsDir + wxT("/resources/"));
-
-        bmp.LoadFile(basePath + name, type);
-        if(bmp.IsOk()) {
-            return bmp;
-        }
-        return wxNullBitmap;
-    }
-
     /**
      * @brief allow the plugins to hook a tab in the project settings
      * @param notebook the parent
@@ -203,13 +187,14 @@ public:
     }
 };
 
-#define CHECK_CL_SHUTDOWN()                       \
-    {                                             \
-        if(m_mgr->IsShutdownInProgress()) return; \
+#define CHECK_CL_SHUTDOWN()                \
+    {                                      \
+        if (m_mgr->IsShutdownInProgress()) \
+            return;                        \
     }
 
 // Every dll must contain at least this function
-typedef IPlugin* (*GET_PLUGIN_CREATE_FUNC)(IManager*);
-typedef PluginInfo* (*GET_PLUGIN_INFO_FUNC)();
-typedef int (*GET_PLUGIN_INTERFACE_VERSION_FUNC)();
+using GET_PLUGIN_CREATE_FUNC = IPlugin* (*)(IManager*);
+using GET_PLUGIN_INFO_FUNC = PluginInfo* (*)();
+using GET_PLUGIN_INTERFACE_VERSION_FUNC = int (*)();
 #endif // PLUGIN_H
