@@ -23,11 +23,12 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "ContextJavaScript.h"
-#include "cl_editor.h"
-#include "editor_config.h"
-#include "cl_editor_tip_window.h"
 
-ContextJavaScript::ContextJavaScript(LEditor* editor)
+#include "cl_editor.h"
+#include "cl_editor_tip_window.h"
+#include "editor_config.h"
+
+ContextJavaScript::ContextJavaScript(clEditor* editor)
     : ContextBase(editor)
 {
     editor->SetWordChars(wxT("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_$"));
@@ -40,21 +41,19 @@ ContextJavaScript::ContextJavaScript()
 {
 }
 
-ContextJavaScript::~ContextJavaScript() {}
-
 void ContextJavaScript::AddMenuDynamicContent(wxMenu* menu) { wxUnusedVar(menu); }
 
 void ContextJavaScript::ApplySettings()
 {
     SetName(wxT("javascript"));
     LexerConf::Ptr_t lexPtr;
-    if(EditorConfigST::Get()->IsOk()) {
+    if (EditorConfigST::Get()->IsOk()) {
         lexPtr = EditorConfigST::Get()->GetLexer(GetName());
     }
-    LEditor& rCtrl = GetCtrl();
-    if(lexPtr) {
+    clEditor& rCtrl = GetCtrl();
+    if (lexPtr) {
         rCtrl.SetLexer(lexPtr->GetLexerId());
-        for(int i = 0; i <= 4; ++i) {
+        for (int i = 0; i <= 4; ++i) {
             wxString keyWords = lexPtr->GetKeyWords(i);
             keyWords.Replace(wxT("\n"), wxT(" "));
             keyWords.Replace(wxT("\r"), wxT(" "));
@@ -68,27 +67,27 @@ void ContextJavaScript::ApplySettings()
 
 void ContextJavaScript::AutoIndent(const wxChar& nChar)
 {
-    LEditor& rCtrl = GetCtrl();
+    clEditor& rCtrl = GetCtrl();
 
-    if(rCtrl.GetDisableSmartIndent()) {
+    if (rCtrl.GetDisableSmartIndent()) {
         return;
     }
-    if(rCtrl.GetLineIndentation(rCtrl.GetCurrentLine()) && nChar == wxT('\n')) {
+    if (rCtrl.GetLineIndentation(rCtrl.GetCurrentLine()) && nChar == wxT('\n')) {
         return;
     }
 
     int curpos = rCtrl.GetCurrentPos();
-    if(IsCommentOrString(curpos) && nChar == wxT('\n')) {
+    if (IsCommentOrString(curpos) && nChar == wxT('\n')) {
         AutoAddComment();
         return;
     }
 
-    if(IsCommentOrString(curpos)) {
+    if (IsCommentOrString(curpos)) {
         ContextBase::AutoIndent(nChar);
         return;
     }
     int line = rCtrl.LineFromPosition(curpos);
-    if(nChar == wxT('\n')) {
+    if (nChar == wxT('\n')) {
 
         int prevpos(wxNOT_FOUND);
         int foundPos(wxNOT_FOUND);
@@ -98,7 +97,7 @@ void ContextJavaScript::AutoIndent(const wxChar& nChar)
         word = rCtrl.PreviousWord(curpos, foundPos);
 
         // user hit ENTER after 'else'
-        if(word == wxT("else")) {
+        if (word == wxT("else")) {
             int prevLine = rCtrl.LineFromPosition(prevpos);
             rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
             rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
@@ -106,19 +105,19 @@ void ContextJavaScript::AutoIndent(const wxChar& nChar)
             return;
         }
 
-        // User typed 'ENTER' immediatly after closing brace ')'
-        if(prevpos != wxNOT_FOUND && ch == wxT(')')) {
+        // User typed 'ENTER' immediately after closing brace ')'
+        if (prevpos != wxNOT_FOUND && ch == wxT(')')) {
 
             long openBracePos(wxNOT_FOUND);
             int posWordBeforeOpenBrace(wxNOT_FOUND);
 
-            if(rCtrl.MatchBraceBack(wxT(')'), prevpos, openBracePos)) {
+            if (rCtrl.MatchBraceBack(wxT(')'), prevpos, openBracePos)) {
                 rCtrl.PreviousChar(openBracePos, posWordBeforeOpenBrace);
-                if(posWordBeforeOpenBrace != wxNOT_FOUND) {
+                if (posWordBeforeOpenBrace != wxNOT_FOUND) {
                     word = rCtrl.PreviousWord(posWordBeforeOpenBrace, foundPos);
 
-                    // c++ expression with single line and should be treated separatly
-                    if(word == wxT("if") || word == wxT("while") || word == wxT("for")) {
+                    // c++ expression with single line and should be treated separately
+                    if (word == wxT("if") || word == wxT("while") || word == wxT("for")) {
                         int prevLine = rCtrl.LineFromPosition(prevpos);
                         rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
                         rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
@@ -130,7 +129,7 @@ void ContextJavaScript::AutoIndent(const wxChar& nChar)
         }
 
         // use the previous line indentation level
-        if(prevpos == wxNOT_FOUND || ch != wxT('{') || IsCommentOrString(prevpos)) {
+        if (prevpos == wxNOT_FOUND || ch != wxT('{') || IsCommentOrString(prevpos)) {
             ContextBase::AutoIndent(nChar);
             return;
         }
@@ -140,22 +139,24 @@ void ContextJavaScript::AutoIndent(const wxChar& nChar)
         rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
         rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
 
-    } else if(nChar == wxT('}')) {
+    } else if (nChar == wxT('}')) {
 
         long matchPos = wxNOT_FOUND;
-        if(!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos)) return;
+        if (!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos))
+            return;
         int secondLine = rCtrl.LineFromPosition(matchPos);
-        if(secondLine == line) return;
+        if (secondLine == line)
+            return;
         rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(secondLine));
 
-    } else if(nChar == wxT('{')) {
+    } else if (nChar == wxT('{')) {
         wxString lineString = rCtrl.GetLine(line);
         lineString.Trim().Trim(false);
 
         int matchPos = wxNOT_FOUND;
         wxChar previousChar = rCtrl.PreviousChar(rCtrl.PositionBefore(curpos), matchPos);
-        if(previousChar != wxT('{') && lineString == wxT("{")) {
-            // indent this line accroding to the previous line
+        if (previousChar != wxT('{') && lineString == wxT("{")) {
+            // indent this line according to the previous line
             int line = rCtrl.LineFromPosition(rCtrl.GetCurrentPos());
             rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(line - 1));
             rCtrl.ChooseCaretX();
@@ -168,10 +169,6 @@ void ContextJavaScript::AutoIndent(const wxChar& nChar)
 
 wxString ContextJavaScript::CallTipContent() { return wxEmptyString; }
 
-void ContextJavaScript::CodeComplete(long pos) {}
-
-void ContextJavaScript::CompleteWord() {}
-
 int ContextJavaScript::DoGetCalltipParamterIndex() { return ContextBase::DoGetCalltipParamterIndex(); }
 
 wxString ContextJavaScript::GetCurrentScopeName() { return wxT(""); }
@@ -180,10 +177,6 @@ wxMenu* ContextJavaScript::GetMenu() { return ContextBase::GetMenu(); }
 
 TagEntryPtr ContextJavaScript::GetTagAtCaret(bool scoped, bool impl) { return NULL; }
 
-void ContextJavaScript::GoHyperlink(int start, int end, int type, bool alt) {}
-
-void ContextJavaScript::GotoDefinition() {}
-
 void ContextJavaScript::GotoPreviousDefintion() {}
 
 bool ContextJavaScript::IsCommentOrString(long pos)
@@ -194,7 +187,7 @@ bool ContextJavaScript::IsCommentOrString(long pos)
 
 bool ContextJavaScript::IsDefaultContext() const { return false; }
 
-ContextBase* ContextJavaScript::NewInstance(LEditor* container) { return new ContextJavaScript(container); }
+ContextBase* ContextJavaScript::NewInstance(clEditor* container) { return new ContextJavaScript(container); }
 
 void ContextJavaScript::OnCallTipClick(wxStyledTextEvent& event) {}
 
@@ -212,12 +205,12 @@ void ContextJavaScript::OnEnterHit() {}
 
 void ContextJavaScript::OnFileSaved() {}
 
-void ContextJavaScript::OnKeyDown(wxKeyEvent& event) { event.Skip(); }
+void ContextJavaScript::OnKeyDown(wxKeyEvent& event) { ContextBase::OnKeyDown(event); }
 
 void ContextJavaScript::OnSciUpdateUI(wxStyledTextEvent& event)
 {
-    LEditor& ctrl = GetCtrl();
-    if(ctrl.GetFunctionTip()->IsActive()) {
+    clEditor& ctrl = GetCtrl();
+    if (ctrl.GetFunctionTip()->IsActive()) {
         ctrl.GetFunctionTip()->Highlight(DoGetCalltipParamterIndex());
     }
 }
@@ -230,16 +223,16 @@ void ContextJavaScript::SemicolonShift()
 {
     int foundPos(wxNOT_FOUND);
     int semiColonPos(wxNOT_FOUND);
-    LEditor& ctrl = GetCtrl();
-    if(ctrl.NextChar(ctrl.GetCurrentPos(), semiColonPos) == wxT(')')) {
+    clEditor& ctrl = GetCtrl();
+    if (ctrl.NextChar(ctrl.GetCurrentPos(), semiColonPos) == wxT(')')) {
 
         // test to see if we are inside a 'for' statement
         long openBracePos(wxNOT_FOUND);
         int posWordBeforeOpenBrace(wxNOT_FOUND);
 
-        if(ctrl.MatchBraceBack(wxT(')'), semiColonPos, openBracePos)) {
+        if (ctrl.MatchBraceBack(wxT(')'), semiColonPos, openBracePos)) {
             ctrl.PreviousChar(openBracePos, posWordBeforeOpenBrace);
-            if(posWordBeforeOpenBrace != wxNOT_FOUND) {
+            if (posWordBeforeOpenBrace != wxNOT_FOUND) {
                 wxString word = ctrl.PreviousWord(posWordBeforeOpenBrace, foundPos);
 
                 // At the current pos, we got a ';'
@@ -269,15 +262,15 @@ int ContextJavaScript::GetActiveKeywordSet() const { return wxNOT_FOUND; }
 
 bool ContextJavaScript::IsAtBlockComment() const
 {
-    int curpos = GetCtrl().GetCurrentPos();
-    int cur_style = GetCtrl().GetStyleAt(curpos);
+    int pos = PositionBeforeCurrent();
+    int cur_style = GetCtrl().GetStyleAt(pos);
     return cur_style == wxSTC_C_COMMENT || cur_style == wxSTC_C_COMMENTDOC || cur_style == wxSTC_C_COMMENTDOCKEYWORD ||
            cur_style == wxSTC_C_COMMENTDOCKEYWORDERROR;
 }
 
 bool ContextJavaScript::IsAtLineComment() const
 {
-    int curpos = GetCtrl().GetCurrentPos();
-    int cur_style = GetCtrl().GetStyleAt(curpos);
+    int pos = PositionBeforeCurrent();
+    int cur_style = GetCtrl().GetStyleAt(pos);
     return cur_style == wxSTC_C_COMMENTLINE || cur_style == wxSTC_C_COMMENTLINEDOC;
 }
