@@ -31,28 +31,24 @@ class ContextJavaScript : public ContextBase
 {
 public:
     ContextJavaScript();
-    ContextJavaScript(LEditor *Editor);
-    virtual ~ContextJavaScript();
+    ContextJavaScript(clEditor* Editor);
+    virtual ~ContextJavaScript() = default;
 
 public:
     virtual int GetActiveKeywordSet() const;
-    virtual int  DoGetCalltipParamterIndex();
+    virtual int DoGetCalltipParamterIndex();
     virtual wxMenu* GetMenu();
     virtual void AddMenuDynamicContent(wxMenu* menu);
     virtual void ApplySettings();
     virtual void AutoIndent(const wxChar&);
     virtual wxString CallTipContent();
-    virtual void CodeComplete(long pos = wxNOT_FOUND);
-    virtual void CompleteWord();
     virtual wxString GetCurrentScopeName();
     virtual TagEntryPtr GetTagAtCaret(bool scoped, bool impl);
-    virtual void GoHyperlink(int start, int end, int type, bool alt);
-    virtual void GotoDefinition();
     virtual void GotoPreviousDefintion();
     virtual bool IsComment(long pos);
     virtual bool IsCommentOrString(long pos);
     virtual bool IsDefaultContext() const;
-    virtual ContextBase* NewInstance(LEditor* container);
+    virtual ContextBase* NewInstance(clEditor* container);
     virtual void OnCallTipClick(wxStyledTextEvent& event);
     virtual void OnCalltipCancel();
     virtual void OnDbgDwellEnd(wxStyledTextEvent& event);
