@@ -26,18 +26,12 @@
 #ifndef EDITOROPTIONSGENERALEDIT_H
 #define EDITOROPTIONSGENERALEDIT_H
 
-#include "editoroptionsgeneralguidespanelbase.h"
-#include "treebooknodebase.h"
-#include "optionsconfig.h"
+#include "OptionsConfigPage.hpp"
 
-class EditorOptionsGeneralEdit : public EditorOptionsGeneralEditBase,
-                                 public TreeBookNode<EditorOptionsGeneralEdit>
+class EditorOptionsGeneralEdit : public OptionsConfigPage
 {
 public:
-    EditorOptionsGeneralEdit(wxWindow* parent);
-    virtual ~EditorOptionsGeneralEdit();
-    void Save(OptionsConfigPtr options);
-protected:
-    virtual void OnValueChanged(wxPropertyGridEvent& event);
+    EditorOptionsGeneralEdit(wxWindow* parent, OptionsConfigPtr options);
+    virtual ~EditorOptionsGeneralEdit() = default;
 };
 #endif // EDITOROPTIONSGENERALEDIT_H
