@@ -6,12 +6,11 @@ NewThemeDialog::NewThemeDialog(wxWindow* parent, LexerConf::Ptr_t lexer)
     : NewThemeDialogBase(parent)
 {
     Center();
-    WindowAttrManager::Load(this, "NewThemeDialog");
+    SetName("NewThemeDialog");
+    WindowAttrManager::Load(this);
     DoInitialize(lexer);
 }
 
-NewThemeDialog::~NewThemeDialog() { WindowAttrManager::Save(this, "NewThemeDialog"); }
-
 void NewThemeDialog::OnOkUI(wxUpdateUIEvent& event) { event.Enable(!m_textCtrlName->IsEmpty()); }
 
 void NewThemeDialog::OnLexerSelected(wxCommandEvent& event)
