@@ -23,15 +23,18 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "acceltabledlg.h"
+
+#include "Keyboard/newkeyshortcutdlg.h"
 #include "fileutils.h"
 #include "globals.h"
 #include "manager.h"
-#include "newkeyshortcutdlg.h"
 #include "pluginmanager.h"
 #include "windowattrmanager.h"
+
 #include <algorithm>
 #include <wx/ffile.h>
 #include <wx/imaglist.h>
+#include <wx/msgdlg.h>
 #include <wx/stdpaths.h>
 #include <wx/tokenzr.h>
 
@@ -42,10 +45,6 @@
 AccelTableDlg::AccelTableDlg(wxWindow* parent)
     : AccelTableBaseDlg(parent)
 {
-    wxImageList* imageList = new wxImageList(16, 16);
-    imageList->Add(PluginManager::Get()->GetStdIcons()->LoadBitmap("list-control/16/sort"));
-    imageList->Add(PluginManager::Get()->GetStdIcons()->LoadBitmap("list-control/16/sort"));
-
     clKeyboardManager::Get()->GetAllAccelerators(m_accelMap);
     PopulateTable("");
 
@@ -66,10 +65,11 @@ void AccelTableDlg::PopulateTable(const wxString& filter)
     if(filter.IsEmpty()) {
         filteredMap = m_accelMap;
     } else {
-        for(MenuItemDataMap_t::iterator iter = m_accelMap.begin(); iter != m_accelMap.end(); ++iter) {
-            if(!IsMatchesFilter(filter, iter->second))
+        for (const auto& p : m_accelMap) {
+            if (!IsMatchesFilter(filter, p.second)) {
                 continue;
-            filteredMap.insert(std::make_pair(iter->first, iter->second));
+            }
+            filteredMap.insert(p);
         }
     }
 
@@ -78,19 +78,11 @@ void AccelTableDlg::PopulateTable(const wxString& filter)
     }
 
     // Add core entries
-    std::vector<std::tuple<wxString, wxString, AccelItemData*>> V;
-    for(MenuItemDataMap_t::const_iterator iter = filteredMap.begin(); iter != filteredMap.end(); ++iter) {
-        const MenuItemData& mid = iter->second;
-
-        wxString desc;
-        wxArrayString parts = wxStringTokenize(mid.parentMenu, ":", wxTOKEN_STRTOK);
-
-        if(parts.empty()) {
-            desc << "Global Accelerator | ";
-        } else {
-            for(const wxString& word : parts) {
-                desc << word << " | ";
-            }
+    std::vector<std::tuple<wxString, clKeyboardShortcut, AccelItemData*>> V;
+    for (const auto& [_, mid] : filteredMap) {
+        wxString desc = mid.parentMenu;
+        if(!desc.IsEmpty()) {
+            desc << " | ";
         }
         desc << mid.action;
         V.push_back(std::make_tuple(desc, mid.accel, new AccelItemData(mid)));
@@ -98,16 +90,16 @@ void AccelTableDlg::PopulateTable(const wxString& filter)
 
     // Sort the items in the list, based on the description
     std::sort(V.begin(), V.end());
-    std::for_each(V.begin(), V.end(), [&](const std::tuple<wxString, wxString, AccelItemData*>& entry) {
+    for(const std::tuple<wxString, clKeyboardShortcut, AccelItemData*>& entry : V) {
         const wxString& desc = std::get<0>(entry);
-        const wxString& shortcut = std::get<1>(entry);
+        const clKeyboardShortcut& shortcut = std::get<1>(entry);
         AccelItemData* itemData = std::get<2>(entry);
 
         wxVector<wxVariant> cols;
-        cols.push_back(shortcut);
+        cols.push_back(shortcut.DisplayString());
         cols.push_back(desc);
         m_dvListCtrl->AppendItem(cols, (wxUIntPtr)itemData);
-    });
+    }
 }
 
 void AccelTableDlg::OnButtonOk(wxCommandEvent& e)
@@ -140,8 +132,9 @@ void AccelTableDlg::DoItemActivated()
     CHECK_ITEM_RET(sel);
 
     AccelItemData* itemData = DoGetItemData(sel);
-    if(!itemData)
+    if(!itemData) {
         return;
+    }
 
     // build the selected entry
     MenuItemData mid = itemData->m_menuItemData;
@@ -153,8 +146,8 @@ void AccelTableDlg::DoItemActivated()
                 return;
             }
             if(wxMessageBox(wxString::Format(_("'%s' is already assigned to: '%s'\nWould you like to replace it?"),
-                                             mid.accel, who.action),
-                            _("CodeLite"), wxYES_NO | wxCENTER | wxICON_QUESTION, this) != wxYES) {
+                                             mid.accel.ToString(), who.action),
+                            wxT("CodeLite"), wxYES_NO | wxCENTER | wxICON_QUESTION, this) != wxYES) {
                 return;
             }
 
@@ -165,7 +158,7 @@ void AccelTableDlg::DoItemActivated()
                 if(cd) {
                     cd->m_menuItemData.accel.Clear();
                     int row = m_dvListCtrl->ItemToRow(oldItem);
-                    m_dvListCtrl->SetValue(wxString(), row, 2);
+                    m_dvListCtrl->SetValue(wxString(), row, 0);
                 }
             }
 
@@ -180,9 +173,10 @@ void AccelTableDlg::DoItemActivated()
 
         // Update the UI
         int row = m_dvListCtrl->ItemToRow(sel);
-        if(row == wxNOT_FOUND)
+        if(row == wxNOT_FOUND) {
             return;
-        m_dvListCtrl->SetValue(mid.accel, row, 0);
+        }
+        m_dvListCtrl->SetValue(mid.accel.ToString(), row, 0);
 
         // and update the map
         MenuItemDataMap_t::iterator iter = m_accelMap.find(itemData->m_menuItemData.resourceID);
@@ -198,8 +192,6 @@ void AccelTableDlg::OnText(wxCommandEvent& event)
     CallAfter(&AccelTableDlg::PopulateTable, m_textCtrlFilter->GetValue());
 }
 
-AccelTableDlg::~AccelTableDlg() {}
-
 void AccelTableDlg::OnDVItemActivated(wxDataViewEvent& event)
 {
     wxUnusedVar(event);
@@ -212,23 +204,25 @@ bool AccelTableDlg::IsMatchesFilter(const wxString& filter, const MenuItemData&
 {
     wxString lcFilter = filter.Lower();
     lcFilter.Trim().Trim(false);
-    if(lcFilter.IsEmpty())
+    if(lcFilter.IsEmpty()) {
         return true;
+    }
 
     wxString parentMenu = item.parentMenu;
 
     wxString haystack;
-    haystack << parentMenu << " " << item.accel << " " << item.action;
+    haystack << parentMenu << " " << item.accel.ToString() << " " << item.action;
     return FileUtils::FuzzyMatch(filter, haystack);
 }
 
-bool AccelTableDlg::HasAccelerator(const wxString& accel, MenuItemData& who)
+bool AccelTableDlg::HasAccelerator(const clKeyboardShortcut& accel, MenuItemData& who)
 {
-    if(accel.IsEmpty())
+    if(!accel.IsOk()) {
         return false;
-    for(MenuItemDataMap_t::iterator iter = m_accelMap.begin(); iter != m_accelMap.end(); ++iter) {
-        if(iter->second.accel == accel) {
-            who = iter->second;
+    }
+    for (const auto& p : m_accelMap) {
+        if (p.second.accel == accel) {
+            who = p.second;
             return true;
         }
     }
@@ -244,12 +238,14 @@ wxDataViewItem AccelTableDlg::FindAccel(const MenuItemData& mid)
 {
     for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         wxDataViewItem item = m_dvListCtrl->RowToItem(i);
-        if(!item.IsOk())
+        if(!item.IsOk()) {
             continue;
+        }
 
         AccelItemData* cd = DoGetItemData(item);
-        if(cd && cd->m_menuItemData.accel == mid.accel)
+        if(cd && cd->m_menuItemData.accel == mid.accel) {
             return item;
+        }
     }
     return wxDataViewItem();
 }
