@@ -26,24 +26,15 @@
 #define __acceltabledlg__
 
 #include "AccelTableBaseDlg.h"
+#include "Keyboard/clKeyboardManager.h"
+
 #include <map>
 #include <vector>
-#include "clKeyboardManager.h"
 
 struct AccelItemData : public wxClientData {
     MenuItemData m_menuItemData;
-    bool m_isParent;
-    wxString m_displayName;
-    AccelItemData(const wxString& displayName)
-        : m_isParent(true)
-        , m_displayName(displayName)
-    {
-    }
-
-    AccelItemData(const MenuItemData& data, bool isParent, const wxString& displayName)
+    AccelItemData(const MenuItemData& data)
         : m_menuItemData(data)
-        , m_isParent(isParent)
-        , m_displayName(displayName)
     {
     }
 };
@@ -57,7 +48,7 @@ protected:
     virtual void OnDVItemActivated(wxDataViewEvent& event);
 
     // Handlers for AccelTableBaseDlg events
-    void PopulateTable(const wxString& filter = "");
+    void PopulateTable(const wxString& filter);
     void OnButtonOk(wxCommandEvent& e);
     void OnButtonDefaults(wxCommandEvent& e);
     void OnEditButton(wxCommandEvent& e);
@@ -65,15 +56,14 @@ protected:
 
     void DoItemActivated();
     bool IsMatchesFilter(const wxString& filter, const MenuItemData& item);
-    bool HasAccelerator(const wxString& accel, MenuItemData& who);
-    wxDataViewItem DoAddParentNode(std::map<wxString, wxDataViewItem>& parentsMap, const wxString& parentKey);
+    bool HasAccelerator(const clKeyboardShortcut& accel, MenuItemData& who);
     AccelItemData* DoGetItemData(const wxDataViewItem& item);
     wxDataViewItem FindAccel(const MenuItemData& mid);
 
 public:
     /** Constructor */
     AccelTableDlg(wxWindow* parent);
-    virtual ~AccelTableDlg();
+    virtual ~AccelTableDlg() = default;
 };
 
 #endif // __acceltabledlg__
