@@ -23,12 +23,15 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "attachdbgprocdlg.h"
-#include "windowattrmanager.h"
-#include "debuggermanager.h"
+
+#include "cl_config.h"
+#include "Debugger/debuggermanager.h"
+#include "fileutils.h"
 #include "globals.h"
 #include "procutils.h"
+#include "windowattrmanager.h"
+
 #include <algorithm>
-#include "fileutils.h"
 #include <wx/wupdlock.h>
 
 /// Ascending sorting function
@@ -49,19 +52,17 @@ AttachDbgProcDlg::AttachDbgProcDlg(wxWindow* parent)
     wxArrayString choices = DebuggerMgr::Get().GetAvailableDebuggers();
     m_choiceDebugger->Append(choices);
 
-    if(choices.IsEmpty() == false) {
-        m_choiceDebugger->SetSelection(0);
-    }
+    if(choices.IsEmpty() == false) { m_choiceDebugger->SetSelection(0); }
 
-    RefreshProcessesList(wxEmptyString);
+    wxString filter = clConfig::Get().Read("AttachDebuggerDialog/Filter", wxString());
+    m_textCtrlFilter->ChangeValue(filter);
+    CallAfter(&AttachDbgProcDlg::RefreshProcessesList, filter);
     m_textCtrlFilter->SetFocus();
-    CentreOnParent();
-
     SetName("AttachDbgProcDlg");
     WindowAttrManager::Load(this);
 }
 
-void AttachDbgProcDlg::RefreshProcessesList(wxString filter, int colToSort)
+void AttachDbgProcDlg::RefreshProcessesList(wxString filter)
 {
     wxWindowUpdateLocker locker(m_dvListCtrl);
     m_dvListCtrl->DeleteAllItems();
@@ -69,29 +70,26 @@ void AttachDbgProcDlg::RefreshProcessesList(wxString filter, int colToSort)
     filter.Trim().Trim(false);
 
     // Populate the list with list of processes
-    std::vector<ProcessEntry> proclist;
-    ProcUtils::GetProcessList(proclist);
-
-    //    if(colToSort == 0) { // sort by PID
-    //        std::sort(proclist.begin(), proclist.end(), PIDSorter());
-    //
-    //    } else if(colToSort == 1) { // sort by name
-    //        std::sort(proclist.begin(), proclist.end(), NameSorter());
-    //    }
+    const std::vector<ProcessEntry> proclist = ProcUtils::GetProcessList();
 
     filter.MakeLower();
     for(size_t i = 0; i < proclist.size(); ++i) {
 
         // Use case in-sensitive match for the filter
-        wxString entryName(proclist.at(i).name);
+        wxString processName;
+        wxString processID;
+
+        const ProcessEntry& processEntry = proclist.at(i);
+
+        processName << processEntry.name;
+        processID << processEntry.pid;
 
         // Append only processes that matches the filter string
-        if(filter.IsEmpty() || FileUtils::FuzzyMatch(filter, entryName)) {
-            const ProcessEntry& entry = proclist.at(i);
-            if(entry.pid == (long)wxGetProcessId()) continue;
+        if(filter.IsEmpty() || FileUtils::FuzzyMatch(filter, processName) || FileUtils::FuzzyMatch(filter, processID)) {
+            if(processEntry.pid == (long)wxGetProcessId()) continue;
             wxVector<wxVariant> cols;
-            cols.push_back(wxString() << entry.pid);
-            cols.push_back(entry.name);
+            cols.push_back(wxString() << processEntry.pid);
+            cols.push_back(processEntry.name);
             m_dvListCtrl->AppendItem(cols);
         }
     }
@@ -99,30 +97,27 @@ void AttachDbgProcDlg::RefreshProcessesList(wxString filter, int colToSort)
 
 wxString AttachDbgProcDlg::GetExeName() const
 {
-    wxVariant v;
-    int sel = m_dvListCtrl->GetSelectedRow();
-    if(sel != wxNOT_FOUND) {
-        m_dvListCtrl->GetValue(v, sel, 1);
-        return v.GetString();
-    }
-    return wxEmptyString;
+    wxDataViewItem item = m_dvListCtrl->GetSelection();
+    CHECK_ITEM_RET_EMPTY_STRING(item);
+    return m_dvListCtrl->GetItemText(item, 1);
 }
 
 wxString AttachDbgProcDlg::GetProcessId() const
 {
-    wxVariant v;
-    int sel = m_dvListCtrl->GetSelectedRow();
-    if(sel != wxNOT_FOUND) {
-        m_dvListCtrl->GetValue(v, sel, 0);
-        return v.GetString();
-    }
-    return wxEmptyString;
+    wxDataViewItem item = m_dvListCtrl->GetSelection();
+    CHECK_ITEM_RET_EMPTY_STRING(item);
+    return m_dvListCtrl->GetItemText(item, 0);
 }
 
+void AttachDbgProcDlg::OnBtnAttachUI(wxUpdateUIEvent& event)
+{
+    event.Enable(m_dvListCtrl->GetSelectedItemsCount() == 1);
+}
 
-void AttachDbgProcDlg::OnBtnAttachUI(wxUpdateUIEvent& event) { event.Enable(m_dvListCtrl->GetSelectedRow() != wxNOT_FOUND); }
-
-AttachDbgProcDlg::~AttachDbgProcDlg() {}
+AttachDbgProcDlg::~AttachDbgProcDlg()
+{
+    clConfig::Get().Write("AttachDebuggerDialog/Filter", m_textCtrlFilter->GetValue());
+}
 
 void AttachDbgProcDlg::OnFilter(wxCommandEvent& event)
 {
@@ -138,3 +133,8 @@ void AttachDbgProcDlg::OnRefresh(wxCommandEvent& event)
     RefreshProcessesList(wxEmptyString);
     m_textCtrlFilter->SetFocus();
 }
+void AttachDbgProcDlg::OnEnter(wxCommandEvent& event)
+{
+    if(!GetProcessId().IsEmpty()) { EndModal(wxID_OK); }
+}
+void AttachDbgProcDlg::OnItemActivated(wxDataViewEvent& event) { EndModal(wxID_OK); }
