@@ -26,39 +26,27 @@
 #include "build_custom_targets_menu_manager.h"
 #include "macros.h"
 
-CustomTargetsMgr::CustomTargetsMgr()
-{
-}
-
-CustomTargetsMgr::~CustomTargetsMgr()
-{
-}
-
 CustomTargetsMgr& CustomTargetsMgr::Get()
 {
     static CustomTargetsMgr theMgr;
     return theMgr;
 }
 
-void CustomTargetsMgr::SetTargets(const wxString& projectName, const BuildConfig::StringMap_t& targets)
+void CustomTargetsMgr::SetTargets(const wxString& projectName, const std::map<wxString, wxString>& targets)
 {
     Clear();
-    
     m_projectName = projectName;
-    BuildConfig::StringMap_t::const_iterator iter = targets.begin();
-    
+
     int id = ID_MENU_CUSTOM_TARGET_FIRST;
-    for(; iter != targets.end(); ++iter) {
-        m_targets.insert( std::make_pair( id, std::make_pair(iter->first, iter->second) ) );
+    for(const auto& vt : targets) {
+        m_targets.insert({ id, { vt.first, vt.second } });
         ++id;
     }
 }
 
 CustomTargetsMgr::Pair_t CustomTargetsMgr::GetTarget(int menuId) const
 {
-    if ( m_targets.count(menuId) ) {
-        return m_targets.find(menuId)->second;
-    }
+    if(m_targets.count(menuId)) { return m_targets.find(menuId)->second; }
     return Pair_t();
 }
 
@@ -67,4 +55,3 @@ void CustomTargetsMgr::Clear()
     m_projectName.Clear();
     m_targets.clear();
 }
-
