@@ -28,7 +28,7 @@
 
 #include "unredobase.h"
 
-class LEditor;
+class clEditor;
 
 
 class CLTextCommand : public CLCommand
@@ -36,41 +36,32 @@ class CLTextCommand : public CLCommand
 public:
     CLTextCommand(CLC_types type, const wxString& name="") : CLCommand(type, name)
     {}
-    virtual ~CLTextCommand() {}
+    virtual ~CLTextCommand() = default;
 
     virtual bool GetIsAppendable() const { // We can append to a text command
         return true;
     }
-
-protected:
-
 };
 
 class CLInsertTextCommand : public CLTextCommand
 {
 public:
     CLInsertTextCommand(const wxString& name="insertion:") : CLTextCommand(CLC_insert, name) {}
-    virtual ~CLInsertTextCommand() {}
-
-protected:
-
+    virtual ~CLInsertTextCommand() = default;
 };
 
 class CLDeleteTextCommand : public CLTextCommand
 {
 public:
     CLDeleteTextCommand(const wxString& name="deletion:") : CLTextCommand(CLC_delete, name) {}
-    virtual ~CLDeleteTextCommand() {}
-
-protected:
-
+    virtual ~CLDeleteTextCommand() = default;
 };
 
 class CLCommandProcessor : public CommandProcessorBase
 {
 public:
     CLCommandProcessor();
-    virtual ~CLCommandProcessor() {}
+    virtual ~CLCommandProcessor() = default;
 
     void StartNewTextCommand(CLC_types type, const wxString& text = "");
 
@@ -78,11 +69,11 @@ public:
     
     virtual void ProcessOpenCommand();
 
-    LEditor* GetParent() const {
+    clEditor* GetParent() const {
         return m_parent;
     }
 
-    void SetParent(LEditor* parent) {
+    void SetParent(clEditor* parent) {
         m_parent = parent;
     }
 
@@ -97,7 +88,7 @@ public:
     virtual bool DoRedo();
 
 protected:
-    LEditor* m_parent;
+    clEditor* m_parent;
 
 };
 
