@@ -22,34 +22,28 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <wx/xrc/xmlres.h>
 #include "context_base.h"
-#include "drawingutils.h"
-#include <vector>
-#include "editor_config.h"
-#include "cl_editor.h"
-#include "frame.h"
-#include "ctags_manager.h"
+
+#include "LSP/LSPManager.hpp"
 #include "cl_command_event.h"
-#include "event_notifier.h"
-#include "plugin.h"
-#include "macros.h"
+#include "cl_editor.h"
+#include "cl_editor_tip_window.h"
 #include "commentconfigdata.h"
+#include "ctags_manager.h"
+#include "drawingutils.h"
 #include "editor_config.h"
-#include <wx/tokenzr.h>
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "frame.h"
+#include "macros.h"
+#include "plugin.h"
+
+#include <vector>
 #include <wx/regex.h>
+#include <wx/tokenzr.h>
+#include <wx/xrc/xmlres.h>
 
-// static wxColor GetInactiveColor(const wxColor& col)
-//{
-//    wxUnusedVar(col);
-//#ifdef __WXGTK__
-//    return wxColor(wxT("GREY"));
-//#else
-//    return wxColor(wxT("LIGHT GREY"));
-//#endif
-//}
-
-ContextBase::ContextBase(LEditor* container)
+ContextBase::ContextBase(clEditor* container)
     : m_container(container)
     , m_name(wxEmptyString)
 {
@@ -60,19 +54,17 @@ ContextBase::ContextBase(const wxString& name)
 {
 }
 
-ContextBase::~ContextBase() {}
-
 // provide basic indentation
 void ContextBase::AutoIndent(const wxChar& ch)
 {
-    LEditor& rCtrl = GetCtrl();
+    clEditor& rCtrl = GetCtrl();
     int prevpos(wxNOT_FOUND);
     int curpos = rCtrl.GetCurrentPos();
     int line = rCtrl.LineFromPosition(curpos);
 
-    if(ch == wxT('\n')) {
+    if (ch == wxT('\n')) {
         wxChar prevCh = rCtrl.PreviousChar(curpos, prevpos);
-        if(prevCh == '{') {
+        if (prevCh == '{') {
             // an enter was hit just after an open brace
             int prevLine = rCtrl.LineFromPosition(prevpos);
             rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
@@ -86,35 +78,36 @@ void ContextBase::AutoIndent(const wxChar& ch)
             rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
             rCtrl.ChooseCaretX();
         }
-    } else if(ch == '}' && !IsCommentOrString(curpos)) {
+    } else if (ch == '}' && !IsCommentOrString(curpos)) {
         long matchPos = wxNOT_FOUND;
-        if(!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos)) return;
+        if (!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos))
+            return;
         int secondLine = rCtrl.LineFromPosition(matchPos);
-        if(secondLine == line) return;
+        if (secondLine == line)
+            return;
         rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(secondLine));
     }
 }
 
-void ContextBase::DoApplySettings(LexerConf::Ptr_t lexPtr) { lexPtr->Apply(&GetCtrl()); }
+void ContextBase::DoApplySettings(LexerConf::Ptr_t lexPtr) { lexPtr->Apply(&GetCtrl(), true); }
 
-int ContextBase::GetHyperlinkRange(int pos, int& start, int& end)
+bool ContextBase::GetHyperlinkRange(int& start, int& end)
 {
-    LEditor& rCtrl = GetCtrl();
-    if(!IsCommentOrString(rCtrl.GetCurrentPos())) {
-        // get tag as hyperlink
-        start = rCtrl.WordStartPos(pos, true);
-        end = rCtrl.WordEndPos(pos, true);
-        if(start < end) return XRCID("find_tag");
+    clEditor& rCtrl = GetCtrl();
+    wxPoint pt = wxGetMousePosition();
+    if (pt == wxDefaultPosition) {
+        return false;
     }
-    return wxID_NONE;
-}
-
-void ContextBase::GoHyperlink(int start, int end, int type, bool alt)
-{
-    wxUnusedVar(start);
-    wxUnusedVar(end);
-    wxUnusedVar(type);
-    wxUnusedVar(alt);
+    wxPoint clientPt = rCtrl.ScreenToClient(pt);
+    int mouse_pos = rCtrl.PositionFromPointClose(clientPt.x, clientPt.y);
+    if (!IsCommentOrString(mouse_pos)) {
+        // get tag as hyperlink
+        start = rCtrl.WordStartPos(mouse_pos, true);
+        end = rCtrl.WordEndPos(mouse_pos, true);
+        if (start < end)
+            return true;
+    }
+    return false;
 }
 
 wxMenu* ContextBase::GetMenu() { return wxXmlResource::Get()->LoadMenu(wxT("editor_right_click_default")); }
@@ -123,7 +116,8 @@ void ContextBase::PrependMenuItem(wxMenu* menu, const wxString& text, wxObjectEv
 {
     wxMenuItem* item;
     wxString menuItemText;
-    if(eventId == -1) eventId = wxNewId();
+    if (eventId == -1)
+        eventId = wxNewId();
 
     item = new wxMenuItem(menu, eventId, text);
     menu->Prepend(item);
@@ -151,29 +145,33 @@ void ContextBase::PrependMenuItemSeparator(wxMenu* menu)
 int ContextBase::DoGetCalltipParamterIndex()
 {
     int index(0);
-    LEditor& ctrl = GetCtrl();
+    clEditor& ctrl = GetCtrl();
     int pos = ctrl.DoGetOpenBracePos();
-    if(pos != wxNOT_FOUND) {
+    if (pos != wxNOT_FOUND) {
 
         // loop over the text from pos -> current position and count the number of commas found
-        int depth(0);
-        while(pos < ctrl.GetCurrentPos()) {
+        int depth = 0;
+        while (pos < ctrl.GetCurrentPos()) {
             wxChar ch = ctrl.SafeGetChar(pos);
-            // wxChar ch_before = ctrl.SafeGetChar(ctrl.PositionBefore(pos));
-
-            if(IsCommentOrString(pos)) {
+            if (IsCommentOrString(pos)) {
                 pos = ctrl.PositionAfter(pos);
                 continue;
             }
 
-            switch(ch) {
-            case wxT(','):
-                if(depth == 0) index++;
+            switch (ch) {
+            case ',':
+                if (depth == 0) {
+                    index++;
+                }
                 break;
-            case wxT('('):
+            case '(':
+            case '[':
+            case '{':
                 depth++;
                 break;
-            case wxT(')'):
+            case ')':
+            case ']':
+            case '}':
                 depth--;
                 break;
             default:
@@ -187,36 +185,15 @@ int ContextBase::DoGetCalltipParamterIndex()
     return index;
 }
 
-void ContextBase::OnUserTypedXChars(const wxString& word)
+void ContextBase::OnUserTypedXChars(int pos)
 {
-    // user typed more than X chars
-    // trigger code complete event (as if the user typed ctrl-space)
-    // if no one handles this event, fire a word completion event
-    if(IsCommentOrString(GetCtrl().GetCurrentPos())) {
-        return;
-    }
-
-    const TagsOptionsData& options = TagsManagerST::Get()->GetCtagsOptions();
-    if(options.GetFlags() & CC_WORD_ASSIST) {
-        // Try to call code completion
-        clCodeCompletionEvent ccEvt(wxEVT_CC_CODE_COMPLETE);
-        ccEvt.SetEditor(&GetCtrl());
-        ccEvt.SetPosition(GetCtrl().GetCurrentPos());
-        ccEvt.SetWord(word);
-
-        if(!EventNotifier::Get()->ProcessEvent(ccEvt)) {
-            // This is ugly, since CodeLite should not be calling
-            // the plugins... we take comfort in the fact that it
-            // merely fires an event and not calling it directly
-            wxCommandEvent wordCompleteEvent(wxEVT_MENU, XRCID("word_complete_no_single_insert"));
-            wxTheApp->ProcessEvent(wordCompleteEvent);
-        }
-    }
+    wxUnusedVar(pos);
+    LSP::Manager::GetInstance().CodeComplete(&GetCtrl(), LSP::CompletionItem::kTriggerKindInvoked);
 }
 
 void ContextBase::AutoAddComment()
 {
-    LEditor& rCtrl = GetCtrl();
+    clEditor& rCtrl = GetCtrl();
 
     CommentConfigData data;
     EditorConfigST::Get()->ReadObject(wxT("CommentConfigData"), &data);
@@ -227,37 +204,37 @@ void ContextBase::AutoAddComment()
     wxString text = rCtrl.GetLine(line - 1).Trim(false);
 
     bool dontadd = false;
-    if(IsAtLineComment()) {
+    if (IsAtLineComment()) {
         dontadd = !text.StartsWith(wxT("//")) || !data.GetContinueCppComment();
-    } else if(IsAtBlockComment()) {
+    } else if (IsAtBlockComment()) {
         dontadd = !data.GetAddStarOnCComment();
 
     } else {
         dontadd = true;
     }
 
-    if(dontadd) {
+    if (dontadd) {
         ContextBase::AutoIndent(wxT('\n'));
         return;
     }
 
     wxString toInsert;
-    if(IsAtLineComment()) {
-        if(text.StartsWith(wxT("//"))) {
+    if (IsAtLineComment()) {
+        if (text.StartsWith(wxT("//"))) {
             toInsert = wxT("// ");
         }
-    } else if(IsAtBlockComment()) {
+    } else if (IsAtBlockComment()) {
         // Check the text typed before this char
         int startPos = rCtrl.PositionBefore(curpos);
         startPos -= 3; // for "/**"
-        if(startPos >= 0) {
+        if (startPos >= 0) {
             wxString textTyped = rCtrl.GetTextRange(startPos, rCtrl.PositionBefore(curpos));
-            if(((textTyped == "/**") || (textTyped == "/*!")) && data.IsAutoInsertAfterSlash2Stars()) {
+            if (((textTyped == "/**") || (textTyped == "/*!")) && data.IsAutoInsert()) {
                 // Let the plugins/codelite check if they can provide a doxy comment
                 // for the current entry
                 clCodeCompletionEvent event(wxEVT_CC_GENERATE_DOXY_BLOCK);
-                event.SetEditor(&rCtrl);
-                if(EventNotifier::Get()->ProcessEvent(event) && !event.GetTooltip().IsEmpty()) {
+                event.SetFileName(GetCtrl().GetFileName().GetFullPath());
+                if (EventNotifier::Get()->ProcessEvent(event) && !event.GetTooltip().IsEmpty()) {
                     rCtrl.BeginUndoAction();
 
                     // To make the doxy block fit in, we need to prepend each line
@@ -266,25 +243,25 @@ void ContextBase::AutoAddComment()
                     wxString whitespace = rCtrl.GetTextRange(lineStartPos, startPos);
                     // Break the comment, for each line, prepend the 'whitespace' buffer
                     wxArrayString lines = ::wxStringTokenize(event.GetTooltip(), "\n", wxTOKEN_STRTOK);
-                    for(size_t i = 0; i < lines.GetCount(); ++i) {
-                        if(i) { // don't add it to the first line (it already exists in the editor)
+                    for (size_t i = 0; i < lines.GetCount(); ++i) {
+                        if (i) { // don't add it to the first line (it already exists in the editor)
                             lines.Item(i).Prepend(whitespace);
                         }
                     }
 
                     // Join the lines back
-                    wxString doxyBlock = ::wxJoin(lines, '\n');
+                    wxString doxyBlock = StringUtils::clJoinLinesWithEOL(lines, rCtrl.GetEOL());
 
                     rCtrl.SetSelection(startPos, curpos);
                     rCtrl.ReplaceSelection(doxyBlock);
 
                     // Try to place the caret after the @brief
                     wxRegEx reBrief("[@\\]brief[ \t]*");
-                    if(reBrief.IsValid() && reBrief.Matches(doxyBlock)) {
+                    if (reBrief.IsValid() && reBrief.Matches(doxyBlock)) {
                         wxString match = reBrief.GetMatch(doxyBlock);
                         // Get the index
                         int where = doxyBlock.Find(match);
-                        if(where != wxNOT_FOUND) {
+                        if (where != wxNOT_FOUND) {
                             where += match.length();
                             int caretPos = startPos + where;
                             rCtrl.SetCaretAt(caretPos);
@@ -299,12 +276,12 @@ void ContextBase::AutoAddComment()
             }
         }
 
-        if(rCtrl.GetStyleAt(rCtrl.PositionBefore(rCtrl.PositionBefore(curpos))) == cur_style) {
+        if (rCtrl.GetStyleAt(rCtrl.PositionBefore(rCtrl.PositionBefore(curpos))) == cur_style) {
             toInsert = rCtrl.GetCharAt(rCtrl.GetLineIndentPosition(line - 1)) == wxT('*') ? wxT("* ") : wxT(" * ");
         }
     }
 
-    if(!toInsert.IsEmpty()) {
+    if (!toInsert.IsEmpty()) {
         rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(line - 1));
         int insertPos = rCtrl.GetLineIndentPosition(line);
         rCtrl.InsertText(insertPos, toInsert);
@@ -316,12 +293,21 @@ void ContextBase::AutoAddComment()
 bool ContextBase::IsStringTriggerCodeComplete(const wxString& str) const
 {
     // default behavior is to check if 'str' exists in the m_completionTriggerStrings container
-    if(GetCtrl().GetLexer() == wxSTC_LEX_XML) {
+    if (!m_completionTriggerStrings.empty()) {
+        return m_completionTriggerStrings.count(str) > 0;
+    }
+
+    if (GetCtrl().GetLexer() == wxSTC_LEX_XML) {
         return str == "<" || str == "</";
-    } else if(GetCtrl().GetLexer() == wxSTC_LEX_CSS) {
+    } else if (GetCtrl().GetLexer() == wxSTC_LEX_CSS) {
         return str == ":";
+    } else if (GetCtrl().GetLexer() == wxSTC_LEX_PYTHON) {
+        return str == ".";
+    } else if ((GetCtrl().GetLexer() == wxSTC_LEX_CPP)) {
+        // This can happen for Java
+        return str == "." || str == "::";
     } else {
-        return (m_completionTriggerStrings.count(str) > 0);
+        return false;
     }
 }
 
@@ -331,7 +317,7 @@ int ContextBase::FindNext(const wxString& what, int& pos, bool wholePage)
     int startpos(wxNOT_FOUND);
     int lastLine(wxNOT_FOUND);
     int endpos(wxNOT_FOUND);
-    if(wholePage) {
+    if (wholePage) {
         startpos = ctrl->GetCurrentPos();
         endpos = ctrl->GetLastPosition();
     } else {
@@ -339,9 +325,10 @@ int ContextBase::FindNext(const wxString& what, int& pos, bool wholePage)
         lastLine = ctrl->GetFirstVisibleLine() + ctrl->LinesOnScreen();
         endpos = ctrl->GetLineEndPosition(lastLine);
     }
-    if((pos < startpos) || (pos > endpos)) return wxNOT_FOUND;
+    if ((pos < startpos) || (pos > endpos))
+        return wxNOT_FOUND;
     int where = ctrl->FindText(pos, endpos, what);
-    if(where != wxNOT_FOUND) {
+    if (where != wxNOT_FOUND) {
         pos = where + what.length();
     }
     return where;
@@ -353,7 +340,7 @@ int ContextBase::FindPrev(const wxString& what, int& pos, bool wholePage)
     int startpos(wxNOT_FOUND);
     int lastLine(wxNOT_FOUND);
     int endpos(wxNOT_FOUND);
-    if(wholePage) {
+    if (wholePage) {
         startpos = 0;
         endpos = ctrl->GetCurrentPos();
     } else {
@@ -361,10 +348,65 @@ int ContextBase::FindPrev(const wxString& what, int& pos, bool wholePage)
         lastLine = ctrl->GetFirstVisibleLine() + ctrl->LinesOnScreen();
         endpos = ctrl->GetLineEndPosition(lastLine);
     }
-    if((pos < startpos) || (pos > endpos)) return wxNOT_FOUND;
+    if ((pos < startpos) || (pos > endpos))
+        return wxNOT_FOUND;
     int where = ctrl->FindText(pos, startpos, what);
-    if(where != wxNOT_FOUND) {
+    if (where != wxNOT_FOUND) {
         pos = where;
     }
     return where;
 }
+
+void ContextBase::BlockCommentComplete()
+{
+    wxStyledTextCtrl* stc = GetCtrl().GetCtrl();
+    int curPos = stc->GetCurrentPos();
+    int start = stc->WordStartPosition(stc->GetCurrentPos(), true);
+    if (curPos < start)
+        return;
+
+    // Fire an event indicating user typed '@' in a block comment
+    clCodeCompletionEvent ccEvent(wxEVT_CC_BLOCK_COMMENT_CODE_COMPLETE);
+    ccEvent.SetFileName(GetCtrl().GetFileName().GetFullPath());
+    EventNotifier::Get()->AddPendingEvent(ccEvent);
+}
+
+int ContextBase::PositionBeforeCurrent() const
+{
+    int curpos = GetCtrl().GetCurrentPos();
+    if (curpos == 0) {
+        return 0;
+    }
+    return GetCtrl().PositionBefore(curpos);
+}
+
+void ContextBase::OnKeyDown(wxKeyEvent& event)
+{
+    clEditor& ctrl = GetCtrl();
+    if (!ctrl.GetFunctionTip()->IsActive()) {
+        event.Skip();
+        return;
+    }
+    switch (event.GetKeyCode()) {
+    case WXK_UP:
+        ctrl.GetFunctionTip()->SelectPrev(DoGetCalltipParamterIndex());
+        return;
+    case WXK_DOWN:
+        ctrl.GetFunctionTip()->SelectNext(DoGetCalltipParamterIndex());
+        return;
+    default: {
+        int modifier_key = event.GetModifiers();
+        wxChar ch = event.GetUnicodeKey();
+        if (modifier_key == wxMOD_CONTROL && (ch == 'J' || ch == 'N')) {
+            ctrl.GetFunctionTip()->SelectNext(DoGetCalltipParamterIndex());
+            return;
+        } else if (modifier_key == wxMOD_CONTROL && (ch == 'K' || ch == 'P')) {
+            ctrl.GetFunctionTip()->SelectPrev(DoGetCalltipParamterIndex());
+            return;
+        }
+        break;
+    }
+    }
+    // if we got here, it means that the event was not handled - call skip and return
+    event.Skip();
+}
