@@ -28,7 +28,7 @@
 #include "editor_config.h"
 #include "cl_editor_tip_window.h"
 
-ContextHtml::ContextHtml(LEditor *editor)
+ContextHtml::ContextHtml(clEditor* editor)
     : ContextBase(editor)
 {
     SetName("html");
@@ -43,26 +43,17 @@ ContextHtml::ContextHtml()
 {
 }
 
-ContextHtml::~ContextHtml()
-{
-}
-
-void ContextHtml::AddMenuDynamicContent(wxMenu* menu)
-{
-    wxUnusedVar(menu);
-}
+void ContextHtml::AddMenuDynamicContent(wxMenu* menu) { wxUnusedVar(menu); }
 
 void ContextHtml::ApplySettings()
 {
     SetName(wxT("Html"));
     LexerConf::Ptr_t lexPtr;
-    if (EditorConfigST::Get()->IsOk()) {
-        lexPtr = EditorConfigST::Get()->GetLexer(GetName());
-    }
-    LEditor &rCtrl = GetCtrl();
-    if (lexPtr) {
+    if(EditorConfigST::Get()->IsOk()) { lexPtr = EditorConfigST::Get()->GetLexer(GetName()); }
+    clEditor& rCtrl = GetCtrl();
+    if(lexPtr) {
         rCtrl.SetLexer(lexPtr->GetLexerId());
-        for (int i = 0; i <= 4; ++i) {
+        for(int i = 0; i <= 4; ++i) {
             wxString keyWords = lexPtr->GetKeyWords(i);
             keyWords.Replace(wxT("\n"), wxT(" "));
             keyWords.Replace(wxT("\r"), wxT(" "));
@@ -72,42 +63,37 @@ void ContextHtml::ApplySettings()
         rCtrl.SetLexer(wxSTC_LEX_NULL);
     }
     DoApplySettings(lexPtr);
-
 }
 
 void ContextHtml::AutoIndent(const wxChar& nChar)
 {
-    LEditor &rCtrl = GetCtrl();
+    clEditor& rCtrl = GetCtrl();
 
-    if (rCtrl.GetDisableSmartIndent()) {
-        return;
-    }
-    if(rCtrl.GetLineIndentation(rCtrl.GetCurrentLine()) && nChar == wxT('\n')) {
-        return;
-    }
+    if(rCtrl.GetDisableSmartIndent()) { return; }
+    if(rCtrl.GetLineIndentation(rCtrl.GetCurrentLine()) && nChar == wxT('\n')) { return; }
 
     int curpos = rCtrl.GetCurrentPos();
-    if (IsCommentOrString(curpos) && nChar == wxT('\n')) {
+    if(IsCommentOrString(curpos) && nChar == wxT('\n')) {
         AutoAddComment();
         return;
     }
 
-    if (IsCommentOrString(curpos)) {
+    if(IsCommentOrString(curpos)) {
         ContextBase::AutoIndent(nChar);
         return;
     }
     int line = rCtrl.LineFromPosition(curpos);
-    if (nChar == wxT('\n')) {
+    if(nChar == wxT('\n')) {
 
-        int      prevpos (wxNOT_FOUND);
-        int      foundPos(wxNOT_FOUND);
+        int prevpos(wxNOT_FOUND);
+        int foundPos(wxNOT_FOUND);
 
         wxString word;
-        wxChar ch = rCtrl.PreviousChar(curpos, prevpos );
-        word      = rCtrl.PreviousWord(curpos, foundPos);
+        wxChar ch = rCtrl.PreviousChar(curpos, prevpos);
+        word = rCtrl.PreviousWord(curpos, foundPos);
 
         // user hit ENTER after 'else'
-        if ( word == wxT("else") ) {
+        if(word == wxT("else")) {
             int prevLine = rCtrl.LineFromPosition(prevpos);
             rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
             rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
@@ -115,19 +101,19 @@ void ContextHtml::AutoIndent(const wxChar& nChar)
             return;
         }
 
-        // User typed 'ENTER' immediatly after closing brace ')'
-        if ( prevpos != wxNOT_FOUND && ch == wxT(')') ) {
+        // User typed 'ENTER' immediately after closing brace ')'
+        if(prevpos != wxNOT_FOUND && ch == wxT(')')) {
 
-            long openBracePos          (wxNOT_FOUND);
-            int  posWordBeforeOpenBrace(wxNOT_FOUND);
+            long openBracePos(wxNOT_FOUND);
+            int posWordBeforeOpenBrace(wxNOT_FOUND);
 
-            if (rCtrl.MatchBraceBack(wxT(')'), prevpos, openBracePos)) {
+            if(rCtrl.MatchBraceBack(wxT(')'), prevpos, openBracePos)) {
                 rCtrl.PreviousChar(openBracePos, posWordBeforeOpenBrace);
-                if (posWordBeforeOpenBrace != wxNOT_FOUND) {
+                if(posWordBeforeOpenBrace != wxNOT_FOUND) {
                     word = rCtrl.PreviousWord(posWordBeforeOpenBrace, foundPos);
 
-                    // c++ expression with single line and should be treated separatly
-                    if ( word == wxT("if") || word == wxT("while") || word == wxT("for")) {
+                    // c++ expression with single line and should be treated separately
+                    if(word == wxT("if") || word == wxT("while") || word == wxT("for")) {
                         int prevLine = rCtrl.LineFromPosition(prevpos);
                         rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
                         rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
@@ -138,24 +124,24 @@ void ContextHtml::AutoIndent(const wxChar& nChar)
             }
         }
 
-        // User typed 'ENTER' immediatly after colons ':'
-        if ( prevpos != wxNOT_FOUND && ch == wxT(':') ) {
-            int  posWordBeforeColons(wxNOT_FOUND);
+        // User typed 'ENTER' immediately after colons ':'
+        if(prevpos != wxNOT_FOUND && ch == wxT(':')) {
+            int posWordBeforeColons(wxNOT_FOUND);
 
             rCtrl.PreviousChar(prevpos, posWordBeforeColons);
-            if (posWordBeforeColons != wxNOT_FOUND) {
+            if(posWordBeforeColons != wxNOT_FOUND) {
                 word = rCtrl.PreviousWord(posWordBeforeColons, foundPos);
                 int prevLine = rCtrl.LineFromPosition(posWordBeforeColons);
 
                 // If we found one of the following keywords, un-indent their line by (foldLevel - 1)*indentSize
-                if ( word == wxT("public") || word == wxT("private") || word == wxT("protected")) {
+                if(word == wxT("public") || word == wxT("private") || word == wxT("protected")) {
 
                     ContextBase::AutoIndent(nChar);
 
                     // Indent this line according to the block indentation level
                     int foldLevel = (rCtrl.GetFoldLevel(prevLine) & wxSTC_FOLDLEVELNUMBERMASK) - wxSTC_FOLDLEVELBASE;
-                    if (foldLevel) {
-                        rCtrl.SetLineIndentation(prevLine, ((foldLevel-1)*rCtrl.GetIndent()) );
+                    if(foldLevel) {
+                        rCtrl.SetLineIndentation(prevLine, ((foldLevel - 1) * rCtrl.GetIndent()));
                         rCtrl.ChooseCaretX();
                     }
                     return;
@@ -164,7 +150,7 @@ void ContextHtml::AutoIndent(const wxChar& nChar)
         }
 
         // use the previous line indentation level
-        if (prevpos == wxNOT_FOUND || ch != wxT('{') || IsCommentOrString(prevpos)) {
+        if(prevpos == wxNOT_FOUND || ch != wxT('{') || IsCommentOrString(prevpos)) {
             ContextBase::AutoIndent(nChar);
             return;
         }
@@ -174,26 +160,24 @@ void ContextHtml::AutoIndent(const wxChar& nChar)
         rCtrl.SetLineIndentation(line, rCtrl.GetIndent() + rCtrl.GetLineIndentation(prevLine));
         rCtrl.SetCaretAt(rCtrl.GetLineIndentPosition(line));
 
-    } else if (nChar == wxT('}')) {
+    } else if(nChar == wxT('}')) {
 
         long matchPos = wxNOT_FOUND;
-        if (!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos))
-            return;
+        if(!rCtrl.MatchBraceBack(wxT('}'), rCtrl.PositionBefore(curpos), matchPos)) return;
         int secondLine = rCtrl.LineFromPosition(matchPos);
-        if (secondLine == line)
-            return;
+        if(secondLine == line) return;
         rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(secondLine));
 
-    } else if (nChar == wxT('{')) {
+    } else if(nChar == wxT('{')) {
         wxString lineString = rCtrl.GetLine(line);
         lineString.Trim().Trim(false);
 
         int matchPos = wxNOT_FOUND;
         wxChar previousChar = rCtrl.PreviousChar(rCtrl.PositionBefore(curpos), matchPos);
-        if (previousChar != wxT('{') && lineString == wxT("{")) {
-            // indent this line accroding to the previous line
+        if(previousChar != wxT('{') && lineString == wxT("{")) {
+            // indent this line according to the previous line
             int line = rCtrl.LineFromPosition(rCtrl.GetCurrentPos());
-            rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(line-1));
+            rCtrl.SetLineIndentation(line, rCtrl.GetLineIndentation(line - 1));
             rCtrl.ChooseCaretX();
         }
     }
@@ -202,152 +186,78 @@ void ContextHtml::AutoIndent(const wxChar& nChar)
     rCtrl.ChooseCaretX();
 }
 
-wxString ContextHtml::CallTipContent()
-{
-    return wxEmptyString;
-}
+wxString ContextHtml::CallTipContent() { return wxEmptyString; }
 
-void ContextHtml::CodeComplete(long pos)
-{
-}
+int ContextHtml::DoGetCalltipParamterIndex() { return ContextBase::DoGetCalltipParamterIndex(); }
 
-void ContextHtml::CompleteWord()
-{
-}
+wxString ContextHtml::GetCurrentScopeName() { return wxT(""); }
 
-int ContextHtml::DoGetCalltipParamterIndex()
-{
-    return ContextBase::DoGetCalltipParamterIndex();
-}
+wxMenu* ContextHtml::GetMenu() { return ContextBase::GetMenu(); }
 
-wxString ContextHtml::GetCurrentScopeName()
-{
-    return wxT("");
-}
+TagEntryPtr ContextHtml::GetTagAtCaret(bool scoped, bool impl) { return NULL; }
 
-wxMenu* ContextHtml::GetMenu()
-{
-    return ContextBase::GetMenu();
-}
+bool ContextHtml::GotoDefinition() { return false; }
 
-TagEntryPtr ContextHtml::GetTagAtCaret(bool scoped, bool impl)
-{
-    return NULL;
-}
-
-void ContextHtml::GoHyperlink(int start, int end, int type, bool alt)
-{
-}
-
-void ContextHtml::GotoDefinition()
-{
-}
-
-void ContextHtml::GotoPreviousDefintion()
-{
-}
+void ContextHtml::GotoPreviousDefintion() {}
 
 bool ContextHtml::IsCommentOrString(long pos)
 {
     int style = GetCtrl().GetStyleAt(pos);
-    return IsComment(pos) ||
-           style == wxSTC_H_DOUBLESTRING ||
-           style == wxSTC_H_SINGLESTRING ||
-           style == wxSTC_H_SGML_DOUBLESTRING ||
-           style == wxSTC_H_SGML_SIMPLESTRING ||
-           style == wxSTC_HJ_DOUBLESTRING ||
-           style == wxSTC_HJ_SINGLESTRING ||
-           style == wxSTC_HJ_STRINGEOL ||
-           style == wxSTC_HJA_DOUBLESTRING ||
-           style == wxSTC_HJA_SINGLESTRING ||
-           style == wxSTC_HJA_STRINGEOL ||
-           style == wxSTC_HB_STRING ||
-           style == wxSTC_HBA_STRING ||
-           style == wxSTC_HBA_STRINGEOL ||
-           style == wxSTC_HP_STRING ||
-           style == wxSTC_HPA_STRING ||
-           style == wxSTC_HPA_CHARACTER ||
-           style == wxSTC_HPHP_HSTRING ||
+    return IsComment(pos) || style == wxSTC_H_DOUBLESTRING || style == wxSTC_H_SINGLESTRING ||
+           style == wxSTC_H_SGML_DOUBLESTRING || style == wxSTC_H_SGML_SIMPLESTRING || style == wxSTC_HJ_DOUBLESTRING ||
+           style == wxSTC_HJ_SINGLESTRING || style == wxSTC_HJ_STRINGEOL || style == wxSTC_HJA_DOUBLESTRING ||
+           style == wxSTC_HJA_SINGLESTRING || style == wxSTC_HJA_STRINGEOL || style == wxSTC_HB_STRING ||
+           style == wxSTC_HBA_STRING || style == wxSTC_HBA_STRINGEOL || style == wxSTC_HP_STRING ||
+           style == wxSTC_HPA_STRING || style == wxSTC_HPA_CHARACTER || style == wxSTC_HPHP_HSTRING ||
            style == wxSTC_HPHP_SIMPLESTRING;
 }
 
-bool ContextHtml::IsDefaultContext() const
-{
-    return false;
-}
+bool ContextHtml::IsDefaultContext() const { return false; }
 
-ContextBase* ContextHtml::NewInstance(LEditor* container)
-{
-    return new ContextHtml(container);
-}
+ContextBase* ContextHtml::NewInstance(clEditor* container) { return new ContextHtml(container); }
 
-void ContextHtml::OnCallTipClick(wxStyledTextEvent& event)
-{
-}
+void ContextHtml::OnCallTipClick(wxStyledTextEvent& event) {}
 
-void ContextHtml::OnCalltipCancel()
-{
-}
+void ContextHtml::OnCalltipCancel() {}
 
-void ContextHtml::OnDbgDwellEnd(wxStyledTextEvent& event)
-{
-}
+void ContextHtml::OnDbgDwellEnd(wxStyledTextEvent& event) {}
 
-void ContextHtml::OnDbgDwellStart(wxStyledTextEvent& event)
-{
-}
+void ContextHtml::OnDbgDwellStart(wxStyledTextEvent& event) {}
 
-void ContextHtml::OnDwellEnd(wxStyledTextEvent& event)
-{
-}
+void ContextHtml::OnDwellEnd(wxStyledTextEvent& event) {}
 
-void ContextHtml::OnDwellStart(wxStyledTextEvent& event)
-{
-}
+void ContextHtml::OnDwellStart(wxStyledTextEvent& event) {}
 
-void ContextHtml::OnEnterHit()
-{
-}
+void ContextHtml::OnEnterHit() {}
 
-void ContextHtml::OnFileSaved()
-{
-}
+void ContextHtml::OnFileSaved() {}
 
-void ContextHtml::OnKeyDown(wxKeyEvent& event)
-{
-    event.Skip();
-}
+void ContextHtml::OnKeyDown(wxKeyEvent& event) { event.Skip(); }
 
 void ContextHtml::OnSciUpdateUI(wxStyledTextEvent& event)
 {
-    LEditor &ctrl = GetCtrl();
-    if (ctrl.GetFunctionTip()->IsActive()) {
-        ctrl.GetFunctionTip()->Highlight(DoGetCalltipParamterIndex());
-    }
+    clEditor& ctrl = GetCtrl();
+    if(ctrl.GetFunctionTip()->IsActive()) { ctrl.GetFunctionTip()->Highlight(DoGetCalltipParamterIndex()); }
 }
 
-void ContextHtml::RemoveMenuDynamicContent(wxMenu* menu)
-{
-}
+void ContextHtml::RemoveMenuDynamicContent(wxMenu* menu) {}
 
-void ContextHtml::RetagFile()
-{
-}
+void ContextHtml::RetagFile() {}
 
 void ContextHtml::SemicolonShift()
 {
-    int foundPos    (wxNOT_FOUND);
+    int foundPos(wxNOT_FOUND);
     int semiColonPos(wxNOT_FOUND);
-    LEditor &ctrl = GetCtrl();
-    if (ctrl.NextChar(ctrl.GetCurrentPos(), semiColonPos) == wxT(')')) {
+    clEditor& ctrl = GetCtrl();
+    if(ctrl.NextChar(ctrl.GetCurrentPos(), semiColonPos) == wxT(')')) {
 
         // test to see if we are inside a 'for' statement
-        long openBracePos          (wxNOT_FOUND);
-        int  posWordBeforeOpenBrace(wxNOT_FOUND);
+        long openBracePos(wxNOT_FOUND);
+        int posWordBeforeOpenBrace(wxNOT_FOUND);
 
-        if (ctrl.MatchBraceBack(wxT(')'), semiColonPos, openBracePos)) {
+        if(ctrl.MatchBraceBack(wxT(')'), semiColonPos, openBracePos)) {
             ctrl.PreviousChar(openBracePos, posWordBeforeOpenBrace);
-            if (posWordBeforeOpenBrace != wxNOT_FOUND) {
+            if(posWordBeforeOpenBrace != wxNOT_FOUND) {
                 wxString word = ctrl.PreviousWord(posWordBeforeOpenBrace, foundPos);
 
                 // At the current pos, we got a ';'
@@ -356,38 +266,26 @@ void ContextHtml::SemicolonShift()
                 ctrl.DeleteBack();
                 ctrl.SetCurrentPos(semiColonPos);
                 ctrl.InsertText(semiColonPos, wxT(";"));
-                ctrl.SetCaretAt(semiColonPos+1);
+                ctrl.SetCaretAt(semiColonPos + 1);
                 ctrl.GetFunctionTip()->Deactivate();
             }
         }
     }
 }
 
-void ContextHtml::SetActive()
-{
-}
+void ContextHtml::SetActive() {}
 
 bool ContextHtml::IsComment(long pos)
 {
     int style = GetCtrl().GetStyleAt(pos);
-    return  style == wxSTC_H_COMMENT       ||
-            style == wxSTC_H_XCCOMMENT     ||
-            style == wxSTC_H_SGML_COMMENT  ||
-            style == wxSTC_HJ_COMMENT      ||
-            style == wxSTC_HJ_COMMENTLINE  ||
-            style == wxSTC_HJ_COMMENTDOC   ||
-            style == wxSTC_HJA_COMMENT     ||
-            style == wxSTC_HJA_COMMENTLINE ||
-            style == wxSTC_HJA_COMMENTDOC  ||
-            style == wxSTC_HB_COMMENTLINE  ||
-            style == wxSTC_HBA_COMMENTLINE ||
-            style == wxSTC_HP_COMMENTLINE  ||
-            style == wxSTC_HPA_COMMENTLINE ||
-            style == wxSTC_HPHP_COMMENT    ||
-            style == wxSTC_HPHP_COMMENTLINE;
+    return style == wxSTC_H_COMMENT || style == wxSTC_H_XCCOMMENT || style == wxSTC_H_SGML_COMMENT ||
+           style == wxSTC_HJ_COMMENT || style == wxSTC_HJ_COMMENTLINE || style == wxSTC_HJ_COMMENTDOC ||
+           style == wxSTC_HJA_COMMENT || style == wxSTC_HJA_COMMENTLINE || style == wxSTC_HJA_COMMENTDOC ||
+           style == wxSTC_HB_COMMENTLINE || style == wxSTC_HBA_COMMENTLINE || style == wxSTC_HP_COMMENTLINE ||
+           style == wxSTC_HPA_COMMENTLINE || style == wxSTC_HPHP_COMMENT || style == wxSTC_HPHP_COMMENTLINE;
 }
 
-#define IS_BETWEEN(style, x, y) (style >=x && style <=y)
+#define IS_BETWEEN(style, x, y) (style >= x && style <= y)
 
 int ContextHtml::GetActiveKeywordSet() const
 {
@@ -395,14 +293,15 @@ int ContextHtml::GetActiveKeywordSet() const
     // JS 1,
     // Python 3
     // PHP 4
-    int style = GetCtrl().GetStyleAt( GetCtrl().GetCurrentPos() );
-    if ( IS_BETWEEN(style, wxSTC_H_DEFAULT, wxSTC_H_SGML_BLOCK_DEFAULT) )
+    int style = GetCtrl().GetStyleAt(GetCtrl().GetCurrentPos());
+    if(IS_BETWEEN(style, wxSTC_H_DEFAULT, wxSTC_H_SGML_BLOCK_DEFAULT))
         return 0;
-    else if ( IS_BETWEEN(style, wxSTC_HJ_START, wxSTC_HJA_REGEX) )
+    else if(IS_BETWEEN(style, wxSTC_HJ_START, wxSTC_HJA_REGEX))
         return 1;
-    else if ( IS_BETWEEN(style, wxSTC_HPHP_DEFAULT, wxSTC_HPHP_OPERATOR) || style == wxSTC_HPHP_COMPLEX_VARIABLE)
+    else if(IS_BETWEEN(style, wxSTC_HPHP_DEFAULT, wxSTC_HPHP_OPERATOR) || style == wxSTC_HPHP_COMPLEX_VARIABLE)
         return 4;
-    else if ( IS_BETWEEN(style, wxSTC_HP_START, wxSTC_HP_IDENTIFIER) || IS_BETWEEN(style, wxSTC_HPA_START, wxSTC_HPA_IDENTIFIER) )
+    else if(IS_BETWEEN(style, wxSTC_HP_START, wxSTC_HP_IDENTIFIER) ||
+            IS_BETWEEN(style, wxSTC_HPA_START, wxSTC_HPA_IDENTIFIER))
         return 3;
     return wxNOT_FOUND;
 }
