@@ -25,8 +25,8 @@
 #ifndef LITEEDITOR_CPP_SYMBOL_TREE_H
 #define LITEEDITOR_CPP_SYMBOL_TREE_H
 
-#include "symbol_tree.h"
 #include "stack"
+#include "symbol_tree.h"
 
 extern const wxEventType wxEVT_CMD_CPP_SYMBOL_ITEM_SELECTED;
 
@@ -36,22 +36,24 @@ class CppSymbolTree : public SymbolTree
     std::stack<wxTreeItemId> m_itemsStack;
 
 public:
-    CppSymbolTree();
+    CppSymbolTree() = default;
 
     /// Nothing special here, just call our parent constructor
-    CppSymbolTree(wxWindow* parent,
-                  const wxWindowID id,
-                  const wxPoint& pos = wxDefaultPosition,
-                  const wxSize& size = wxDefaultSize,
-                  long style = wxTR_HIDE_ROOT | wxTR_HAS_BUTTONS);
+    CppSymbolTree(wxWindow* parent, const wxWindowID id, const wxPoint& pos = wxDefaultPosition,
+                  const wxSize& size = wxDefaultSize, long style = wxTR_HIDE_ROOT | wxTR_HAS_BUTTONS);
 
     /// destructor
-    virtual ~CppSymbolTree(){};
+    ~CppSymbolTree() override = default;
+    
+    /**
+     * @brief emulate user activated the selected item
+     */
+    void ItemActivated();
 
 protected:
     virtual void OnItemActivated(wxTreeEvent& event);
     bool DoItemActivated(wxTreeItemId item, wxEvent& event, bool notify);
-    void FindAndSelect(LEditor* editor, wxString& pattern, const wxString& name);
+    void FindAndSelect(clEditor* editor, wxString& pattern, const wxString& name);
 
     DECLARE_DYNAMIC_CLASS(CppSymbolTree)
 };
