@@ -22,47 +22,49 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "debuggerpane.h"
+
+#include "BreakpointsView.hpp"
+#include "Debugger/debuggermanager.h"
+#include "Debugger/memoryview.h"
 #include "DebuggerCallstackView.h"
 #include "DebuggerDisassemblyTab.h"
-#include "breakpointdlg.h"
 #include "codelite_events.h"
 #include "debugger.h"
 #include "debuggerasciiviewer.h"
-#include "debuggermanager.h"
-#include "debuggerpane.h"
 #include "detachedpanesinfo.h"
 #include "dockablepane.h"
 #include "editor_config.h"
 #include "event_notifier.h"
 #include "localstable.h"
 #include "manager.h"
-#include "memoryview.h"
 #include "plugin_general_wxcp.h"
 #include "shelltab.h"
 #include "simpletable.h"
 #include "threadlistpanel.h"
-#include "wx/dcbuffer.h"
-#include "wx/xrc/xmlres.h"
-#include <wx/aui/framemanager.h>
 
-const wxString DebuggerPane::LOCALS = _("Locals");
-const wxString DebuggerPane::WATCHES = _("Watches");
-const wxString DebuggerPane::FRAMES = _("Call Stack");
-const wxString DebuggerPane::BREAKPOINTS = _("Breakpoints");
-const wxString DebuggerPane::THREADS = _("Threads");
-const wxString DebuggerPane::MEMORY = _("Memory");
-const wxString DebuggerPane::ASCII_VIEWER = _("Ascii Viewer");
-const wxString DebuggerPane::DEBUGGER_OUTPUT = _("Output");
-const wxString DebuggerPane::DISASSEMBLY = _("Disassemble");
+#include <wx/aui/framemanager.h>
+#include <wx/dcbuffer.h>
+#include <wx/xrc/xmlres.h>
+
+const wxString DebuggerPane::LOCALS = wxTRANSLATE("Locals");
+const wxString DebuggerPane::WATCHES = wxTRANSLATE("Watches");
+const wxString DebuggerPane::FRAMES = wxTRANSLATE("Call Stack");
+const wxString DebuggerPane::BREAKPOINTS = wxTRANSLATE("Breakpoints");
+const wxString DebuggerPane::THREADS = wxTRANSLATE("Threads");
+const wxString DebuggerPane::MEMORY = wxTRANSLATE("Memory");
+const wxString DebuggerPane::ASCII_VIEWER = wxTRANSLATE("Ascii Viewer");
+const wxString DebuggerPane::DEBUGGER_OUTPUT = wxTRANSLATE("Output");
+const wxString DebuggerPane::DISASSEMBLY = wxTRANSLATE("Disassemble");
 
 #define IS_DETACHED(name) (detachedPanes.Index(name) != wxNOT_FOUND) ? true : false
 
-DebuggerPane::DebuggerPane(wxWindow* parent, const wxString& caption, wxAuiManager* mgr)
-    : wxPanel(parent, wxID_ANY, wxDefaultPosition, wxSize(400, 300))
+DebuggerPane::DebuggerPane(wxWindow* parent, const wxString& caption, wxAuiManager* mgr, long style)
+    : wxPanel(parent, wxID_ANY, wxDefaultPosition, wxSize(400, 300), style)
     , m_caption(caption)
     , m_initDone(false)
-    , m_mgr(mgr)
 {
+    Hide();
     EventNotifier::Get()->Bind(wxEVT_EDITOR_CONFIG_CHANGED, &DebuggerPane::OnSettingsChanged, this);
     CreateGUIControls();
 }
@@ -74,8 +76,8 @@ DebuggerPane::~DebuggerPane()
 
 void DebuggerPane::OnPageChanged(wxBookCtrlEvent& event)
 {
-    if(m_initDone && DebuggerMgr::Get().GetActiveDebugger() && DebuggerMgr::Get().GetActiveDebugger()->IsRunning()) {
-        if(event.GetEventObject() == m_book) {
+    if (m_initDone && DebuggerMgr::Get().GetActiveDebugger() && DebuggerMgr::Get().GetActiveDebugger()->IsRunning()) {
+        if (event.GetEventObject() == m_book) {
             ManagerST::Get()->CallAfter(&Manager::UpdateDebuggerPane);
         } else {
             event.Skip();
@@ -91,17 +93,20 @@ void DebuggerPane::CreateGUIControls()
     SetSizer(mainSizer);
 
     long style = (kNotebook_Default | kNotebook_AllowDnD);
-    if(!EditorConfigST::Get()->GetOptions()->GetOutputTabsDirection()) {
+    if (!EditorConfigST::Get()->GetOptions()->GetOutputTabsDirection()) {
         style |= kNotebook_BottomTabs;
     }
-    if(EditorConfigST::Get()->GetOptions()->IsMouseScrollSwitchTabs()) {
+    if (EditorConfigST::Get()->GetOptions()->IsMouseScrollSwitchTabs()) {
         style |= kNotebook_MouseScrollSwitchTabs;
     }
     style |= kNotebook_UnderlineActiveTab;
 
-    GeneralImages img;
     m_book = new Notebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, style);
+
+#if !MAINBOOK_AUIBOOK
     m_book->SetTabDirection(EditorConfigST::Get()->GetOptions()->GetOutputTabsDirection());
+#endif
+
     mainSizer->Add(m_book, 1, wxEXPAND | wxALL, 0);
 
     // Calculate the widthest tab (the one with the 'Call Stack' label)
@@ -117,120 +122,112 @@ void DebuggerPane::CreateGUIControls()
 
     wxString name;
     name = wxGetTranslation(LOCALS);
-    wxBitmap bmp = wxNullBitmap;
     // Add the 'Locals View'
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp =
+            new DockablePane(clGetManager()->GetMainPanel(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_localsTable = new LocalsTable(cp);
         cp->SetChildNoReparent(m_localsTable);
 
     } else {
         m_localsTable = new LocalsTable(m_book);
-        m_book->AddPage(m_localsTable, name, false, bmp);
+        m_book->AddPage(m_localsTable, name, false, wxNOT_FOUND);
     }
 
     // Add the 'watches View'
     name = wxGetTranslation(WATCHES);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_watchesTable = new WatchesTable(cp);
         cp->SetChildNoReparent(m_watchesTable);
 
     } else {
         m_watchesTable = new WatchesTable(m_book);
-        m_book->AddPage(m_watchesTable, name, false, bmp);
+        m_book->AddPage(m_watchesTable, name, false, wxNOT_FOUND);
     }
 
     // Add the 'ASCII Viewer'
     name = wxGetTranslation(ASCII_VIEWER);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_asciiViewer = new DebuggerAsciiViewer(cp);
         cp->SetChildNoReparent(m_asciiViewer);
 
     } else {
         m_asciiViewer = new DebuggerAsciiViewer(m_book);
-        m_book->AddPage(m_asciiViewer, name, false, bmp);
+        m_book->AddPage(m_asciiViewer, name, false, wxNOT_FOUND);
     }
 
     // Add the 'Call Stack'
     name = wxGetTranslation(FRAMES);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_frameList = new DebuggerCallstackView(cp);
         cp->SetChildNoReparent(m_frameList);
 
     } else {
         m_frameList = new DebuggerCallstackView(m_book);
-        m_book->AddPage(m_frameList, name, false, bmp);
+        m_book->AddPage(m_frameList, name, false, wxNOT_FOUND);
     }
 
     // Add the 'Breakpoints'
     name = wxGetTranslation(BREAKPOINTS);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
-        m_breakpoints = new BreakpointDlg(cp);
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
+        m_breakpoints = new BreakpointsView(cp);
         cp->SetChildNoReparent(m_breakpoints);
 
     } else {
-        m_breakpoints = new BreakpointDlg(m_book);
-        m_book->AddPage(m_breakpoints, name, false, bmp);
+        m_breakpoints = new BreakpointsView(m_book);
+        m_book->AddPage(m_breakpoints, name, false, wxNOT_FOUND);
     }
 
     // Add the 'Threads'
     name = wxGetTranslation(THREADS);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_threads = new ThreadListPanel(cp);
         cp->SetChildNoReparent(m_threads);
 
     } else {
         m_threads = new ThreadListPanel(m_book);
-        m_book->AddPage(m_threads, name, false, bmp);
+        m_book->AddPage(m_threads, name, false, wxNOT_FOUND);
     }
 
     // Add the 'Memory View'
     name = wxGetTranslation(MEMORY);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_memory = new MemoryView(cp);
         cp->SetChildNoReparent(m_memory);
 
     } else {
         m_memory = new MemoryView(m_book);
-        m_book->AddPage(m_memory, name, false, bmp);
+        m_book->AddPage(m_memory, name, false, wxNOT_FOUND);
     }
 
     // Add the "Output" tab
     name = wxGetTranslation(DEBUGGER_OUTPUT);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_outputDebug = new DebugTab(cp, wxID_ANY, wxGetTranslation(DEBUGGER_OUTPUT));
         cp->SetChildNoReparent(m_outputDebug);
 
     } else {
         m_outputDebug = new DebugTab(m_book, wxID_ANY, wxGetTranslation(DEBUGGER_OUTPUT));
-        m_book->AddPage(m_outputDebug, name, false, bmp);
+        m_book->AddPage(m_outputDebug, name, false, wxNOT_FOUND);
     }
 
     // Add the "Output" tab
     name = wxGetTranslation(DISASSEMBLY);
-    bmp = wxNullBitmap;
-    if(IS_DETACHED(name)) {
-        DockablePane* cp = new DockablePane(GetParent(), m_book, name, false, bmp, wxSize(200, 200));
+    if (IS_DETACHED(name)) {
+        DockablePane* cp = new DockablePane(GetParent(), PaneId::DEBUG_BAR, name, false, wxSize(200, 200));
         m_disassemble = new DebuggerDisassemblyTab(cp, wxGetTranslation(DISASSEMBLY));
         cp->SetChildNoReparent(m_disassemble);
 
     } else {
         m_disassemble = new DebuggerDisassemblyTab(m_book, wxGetTranslation(DISASSEMBLY));
-        m_book->AddPage(m_disassemble, name, false, bmp);
+        m_book->AddPage(m_disassemble, name, false, wxNOT_FOUND);
     }
     m_book->Bind(wxEVT_BOOK_PAGE_CHANGED, &DebuggerPane::OnPageChanged, this);
     m_initDone = true;
@@ -238,8 +235,8 @@ void DebuggerPane::CreateGUIControls()
 
 void DebuggerPane::SelectTab(const wxString& tabName)
 {
-    for(size_t i = 0; i < m_book->GetPageCount(); i++) {
-        if(m_book->GetPageText(i) == tabName) {
+    for (size_t i = 0; i < m_book->GetPageCount(); i++) {
+        if (m_book->GetPageText(i) == tabName) {
             m_book->SetSelection(i);
             break;
         }
@@ -258,8 +255,10 @@ void DebuggerPane::Clear()
 void DebuggerPane::OnSettingsChanged(wxCommandEvent& event)
 {
     event.Skip();
-    m_book->EnableStyle(kNotebook_BottomTabs,
-                        EditorConfigST::Get()->GetOptions()->GetOutputTabsDirection() == wxBOTTOM);
+#if !MAINBOOK_AUIBOOK
+    m_book->EnableStyle(
+        kNotebook_BottomTabs, EditorConfigST::Get()->GetOptions()->GetOutputTabsDirection() == wxBOTTOM);
+#endif
 }
 
 //----------------------------------------------------------------
@@ -281,11 +280,9 @@ DebuggerPaneConfig::DebuggerPaneConfig()
 {
 }
 
-DebuggerPaneConfig::~DebuggerPaneConfig() {}
-
 wxString DebuggerPaneConfig::WindowName(eDebuggerWindows flag) const
 {
-    switch(flag) {
+    switch (flag) {
     default:
     case All:
         return wxEmptyString;
