@@ -25,15 +25,16 @@
 #ifndef DEBUGGERPANE_H
 #define DEBUGGERPANE_H
 
-#include "wx/panel.h"
 #include "Notebook.h"
-#include <wx/imaglist.h>
 #include "cl_config.h"
 
+#include <wx/imaglist.h>
+#include <wx/panel.h>
+
 class DebuggerCallstackView;
 class LocalsTable;
 class WatchesTable;
-class BreakpointDlg;
+class BreakpointsView;
 class ThreadListPanel;
 class MemoryView;
 class wxAuiManager;
@@ -61,8 +62,8 @@ public:
     };
 
 public:
-    virtual void FromJSON(const JSONElement& json);
-    virtual JSONElement ToJSON() const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON() const;
 
     void SetWindows(size_t windows) { this->m_windows = windows; }
     size_t GetWindows() const { return m_windows; }
@@ -74,7 +75,7 @@ public:
 
     void ShowDebuggerWindow(eDebuggerWindows win, bool show)
     {
-        if(show) {
+        if (show) {
             m_windows |= win;
         } else {
             m_windows &= ~win;
@@ -85,7 +86,7 @@ public:
 
 public:
     DebuggerPaneConfig();
-    virtual ~DebuggerPaneConfig();
+    virtual ~DebuggerPaneConfig() = default;
 };
 
 class DebuggerPane : public wxPanel
@@ -107,13 +108,12 @@ private:
     wxString m_caption;
     WatchesTable* m_watchesTable;
     DebuggerCallstackView* m_frameList;
-    BreakpointDlg* m_breakpoints;
+    BreakpointsView* m_breakpoints;
     ThreadListPanel* m_threads;
     MemoryView* m_memory;
     DebuggerAsciiViewer* m_asciiViewer;
     DebuggerDisassemblyTab* m_disassemble;
     bool m_initDone;
-    wxAuiManager* m_mgr;
     DebugTab* m_outputDebug;
     wxStringSet_t m_visibleWindows;
 
@@ -122,7 +122,7 @@ private:
     void OnSettingsChanged(wxCommandEvent& event);
 
 public:
-    DebuggerPane(wxWindow* parent, const wxString& caption, wxAuiManager* mgr);
+    DebuggerPane(wxWindow* parent, const wxString& caption, wxAuiManager* mgr, long style);
     virtual ~DebuggerPane();
 
     // setters/getters
@@ -130,10 +130,11 @@ public:
     LocalsTable* GetLocalsTable() { return m_localsTable; }
     WatchesTable* GetWatchesTable() { return m_watchesTable; }
     DebuggerCallstackView* GetFrameListView() { return m_frameList; }
-    BreakpointDlg* GetBreakpointView() { return m_breakpoints; }
+    BreakpointsView* GetBreakpointView() { return m_breakpoints; }
     ThreadListPanel* GetThreadsView() { return m_threads; }
     MemoryView* GetMemoryView() { return m_memory; }
     DebuggerAsciiViewer* GetAsciiViewer() { return m_asciiViewer; }
+    DebuggerDisassemblyTab* GetDisassemblyTab() { return m_disassemble; }
     DebugTab* GetDebugWindow() { return m_outputDebug; }
 
     Notebook* GetNotebook() { return m_book; }
