@@ -23,17 +23,20 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "debuggersettingsdlg.h"
-#include "windowattrmanager.h"
+
+#include "ColoursAndFontsManager.h"
+#include "Debugger/debuggermanager.h"
+#include "dbgcommanddlg.h"
 #include "debugger_predefined_types_page.h"
+#include "debuggerconfigtool.h"
 #include "editor_config.h"
-#include "debuggermanager.h"
+#include "globals.h"
+#include "lexer_configuration.h"
 #include "macros.h"
 #include "manager.h"
-#include "globals.h"
-#include "dbgcommanddlg.h"
-#include "debuggerconfigtool.h"
-#include "ColoursAndFontsManager.h"
-#include "lexer_configuration.h"
+#include "windowattrmanager.h"
+
+#include <wx/msgdlg.h>
 
 ///////////////////////////////////////////////////
 // Misc Page
@@ -63,8 +66,6 @@ DebuggerPageMisc::DebuggerPageMisc(wxWindow* parent, const wxString& title)
 #endif
 }
 
-DebuggerPageMisc::~DebuggerPageMisc() {}
-
 void DebuggerPageMisc::OnDebugAssert(wxCommandEvent& event) {}
 
 void DebuggerPageMisc::OnWindowsUI(wxUpdateUIEvent& event) {}
@@ -77,19 +78,17 @@ DebuggerPageStartupCmds::DebuggerPageStartupCmds(wxWindow* parent, const wxStrin
     : DbgPageStartupCmdsBase(parent)
     , m_title(title)
 {
-    LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("text", "Default");
+    LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("text");
     if(lexer) {
         lexer->Apply(m_textCtrlStartupCommands);
     }
 
     DebuggerInformation info;
     if(DebuggerMgr::Get().GetDebuggerInformation(title, info)) {
-        m_textCtrlStartupCommands->SetText(info.startupCommands);
+        m_textCtrlStartupCommands->SetText(info.initFileCommands);
     }
 }
 
-DebuggerPageStartupCmds::~DebuggerPageStartupCmds() {}
-
 ///////////////////////////////////////////////////
 // General Page
 ///////////////////////////////////////////////////
@@ -104,7 +103,8 @@ DebuggerPage::DebuggerPage(wxWindow* parent, wxString title)
         m_checkBoxEnablePendingBreakpoints->SetValue(info.enablePendingBreakpoints);
         m_checkBreakAtWinMain->SetValue(info.breakAtWinMain);
         m_catchThrow->SetValue(info.catchThrow);
-        m_spinCtrlNumElements->SetValue(info.maxDisplayStringSize);
+        m_spinCtrlStringSize->SetValue(info.maxDisplayStringSize);
+        m_spinCtrlMaxElements->SetValue(info.maxDisplayElements);
         m_showTooltipsRequiresControl->SetValue(info.showTooltipsOnlyWithControlKeyIsDown);
         m_checkBoxAutoExpand->SetValue(info.autoExpandTipItems);
         m_checkBoxExpandLocals->SetValue(info.resolveLocals);
@@ -114,19 +114,18 @@ DebuggerPage::DebuggerPage(wxWindow* parent, wxString title)
         m_checkBoxUsePrettyPrinting->SetValue(info.enableGDBPrettyPrinting);
         m_checkBoxPrintObjectOn->SetValue(!(info.flags & DebuggerInformation::kPrintObjectOff));
         m_checkBoxRunAsSuperuser->SetValue(info.flags & DebuggerInformation::kRunAsSuperuser);
+        m_checkBoxDefaultHexDisplay->SetValue(info.defaultHexDisplay);
     }
 }
 
-DebuggerPage::~DebuggerPage() {}
-
 void DebuggerPage::OnBrowse(wxCommandEvent& e)
 {
     wxUnusedVar(e);
     wxString newfilepath, filepath(m_textCtrDbgPath->GetValue());
     if((!filepath.IsEmpty()) && wxFileName::FileExists(filepath)) {
-        newfilepath = wxFileSelector(wxT("Select file:"), filepath.c_str());
+        newfilepath = wxFileSelector(_("Select file:"), filepath.c_str());
     } else {
-        newfilepath = wxFileSelector(wxT("Select file:"));
+        newfilepath = wxFileSelector(_("Select file:"));
     }
 
     if(!newfilepath.IsEmpty()) {
@@ -158,15 +157,12 @@ DbgPagePreDefTypes::DbgPagePreDefTypes(wxWindow* parent)
     DebuggerSettingsPreDefMap data;
     DebuggerConfigTool::Get()->ReadObject(wxT("DebuggerCommands"), &data);
 
-    std::map<wxString, DebuggerPreDefinedTypes>::const_iterator iter = data.GePreDefinedTypesMap().begin();
-    for(; iter != data.GePreDefinedTypesMap().end(); iter++) {
+    for (const auto& p : data.GePreDefinedTypesMap()) {
         m_notebookPreDefTypes->AddPage(
-            new PreDefinedTypesPage(m_notebookPreDefTypes, iter->second), iter->first, iter->second.IsActive());
+            new PreDefinedTypesPage(m_notebookPreDefTypes, p.second), p.first, p.second.IsActive());
     }
 }
 
-DbgPagePreDefTypes::~DbgPagePreDefTypes() {}
-
 void DbgPagePreDefTypes::Save()
 {
     // copy the commands the serialized object m_data
@@ -191,12 +187,13 @@ void DbgPagePreDefTypes::OnDeleteSet(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     int sel = m_notebookPreDefTypes->GetSelection();
-    if(sel == wxNOT_FOUND) return;
+    if(sel == wxNOT_FOUND)
+        return;
 
     wxString name = m_notebookPreDefTypes->GetPageText((size_t)sel);
     if(wxMessageBox(
-           wxString::Format(wxT("You are about to delete 'PreDefined Types' set '%s'\nContinue ?"), name.c_str()),
-           wxT("Confirm deleting 'PreDefined Types' set"), wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
+           wxString::Format(_("You are about to delete 'PreDefined Types' set '%s'\nContinue ?"), name.c_str()),
+           _("Confirm deleting 'PreDefined Types' set"), wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
         m_notebookPreDefTypes->DeletePage((size_t)sel);
     }
 }
@@ -225,13 +222,14 @@ void DbgPagePreDefTypes::OnNewSet(wxCommandEvent& event)
     if(dlg.ShowModal() == wxID_OK) {
         wxString newName = dlg.GetNameTextctl()->GetValue();
         newName.Trim().Trim(false);
-        if(newName.IsEmpty()) return;
+        if(newName.IsEmpty())
+            return;
 
         // Make sure that a set with this name does not already exists
         for(size_t i = 0; i < m_notebookPreDefTypes->GetPageCount(); i++) {
             if(m_notebookPreDefTypes->GetPageText((size_t)i) == newName) {
-                wxMessageBox(wxT("A set with this name already exist"), wxT("Name Already Exists"),
-                    wxICON_WARNING | wxOK | wxCENTER);
+                wxMessageBox(_("A set with this name already exist"), _("Name Already Exists"),
+                             wxICON_WARNING | wxOK | wxCENTER);
                 return;
             }
         }
@@ -250,7 +248,7 @@ void DbgPagePreDefTypes::OnNewSet(wxCommandEvent& event)
 
         initialValues.SetName(newName);
         m_notebookPreDefTypes->AddPage(new PreDefinedTypesPage(m_notebookPreDefTypes, initialValues),
-            initialValues.GetName(), dlg.GetCheckBoxMakeActive()->IsChecked());
+                                       initialValues.GetName(), dlg.GetCheckBoxMakeActive()->IsChecked());
     }
 }
 
@@ -262,7 +260,6 @@ DebuggerSettingsDlg::DebuggerSettingsDlg(wxWindow* parent)
 {
     // fill the notebook with the available debuggers
     Initialize();
-    ConnectButton(m_buttonOK, DebuggerSettingsDlg::OnOk);
 
     GetSizer()->Fit(this);
     CenterOnParent();
@@ -273,26 +270,34 @@ DebuggerSettingsDlg::DebuggerSettingsDlg(wxWindow* parent)
 
 void DebuggerSettingsDlg::Initialize()
 {
-    MSWSetNativeTheme(m_treebook2->GetTreeCtrl());
-
-    // create page per-debugger
-    m_treebook2->AddPage(0, "GNU gdb debugger", true);
-
     // for each debugger, add page
-    m_treebook2->AddSubPage(new DebuggerPage(m_treebook2, "GNU gdb debugger"), wxT("General"), true);
-    m_treebook2->AddSubPage(new DebuggerPageMisc(m_treebook2, "GNU gdb debugger"), wxT("Misc"), false);
-    m_treebook2->AddSubPage(
-        new DebuggerPageStartupCmds(m_treebook2, "GNU gdb debugger"), wxT("Startup Commands"), false);
-    m_treebook2->AddPage(new DbgPagePreDefTypes(m_treebook2), wxT("Pre Defined Types"), false);
+    m_pages.clear();
+    DebuggerPage* p = new DebuggerPage(m_notebook, "GNU gdb debugger");
+    m_notebook->AddPage(p, _("GNU gdb debugger"), true);
+    m_pages.push_back(p);
+
+    wxNotebook* innerBook = p->GetNotebook73();
+    DebuggerPageMisc* misc = new DebuggerPageMisc(innerBook, "GNU gdb debugger");
+    innerBook->AddPage(misc, _("Misc"), false);
+    m_pages.push_back(misc);
+
+    DebuggerPageStartupCmds* cmds = new DebuggerPageStartupCmds(innerBook, "GNU gdb debugger");
+    innerBook->AddPage(cmds, _("Startup Commands"), false);
+    m_pages.push_back(cmds);
+
+    DbgPagePreDefTypes* types = new DbgPagePreDefTypes(m_notebook);
+    m_notebook->AddPage(types, _("Pre-Defined Types"), false);
+    m_pages.push_back(types);
 }
 
 void DebuggerSettingsDlg::OnOk(wxCommandEvent& e)
 {
     wxUnusedVar(e);
     // go over the debuggers and set the debugger path
-    for(size_t i = 0; i < (size_t)m_treebook2->GetPageCount(); i++) {
-        wxWindow* win = m_treebook2->GetPage(i);
-        if(!win) continue;
+    for(size_t i = 0; i < (size_t)m_pages.size(); ++i) {
+        wxWindow* win = m_pages[i];
+        if(!win)
+            continue;
 
         DebuggerPage* page = dynamic_cast<DebuggerPage*>(win);
         if(page) {
@@ -308,13 +313,15 @@ void DebuggerSettingsDlg::OnOk(wxCommandEvent& e)
             info.consoleCommand = EditorConfigST::Get()->GetOptions()->GetProgramConsoleCommand();
             info.catchThrow = page->m_catchThrow->IsChecked();
             info.showTooltipsOnlyWithControlKeyIsDown = page->m_showTooltipsRequiresControl->IsChecked();
-            info.maxDisplayStringSize = page->m_spinCtrlNumElements->GetValue();
+            info.maxDisplayStringSize = page->m_spinCtrlStringSize->GetValue();
+            info.maxDisplayElements = page->m_spinCtrlMaxElements->GetValue();
             info.resolveLocals = page->m_checkBoxExpandLocals->IsChecked();
             info.autoExpandTipItems = page->m_checkBoxAutoExpand->IsChecked();
             info.applyBreakpointsAfterProgramStarted = page->m_checkBoxSetBreakpointsAfterMain->IsChecked();
             info.whenBreakpointHitRaiseCodelite = page->m_raiseOnBpHit->IsChecked();
             info.charArrAsPtr = page->m_checkBoxCharArrAsPtr->IsChecked();
             info.enableGDBPrettyPrinting = page->m_checkBoxUsePrettyPrinting->IsChecked();
+            info.defaultHexDisplay = page->m_checkBoxDefaultHexDisplay->IsChecked();
 
             // Update the flags
             if(page->m_checkBoxPrintObjectOn->IsChecked()) {
@@ -353,7 +360,7 @@ void DebuggerSettingsDlg::OnOk(wxCommandEvent& e)
             // find the debugger
             DebuggerInformation info;
             DebuggerMgr::Get().GetDebuggerInformation(suCmds->m_title, info);
-            info.startupCommands = suCmds->m_textCtrlStartupCommands->GetText();
+            info.initFileCommands = suCmds->m_textCtrlStartupCommands->GetText();
             DebuggerMgr::Get().SetDebuggerInformation(suCmds->m_title, info);
         }
 
@@ -372,8 +379,6 @@ void DebuggerSettingsDlg::OnButtonCancel(wxCommandEvent& e)
     EndModal(wxID_CANCEL);
 }
 
-DebuggerSettingsDlg::~DebuggerSettingsDlg() {}
-
 void DebuggerPage::OnSuperuserUI(wxUpdateUIEvent& event)
 {
     event.Check(false);
