@@ -24,37 +24,31 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "editorsettingsterminal.h"
+
+#include "Console/clConsoleBase.h"
+#include "cl_config.h"
 #include "editor_config.h"
+#include "exelocator.h"
 
-EditorSettingsTerminal::EditorSettingsTerminal(wxWindow* parent)
-    : EditorSettingsTerminalBase(parent)
-    , TreeBookNode<EditorSettingsTerminal>()
+EditorSettingsTerminal::EditorSettingsTerminal(wxWindow* parent, OptionsConfigPtr options)
+    : OptionsConfigPage(parent, options)
 {
-    OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
-    m_textCtrlProgramConsoleCmd->SetValue(options->GetProgramConsoleCommand());
-    m_checkBoxUseCodeLiteTerminal->SetValue(options->HasOption(OptionsConfig::Opt_Use_CodeLite_Terminal));
-}
-
-void EditorSettingsTerminal::Save(OptionsConfigPtr options)
-{
-    options->SetProgramConsoleCommand(m_textCtrlProgramConsoleCmd->GetValue());
-    options->EnableOption(OptionsConfig::Opt_Use_CodeLite_Terminal, m_checkBoxUseCodeLiteTerminal->IsChecked());
-}
-
-void EditorSettingsTerminal::OnUseCodeLiteTerminalUI(wxUpdateUIEvent& event)
-{
-#if defined(__WXMSW__) || defined(__WXOSX__)
-    event.Enable(false);
-#else
-    event.Enable(!m_checkBoxUseCodeLiteTerminal->IsChecked());
+    wxArrayString terminals = clConsoleBase::GetAvailableTerminals();
+#if defined(__WXGTK__)
+    wxString where; // GetAvailableTerminals() doesn't, it gets a list of supported ones; so check for existence
+    for(size_t t = terminals.GetCount(); t > 0; --t) {
+        if(!ExeLocator::Locate(terminals.Item(t - 1), where)) {
+            terminals.RemoveAt(t - 1);
+        }
+    }
 #endif
-}
+    AddHeader(_("Terminals"));
 
-void EditorSettingsTerminal::OnCheckboxmswwrapdoublequotesUpdateUi(wxUpdateUIEvent& event)
-{
-#ifdef __WXMSW__
-    event.Enable(true);
-#else
-    event.Enable(false);
-#endif
+    wxString selection = clConsoleBase::GetSelectedTerminalName();
+    AddProperty(_("Choose your terminal"), terminals, selection, [&](const wxString& label, const wxAny& value) {
+        wxString value_str;
+        if(value.GetAs(&value_str)) {
+            clConfig::Get().Write("Terminal", value_str);
+        }
+    });
 }
