@@ -25,14 +25,14 @@
  #ifndef FILE_HISTORY_H
 #define FILE_HISTORY_H
 
-#include "wx/docview.h"
+#include <wx/docview.h>
 
 class FileHistory : public wxFileHistory
 {
 public:
-	FileHistory();
-	virtual ~FileHistory();
-	
+	FileHistory() = default;
+	virtual ~FileHistory() = default;
+
 	/**
 	 * \brief 
 	 * \param files
