@@ -25,12 +25,16 @@
 #ifndef FILE_VIEW_TREE_H
 #define FILE_VIEW_TREE_H
 
-#include "wx/treectrl.h"
-#include "project.h"
-#include "pluginmanager.h"
+#include "VirtualDirectoryColour.h"
+#include "clThemedTreeCtrl.h"
+#include "clTreeCtrlColourHelper.h"
 #include "imanager.h"
-#include "map"
-#include "clTreeKeyboardInput.h"
+#include "pluginmanager.h"
+#include "project.h"
+#include "wxStringHash.h"
+
+#include <map>
+#include <wx/treectrl.h>
 
 class wxMenu;
 
@@ -40,31 +44,27 @@ struct FileViewItem {
     wxString displayName;
 };
 
-class FileViewTree : public wxTreeCtrl
+class FileViewTree : public clThemedTreeCtrl
 {
-    DECLARE_DYNAMIC_CLASS()
-
-    std::map<void*, bool> m_itemsToSort;
     wxArrayTreeItemIds m_draggedFiles;
     wxArrayTreeItemIds m_draggedProjects;
-    clTreeKeyboardInput::Ptr_t m_keyboardHelper;
-    std::map<wxString, wxTreeItemId> m_workspaceFolders;
-    std::map<wxString, wxTreeItemId> m_projectsMap;
+    std::unordered_map<wxString, wxTreeItemId> m_workspaceFolders;
+    std::unordered_map<wxString, wxTreeItemId> m_projectsMap;
+    std::unordered_map<wxString, wxTreeItemId> m_excludeBuildFiles;
     bool m_eventsBound;
+    clTreeCtrlColourHelper::Ptr_t m_colourHelper;
 
 protected:
-    void DoCreateProjectContextMenu(wxMenu& menu, const wxString& projectName);
     void DoBindEvents();
     void DoUnbindEvents();
     void DoFilesEndDrag(wxTreeItemId& itemDst);
     void DoProjectsEndDrag(wxTreeItemId& itemDst);
+    void DoSetItemBackgroundColour(const wxTreeItemId& item, const FolderColour::List_t& colours,
+                                   const ProjectItem& projectItem);
+
+    void ExcludeFileFromBuildUI(const wxTreeItemId& item, bool exclude);
 
 public:
-    /**
-     * Default cosntructor.
-     */
-    FileViewTree();
-
     /**
      * Parameterized constructor.
      * @param parent Tree parent window
@@ -74,7 +74,7 @@ public:
      * @param style Window style
      */
     FileViewTree(wxWindow* parent, const wxWindowID id, const wxPoint& pos = wxDefaultPosition,
-        const wxSize& size = wxDefaultSize, long style = wxBORDER_NONE);
+                 const wxSize& size = wxDefaultSize, long style = wxBORDER_NONE);
 
     /**
      * Destructor .
@@ -82,15 +82,9 @@ public:
     virtual ~FileViewTree();
 
     /**
-     * Create tree, usually called after constructing FileViewTree with default constructor.
-     * @param parent Tree parent window
-     * @param id Window id
-     * @param pos Window position
-     * @param size Window size
-     * @param style Window style
+     * @brief build project context menu
      */
-    virtual void Create(wxWindow* parent, const wxWindowID id, const wxPoint& pos = wxDefaultPosition,
-        const wxSize& size = wxDefaultSize, long style = 0);
+    void CreateProjectContextMenu(wxMenu& menu, const wxString& projectName, bool usedByFileView = true);
 
     // Build the actual tree from the workspace
     void BuildTree();
@@ -132,6 +126,11 @@ public:
      */
     ProjectPtr GetSelectedProject() const;
 
+    /**
+     * @brief find the parent project of a given item
+     */
+    ProjectPtr GetItemProject(const wxTreeItemId& item) const;
+
     /**
      * @brief public access to the "OnFolderDropped" function
      * @param event
@@ -139,9 +138,10 @@ public:
     void FolderDropped(const wxArrayString& folders);
 
 protected:
+    void OnItemExpanding(wxTreeEvent& e);
     virtual void OnPopupMenu(wxTreeEvent& event);
     virtual void OnItemActivated(wxTreeEvent& event);
-    virtual void OnMouseDblClick(wxMouseEvent& event);
+    virtual void OnTreeKeyDown(wxTreeEvent& event);
     virtual void OnSelectionChanged(wxTreeEvent& e);
     virtual void OnOpenInEditor(wxCommandEvent& event);
     virtual void OnRemoveProject(wxCommandEvent& event);
@@ -152,13 +152,13 @@ protected:
     virtual void OnNewVirtualFolder(wxCommandEvent& event);
     virtual void OnLocalPrefs(wxCommandEvent& event);
     virtual void OnProjectProperties(wxCommandEvent& event);
-    virtual void OnSortItem(wxCommandEvent& event);
     virtual void OnRemoveVirtualFolder(wxCommandEvent& event);
     virtual void OnRemoveItem(wxCommandEvent& event);
     virtual void OnSaveAsTemplate(wxCommandEvent& event);
     virtual void OnBuildOrder(wxCommandEvent& event);
     virtual void OnClean(wxCommandEvent& event);
     virtual void OnBuild(wxCommandEvent& event);
+    virtual void OnPinProject(wxCommandEvent& event);
     virtual void OnReBuild(wxCommandEvent& event);
     virtual void OnRunPremakeStep(wxCommandEvent& event);
     virtual void OnBuildProjectOnly(wxCommandEvent& event);
@@ -180,20 +180,23 @@ protected:
     virtual void OnOpenFileExplorerFromFilePath(wxCommandEvent& e);
     virtual void OnExcludeFromBuild(wxCommandEvent& e);
     virtual void OnPreprocessItem(wxCommandEvent& e);
-    virtual void SortTree();
-    virtual void SortItem(wxTreeItemId& item);
+    virtual void OnBuildParentProject(wxCommandEvent& e);
     virtual void OnRenameVirtualFolder(wxCommandEvent& e);
+    virtual void OnSetBgColourVirtualFolder(wxCommandEvent& e);
+    virtual void OnClearBgColourVirtualFolder(wxCommandEvent& e);
     virtual wxTreeItemId ItemByFullPath(const wxString& fullPath);
     virtual void OnLocalWorkspaceSettings(wxCommandEvent& e);
     virtual void OnOpenWithDefaultApplication(wxCommandEvent& event);
     virtual void OnBuildTree(wxCommandEvent& e);
     void OnFolderDropped(clCommandEvent& event);
-
+    void OnFindInFilesShowing(clFindInFilesEvent& event);
+    void OnActiveProjectChanged(clProjectSettingsEvent& e);
     // Called from the context menu of a workspace folder
     void OnWorkspaceNewWorkspaceFolder(wxCommandEvent& evt);
     void OnNewProject(wxCommandEvent& evt);
     // Called from the workspace context menu
     void OnWorkspaceFolderNewFolder(wxCommandEvent& evt);
+    void OnAddProjectToWorkspaceFolder(wxCommandEvent& evt);
 
     void OnWorkspaceFolderDelete(wxCommandEvent& evt);
 
@@ -210,16 +213,24 @@ protected:
     // internal
     void OnBuildProjectOnlyInternal(wxCommandEvent& e);
     void OnCleanProjectOnlyInternal(wxCommandEvent& e);
+    void OnBuildConfigChanged(wxCommandEvent& e);
 
     /**
      * @brief clear the "active" marker from all the projects
      */
     void UnselectAllProject();
 
+    /**
+     * @brief return the item data for an item
+     */
+    FilewViewTreeItemData* ItemData(const wxTreeItemId& item) const;
+
 private:
     // Build project node
     void BuildProjectNode(const wxString& projectName);
     void DoClear();
+    void DoAddChildren(const wxTreeItemId& parentItem);
+    void DoBuildSubTreeIfNeeded(const wxTreeItemId& parent);
 
     /**
      * @brief add a workspace folder
@@ -228,20 +239,21 @@ private:
     wxTreeItemId AddWorkspaceFolder(const wxString& folderPath);
 
     int GetIconIndex(const ProjectItem& item);
-    wxString GetItemPath(wxTreeItemId& item) const;
+    wxString GetItemPath(const wxTreeItemId& item, const wxChar& sep = ':') const;
     bool IsFileExcludedFromBuild(const wxTreeItemId& item) const;
 
     void DoGetProjectIconIndex(const wxString& projectName, int& iconIndex, bool& fromPlugin);
     bool DoAddNewItem(wxTreeItemId& item, const wxString& filename, const wxString& vdFullpath);
-    void DoRemoveProject(const wxString& name);
+    bool DoRemoveProject(const wxString& name);
     void DoSetProjectActive(wxTreeItemId& item);
+    void DoSetProjectActiveUI(wxTreeItemId& item);
     wxTreeItemId DoAddVirtualFolder(wxTreeItemId& parent, const wxString& text);
-    void DoRemoveVirtualFolder(wxTreeItemId& parent);
+    bool DoRemoveVirtualFolder(const wxTreeItemId& parent);
     void DoRemoveItems();
     void DoItemActivated(wxTreeItemId& item, wxEvent& event);
     void DoAddItem(ProjectPtr proj, const FileViewItem& item);
     void DoImportFolder(ProjectPtr proj, const wxString& baseDir, const wxArrayString& all_files,
-        const wxString& filespec, bool extlessFiles);
+                        const wxString& filespec, bool extlessFiles);
 
     wxTreeItemId DoGetItemByText(const wxTreeItemId& parent, const wxString& text);
 
