@@ -22,40 +22,37 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <wx/xrc/xmlres.h>
-#include "bitmap_loader.h"
-#include <wx/wupdlock.h>
-#include "drawingutils.h"
-#include "event_notifier.h"
-#include <wx/tokenzr.h>
-#include "editor_config.h"
-#include "globals.h"
-#include "manager.h"
-#include "frame.h"
-#include "ctags_manager.h"
-#include "cl_editor.h"
-#include "editor_config.h"
-#include "pluginmanager.h"
-#include "globals.h"
 #include "findresultstab.h"
-#include "search_thread.h"
-#include "event_notifier.h"
-#include "theme_handler.h"
-#include "cl_config.h"
+
 #include "ColoursAndFontsManager.h"
-#include "lexer_configuration.h"
 #include "attribute_style.h"
-#include <algorithm>
+#include "bitmap_loader.h"
+#include "clStrings.h"
+#include "clToolBarButtonBase.h"
 #include "cl_aui_tool_stickness.h"
-#include "optionsconfig.h"
-#include "editor_config.h"
+#include "cl_command_event.h"
+#include "cl_config.h"
+#include "cl_editor.h"
 #include "codelite_events.h"
+#include "ctags_manager.h"
+#include "drawingutils.h"
+#include "editor_config.h"
+#include "event_notifier.h"
+#include "frame.h"
+#include "globals.h"
+#include "lexer_configuration.h"
+#include "manager.h"
+#include "optionsconfig.h"
+#include "pluginmanager.h"
+#include "search_thread.h"
+
+#include <algorithm>
+#include <wx/msgdlg.h>
+#include <wx/tokenzr.h>
+#include <wx/wupdlock.h>
+#include <wx/xrc/xmlres.h>
 
 BEGIN_EVENT_TABLE(FindResultsTab, OutputTabWindow)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHSTARTED, FindResultsTab::OnSearchStart)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_MATCHFOUND, FindResultsTab::OnSearchMatch)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHEND, FindResultsTab::OnSearchEnded)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHCANCELED, FindResultsTab::OnSearchCancel)
 EVT_UPDATE_UI(XRCID("hold_pane_open"), FindResultsTab::OnHoldOpenUpdateUI)
 END_EVENT_TABLE()
 
@@ -63,46 +60,50 @@ FindResultsTab::FindResultsTab(wxWindow* parent, wxWindowID id, const wxString&
     : OutputTabWindow(parent, id, name)
     , m_searchInProgress(false)
 {
+    BindSearchEvents(this);
     m_sci->Connect(wxEVT_STC_STYLENEEDED, wxStyledTextEventHandler(FindResultsTab::OnStyleNeeded), NULL, this);
-
-    BitmapLoader& loader = *(PluginManager::Get()->GetStdIcons());
-
     wxTheApp->Connect(XRCID("find_in_files"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
-    m_tb->Bind(wxEVT_AUITOOLBAR_TOOL_DROPDOWN, &FindResultsTab::OnRecentSearches, this, XRCID("recent_searches"));
+                      wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
+    m_tb->Bind(wxEVT_TOOL_DROPDOWN, &FindResultsTab::OnRecentSearches, this, XRCID("recent_searches"));
     m_tb->Bind(wxEVT_UPDATE_UI, &FindResultsTab::OnRecentSearchesUI, this, XRCID("recent_searches"));
 
-    m_tb->AddTool(XRCID("stop_search"), _("Stop current search"), loader.LoadBitmap("stop"), _("Stop current search"));
-    m_tb->AddTool(XRCID("recent_searches"), _("Show Recent Searches"), loader.LoadBitmap("history"),
-            _("Show Recent Searches"))
-        ->SetHasDropDown(true);
+    auto images = m_tb->GetBitmapsCreateIfNeeded();
+    m_tb->AddTool(XRCID("stop_search"), _("Stop current search"), images->Add("stop"), _("Stop current search"));
+    m_tb->AddTool(XRCID("recent_searches"), _("Show Recent Searches"), images->Add("history"),
+                  _("Show Recent Searches"), wxITEM_DROPDOWN);
 
     Connect(XRCID("stop_search"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(FindResultsTab::OnStopSearch),
-        NULL, this);
+            NULL, this);
     Connect(XRCID("stop_search"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(FindResultsTab::OnStopSearchUI), NULL, this);
     m_tb->Realize();
 
-    EventNotifier::Get()->Connect(
-        wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(FindResultsTab::OnThemeChanged), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(FindResultsTab::OnThemeChanged), NULL,
+                                  this);
 
     // Use the same eventhandler for editor config changes too e.g. show/hide whitespace
     EventNotifier::Get()->Bind(wxEVT_EDITOR_CONFIG_CHANGED, &FindResultsTab::OnThemeChanged, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &FindResultsTab::OnWorkspaceClosed, this);
 }
 
 FindResultsTab::~FindResultsTab()
 {
-    EventNotifier::Get()->Connect(
-        wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(FindResultsTab::OnThemeChanged), NULL, this);
+    UnbindSearchEvents(this);
+    EventNotifier::Get()->Connect(wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(FindResultsTab::OnThemeChanged), NULL,
+                                  this);
     wxTheApp->Disconnect(XRCID("find_in_files"), wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
+                         wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &FindResultsTab::OnWorkspaceClosed, this);
 }
 
 void FindResultsTab::SetStyles(wxStyledTextCtrl* sci) { m_styler->SetStyles(sci); }
 
-void FindResultsTab::AppendText(const wxString& line)
+void FindResultsTab::AppendLine(const wxString& line, bool scroll_to_bottom)
 {
     m_sci->SetIndicatorCurrent(1);
     OutputTabWindow::AppendText(line);
+    if(scroll_to_bottom) {
+        ScrollToBottom();
+    }
 }
 
 void FindResultsTab::Clear()
@@ -116,24 +117,13 @@ void FindResultsTab::Clear()
 
 void FindResultsTab::OnFindInFiles(wxCommandEvent& e)
 {
+    wxUnusedVar(e);
     if(m_searchInProgress) {
-        ::wxMessageBox(_("The search thread is currently busy"), _("CodeLite"), wxICON_INFORMATION | wxOK);
+        ::wxMessageBox(_("Another search is currently running, try again later"), wxT("CodeLite"),
+                       wxICON_WARNING | wxOK | wxOK_DEFAULT);
         return;
     }
-
-    // Fire the wxEVT_CMD_FIND_IN_FILES_SHOWING showing event
-    clCommandEvent fifDlgShowing(wxEVT_CMD_FIND_IN_FILES_SHOWING);
-    EventNotifier::Get()->ProcessEvent(fifDlgShowing);
-
-    // Display the Find In Files dialog
-    FindInFilesDialog dlg(EventNotifier::Get()->TopFrame(), "FindInFilesData", fifDlgShowing.GetStrings());
-    wxArrayString* paths = (wxArrayString*)e.GetClientData();
-    if(paths) {
-        dlg.SetSearchPaths(*paths);
-        e.SetClientData(NULL);
-        wxDELETE(paths);
-    }
-    dlg.ShowDialog();
+    clGetManager()->OpenFindInFileForPaths({});
 }
 
 void FindResultsTab::OnSearchStart(wxCommandEvent& e)
@@ -151,55 +141,49 @@ void FindResultsTab::OnSearchStart(wxCommandEvent& e)
                 << (data->IsMatchCase() ? _("true") : _("false")) << _(" ; Match whole word: ")
                 << (data->IsMatchWholeWord() ? _("true") : _("false")) << _(" ; Regular expression: ")
                 << (data->IsRegularExpression() ? _("true") : _("false")) << wxT(" ======\n");
-        AppendText(message);
+        AppendLine(message);
+        ScrollToBottom();
     }
     wxDELETE(data);
+
+    // Make sure that the Output view & the "Replace" tab
+    // are visible
+
+    clCommandEvent event(wxEVT_SHOW_OUTPUT_TAB);
+    event.SetSelected(true).SetString(FIND_IN_FILES_WIN);
+    EventNotifier::Get()->AddPendingEvent(event);
 }
 
 void FindResultsTab::OnSearchMatch(wxCommandEvent& e)
 {
     SearchResultList* res = (SearchResultList*)e.GetClientData();
-    if(!res) return;
+    if(!res) {
+        return;
+    }
 
-    SearchResultList::iterator iter = res->begin();
-    for(; iter != res->end(); ++iter) {
-        if(m_matchInfo.empty() || m_matchInfo.rbegin()->second.GetFileName() != iter->GetFileName()) {
+    wxWindowUpdateLocker locker{ m_sci };
+    m_indicators.reserve(m_indicators.size() + res->size());
+
+    for (const auto& searchResult : *res) {
+        if (m_matchInfo.empty() || m_matchInfo.rbegin()->second.GetFileName() != searchResult.GetFileName()) {
             if(!m_matchInfo.empty()) {
-                AppendText("\n");
+                AppendLine("\n", false);
             }
-            wxFileName fn(iter->GetFileName());
-            fn.MakeRelativeTo();
-            AppendText(fn.GetFullPath() + wxT("\n"));
+            AppendLine(searchResult.GetFileName() + wxT("\n"), false);
         }
 
         int lineno = m_sci->GetLineCount() - 1;
-        m_matchInfo.insert(std::make_pair(lineno, *iter));
-        wxString text = iter->GetPattern();
-        // int delta = -text.Length();
-        // text.Trim(false);
-        // delta += text.Length();
-        // text.Trim();
+        m_matchInfo.insert(std::make_pair(lineno, searchResult));
+        wxString text = searchResult.GetPattern();
 
-        wxString linenum = wxString::Format(wxT(" %5u: "), iter->GetLineNumber());
-        SearchData* d = GetSearchData();
-        // Print the scope name
-        if(d->GetDisplayScope()) {
-            TagEntryPtr tag = TagsManagerST::Get()->FunctionFromFileLine(iter->GetFileName(), iter->GetLineNumber());
-            wxString scopeName(wxT("global"));
-            if(tag) {
-                scopeName = tag->GetPath();
-            }
-
-            linenum << wxT("[ ") << scopeName << wxT(" ] ");
-            iter->SetScope(scopeName);
-        }
-
-        AppendText(linenum + text + wxT("\n"));
-        int indicatorStartPos = m_sci->PositionFromLine(lineno) + iter->GetColumn() + linenum.Length();
-        int indicatorLen = iter->GetLen();
-        m_indicators.push_back(indicatorStartPos);
+        wxString linenum = wxString::Format(wxT(" %5u: "), searchResult.GetLineNumber());
+        AppendLine(linenum + text + wxT("\n"), false);
+        int indicatorStartPos = m_sci->PositionFromLine(lineno) + searchResult.GetColumn() + linenum.Length();
+        int indicatorLen = searchResult.GetLen();
+        m_indicators.emplace_back(indicatorStartPos);
         m_sci->IndicatorFillRange(indicatorStartPos, indicatorLen);
     }
+    ScrollToBottom();
     wxDELETE(res);
 }
 
@@ -207,12 +191,13 @@ void FindResultsTab::OnSearchEnded(wxCommandEvent& e)
 {
     m_searchInProgress = false;
     SearchSummary* summary = (SearchSummary*)e.GetClientData();
-    if(!summary) return;
+    if(!summary)
+        return;
 
     // did the page closed before the search ended?
-    AppendText(summary->GetMessage() + wxT("\n"));
+    AppendLine(summary->GetMessage() + wxT("\n"));
 
-    if(m_tb->GetToolToggled(XRCID("scroll_on_output"))) {
+    if(m_tb->FindById(XRCID("scroll_on_output")) && m_tb->FindById(XRCID("scroll_on_output"))->IsToggled()) {
         m_sci->GotoLine(0);
     }
 
@@ -229,31 +214,22 @@ void FindResultsTab::OnSearchEnded(wxCommandEvent& e)
         }
     }
 
-    delete summary;
+    wxDELETE(summary);
     SaveSearchData();
 
     // We need to tell all editors that there's been a (new) search
     // This lets them clear any already-saved line-changes,
     // which a new save will have taken into account
-    LEditor::Vec_t editors;
-    clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_IncludeDetached);
+    auto editors = clMainFrame::Get()->GetMainBook()->GetAllEditors();
     for(size_t n = 0; n < editors.size(); ++n) {
-        LEditor* editor = dynamic_cast<LEditor*>(*(editors.begin() + n));
+        clEditor* editor = dynamic_cast<clEditor*>(*(editors.begin() + n));
         if(editor) {
             editor->OnFindInFiles();
         }
     }
 }
 
-void FindResultsTab::OnSearchCancel(wxCommandEvent& e)
-{
-    m_searchInProgress = false;
-    wxString* str = (wxString*)e.GetClientData();
-    if(!str) return;
-    AppendText((*str) + wxT("\n"));
-    SaveSearchData();
-    wxDELETE(str);
-}
+void FindResultsTab::OnSearchCancel(wxCommandEvent& e) { AppendLine(_("====== Search cancelled by user ======\n")); }
 
 void FindResultsTab::OnClearAll(wxCommandEvent& e)
 {
@@ -348,12 +324,28 @@ void FindResultsTab::PrevMatch()
 void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledTextCtrl* sci, int markerLine)
 {
     if(!result.GetFileName().IsEmpty()) {
-        LEditor* editor = clMainFrame::Get()->GetMainBook()->OpenFile(result.GetFileName());
+        // let plugins handle this first
+        clFindInFilesEvent open_event(wxEVT_FINDINFILES_OPEN_MATCH);
+
+        // prepare a single match entry and fire it
+        clFindInFilesEvent::Match match;
+        clFindInFilesEvent::Location loc;
+        match.file = result.GetFileName();
+        loc.column_start = result.GetColumn();
+        loc.column_end = result.GetColumn() + result.GetLen();
+        loc.line = result.GetLineNumber();
+        match.locations.push_back(loc);
+        open_event.GetMatches().push_back(match);
+
+        if(EventNotifier::Get()->ProcessEvent(open_event)) {
+            return;
+        }
+
+        clEditor* editor = clMainFrame::Get()->GetMainBook()->OpenFile(result.GetFileName());
         if(editor && result.GetLen() >= 0) {
             // Update the destination position if there have been subsequent changes in the editor
-            int position = result.GetPosition();
-            std::vector<int> changes;
-            editor->GetChanges(changes);
+            int position = editor->PositionFromLine(result.GetLineNumber() - 1) + result.GetColumn();
+            const std::vector<int> changes = editor->GetChanges();
             unsigned int changesTotal = changes.size();
             int changePosition = 0;
             int changeLength = 0;
@@ -363,7 +355,7 @@ void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledText
                 changePosition = changes.at(i);
                 changeLength = changes.at(i + 1);
                 if((changeLength < 0) && (changePosition - changeLength > position) &&
-                    (changePosition < position + resultLength)) {
+                   (changePosition < position + resultLength)) {
                     // It looks like the data corresponding to this search result has been deleted
                     // While it's possible that it's been cut, then (later in the changes) re-pasted
                     // so that the result still matches, it's more likely to have been replaced by different text
@@ -377,18 +369,15 @@ void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledText
                 }
             }
             if(!removed) {
-                editor->SetEnsureCaretIsVisible(position + resultLength, true,
-                    true); // The 3rd parameter sets a small delay, otherwise it fails for long folded files
+                // use the "Async" way of loading the file and then selecting the match
+                // this ensures that the results are visible and centered in screen
                 int lineNumber = editor->LineFromPos(position);
-                if(lineNumber) {
-                    lineNumber--;
-                }
-                editor->SetLineVisible(lineNumber);
-                editor->SetSelection(position, position + resultLength);
-
-#ifdef __WXGTK__
-                editor->ScrollToColumn(0);
-#endif
+                auto callback = [=](IEditor* p_editor) {
+                    p_editor->GetCtrl()->ClearSelections();
+                    p_editor->GetCtrl()->SetSelection(position, position + resultLength);
+                    p_editor->CenterLinePreserveSelection(lineNumber);
+                };
+                clGetManager()->OpenFileAndAsyncExecute(editor->GetFileName().GetFullPath(), std::move(callback));
 
                 if(sci) {
                     // remove the previous marker and add the new one
@@ -404,8 +393,14 @@ void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledText
 
 void FindResultsTab::OnStopSearch(wxCommandEvent& e)
 {
+    // stop the search thread
+    wxUnusedVar(e);
     // stop the search thread
     SearchThreadST::Get()->StopSearch();
+
+    // and in case the search functionality is done by a plugin, fire an event
+    clFindInFilesEvent stop_event{ wxEVT_FINDINFILES_STOP_SEARCH };
+    EventNotifier::Get()->AddPendingEvent(stop_event);
 }
 
 void FindResultsTab::OnStopSearchUI(wxUpdateUIEvent& e) { e.Enable(m_searchInProgress); }
@@ -417,7 +412,7 @@ void FindResultsTab::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
         return;
     }
 
-    if(EditorConfigST::Get()->GetOptions()->GetHideOutpuPaneOnUserClick()) {
+    if (EditorConfigST::Get()->GetOptions()->GetHideOutputPaneOnUserClick()) {
         e.Enable(true);
         e.Check(EditorConfigST::Get()->GetOptions()->GetHideOutputPaneNotIfSearch());
 
@@ -430,7 +425,8 @@ void FindResultsTab::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
 void FindResultsTab::OnStyleNeeded(wxStyledTextEvent& e)
 {
     wxStyledTextCtrl* ctrl = dynamic_cast<wxStyledTextCtrl*>(e.GetEventObject());
-    if(!ctrl) return;
+    if(!ctrl)
+        return;
     StyleText(ctrl, e);
 }
 
@@ -445,25 +441,29 @@ void FindResultsTab::OnThemeChanged(wxCommandEvent& e)
     SetStyles(m_sci);
 }
 
-void FindResultsTab::OnRecentSearches(wxAuiToolBarEvent& e)
+void FindResultsTab::OnRecentSearches(wxCommandEvent& e)
 {
     // Show the menu
     wxMenu menu;
-    clAuiToolStickness s(m_tb, e.GetId());
     const int firstID = 8000;
     int counter = 0;
     std::map<int, History> entries;
-    std::for_each(m_history.Begin(), m_history.End(), [&](const std::pair<wxString, History>& p) {
+    for (const auto& p : m_history) {
         menu.Prepend(firstID + counter, p.first, "", wxITEM_CHECK)->Check(m_searchTitle == p.first);
         entries.insert(std::make_pair(firstID + counter, p.second));
         ++counter;
-    });
+    }
+
+    auto button = m_tb->FindById(e.GetId());
+    CHECK_PTR_RET(button);
 
     menu.AppendSeparator();
     int clearHistory = ::wxNewId();
     menu.Append(clearHistory, _("Clear History"));
-    int sel = GetPopupMenuSelectionFromUser(menu, e.GetItemRect().GetBottomLeft());
-    if(sel == wxID_NONE) return;
+    int sel = m_tb->GetMenuSelectionFromUser(XRCID("recent_searches"), &menu);
+    if(sel == wxID_NONE) {
+        return;
+    }
     if(sel == clearHistory) {
         m_history.Clear();
 
@@ -501,8 +501,9 @@ void FindResultsTab::LoadSearch(const History& h)
     m_sci->SetText(h.text);
 
     // restore the indicators
-    std::for_each(
-        h.indicators.begin(), h.indicators.end(), [&](int pos) { m_sci->IndicatorFillRange(pos, h.title.length()); });
+    for (int pos : h.indicators) {
+        m_sci->IndicatorFillRange(pos, h.title.length());
+    }
     m_sci->SetFirstVisibleLine(0);
     m_sci->SetEditable(false);
 }
@@ -511,9 +512,35 @@ void FindResultsTab::OnRecentSearchesUI(wxUpdateUIEvent& e) { e.Enable(!m_histor
 
 void FindResultsTab::ResetStyler() { m_styler->Reset(); }
 
+void FindResultsTab::OnWorkspaceClosed(clWorkspaceEvent& event)
+{
+    event.Skip();
+    Clear();
+}
+
+void FindResultsTab::UnbindSearchEvents(wxEvtHandler* binder)
+{
+    if(!m_searchEventsConnected)
+        return;
+    m_searchEventsConnected = false;
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHSTARTED, &FindResultsTab::OnSearchStart, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_MATCHFOUND, &FindResultsTab::OnSearchMatch, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHEND, &FindResultsTab::OnSearchEnded, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHCANCELED, &FindResultsTab::OnSearchCancel, this);
+}
+
+void FindResultsTab::BindSearchEvents(wxEvtHandler* binder)
+{
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHSTARTED, &FindResultsTab::OnSearchStart, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_MATCHFOUND, &FindResultsTab::OnSearchMatch, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHEND, &FindResultsTab::OnSearchEnded, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHCANCELED, &FindResultsTab::OnSearchCancel, this);
+    m_searchEventsConnected = true;
+}
+
 /////////////////////////////////////////////////////////////////////////////////
 
-void EditorDeltasHolder::GetChanges(std::vector<int>& changes)
+std::vector<int> EditorDeltasHolder::GetChanges()
 {
     // There may have been net +ve or -ve position changes (i.e. undos) subsequent to a last save
     // and some of these may have then been overwritten by different ones. So we need to add both the originals and
@@ -523,10 +550,11 @@ void EditorDeltasHolder::GetChanges(std::vector<int>& changes)
     // none since the last save,
     // but it may also mean that there have been n undos, followed by n different alterations. So we have to treat all
     // array sizes the same
-    changes.clear();
+    std::vector<int> changes;
     for(int index = m_changesForCurrentMatches.size() - 2; index >= 0; index -= 2) {
         changes.push_back(m_changesForCurrentMatches.at(index));      // position
         changes.push_back(-m_changesForCurrentMatches.at(index + 1)); // length
     }
     changes.insert(changes.end(), m_changes.begin(), m_changes.end());
+    return changes;
 }
