@@ -25,18 +25,19 @@
 #ifndef __findresultstab__
 #define __findresultstab__
 
-#include <vector>
-#include <map>
-#include <list>
-#include <wx/stc/stc.h>
-#include "wx/debug.h"
-
 #include "Notebook.h"
+#include "clWorkspaceEvent.hpp"
+#include "findinfilesdlg.h"
 #include "outputtabwindow.h"
 #include "search_thread.h"
-#include "findinfilesdlg.h"
 #include "wx_ordered_map.h"
+
+#include <map>
+#include <unordered_map>
+#include <vector>
 #include <wx/aui/auibar.h>
+#include <wx/debug.h>
+#include <wx/stc/stc.h>
 
 // Map between the line numbers and a search results
 typedef std::map<int, SearchResult> MatchInfo_t;
@@ -46,15 +47,16 @@ class FindResultsTab : public OutputTabWindow
 protected:
     SearchData m_searchData;
     wxString m_searchTitle;
-    std::list<int> m_indicators;
+    std::vector<int> m_indicators;
     bool m_searchInProgress;
+    bool m_searchEventsConnected = false;
 
     struct History {
         wxString title;
         SearchData searchData;
         wxString text;
         MatchInfo_t matchInfo;
-        std::list<int> indicators;
+        std::vector<int> indicators;
         typedef wxOrderedMap<wxString, History> Map_t;
     };
 
@@ -62,13 +64,15 @@ protected:
 
 protected:
     MatchInfo_t m_matchInfo;
+    void UnbindSearchEvents(wxEvtHandler* binder);
+    void BindSearchEvents(wxEvtHandler* binder);
 
-    void AppendText(const wxString& line);
+    void AppendLine(const wxString& line, bool scroll_to_bottom = true);
     void Clear();
     void SaveSearchData();
     void LoadSearch(const History& h);
     virtual void OnFindInFiles(wxCommandEvent& e);
-    virtual void OnRecentSearches(wxAuiToolBarEvent& e);
+    virtual void OnRecentSearches(wxCommandEvent& e);
     virtual void OnSearchStart(wxCommandEvent& e);
     virtual void OnSearchMatch(wxCommandEvent& e);
     virtual void OnSearchEnded(wxCommandEvent& e);
@@ -88,13 +92,14 @@ protected:
     SearchData* GetSearchData();
     void DoOpenSearchResult(const SearchResult& result, wxStyledTextCtrl* sci, int markerLine);
     void OnThemeChanged(wxCommandEvent& e);
+    void OnWorkspaceClosed(clWorkspaceEvent& event);
     DECLARE_EVENT_TABLE()
 
 public:
     FindResultsTab(wxWindow* parent, wxWindowID id, const wxString& name);
     ~FindResultsTab();
 
-    void SetStyles(wxStyledTextCtrl* sci);
+    virtual void SetStyles(wxStyledTextCtrl* sci);
     void StyleText(wxStyledTextCtrl* ctrl, wxStyledTextEvent& e, bool hasSope = false);
     void ResetStyler();
 
@@ -141,7 +146,7 @@ class EditorDeltasHolder
     // GetChanges()
 
 public:
-    EditorDeltasHolder() {}
+    EditorDeltasHolder() = default;
     ~EditorDeltasHolder() { Clear(); }
 
     void Clear()
@@ -166,7 +171,7 @@ public:
 
     void OnFileSaved() { m_changesAtLastSave = m_changes; }
     void OnFileInFiles() { m_changesForCurrentMatches = m_changesAtLastSave; }
-    void GetChanges(std::vector<int>& changes);
+    std::vector<int> GetChanges();
 
 protected:
     std::vector<int> m_changes;
