@@ -25,13 +25,16 @@
 #ifndef LITEEDITOR_FRAME_H
 #define LITEEDITOR_FRAME_H
 
+#include "AsyncProcess/ZombieReaperPOSIX.h"
 #include "EnvironmentVariablesDlg.h"
 #include "Notebook.h"
-#include "ZombieReaperPOSIX.h"
+#include "SecondarySideBar.hpp"
+#include "ai/ChatAI.hpp"
+#include "clCaptionBar.hpp"
 #include "clDockingManager.h"
 #include "clInfoBar.h"
-#include "clMainFrameHelper.h"
 #include "clStatusBar.h"
+#include "clToolBar.h"
 #include "cl_command_event.h"
 #include "cl_editor.h"
 #include "cl_process.h"
@@ -40,33 +43,32 @@
 #include "macros.h"
 #include "mainbook.h"
 #include "output_pane.h"
-#include "parse_thread.h"
-#include "refactorengine.h"
 #include "tags_options_dlg.h"
-#include "theme_handler.h"
-#include "wx/aui/aui.h"
-#include "wx/choice.h"
-#include "wx/combobox.h"
-#include "wx/frame.h"
-#include "wx/timer.h"
+#include "wxCustomControls.hpp"
+
 #include <set>
+#include <wx/aui/aui.h>
+#include <wx/choice.h>
 #include <wx/cmndata.h>
+#include <wx/combobox.h>
 #include <wx/dcbuffer.h>
+#include <wx/frame.h>
 #include <wx/html/htmlwin.h>
 #include <wx/infobar.h>
 #include <wx/minifram.h>
 #include <wx/process.h>
 #include <wx/splash.h>
+#include <wx/timer.h>
 
 // forward decls
+class OnSysColoursChanged;
 class DebuggerToolBar;
-class clToolBar;
 class WebUpdateJob;
 class CodeLiteApp;
 class clSingleInstanceThread;
 class wxCustomStatusBar;
 class TagEntry;
-class WorkspacePane;
+class SideBar;
 class wxToolBar;
 class OpenWindowsPanel;
 class WorkspaceTab;
@@ -90,68 +92,73 @@ struct StartPageData {
 
 class clMainFrame : public wxFrame
 {
+    enum class ePostBuildEndAction { kNone, kRunProject, kRebuildProject };
+
     MainBook* m_mainBook;
     static clMainFrame* m_theFrame;
     clDockingManager m_mgr;
     OutputPane* m_outputPane;
-    WorkspacePane* m_workspacePane;
+    SideBar* m_sidebar = nullptr;
+    SecondarySideBar* m_secondary_sidebar = nullptr;
     wxArrayString m_files;
     wxTimer* m_timer;
     std::map<int, wxString> m_viewAsMap;
     TagsOptionsData m_tagsOptionsData;
     DebuggerPane* m_debuggerPane;
-    bool m_buildAndRun;
+    ePostBuildEndAction m_postBuildEndAction{ePostBuildEndAction::kNone};
     GeneralInfo m_frameGeneralInfo;
-    std::map<int, wxString> m_toolbars;
     std::map<int, wxString> m_panes;
-    wxMenu* m_cppMenu;
-    bool m_highlightWord;
+    bool m_highlightWord{false};
     DockablePaneMenuManager* m_DPmenuMgr;
     wxPanel* m_mainPanel;
     wxString m_codeliteDownloadPageURL;
     wxString m_defaultLayout;
-    bool m_workspaceRetagIsRequired;
+    bool m_workspaceRetagIsRequired{false};
     bool m_loadLastSession;
-    wxSizer* m_horzSizer;
-    MyMenuBar* m_myMenuBar;
-    wxMenu* m_bookmarksDropDownMenu;
-    ThemeHandler m_themeHandler;
-    bool m_noSavePerspectivePrompt;
+    wxMenuBar* m_mainMenuBar;
 
 #ifndef __WXMSW__
     ZombieReaperPOSIX m_zombieReaper;
-#else
-    HMENU hMenu = nullptr; // Menu bar
 #endif
 
 #ifdef __WXGTK__
-    bool m_isWaylandSession = false;
+    bool m_isWaylandSession{false};
 #endif
 
     // Maintain a set of core toolbars (i.e. toolbars not owned by any plugin)
     wxStringSet_t m_coreToolbars;
     clStatusBar* m_statusBar;
-    clSingleInstanceThread* m_singleInstanceThread;
-    bool m_toggleToolBar;
+    clSingleInstanceThread* m_singleInstanceThread{nullptr};
 
     // Printing
     wxPrintDialogData m_printDlgData;
-    clMainFrameHelper::Ptr_t m_frameHelper;
-    WebUpdateJob* m_webUpdate;
-    clToolBar* m_toolbar;
+    size_t m_debuggerFeatures = clDebugEvent::kAllFeatures;
+    WebUpdateJob* m_webUpdate{nullptr};
+    wxToolBar* m_mainToolbar{nullptr};
+    clToolBarGeneric* m_pluginsToolbar{nullptr};
     DebuggerToolBar* m_debuggerToolbar = nullptr;
     clInfoBar* m_infoBar = nullptr;
+#if !wxUSE_NATIVE_CAPTION
+    clCaptionBar* m_captionBar = nullptr;
+#endif
+    // the main tool default style
+    int m_mainToolbarStyle = wxTB_FLAT | wxTB_NODIVIDER /* toolbar is hidden by default */;
+    wxString m_mainFrameTitleTemplate;
+    std::unique_ptr<ChatAI> m_chatAI{nullptr};
 
 public:
     static bool m_initCompleted;
 
 protected:
     bool IsEditorEvent(wxEvent& event);
+    void DoSysColoursChanged();
     void DoCreateBuildDropDownMenu(wxMenu* menu);
     void DoShowToolbars(bool show, bool update = true);
     void InitializeLogo();
-    void DoFullscreen(bool b);
     void DoShowMenuBar(bool show);
+    void OnSysColoursChanged(clCommandEvent& event);
+    void RestoreFrameSizeAndPosition();
+    void UpdateMainToolbarOrientation(int newOrientation);
 
 public:
     void Raise() override;
@@ -159,13 +166,15 @@ public:
     static clMainFrame* Get();
     static void Initialize(bool loadLastSession);
 
+    wxPanel* GetMainPanel() const { return m_mainPanel; }
+
     clInfoBar* GetMessageBar() { return m_infoBar; }
 
     /**
      * @brief return the menu bar
      * @return
      */
-    wxMenuBar* GetMenuBar() const override;
+    wxMenuBar* GetMainMenuBar() const { return m_mainMenuBar; }
 
     /**
      * @brief goto anything..
@@ -218,7 +227,7 @@ public:
      */
     void SelectBestEnvSet();
 
-    virtual ~clMainFrame(void);
+    virtual ~clMainFrame();
     /**
      * @brief set frame option flag
      * @param set
@@ -260,7 +269,12 @@ public:
     /**
      * @return the workspace pane (the one that contained the Symbol view & class view)
      */
-    WorkspacePane* GetWorkspacePane() { return m_workspacePane; }
+    SideBar* GetWorkspacePane() { return m_sidebar; }
+
+    /**
+     * @return the workspace pane (the one that contained the Symbol view & class view)
+     */
+    SecondarySideBar* GetSecondarySideBar() { return m_secondary_sidebar; }
 
     /**
      * return the workspace tab pane
@@ -286,7 +300,7 @@ public:
 
     /**
      * Compelete the main frame initialization
-     * this method is called immediatly after the
+     * this method is called immediately after the
      * main frame construction is over.
      */
     void CompleteInitialization();
@@ -299,11 +313,23 @@ public:
     void OnSingleInstanceRaise(clCommandEvent& e);
 
     /**
-     * @brief rebuild the give project
+     * @brief build the given project
+     * @param projectName
+     */
+    void BuildProject(const wxString& projectName);
+
+    /**
+     * @brief rebuild the given project
      * @param projectName
      */
     void RebuildProject(const wxString& projectName);
 
+    /**
+     * @brief execute a built program without attaching a debugger
+     * @param promptToBuild
+     */
+    void ExecuteNoDebug(bool promptToBuild);
+
     /**
      * @brief handle custom build targets events
      */
@@ -334,11 +360,14 @@ public:
 
 private:
     // make our frame's constructor private
-    clMainFrame(wxWindow* pParent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size,
+    clMainFrame(wxWindow* pParent,
+                wxWindowID id,
+                const wxString& title,
+                const wxPoint& pos,
+                const wxSize& size,
                 long style = wxMINIMIZE_BOX | wxMAXIMIZE_BOX | wxCLOSE_BOX | wxCAPTION | wxSYSTEM_MENU |
                              wxRESIZE_BORDER | wxCLIP_CHILDREN);
-    wxString CreateWorkspaceTable();
-    wxString CreateFilesTable();
+    void AddKeyboardAccelerators();
     void StartTimer();
 
 private:
@@ -347,11 +376,15 @@ private:
      * at construction time
      */
     void CreateGUIControls();
+
     /**
-     * \brief update the path & name of the build tool
-     * on windows, try to locate make, followed by mingw32-make
+     * @brief construct the frame, we call this function in the first event loop after the application
+     * is ready
      */
-    void UpdateBuildTools();
+    void Construct();
+
+    void PostConstruct();
+
     /**
      * Helper function that prompt user with a simple wxTextEntry dialog
      * @param msg message to display to user
@@ -364,42 +397,24 @@ private:
     void OnSplitSelectionUI(wxUpdateUIEvent& event);
 
     /// Toolbar management
-    void CreateToolBar(int toolSize);
+    void DoCreateToolBar(int toolSize);
     void ToggleToolBars(bool all);
     void ViewPaneUI(const wxString& paneName, wxUpdateUIEvent& event);
     void CreateRecentlyOpenedFilesMenu();
     void CreateWelcomePage();
     bool ReloadExternallyModifiedProjectFiles();
-    void DoEnableWorkspaceViewFlag(bool enable, int flag);
-    void DoUpdatePerspectiveMenu();
-    bool IsWorkspaceViewFlagEnabled(int flag);
     /**
      * @brief show the startup wizard
      * @return true if a restart is needed
      */
     bool StartSetupWizard(bool firstTime);
 
-    /**
-     * @brief see if the wizard changed developer profile
-     * @return true if the 'Save Perspective' dialog should not be shown
-     */
-    bool GetAndResetNoSavePerspectivePrompt()
-    {
-        bool ans = m_noSavePerspectivePrompt;
-        m_noSavePerspectivePrompt = false;
-        return ans;
-    }
-    /**
-     * @brief mark not to show the 'Save Perspective' dialog on next close
-     */
-    void SetNoSavePerspectivePrompt(bool devProfileChanged) { m_noSavePerspectivePrompt = devProfileChanged; }
-
     void DoShowCaptions(bool show);
 
 public:
     void ViewPane(const wxString& paneName, bool checked);
     void ShowOrHideCaptions();
-    clToolBar* GetMainToolBar() const { return m_toolbar; }
+    clToolBarGeneric* GetPluginsToolBar() const { return m_pluginsToolbar; }
     void ShowBuildMenu(clToolBar* toolbar, wxWindowID buttonID);
 
 protected:
@@ -412,7 +427,7 @@ protected:
 
     void OnRestoreDefaultLayout(wxCommandEvent& e);
     void OnIdle(wxIdleEvent& e);
-    void OnBuildEnded(clCommandEvent& event);
+    void OnBuildEnded(clBuildEvent& event);
     void OnQuit(wxCommandEvent& WXUNUSED(event));
     void OnClose(wxCloseEvent& event);
     void OnCustomiseToolbar(wxCommandEvent& event);
@@ -448,8 +463,6 @@ protected:
     void OnIncrementalSearch(wxCommandEvent& event);
     void OnIncrementalReplace(wxCommandEvent& event);
     void OnIncrementalSearchUI(wxUpdateUIEvent& event);
-    void OnViewToolbar(wxCommandEvent& event);
-    void OnViewToolbarUI(wxUpdateUIEvent& event);
     void OnPrint(wxCommandEvent& event);
     void OnPageSetup(wxCommandEvent& event);
     void OnRecentWorkspaceUI(wxUpdateUIEvent& e);
@@ -509,6 +522,7 @@ protected:
     void OnCopyFilePathOnly(wxCommandEvent& event);
     void OnCopyFileName(wxCommandEvent& event);
     void OnHighlightWord(wxCommandEvent& event);
+    void OnHighlightWordUI(wxUpdateUIEvent& event);
     void OnShowNavBar(wxCommandEvent& e);
     void OnShowNavBarUI(wxUpdateUIEvent& e);
     void OnOpenShellFromFilePath(wxCommandEvent& e);
@@ -531,17 +545,6 @@ protected:
     void OnWebSearchSelectionUI(wxUpdateUIEvent& e);
     void OnThemeChanged(wxCommandEvent& e);
     void OnEnvironmentVariablesModified(clCommandEvent& e);
-    void OnFindReferences(clRefactoringEvent& e);
-    void OnRenameSymbol(clRefactoringEvent& e);
-
-    // handle symbol tree events
-    void OnParsingThreadMessage(clParseThreadEvent& e);
-    void OnDatabaseUpgrade(wxCommandEvent& e);
-    void OnDatabaseUpgradeInternally(wxCommandEvent& e);
-    void OnRefreshPerspectiveMenu(wxCommandEvent& e);
-    void OnClearTagsCache(clParseThreadEvent& e);
-    void OnRetaggingCompleted(clParseThreadEvent& e);
-    void OnRetaggingProgress(clParseThreadEvent& e);
 
     void OnRecentFile(wxCommandEvent& event);
     void OnRecentWorkspace(wxCommandEvent& event);
@@ -586,8 +589,6 @@ protected:
     void OnCloseAllButThis(wxCommandEvent& e);
     void OnCloseTabsToTheRight(wxCommandEvent& e);
     void OnWorkspaceMenuUI(wxUpdateUIEvent& e);
-    void OnUpdateBuildRefactorIndexBar(wxCommandEvent& e);
-    void OnUpdateNumberOfBuildProcesses(wxCommandEvent& e);
     void OnBuildWorkspace(wxCommandEvent& e);
     void OnBuildWorkspaceUI(wxUpdateUIEvent& e);
     void OnCleanWorkspace(wxCommandEvent& e);
@@ -595,12 +596,6 @@ protected:
     void OnReBuildWorkspace(wxCommandEvent& e);
     void OnReBuildWorkspaceUI(wxUpdateUIEvent& e);
 
-    // Perspectives management
-    void OnChangePerspective(wxCommandEvent& e);
-    void OnChangePerspectiveUI(wxUpdateUIEvent& e);
-    void OnManagePerspectives(wxCommandEvent& e);
-    void OnSaveLayoutAsPerspective(wxCommandEvent& e);
-
     // EOL
     void OnConvertEol(wxCommandEvent& e);
     void OnViewDisplayEOL(wxCommandEvent& e);
@@ -609,7 +604,6 @@ protected:
     void OnViewDisplayEOL_UI(wxUpdateUIEvent& e);
 
     // Docking windows events
-    void OnAuiManagerRender(wxAuiManagerEvent& e);
     void OnDockablePaneClosed(wxAuiManagerEvent& e);
     void OnViewPane(wxCommandEvent& event);
     void OnViewPaneUI(wxUpdateUIEvent& event);
@@ -623,6 +617,13 @@ protected:
     void OnManagePlugins(wxCommandEvent& e);
     void OnCppContextMenu(wxCommandEvent& e);
 
+    void OnAiPromptEditor(wxCommandEvent& e);
+    void OnAiSettings(wxCommandEvent& e);
+    void OnAiShowChatBox(wxCommandEvent& e);
+    void OnAiConfigureEndpoint(wxCommandEvent& e);
+    void OnAiChooseEndpoint(wxCommandEvent& e);
+    void OnAiAvailableUI(wxUpdateUIEvent& e);
+
     void OnConfigureAccelerators(wxCommandEvent& e);
     void OnStartPageEvent(wxCommandEvent& e);
     void OnNewVersionAvailable(wxCommandEvent& e);
@@ -637,34 +638,40 @@ protected:
     void OnPrevTab(wxCommandEvent& e);
     void OnNextPrevTab_UI(wxUpdateUIEvent& e);
     void OnShowFullScreen(wxCommandEvent& e);
+    void OnShowBuiltInTerminal(wxCommandEvent& e);
     void OnFindResourceXXX(wxCommandEvent& e);
     void OnShowActiveProjectSettings(wxCommandEvent& e);
     void OnShowActiveProjectSettingsUI(wxUpdateUIEvent& e);
-    void OnLoadPerspective(wxCommandEvent& e);
     void OnWorkspaceSettings(wxCommandEvent& e);
     void OnWorkspaceEditorPreferences(wxCommandEvent& e);
-    void OnParserThreadReady(clParseThreadEvent& e);
+    void OnSetActivePoject(wxCommandEvent& e);
+    void OnSetActivePojectUI(wxUpdateUIEvent& e);
 
-    // Clang
-    void OnPchCacheStarted(wxCommandEvent& e);
-    void OnPchCacheEnded(wxCommandEvent& e);
+    void OnMainToolBarHide(wxCommandEvent& event);
+    void OnMainToolBarHideUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceTop(wxCommandEvent& event);
+    void OnMainToolBarPlaceTopUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceBottom(wxCommandEvent& event);
+    void OnMainToolBarPlaceBottomUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceLeft(wxCommandEvent& event);
+    void OnMainToolBarPlaceLeftUI(wxUpdateUIEvent& event);
+    void OnMainToolBarPlaceRight(wxCommandEvent& event);
+    void OnMainToolBarPlaceRightUI(wxUpdateUIEvent& event);
 
     // Misc
     void OnActivateEditor(wxCommandEvent& e);
     void OnActiveEditorChanged(wxCommandEvent& e);
-    void OnWorkspaceLoaded(wxCommandEvent& e);
-    void OnRefactoringCacheStatus(wxCommandEvent& e);
-    void OnWorkspaceClosed(wxCommandEvent& e);
+    void OnWorkspaceLoaded(clWorkspaceEvent& e);
+    void OnWorkspaceClosed(clWorkspaceEvent& e);
     void OnChangeActiveBookmarkType(wxCommandEvent& e);
     void OnSettingsChanged(wxCommandEvent& e);
     void OnEditMenuOpened(wxMenuEvent& e);
     void OnProjectRenamed(clCommandEvent& event);
 
     // Search handlers
-    void OnFindSelection(wxCommandEvent& event);
-    void OnFindSelectionPrev(wxCommandEvent& event);
-    void OnFindWordAtCaret(wxCommandEvent& event);
-    void OnFindWordAtCaretPrev(wxCommandEvent& event);
+    void OnFindNext(wxCommandEvent& event);
+    void OnFindPrevious(wxCommandEvent& event);
+
     DECLARE_EVENT_TABLE()
 };
 
