@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : localstable.cpp
 //
 // -------------------------------------------------------------------------
@@ -24,19 +24,20 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "localstable.h"
-#include <wx/regex.h>
-#include <wx/wupdlock.h>
+
+#include "Debugger/debuggermanager.h"
 #include "debuggerconfigtool.h"
-#include "globals.h"
-#include "debuggermanager.h"
-#include "manager.h"
-#include "new_quick_watch_dlg.h"
-#include <set>
-#include <wx/xrc/xmlres.h>
-#include "frame.h"
-#include "drawingutils.h"
 #include "event_notifier.h"
-#include <algorithm>
+#include "frame.h"
+#include "globals.h"
+#include "macros.h"
+#include "manager.h"
+
+#include <wx/regex.h>
+#include <wx/textdlg.h>
+#include <wx/utils.h>
+#include <wx/wupdlock.h>
+#include <wx/xrc/xmlres.h>
 
 BEGIN_EVENT_TABLE(LocalsTable, DebuggerTreeListCtrlBase)
 EVT_MENU(XRCID("Change_Value"), LocalsTable::OnEditValue)
@@ -48,11 +49,15 @@ LocalsTable::LocalsTable(wxWindow* parent)
     , m_arrayAsCharPtr(false)
     , m_sortAsc(true)
 {
-    m_listTable->AddColumn(_("Name"), 150);
-    m_listTable->AddColumn(_("Value"), 500);
-    m_listTable->AddColumn(_("Type"), 200);
     m_listTable->AddRoot(_("Locals"));
+    m_listTable->AddHeader(_("Name"));
+    m_listTable->AddHeader(_("Value"));
+    m_listTable->AddHeader(_("Type"));
 
+    // Only sort top level items, don't sort their children
+    m_listTable->AddTreeStyle(wxTR_SORT_TOP_LEVEL);
+
+    SetSortingFunction();
     m_DBG_USERR = DBG_USERR_LOCALS;
     m_QUERY_NUM_CHILDS = QUERY_LOCALS_CHILDS;
     m_LIST_CHILDS = LIST_LOCALS_CHILDS;
@@ -61,8 +66,6 @@ LocalsTable::LocalsTable(wxWindow* parent)
         wxEVT_DEBUGGER_FRAME_SELECTED, clCommandEventHandler(LocalsTable::OnStackSelected), NULL, this);
 }
 
-LocalsTable::~LocalsTable() {}
-
 void LocalsTable::UpdateLocals(const LocalVariables& locals) { DoUpdateLocals(locals, DbgTreeItemData::Locals); }
 
 void LocalsTable::UpdateFuncArgs(const LocalVariables& args) { DoUpdateLocals(args, DbgTreeItemData::FuncArgs); }
@@ -75,10 +78,11 @@ void LocalsTable::Initialize()
 
     DebuggerInformation info;
     IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if(dbgr) {
+    if (dbgr) {
         DebuggerMgr::Get().GetDebuggerInformation(dbgr->GetName(), info);
         m_resolveLocals = info.resolveLocals;
         m_arrayAsCharPtr = info.charArrAsPtr;
+        m_defaultHexDisplay = info.defaultHexDisplay;
     }
 
     m_preDefTypes = data.GetActiveSet();
@@ -89,21 +93,23 @@ void LocalsTable::OnCreateVariableObj(const DebuggerEventData& event)
 {
     wxString expr = event.m_expression;
     std::map<wxString, wxTreeItemId>::iterator iter = m_createVarItemId.find(expr);
-    if(iter != m_createVarItemId.end()) {
+    if (iter != m_createVarItemId.end()) {
 
         // set the variable object
         DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(iter->second));
-        if(data) {
+        if (data) {
 
             data->_gdbId = event.m_variableObject.gdbId;
             data->_kind = DbgTreeItemData::VariableObject;
 
             // variable object's type name is extracted from the event.m_variableObject.typeName
-            m_listTable->SetItemText(iter->second, 2, event.m_variableObject.typeName);
+            const wxString& localType = event.m_variableObject.typeName;
+            m_listTable->SetItemText(iter->second, localType, 2);
 
             // refresh this item only
             IDebugger* dbgr = DoGetDebugger();
-            if(dbgr) DoRefreshItem(dbgr, iter->second, false);
+            if (dbgr)
+                DoRefreshItem(dbgr, iter->second, false);
 
             dbgr->UpdateVariableObject(data->_gdbId, m_DBG_USERR);
             dbgr->ListChildren(data->_gdbId, m_LIST_CHILDS);
@@ -117,20 +123,21 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
 {
     wxString gdbId = event.m_expression;
     std::map<wxString, wxTreeItemId>::iterator iter = m_listChildItemId.find(gdbId);
-    if(iter == m_listChildItemId.end()) return;
+    if (iter == m_listChildItemId.end())
+        return;
+
+    IDebugger* dbgr = DoGetDebugger();
+    CHECK_PTR_RET(dbgr);
 
     wxTreeItemId item = iter->second;
     m_listChildItemId.erase(iter);
 
-    if(event.m_userReason == m_LIST_CHILDS) {
-        if(event.m_varObjChildren.empty() == false) {
-            for(size_t i = 0; i < event.m_varObjChildren.size(); i++) {
-
-                IDebugger* dbgr = DoGetDebugger();
-                if(!dbgr) return;
-
-                VariableObjChild ch = event.m_varObjChildren.at(i);
-                if(ch.varName == wxT("public") || ch.varName == wxT("private") || ch.varName == wxT("protected")) {
+    if (event.m_userReason == m_LIST_CHILDS) {
+        m_listTable->Begin();
+        if (event.m_varObjChildren.empty() == false) {
+            for (size_t i = 0; i < event.m_varObjChildren.size(); i++) {
+                const VariableObjChild& ch = event.m_varObjChildren.at(i);
+                if (ch.varName == "public" || ch.varName == "private" || ch.varName == "protected") {
                     // not really a node...
                     // ask for information about this node children
                     dbgr->ListChildren(ch.gdbId, m_LIST_CHILDS);
@@ -143,10 +150,10 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
                     data->_isFake = ch.isAFake;
 
                     wxTreeItemId child = m_listTable->AppendItem(item, ch.varName, -1, -1, data);
-                    m_listTable->SetItemText(child, 2, ch.type);
+                    m_listTable->SetItemText(child, ch.type, 2);
 
                     // Add a dummy node
-                    if(child.IsOk() && ch.numChilds > 0) {
+                    if (child.IsOk() && ch.numChilds > 0) {
                         m_listTable->AppendItem(child, wxT("<dummy>"));
                     }
 
@@ -157,6 +164,7 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
                 }
             }
         }
+        m_listTable->Commit();
     }
 }
 
@@ -165,10 +173,10 @@ void LocalsTable::OnVariableObjUpdate(const DebuggerEventData& event)
     VariableObjectUpdateInfo updateInfo = event.m_varObjUpdateInfo;
 
     // remove all obsolete items
-    for(size_t i = 0; i < updateInfo.removeIds.GetCount(); i++) {
+    for (size_t i = 0; i < updateInfo.removeIds.GetCount(); i++) {
         wxString gdbId = updateInfo.removeIds.Item(i);
         wxTreeItemId item = DoFindItemByGdbId(gdbId);
-        if(item.IsOk()) {
+        if (item.IsOk()) {
             DoDeleteWatch(item);
             m_listTable->Delete(item);
         }
@@ -176,7 +184,7 @@ void LocalsTable::OnVariableObjUpdate(const DebuggerEventData& event)
 
     // refresh the values of the items that requires that
     IDebugger* dbgr = DoGetDebugger();
-    if(dbgr) {
+    if (dbgr) {
         wxArrayString itemsToRefresh = event.m_varObjUpdateInfo.refreshIds;
         DoRefreshItemRecursively(dbgr, m_listTable->GetRootItem(), itemsToRefresh);
     }
@@ -184,23 +192,24 @@ void LocalsTable::OnVariableObjUpdate(const DebuggerEventData& event)
 
 void LocalsTable::OnItemExpanding(wxTreeEvent& event)
 {
+    wxBusyCursor bc;
     wxTreeItemIdValue cookie;
     wxTreeItemId child = m_listTable->GetFirstChild(event.GetItem(), cookie);
 
     IDebugger* dbgr = DoGetDebugger();
-    if(!dbgr || !event.GetItem()) {
-        // dont allow the expansion of this item
+    if (!dbgr || !event.GetItem()) {
+        // don't allow the expansion of this item
         event.Veto();
         return;
     }
 
     size_t childCount = m_listTable->GetChildrenCount(event.GetItem());
-    if(childCount > 1) {
+    if (childCount > 1) {
         // make sure there is no <dummy> node and continue
         wxTreeItemIdValue cookieOne;
         wxTreeItemId dummyItem = m_listTable->GetFirstChild(event.GetItem(), cookieOne);
-        while(dummyItem.IsOk()) {
-            if(m_listTable->GetItemText(dummyItem) == wxT("<dummy>")) {
+        while (dummyItem.IsOk()) {
+            if (m_listTable->GetItemText(dummyItem) == wxT("<dummy>")) {
                 m_listTable->Delete(dummyItem);
                 event.Skip();
                 return;
@@ -208,13 +217,13 @@ void LocalsTable::OnItemExpanding(wxTreeEvent& event)
             dummyItem = m_listTable->GetNextChild(event.GetItem(), cookieOne);
         }
 
-    } else if(child.IsOk() && m_listTable->GetItemText(child) == wxT("<dummy>")) {
+    } else if (child.IsOk() && m_listTable->GetItemText(child) == wxT("<dummy>")) {
 
         // a dummy node, replace it with the real node content
         m_listTable->Delete(child);
 
         wxString gdbId = DoGetGdbId(event.GetItem());
-        if(gdbId.IsEmpty() == false) {
+        if (gdbId.IsEmpty() == false) {
             dbgr->UpdateVariableObject(gdbId, m_DBG_USERR);
             dbgr->ListChildren(gdbId, m_LIST_CHILDS);
             m_listChildItemId[gdbId] = event.GetItem();
@@ -224,7 +233,7 @@ void LocalsTable::OnItemExpanding(wxTreeEvent& event)
             // create a variable object
             wxString expres = m_listTable->GetItemText(event.GetItem());
             DbgTreeItemData* data = (DbgTreeItemData*)m_listTable->GetItemData(event.GetItem());
-            if(data && data->_kind == DbgTreeItemData::FuncRetValue) {
+            if (data && data->_kind == DbgTreeItemData::FuncRetValue) {
                 expres = data->_retValueGdbValue;
             }
 
@@ -244,11 +253,11 @@ void LocalsTable::DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved
     std::vector<wxTreeItemId> itemsToRemove;
 
     wxTreeItemId item = m_listTable->GetFirstChild(m_listTable->GetRootItem(), cookie);
-    while(item.IsOk()) {
+    while (item.IsOk()) {
         wxString gdbId = DoGetGdbId(item);
-        if(gdbId.IsEmpty()) {
+        if (gdbId.IsEmpty()) {
             DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(item));
-            if(data && (data->_kind & flags)) {
+            if (data && (data->_kind & flags)) {
                 // not a variable object entry, remove it
                 itemsToRemove.push_back(item);
             }
@@ -259,7 +268,7 @@ void LocalsTable::DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved
         item = m_listTable->GetNextChild(m_listTable->GetRootItem(), cookie);
     }
 
-    for(size_t i = 0; i < itemsToRemove.size(); i++) {
+    for (size_t i = 0; i < itemsToRemove.size(); i++) {
         oldValues[m_listTable->GetItemText(itemsToRemove[i])] = m_listTable->GetItemText(itemsToRemove[i], 1);
         m_listTable->Delete(itemsToRemove[i]);
     }
@@ -268,18 +277,9 @@ void LocalsTable::DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved
 void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t kind)
 {
     LocalVariables locals = localsUnSorted;
-    std::sort(locals.begin(), locals.end(), [&](const LocalVariable& v1, const LocalVariable& v2) {
-        if(m_sortAsc) {
-            return v1.name.Lower().CmpNoCase(v2.name.Lower()) < 0;
-        } else {
-            return v1.name.Lower().CmpNoCase(v2.name.Lower()) >= 0;
-        }
-    });
-
     wxTreeItemId root = m_listTable->GetRootItem();
-    if(!root.IsOk()) return;
-
-    wxColour rootItemColour = DrawingUtils::LightColour(wxT("LIGHT GRAY"), 3.0);
+    if (!root.IsOk())
+        return;
 
     IDebugger* dbgr = DoGetDebugger();
     wxArrayString itemsNotRemoved;
@@ -288,43 +288,33 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
     std::map<wxString, wxString> oldValues;
     DoClearNonVariableObjectEntries(itemsNotRemoved, kind, oldValues);
-    for(size_t i = 0; i < locals.size(); i++) {
+    for (size_t i = 0; i < locals.size(); i++) {
 
         // try to replace the
         wxString newVarName;
-        if(m_resolveLocals) {
+        if (m_resolveLocals) {
             newVarName = m_preDefTypes.GetPreDefinedTypeForTypename(locals[i].type, locals[i].name);
         }
 
         // Evaluate arrays as char*?
         static wxRegEx reConstArr(wxT("(const )?[ ]*(w)?char(_t)? *[\\[0-9\\]]*"));
         wxString type = locals[i].type;
-        if(m_arrayAsCharPtr && reConstArr.Matches(type)) {
+        if (m_arrayAsCharPtr && reConstArr.Matches(type)) {
             // array
             newVarName.Clear();
             newVarName << wxT("(char*)") << locals[i].name;
         }
 
-        if(newVarName.IsEmpty() == false && !newVarName.Contains(wxT("@"))) {
-            // if(newVarName.Contains(wxT("@"))) {
-            //
-            //	// using GDB special array print,
-            //	// we need to delete this variable object and re-create it
-            //	// otherwise its content wont be updated
-            //	int where = itemsNotRemoved.Index(newVarName);
-            //	if(where != wxNOT_FOUND)
-            //		itemsNotRemoved.RemoveAt(where);
-            //}
-
+        if (newVarName.IsEmpty() == false && !newVarName.Contains(wxT("@"))) {
             wxTreeItemId treeItem = DoFindItemByExpression(newVarName);
-            if(treeItem.IsOk()) {
+            if (treeItem.IsOk()) {
                 // an item with this expression already exists, skip it
                 continue;
             }
 
             // replace the local with a variable object
-            // but make sure we dont enter a duplicate item
-            if(itemsNotRemoved.Index(newVarName) == wxNOT_FOUND) {
+            // but make sure we don't enter a duplicate item
+            if (itemsNotRemoved.Index(newVarName) == wxNOT_FOUND) {
                 // this type has a pre-defined type, use it instead
 
                 // Mark this item as VariableObject so incase another call
@@ -332,12 +322,11 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
                 DbgTreeItemData* data = new DbgTreeItemData();
                 data->_kind = DbgTreeItemData::VariableObject;
                 wxTreeItemId item = m_listTable->AppendItem(root, newVarName, -1, -1, data);
-                // m_listTable->SetItemBackgroundColour(item, rootItemColour);
 
                 m_listTable->AppendItem(item, wxT("<dummy>"));
                 m_listTable->Collapse(item);
 
-                if(dbgr) {
+                if (dbgr) {
                     dbgr->CreateVariableObject(newVarName, false, m_DBG_USERR);
                     m_createVarItemId[newVarName] = item;
                 }
@@ -345,17 +334,17 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
         } else {
 
-            if(itemsNotRemoved.Index(locals[i].name) == wxNOT_FOUND) {
+            if (itemsNotRemoved.Index(locals[i].name) == wxNOT_FOUND) {
                 // New entry
                 wxTreeItemId item = m_listTable->AppendItem(root, locals[i].name, -1, -1, new DbgTreeItemData());
                 // m_listTable->SetItemTextColour(item, DrawingUtils::GetMenuTextColour());
 
-                m_listTable->SetItemText(item, 1, locals[i].value);
-                m_listTable->SetItemText(item, 2, locals[i].type);
+                m_listTable->SetItemText(item, locals[i].value, 1);
+                m_listTable->SetItemText(item, locals[i].type, 2);
 
                 std::map<wxString, wxString>::iterator iter = oldValues.find(locals[i].name);
-                if(iter != oldValues.end() && iter->second != locals[i].value) {
-                    m_listTable->SetItemTextColour(item, *wxRED);
+                if (iter != oldValues.end() && iter->second != locals[i].value) {
+                    m_listTable->SetItemTextColour(item, *wxRED, 1);
                 }
 
                 m_listTable->AppendItem(item, wxT("<dummy>"));
@@ -367,8 +356,8 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
 void LocalsTable::UpdateFrameInfo()
 {
-    if(ManagerST::Get()->DbgGetCurrentFrameInfo().IsValid() &&
-       ManagerST::Get()->DbgGetCurrentFrameInfo() != m_curStackInfo) {
+    if (ManagerST::Get()->DbgGetCurrentFrameInfo().IsValid() &&
+        ManagerST::Get()->DbgGetCurrentFrameInfo() != m_curStackInfo) {
         Clear();
         m_curStackInfo = ManagerST::Get()->DbgGetCurrentFrameInfo();
         clMainFrame::Get()->GetDebuggerPane()->GetDebugWindow()->AppendLine(wxString::Format(
@@ -379,7 +368,7 @@ void LocalsTable::UpdateFrameInfo()
 void LocalsTable::OnRefresh(wxCommandEvent& event)
 {
     IDebugger* dbgr = DoGetDebugger();
-    if(dbgr) {
+    if (dbgr) {
         Clear();
         dbgr->QueryLocals();
     }
@@ -397,20 +386,22 @@ void LocalsTable::OnItemRightClick(wxTreeEvent& event)
 void LocalsTable::OnEditValue(wxCommandEvent& event)
 {
     wxTreeItemId selectedItem = m_listTable->GetSelection();
-    if(selectedItem.IsOk() == false) return;
+    if (selectedItem.IsOk() == false)
+        return;
 
     wxString itemPath = GetItemPath(selectedItem);
     wxString newValue =
         wxGetTextFromUser(wxString::Format(_("Insert new value for '%s':"), itemPath.c_str()), _("Edit expression"));
-    if(newValue.IsEmpty()) return;
+    if (newValue.IsEmpty())
+        return;
 
     IDebugger* debugger = DoGetDebugger();
-    if(debugger) {
+    if (debugger) {
         debugger->AssignValue(itemPath, newValue);
 
         // refresh the item
         DbgTreeItemData* data = (DbgTreeItemData*)m_listTable->GetItemData(selectedItem);
-        if(data && data->_gdbId.IsEmpty()) {
+        if (data && data->_gdbId.IsEmpty()) {
             m_listTable->Delete(selectedItem);
             debugger->QueryLocals();
 
@@ -424,7 +415,7 @@ void LocalsTable::OnEditValueUI(wxUpdateUIEvent& event)
 {
     IDebugger* debugger = DoGetDebugger();
     wxTreeItemId selectedItem = m_listTable->GetSelection();
-    if(selectedItem.IsOk() == false) {
+    if (selectedItem.IsOk() == false) {
         event.Enable(false);
 
     } else {
@@ -436,15 +427,14 @@ void LocalsTable::OnEditValueUI(wxUpdateUIEvent& event)
 void LocalsTable::UpdateFuncReturnValue(const wxString& retValueGdbId)
 {
     wxTreeItemId root = m_listTable->GetRootItem();
-    if(!root.IsOk()) return;
-
-    wxColour rootItemColour = DrawingUtils::LightColour(wxT("LIGHT GRAY"), 3.0);
+    if (!root.IsOk())
+        return;
 
     wxArrayString itemsNotRemoved;
     // remove the non-variable objects and return a list
     // of all the variable objects (at the top level)
     wxTreeItemId item = DoFindItemByExpression(wxT("Function Returned"));
-    if(item.IsOk()) {
+    if (item.IsOk()) {
         DoDeleteWatch(item);
     }
     m_listTable->Delete(item);
@@ -454,11 +444,10 @@ void LocalsTable::UpdateFuncReturnValue(const wxString& retValueGdbId)
     data->_retValueGdbValue = retValueGdbId;
 
     item = m_listTable->AppendItem(root, wxT("Function Returned"), -1, -1, data);
-    m_listTable->SetItemBackgroundColour(item, rootItemColour);
 
-    m_listTable->SetItemText(item, 1, retValueGdbId);
-    m_listTable->SetItemText(item, 2, wxT(""));
-    m_listTable->SetItemTextColour(item, *wxRED);
+    m_listTable->SetItemText(item, retValueGdbId, 1);
+    m_listTable->SetItemText(item, wxT(""), 2);
+    m_listTable->SetItemTextColour(item, *wxRED, 1);
 
     m_listTable->AppendItem(item, wxT("<dummy>"));
     m_listTable->Collapse(item);
@@ -474,7 +463,7 @@ void LocalsTable::OnStackSelected(clCommandEvent& event)
     event.Skip();
     Clear();
     IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if(dbgr && dbgr->IsRunning() && ManagerST::Get()->IsDebuggerViewVisible(DebuggerPane::LOCALS)) {
+    if (dbgr && dbgr->IsRunning() && ManagerST::Get()->IsDebuggerViewVisible(wxGetTranslation(DebuggerPane::LOCALS))) {
         dbgr->QueryLocals();
     }
 }
@@ -483,5 +472,20 @@ void LocalsTable::OnSortItems(wxCommandEvent& event)
 {
     // Change the sorting type and refresh the view
     m_sortAsc = !m_sortAsc;
+    // Update the sorting function
+    SetSortingFunction();
     OnRefresh(event);
 }
+
+void LocalsTable::SetSortingFunction()
+{
+    // Should a be placed before b?
+    clSortFunc_t func = [=, this](clRowEntry* a, clRowEntry* b) {
+        if (m_sortAsc) {
+            return (a->GetLabel().CmpNoCase(b->GetLabel()) < 0);
+        } else {
+            return (a->GetLabel().CmpNoCase(b->GetLabel()) > 0);
+        }
+    };
+    m_listTable->SetSortFunction(func);
+}
