@@ -26,11 +26,12 @@
 #ifndef __localstable__
 #define __localstable__
 
-#include "simpletablebase.h"
-#include <wx/arrstr.h>
-#include "debuggerobserver.h"
-#include "debuggersettings.h"
+#include "Debugger/debuggersettings.h"
 #include "cl_command_event.h"
+#include "debuggerobserver.h"
+#include "simpletablebase.h"
+
+#include <wx/arrstr.h>
 
 #define LIST_LOCALS_CHILDS 600
 #define QUERY_LOCALS_CHILDS 601
@@ -43,10 +44,10 @@ protected:
     bool m_resolveLocals;
     bool m_arrayAsCharPtr;
     bool m_sortAsc;
+    bool m_defaultHexDisplay;
 
 protected:
-    void DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved,
-                                         size_t flags,
+    void DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved, size_t flags,
                                          std::map<wxString, wxString>& oldValues);
     void DoUpdateLocals(const LocalVariables& locals, size_t kind);
 
@@ -59,10 +60,11 @@ protected:
     void OnEditValueUI(wxUpdateUIEvent& event);
     void OnStackSelected(clCommandEvent& event);
     void OnSortItems(wxCommandEvent& event);
+    void SetSortingFunction();
 
 public:
     LocalsTable(wxWindow* parent);
-    virtual ~LocalsTable();
+    virtual ~LocalsTable() = default;
 
 public:
     /**
