@@ -26,118 +26,42 @@
 #define MAINBOOK_H
 
 #include "Notebook.h"
+#include "clAuiBook.hpp"
 #include "clEditorBar.h"
 #include "cl_command_event.h"
-#include "editorframe.h"
+#include "cl_editor.h"
 #include "filehistory.h"
 #include "quickfindbar.h"
 #include "sessionmanager.h"
-#include "wxStringHash.h"
-#include <set>
+
+#include <functional>
+#include <vector>
+#include <wx/aui/auibook.h>
 #include <wx/panel.h>
-#include "navigationmanager.h"
 
 class FilesModifiedDlg;
 
-
+class IEditor;
 class MessagePane;
 class clEditorBar;
+class WelcomePage;
+
 class MainBook : public wxPanel
 {
-private:
-    FileHistory m_recentFiles;
-    clEditorBar* m_navBar;
-    Notebook* m_book;
-    bool m_useBuffereLimit;
-    EditorFrame::List_t m_detachedEditors;
-    bool m_isWorkspaceReloading;
-    bool m_reloadingDoRaise; // Prevents multiple Raises() during RestoreSession()
-    FilesModifiedDlg* m_filesModifiedDlg;
-    std::unordered_map<wxString, TagEntryPtr> m_currentNavBarTags;
-    wxWindow* m_welcomePage;
-    QuickFindBar* m_findBar;
-
-public:
-    enum {
-        kGetAll_Default = 0x00000000,         // booked editors only
-        kGetAll_RetainOrder = 0x00000001,     // Order must keep
-        kGetAll_IncludeDetached = 0x00000002, // return both booked editors and detached
-        kGetAll_DetachedOnly = 0x00000004,    // return detached editors only
-    };
-
-private:
-    FilesModifiedDlg* GetFilesModifiedDlg();
-    void DoShowTabLabelContextMenu();
-    void CreateGuiControls();
-    void ConnectEvents();
-    void DoUpdateNotebookTheme();
-    void DoOpenImageViewer(const wxFileName& filename);
-    void DoUpdateEditorsThemes();
-
-    void OnMouseDClick(wxBookCtrlEvent& e);
-    void OnTabDClicked(wxBookCtrlEvent& e);
-    void OnTabLabelContextMenu(wxBookCtrlEvent& e);
-    void OnPageClosing(wxBookCtrlEvent& e);
-    void OnPageClosed(wxBookCtrlEvent& e);
-    void OnPageChanged(wxBookCtrlEvent& e);
-    void OnClosePage(wxBookCtrlEvent& e);
-    void OnPageChanging(wxBookCtrlEvent& e);
-    void OnProjectFileAdded(clCommandEvent& e);
-    void OnProjectFileRemoved(clCommandEvent& e);
-    void OnWorkspaceLoaded(wxCommandEvent& e);
-    void OnWorkspaceClosed(wxCommandEvent& e);
-    void OnDebugEnded(clDebugEvent& e);
-    void OnInitDone(wxCommandEvent& e);
-    void OnDetachedEditorClosed(clCommandEvent& e);
-    void OnThemeChanged(wxCommandEvent& e);
-    void OnColoursAndFontsChanged(clCommandEvent& e);
-    bool DoSelectPage(wxWindow* win);
-    void DoHandleFrameMenu(clEditor* editor);
-    void DoEraseDetachedEditor(IEditor* editor);
-    void OnWorkspaceReloadStarted(clCommandEvent& e);
-    void OnWorkspaceReloadEnded(clCommandEvent& e);
-    void OnEditorSettingsChanged(wxCommandEvent& e);
-    void OnCacheUpdated(clCommandEvent& e);
-    void OnUpdateNavigationBar(clCodeCompletionEvent& e);
-    void OnNavigationBarMenuShowing(clContextMenuEvent& e);
-    void OnNavigationBarMenuSelectionMade(clCommandEvent& e);
-    void OnSettingsChanged(wxCommandEvent& e);
-    /**
-     * @brief return proper tab label for a given filename
-     */
-    wxString CreateLabel(const wxFileName& fn, bool modified) const;
-    /**
-     * @brief open file and set an alternate content
-     */
-    void DoOpenFile(const wxString& filename, const wxString& content = "");
-
-    /**
-     * @brief update the navigation bar (C++)
-     * @param editor
-     */
-    void UpdateNavBar(clEditor* editor);
-
-    /**
-     * @brief display the welcome page
-     */
-    void ShowWelcomePage(bool show);
-    void DoShowWindow(wxWindow* win, bool show);
-
-    void OnEditorChanged(wxCommandEvent& event);
-    void OnAllEditorClosed(wxCommandEvent& event);
-
 public:
+    using CallbackVec_t = std::vector<std::function<void(IEditor*)>>;
     MainBook(wxWindow* parent);
     virtual ~MainBook();
 
+    WelcomePage* GetWelcomePage(bool createIfMissing = true);
+
     void SetFindBar(QuickFindBar* findBar);
     QuickFindBar* GetFindBar() const { return m_findBar; }
-    
+
     /**
-     * @brief register a welcome page. This page is displayed whenever there are no tabs open
-     * in CodeLite. If there is already a welcome page registered, this call destroys the previous one
+     * @brief create the welcome page
      */
-    void RegisterWelcomePage(wxWindow* welcomePage);
+    void InitWelcomePage();
 
     static bool AskUserToSave(clEditor* editor);
     /**
@@ -150,8 +74,6 @@ public:
      */
     void MovePage(bool movePageRight);
 
-    const EditorFrame::List_t& GetDetachedEditors() const { return m_detachedEditors; }
-    void DetachActiveEditor();
     void ClearFileHistory();
     void GetRecentlyOpenedFiles(wxArrayString& files);
     FileHistory& GetRecentlyOpenedFilesClass() { return m_recentFiles; }
@@ -161,35 +83,35 @@ public:
     void ShowQuickBar(const wxString& findWhat, bool showReplace);
     void ShowTabBar(bool b);
     void ShowNavBar(bool s = true);
-    bool IsNavBarShown() { return m_navBar && m_navBar->IsShown(); }
+    /**
+     * @brief is navigation bar enabled by user?
+     */
+    bool IsNavBarEnabled() const { return m_navBar && m_navBar->ShouldShow(); }
+    /**
+     * @brief is navigation bar shown (either by user or automatically)?
+     */
+    bool IsNavBarShown() const { return m_navBar && m_navBar->IsShown(); }
     clEditorBar* GetEditorBar() { return m_navBar; }
     void SetEditorBar(clEditorBar* bar) { m_navBar = bar; }
-    
+
     void SaveSession(SessionEntry& session, wxArrayInt* excludeArr = NULL);
-    void RestoreSession(SessionEntry& session);
+    void RestoreSession(const SessionEntry& session);
     /**
      * @brief create session from current IDE state
      */
     void CreateSession(SessionEntry& session, wxArrayInt* excludeArr = NULL);
 
-    clEditor* GetActiveEditor(bool includeDetachedEditors = false);
+    clEditor* GetActiveEditor();
     /**
      * @brief return vector of all editors in the notebook. This function only returns instances of type clEditor
-     * @param editors [output]
-     * @param flags kGetAll_*
      */
-    void GetAllEditors(clEditor::Vec_t& editors, size_t flags);
+    clEditor::Vec_t GetAllEditors();
     /**
      * @brief return vector of all tabs in the notebook
      * @param tabs [output]
      */
     void GetAllTabs(clTab::Vec_t& tabs);
 
-    /**
-     * @brief return a list of the detached tabs
-     */
-    void GetDetachedTabs(clTab::Vec_t& tabs);
-
     clEditor* FindEditor(const wxString& fileName);
     bool CloseEditor(const wxString& fileName) { return ClosePage(FindEditor(fileName)); }
 
@@ -198,12 +120,38 @@ public:
     wxWindow* GetPage(size_t page);
     size_t GetPageCount() const;
     wxWindow* FindPage(const wxString& text);
-
+    /**
+     * @brief return the bitmap index or add it if it is missing and then return its index
+     */
+    int GetBitmapIndexOrAdd(const wxString& name);
     clEditor* NewEditor();
 
-    clEditor* OpenFile(const wxString& file_name, const wxString& projectName = wxEmptyString, int lineno = wxNOT_FOUND,
-                       long position = wxNOT_FOUND, OF_extra extra = OF_AddJump, bool preserveSelection = true,
-                       const wxBitmap& bmp = wxNullBitmap, const wxString& tooltip = wxEmptyString);
+    /**
+     * @brief open or select ((if the file is already loaded in CodeLite) editor with a given `file_name` to the
+     * notebook control and make it active Once the page is **visible**, execute the callback provided by the user
+     * @param callback user callback to be executed once the editor is visible on screen
+     * On some platforms (e.g. `GTK`) various operations (e.g. `CenterLine()`) will not work as intended unless the
+     * editor is actually visible on screen. This way you
+     * can delay the call the `CenterLine()` after the editor is visible
+     */
+    clEditor* OpenFileAsync(const wxString& file_name, std::function<void(IEditor*)>&& callback);
+
+    /**
+     * @brief open a remote file into the editor mainbook
+     */
+    clEditor* OpenRemoteFile(const wxString& local_path,
+                             const wxString& remote_path,
+                             const wxString& ssh_account,
+                             const wxString& tooltip = wxEmptyString);
+
+    clEditor* OpenFile(const wxString& file_name,
+                       const wxString& projectName = wxEmptyString,
+                       int lineno = wxNOT_FOUND,
+                       long position = wxNOT_FOUND,
+                       OF_extra extra = OF_AddJump,
+                       bool preserveSelection = true,
+                       int bmp = wxNOT_FOUND,
+                       const wxString& tooltip = wxEmptyString);
     /**
      * @brief open file based on a browsing record
      */
@@ -212,17 +160,22 @@ public:
     /**
      * @brief a simpler version: open a file with a given tooltip and bitmap
      */
-    clEditor* OpenFile(const wxString& file_name, const wxBitmap& bmp, const wxString& tooltip = wxEmptyString)
+    clEditor* OpenFile(const wxString& file_name, int bmp, const wxString& tooltip = wxEmptyString)
     {
         return OpenFile(file_name, "", wxNOT_FOUND, wxNOT_FOUND, OF_AddJump, false, bmp, tooltip);
     }
 
-    bool AddPage(wxWindow* win, const wxString& text, const wxString& tooltip = wxEmptyString,
-                 const wxBitmap& bmp = wxNullBitmap, bool selected = false, int insert_at_index = wxNOT_FOUND);
+    /**
+     * @brief add page to the main book
+     */
+    bool AddBookPage(
+        wxWindow* win, const wxString& text, const wxString& tooltip, int bmp, bool selected, int insert_at_index);
     bool SelectPage(wxWindow* win);
 
-    bool UserSelectFiles(std::vector<std::pair<wxFileName, bool> >& files, const wxString& title,
-                         const wxString& caption, bool cancellable = true);
+    bool UserSelectFiles(std::vector<std::pair<wxFileName, bool>>& files,
+                         const wxString& title,
+                         const wxString& caption,
+                         bool cancellable = true);
 
     bool SaveAll(bool askUser, bool includeUntitled);
 
@@ -260,6 +213,83 @@ public:
 
     void SetUseBuffereLimit(bool useBuffereLimit) { this->m_useBuffereLimit = useBuffereLimit; }
     bool GetUseBuffereLimit() const { return m_useBuffereLimit; }
+
+    MainNotebook* GetNotebook() { return m_book; }
+
+private:
+    FilesModifiedDlg* GetFilesModifiedDlg();
+    void DoShowTabLabelContextMenu(size_t tabIdx);
+    void CreateGuiControls();
+    void ConnectEvents();
+    void DoUpdateNotebookTheme();
+    void DoOpenImageViewer(const wxFileName& filename);
+    void DoUpdateEditorsThemes();
+
+    void OnMouseDClick(wxBookCtrlEvent& e);
+    void OnTabDClicked(wxBookCtrlEvent& e);
+    void OnTabLabelContextMenu(wxBookCtrlEvent& e);
+    void OnPageClosing(wxBookCtrlEvent& e);
+    void OnPageClosed(wxBookCtrlEvent& e);
+    void OnPageChanged(wxBookCtrlEvent& e);
+    void OnClosePage(wxBookCtrlEvent& e);
+    void OnPageChanging(wxBookCtrlEvent& e);
+    void OnEditorModified(clCommandEvent& event);
+    void OnEditorSaved(clCommandEvent& event);
+    void OnProjectFileAdded(clCommandEvent& e);
+    void OnProjectFileRemoved(clCommandEvent& e);
+    void OnWorkspaceLoaded(clWorkspaceEvent& e);
+    void OnWorkspaceClosed(clWorkspaceEvent& e);
+    void OnDebugEnded(clDebugEvent& e);
+    void OnInitDone(wxCommandEvent& e);
+    void OnThemeChanged(clCommandEvent& e);
+    void OnColoursAndFontsChanged(clCommandEvent& e);
+    bool DoSelectPage(wxWindow* win);
+    void DoHandleFrameMenu(clEditor* editor);
+    void OnWorkspaceReloadStarted(clWorkspaceEvent& e);
+    void OnWorkspaceReloadEnded(clWorkspaceEvent& e);
+    void OnEditorSettingsChanged(wxCommandEvent& e);
+    void OnSettingsChanged(wxCommandEvent& e);
+    void OnIdle(wxIdleEvent& event);
+    void OnSessionLoaded(clCommandEvent& event);
+    void OnHideWelcomePage(clCommandEvent& event);
+
+    /**
+     * @brief return proper tab label for a given filename
+     */
+    wxString CreateLabel(const wxFileName& fn, bool modified) const;
+    /**
+     * @brief open file and set an alternate content
+     */
+    void DoOpenFile(const wxString& filename, const wxString& content = "");
+
+    /**
+     * @brief display the welcome page
+     */
+    void ShowWelcomePage(bool show);
+    void DoShowWindow(wxWindow* win, bool show);
+
+    void OnEditorChanged(wxCommandEvent& event);
+    void OnAllEditorClosed(wxCommandEvent& event);
+
+    void push_callback(std::function<void(IEditor*)>&& callback, const wxString& fullpath);
+    void execute_callbacks_for_file(const wxString& fullpath);
+    bool has_callbacks(const wxString& fullpath) const;
+
+    int FindEditorIndexByFullPath(const wxString& fullpath);
+    void DoRestoreSession(const SessionEntry& entry);
+
+    FileHistory m_recentFiles;
+    clEditorBar* m_navBar{nullptr};
+    MainNotebook* m_book{nullptr};
+    bool m_useBuffereLimit{true};
+    bool m_isWorkspaceReloading{false};
+    bool m_reloadingDoRaise{true}; // Prevents multiple Raises() during RestoreSession()
+    FilesModifiedDlg* m_filesModifiedDlg{nullptr};
+    std::unordered_map<wxString, TagEntryPtr> m_currentNavBarTags;
+    WelcomePage* m_welcomePage{nullptr};
+    QuickFindBar* m_findBar{nullptr};
+    std::unordered_map<wxString, CallbackVec_t> m_callbacksTable;
+    bool m_initDone{false};
 };
 
 #endif // MAINBOOK_H
