@@ -25,25 +25,23 @@
 #ifndef MANAGER_H
 #define MANAGER_H
 
-#include <list>
-#include <map>
-#include <wx/event.h>
-
 #include "async_executable_cmd.h"
 #include "breakpointsmgr.h"
 #include "clDebuggerTerminal.h"
-#include "clKeyboardManager.h"
 #include "cl_command_event.h"
 #include "ctags_manager.h"
 #include "debuggerobserver.h"
 #include "filehistory.h"
-#include "parse_thread.h"
 #include "perspectivemanager.h"
 #include "queuecommand.h"
 #include "shell_command.h"
 #include "singleton.h"
 #include "workspace.h"
 
+#include <list>
+#include <map>
+#include <wx/event.h>
+
 class clEditor;
 class IProcess;
 
@@ -51,8 +49,6 @@ class IProcess;
 // The Manager class
 // ====================================================================
 
-extern const wxEventType wxEVT_CMD_RESTART_CODELITE;
-
 class DisplayVariableDlg;
 
 class DbgStackInfo
@@ -69,7 +65,6 @@ public:
     }
 
     ~DbgStackInfo() { Clear(); }
-
     void Clear()
     {
         func.Clear();
@@ -77,9 +72,7 @@ public:
     }
 
     bool operator==(const DbgStackInfo& rhs) { return func == rhs.func && depth == rhs.depth; }
-
     bool operator!=(const DbgStackInfo& rhs) { return func != rhs.func || depth != rhs.depth; }
-
     bool IsValid() const { return !func.IsEmpty() && depth != wxString::npos; }
 };
 
@@ -100,25 +93,21 @@ protected:
     IProcess* m_programProcess;
     BreakptMgr* m_breakptsmgr;
     bool m_isShutdown;
-    bool m_workspceClosing;
     bool m_dbgCanInteract;
     bool m_useTipWin;
     long m_tipWinPos;
     int m_frameLineno;
     std::list<QueueCommand> m_buildQueue;
     wxArrayString m_dbgWatchExpressions;
-    wxFileName m_codeliteLauncher;
     DisplayVariableDlg* m_watchDlg;
     bool m_retagInProgress;
-    bool m_repositionEditor; // flag used for debugging, should editor be repositioned after user updates like "add
-                             // watch"
     DbgStackInfo m_dbgCurrentFrameInfo;
     PerspectiveManager m_perspectiveManager;
     clDebuggerTerminalPOSIX m_debuggerTerminal;
 
 protected:
-    Manager(void);
-    virtual ~Manager(void);
+    Manager();
+    virtual ~Manager();
     void OnHideGdbTooltip(clCommandEvent& event);
 
     //--------------------------- Global State -----------------------------
@@ -142,13 +131,8 @@ public:
     bool IsShutdownInProgress() const { return m_isShutdown; }
     void SetShutdownInProgress(bool b) { m_isShutdown = b; }
 
-    bool GetRepositionEditor() const { return m_repositionEditor; }
-    void SetRepositionEditor(bool b) { m_repositionEditor = b; }
-
-    void SetCodeLiteLauncherPath(const wxString& path);
     void OnRestart(clCommandEvent& event);
-    void OnCmdRestart(wxCommandEvent& event);
-    void GenerateCompileCommands();
+    void OnForcedRestart(clCommandEvent& event);
     void OnFindInFilesDismissed(clFindInFilesEvent& event);
     void OnFindInFilesShowing(clFindInFilesEvent& event);
     void OnUpdateDebuggerActiveView(clDebugEvent& event);
@@ -158,30 +142,27 @@ public:
     void OnDebuggerStopping(clDebugEvent& event);
 
 protected:
-    void DoRestartCodeLite();
-    void InstallClangTools();
+    void DoRestartCodeLite(bool force = false);
 
     //--------------------------- Workspace Loading -----------------------------
 public:
     /*!
-     * \brief
+     * @brief
      * check if a workspace is open
      *
-     * \returns
+     * @returns
      * true if a workspace is open
      */
     bool IsWorkspaceOpen() const;
 
-    const bool& IsWorkspaceClosing() const { return m_workspceClosing; }
-
     /*!
-     * \brief
+     * @brief
      * Create a workspace with a given name and path
      *
-     * \param name
+     * @param name
      * workspace name
      *
-     * \param path
+     * @param path
      * workspace path
      *
      */
@@ -193,8 +174,8 @@ public:
     void OpenWorkspace(const wxString& path);
 
     /**
-     * \brief close the currently opened workspace and reload it without saving any modifications made to it, if no
-     * workspace is opened, this functiond does anything
+     * @brief close the currently opened workspace and reload it without saving any modifications made to it, if no
+     * workspace is opened, this function does anything
      */
     void ReloadWorkspace();
 
@@ -205,13 +186,13 @@ public:
     void CloseWorkspace();
 
     /**
-     * \brief clear the recent workspaces list
+     * @brief clear the recent workspaces list
      */
     void ClearWorkspaceHistory();
 
     /**
      * Return list of recently opened workspaces from the configuration file
-     * \param files [output]
+     * @param files [output]
      */
     void GetRecentlyOpenedWorkspaces(wxArrayString& files);
 
@@ -223,7 +204,7 @@ public:
 
     /**
      * @brief update the C++ parser search / exclude paths with the global paths
-     * and the workspace specifc ones
+     * and the workspace specific ones
      * @return true if the paths were modified, false otherwise
      */
     void UpdateParserPaths(bool notify);
@@ -231,8 +212,6 @@ public:
 protected:
     void DoSetupWorkspace(const wxString& path);
 
-    void OnAddWorkspaceToRecentlyUsedList(wxCommandEvent& e);
-    void OnParserThreadSuggestColourTokens(clParseThreadEvent& event);
     /**
      * @brief a project was renamed, reload the workspace
      */
@@ -252,27 +231,27 @@ public:
     /**
      * Add an existing project to the workspace. If no workspace is open,
      * this function does nothing
-     * \param path project file path name to add
+     * @param path project file path name to add
      */
     void AddProject(const wxString& path);
 
     /**
      * Checks the active project for file entries that no longer exist on the filesystem,
      * and for existing files that are missing from the project
-     * \param projectName the name of the project to reconcile. If "" do the currently-active project
+     * @param projectName the name of the project to reconcile. If "" do the currently-active project
      */
     void ReconcileProject(const wxString& projectName = "");
 
     /**
      * Import a MS Solution file and open it in the editor
-     * \param path path to the .sln file
+     * @param path path to the .sln file
      */
     void ImportMSVSSolution(const wxString& path, const wxString& defaultCompiler);
 
     /**
      * Remove the a project from the workspace
-     * \param name project name to remove
-     * \return true on success false otherwise
+     * @param name project name to remove
+     * @return true on success false otherwise
      */
     bool RemoveProject(const wxString& name, bool notify);
 
@@ -287,13 +266,13 @@ public:
     ProjectPtr GetProject(const wxString& name) const;
 
     /**
-     * \return active project name
+     * @return active project name
      */
     wxString GetActiveProjectName();
 
     /**
      * Set project as active
-     * \param name project name to set as active
+     * @param name project name to set as active
      */
     void SetActiveProject(const wxString& name);
 
@@ -319,107 +298,81 @@ public:
      */
     void GetWorkspaceFiles(wxArrayString& files);
 
-    /**
-     * @brief return list of files in a form of std::set
-     */
-    void GetWorkspaceFiles(std::set<wxString>& files);
-
     /**
      * return list of files that are part of the workspace
      */
     void GetWorkspaceFiles(std::vector<wxFileName>& files, bool absPath = false);
 
-    /**
-     * check if a file is part of the workspace
-     * \param fileName the file name in absolute path
-     */
-    bool IsFileInWorkspace(const wxString& fileName);
-
-    /**
-     * Search for (non-absolute) file in the workspace
-     */
-    wxFileName FindFile(const wxString& fileName, const wxString& project = wxEmptyString);
-
     /**
      * retag workspace
      */
     void RetagWorkspace(TagsManager::RetagType type);
 
     /**
-     * @brief the parser thread has completed to scan for include files to parse
-     * @param event
-     */
-    void OnIncludeFilesScanDone(clParseThreadEvent& event);
-    void OnDbContentCacherLoaded(wxCommandEvent& event);
-
-    /**
-     * \brief retag a given file
-     * \param filename
+     * @brief retag a given file
+     * @param filename
      */
     void RetagFile(const wxString& filename);
 
     /**
-     * \brief Launch the ParseThread to update the preprocessor vizualisation
-     * \param filename
+     * @brief Launch the ParseThread to update the preprocessor visualization
+     * @param filename
      */
     void UpdatePreprocessorFile(clEditor* editor);
 
-protected:
-    wxFileName FindFile(const wxArrayString& files, const wxFileName& fn);
-
     //--------------------------- Project Files Mgmt -----------------------------
 public:
     /**
      * Add new virtual directory to the workspace.
-     * \param virtualDirFullPath a dot separated string of the new virtual directory full path up to the parent project
+     * @param virtualDirFullPath a dot separated string of the new virtual directory full path up to the parent project
      *        for example: to add a new VD name VD3 under: Project1->VD1->VD2 path should contain: Project1.VD1.VD2.VD3
      */
     int AddVirtualDirectory(const wxString& virtualDirFullPath, bool createIt);
 
     /**
      * Remove virtual directory from the workspace.
-     * \param virtualDirFullPath a dot separated string of the virtual directory to be removed
+     * @param virtualDirFullPath a dot separated string of the virtual directory to be removed
      */
     void RemoveVirtualDirectory(const wxString& virtualDirFullPath);
 
     /**
      * Create new file on the disk and open it in the main editor
-     * \param fileName file full path (including directories)
-     * \param vdFullPath path of the virtual directory
+     * @param fileName file full path (including directories)
+     * @param vdFullPath path of the virtual directory
      */
     bool AddNewFileToProject(const wxString& fileName, const wxString& vdFullPath, bool openIt = true);
 
     /**
      * Add an existing file to workspace
-     * \param fileName file full path (including directories)
-     * \param vdFullPath path of the virtual directory
+     * @param fileName file full path (including directories)
+     * @param vdFullPath path of the virtual directory
      */
     bool AddFileToProject(const wxString& fileName, const wxString& vdFullPath, bool openIt = false);
 
     /**
-     * \brief
-     * \param files
-     * \param vdFullPath
-     * \param actualAdded
-     * \return
+     * @brief
+     * @param files
+     * @param vdFullPath
+     * @param actualAdded
+     * @return
      */
     void AddFilesToProject(const wxArrayString& files, const wxString& vdFullPath, wxArrayString& actualAdded);
 
     /**
      * remove file from the workspace
-     * \param fileName the full path of the file to be removed
-     * \param vdFullPath the files' virtual directory path (including project)
-     * \param fullpathRemoved [output] set the full path of the file removed
-     * \param notify if set to true, this function will also fire the wxEVT_PROJ_FILE_REMOVED event
+     * @param fileName the full path of the file to be removed
+     * @param vdFullPath the files' virtual directory path (including project)
+     * @param fullpathRemoved [output] set the full path of the file removed
+     * @param notify if set to true, this function will also fire the wxEVT_PROJ_FILE_REMOVED event
      */
     bool RemoveFile(const wxString& fileName, const wxString& vdFullPath, wxString& fullpathRemoved,
                     bool notify = true);
 
     /**
      * remove file from the workspace
-     * \param origName the full path of the file to be renamed
-     * \param newName the full path the file must be renamed to
-     * \param vdFullPath the files' virtual directory path (including project)
+     * @param origName the full path of the file to be renamed
+     * @param newName the full path the file must be renamed to
+     * @param vdFullPath the files' virtual directory path (including project)
      */
     bool RenameFile(const wxString& origName, const wxString& newName, const wxString& vdFullPath);
 
@@ -428,109 +381,89 @@ public:
     /**
      * Rebuild the database by removing all entries from the database
      * that belongs to a given project, and then re-index all files
-     * \param projectName project to re-tag
+     * @param projectName project to re-tag
      */
     void RetagProject(const wxString& projectName, bool quickRetag);
 
     /**
      * return list of files in absolute path of a given project
-     * \param project project name
+     * @param project project name
      */
     void GetProjectFiles(const wxString& project, wxArrayString& files);
 
-    /**
-     * @brief return list of files belonged the active project (same as running: GetProjectFiles(GetActiveProjectName(),
-     * files)
-     */
-    void GetActiveProjectFiles(wxArrayString& files);
-
-    /**
-     * @brief return the currently opened file's project files
-     */
-    void GetActiveFileProjectFiles(wxArrayString& files);
-
     /**
      * @brief return the project name that 'fullPathFileName' belongs to. if 2 matches are found, return
      * the first one, or empty string if no match is found
-     * \param fullPathFileName the filepath to search with
-     * \param caseSensitive do a case-sensitive search
+     * @param fullPathFileName the filepath to search with
+     * @param caseSensitive do a case-sensitive search
      */
     wxString GetProjectNameByFile(const wxString& fullPathFileName, bool caseSensitive = false);
     /**
      * @brief return the project name that 'fullPathFileName' belongs to. if 2 matches are found, return
      * the first one, or empty string if no match is found
-     * \param fullPathFileName the filepath to search with
-     * \param caseSensitive do a case-sensitive search
+     * @param fullPathFileName the filepath to search with
+     * @param caseSensitive do a case-sensitive search
      */
     wxString GetProjectNameByFile(wxString& fullPathFileName, bool caseSensitive = false);
 
     //--------------------------- Project Settings Mgmt -----------------------------
 public:
-    /**
-     * @brief if a workspace is opened, return the current build configuration
-     * of the active project
-     * @return active build configuration or NULL
-     */
-    BuildConfigPtr GetCurrentBuildConf();
-
     /**
      * Return a project working directory
-     * \param project project name
+     * @param project project name
      */
     wxString GetProjectCwd(const wxString& project) const;
 
     /**
      * Return project settings by name
-     * \param projectName project name
-     * \return project settings smart prt
+     * @param projectName project name
+     * @return project settings smart prt
      */
     ProjectSettingsPtr GetProjectSettings(const wxString& projectName) const;
 
     /**
      * Set project settings
-     * \param projectName project name
-     * \param settings settings to update
+     * @param projectName project name
+     * @param settings settings to update
      */
     void SetProjectSettings(const wxString& projectName, ProjectSettingsPtr settings);
 
     /**
      * Set project global settings
-     * \param projectName project name
-     * \param settings global settings to update
+     * @param projectName project name
+     * @param settings global settings to update
      */
     void SetProjectGlobalSettings(const wxString& projectName, BuildConfigCommonPtr settings);
 
     /**
-     * \brief return the project excution command as it appears in the project settings
-     * \param projectName
-     * \param wd the working directory that the command should be running from
-     * \param considerPauseWhenExecuting when set to true (default) CodeLite will take into consideration the value set
+     * @brief return the project execution command as it appears in the project settings
+     * @param projectName
+     * @param wd the working directory that the command should be running from
+     * @param considerPauseWhenExecuting when set to true (default) CodeLite will take into consideration the value set
      * in the project
      * settings 'Pause when execution ends'
-     * \return project execution command or wxEmptyString if the project does not exist
+     * @return project execution command or wxEmptyString if the project does not exist
      */
     wxString GetProjectExecutionCommand(const wxString& projectName, wxString& wd,
                                         bool considerPauseWhenExecuting = true);
 
-    bool DoFindDockInfo(const wxString& saved_perspective, const wxString& dock_name, wxString& dock_info);
-
     //--------------------------- Top Level Pane Management -----------------------------
 public:
     /**
-     * \brief test if pane_name is resides in the wxAuiManager and is visible
-     * \param pane_name pane name to search for
-     * \return true on success (exist in the AUI manager and visible), false otherwise
+     * @brief test if pane_name is resides in the wxAuiManager and is visible
+     * @param pane_name pane name to search for
+     * @return true on success (exist in the AUI manager and visible), false otherwise
      */
     bool IsPaneVisible(const wxString& pane_name);
 
     /**
      * Show output pane and set focus to focusWin
-     * \param focusWin tab name to set the focus
-     * \return return true if the output pane was hidden and this function forced it to appear. false if the window was
+     * @param focusWin tab name to set the focus
+     * @return return true if the output pane was hidden and this function forced it to appear. false if the window was
      * already
      * shown and nothing needed to be done
      */
-    bool ShowOutputPane(wxString focusWin = wxEmptyString, bool commit = true);
+    bool ShowOutputPane(const wxString& focusWin, bool show, bool take_focus);
 
     /**
      * Show the debugger pane
@@ -539,17 +472,28 @@ public:
 
     /**
      * Show the workspace pane and set focus to focusWin
-     * \param focusWin tab name to set the focus
+     * @param focusWin tab name to set the focus
      */
     void ShowWorkspacePane(wxString focusWin = wxEmptyString, bool commit = true);
 
+    /**
+     * Show the secondary side bar pane and set focus to focusWin
+     * @param focusWin tab name to set the focus
+     */
+    void ShowSecondarySideBarPane(wxString focusWin = wxEmptyString, bool commit = true);
+
     /**
      * Hide pane
      */
     void HidePane(const wxString& paneName, bool commit = true);
 
     /**
-     * Hide/Show all panes. This function saves the current prespective and
+     * Show pane
+     */
+    void ShowPane(const wxString& paneName, bool commit = true);
+
+    /**
+     * Hide/Show all panes. This function saves the current perspective and
      * then hides all panes, when called again, all panes are restored
      */
     void TogglePanes();
@@ -557,9 +501,9 @@ public:
     //--------------------------- Menu and Accelerator Mmgt -----------------------------
 public:
     /**
-     * \brief update the menu bar accelerators
+     * @brief update the menu bar accelerators
      */
-    void UpdateMenuAccelerators(wxFrame* frame = NULL);
+    void UpdateMenuAccelerators();
 
     //--------------------------- Run Program (No Debug) -----------------------------
 public:
@@ -591,7 +535,6 @@ protected:
     //--------------------------- Debugger Support -----------------------------
 protected:
     void DoUpdateDebuggerTabControl(wxWindow* curpage);
-    bool DebuggerPaneWasShown;
 
 public:
     BreakptMgr* GetBreakpointsMgr() { return m_breakptsmgr; }
@@ -608,16 +551,6 @@ public:
 
     void SetMemory(const wxString& address, size_t count, const wxString& hex_value);
 
-    /**
-     * Stores the debugger pane status when the debug session started
-     */
-    void SetDebuggerPaneOriginallyVisible(bool shown) { DebuggerPaneWasShown = shown; }
-
-    /**
-     * Returns true if the debugger pane was already shown when the debug session started
-     */
-    bool GetDebuggerPaneOriginallyVisible() const { return DebuggerPaneWasShown; }
-
     //---------------------------------------------------
     // Debugging API
     //---------------------------------------------------
@@ -636,15 +569,14 @@ public:
     DbgStackInfo DbgGetCurrentFrameInfo() { return m_dbgCurrentFrameInfo; }
 
     //---------------------------------------------------
-    // Internal implementaion for various debugger events
+    // Internal implementation for various debugger events
     //---------------------------------------------------
 
     void UpdateAddLine(const wxString& line, const bool OnlyIfLoggingOn = false);
-    void UpdateFileLine(const wxString& file, int lineno, bool repositionEditor = true);
     void UpdateGotControl(const DebuggerEventData& e);
     void UpdateLostControl();
     void UpdateRemoteTargetConnected(const wxString& line);
-    void UpdateTypeReolsved(const wxString& expression, const wxString& type);
+    void UpdateTypeResolved(const wxString& expression, const wxString& type);
     void UpdateAsciiViewer(const wxString& expression, const wxString& tip);
 
     //---------------------------------------------------
@@ -667,40 +599,40 @@ public:
     void StopBuild();
 
     /**
-     * \brief add build job to the internal queue
-     * \param buildInfo
+     * @brief add build job to the internal queue
+     * @param buildInfo
      */
     void PushQueueCommand(const QueueCommand& buildInfo);
 
     /**
-     * \brief process the next build job
+     * @brief process the next build job
      */
     void ProcessCommandQueue();
 
     /**
-     * \brief build the entire workspace. This operation is equal to
+     * @brief build the entire workspace. This operation is equal to
      * manually right clicking on each project in the workspace and selecting
      * 'build'
      */
     void BuildWorkspace();
 
     /**
-     * \brief clean the entire workspace. This operation is equal to
+     * @brief clean the entire workspace. This operation is equal to
      * manually right clicking on each project in the workspace and selecting
      * 'clean'
      */
     void CleanWorkspace();
 
     /**
-     * \brief clean, followed by buid of the entire workspace. This operation is equal to
+     * @brief clean, followed by build of the entire workspace. This operation is equal to
      * manually right clicking on each project in the workspace and selecting
      * 'clean'
      */
     void RebuildWorkspace();
 
     /**
-     * \brief when building using custom build, execute the makefile generation command provided by the user
-     * \param project project to execute it for
+     * @brief when building using custom build, execute the makefile generation command provided by the user
+     * @param project project to execute it for
      */
     void RunCustomPreMakeCommand(const wxString& project);
 
@@ -711,7 +643,7 @@ public:
     void CompileFile(const wxString& project, const wxString& fileName, bool preprocessOnly = false);
 
     /**
-     * return true if the last buid ended successfully
+     * return true if the last build ended successfully
      */
     bool IsBuildEndedSuccessfully() const;
 
@@ -723,7 +655,7 @@ public:
     void GetActiveProjectAndConf(wxString& project, wxString& conf);
     /**
      * @brief return true if debugger view is visible
-     * This can be true incase the view is the selected tab in the debuggger pane notebook
+     * This can be true incase the view is the selected tab in the debugger pane notebook
      * or incase it is detached and visible
      */
     bool IsDebuggerViewVisible(const wxString& name);
