@@ -23,32 +23,63 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "menu_event_handlers.h"
-#include "manager.h"
-#include "cl_editor.h"
-#include "frame.h"
+
 #include "cl_command_event.h"
-#include "event_notifier.h"
+#include "cl_editor.h"
 #include "codelite_events.h"
+#include "event_notifier.h"
+#include "frame.h"
+#include "manager.h"
+
+#include <wx/numdlg.h>
+#include <wx/textdlg.h>
 
 //------------------------------------
 // Handle copy events
 //------------------------------------
-void EditHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void EditHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    LEditor *editor = (LEditor*)owner;
-    
+    clEditor* editor = (clEditor*)owner;
+
     OptionsConfigPtr options = editor->GetOptions();
-    if (event.GetId() == wxID_COPY) {
-        editor->CopyAllowLine();
-
-    } else if (event.GetId() == wxID_CUT) {
+    switch (event.GetId()) {
+    case wxID_ZOOM_IN:
+        editor->ZoomIn();
+        return;
+    case wxID_ZOOM_OUT:
+        editor->ZoomOut();
+        return;
+    case wxID_ZOOM_FIT:
+        editor->SetZoom(0);
+        return;
+    case wxID_COPY:
+        if (options->GetCopyLineEmptySelection()) {
+            editor->CopyAllowLine();
+        } else {
+            editor->Copy();
+        }
+        return;
+    case wxID_CUT:
         editor->Cut();
-        
-    } else if (event.GetId() == wxID_PASTE) {
+        return;
+    case wxID_PASTE:
         editor->Paste();
+        return;
+    case wxID_SELECTALL:
+        editor->SelectAll();
+        return;
+    case wxID_DUPLICATE:
+        editor->SelectionDuplicate();
+        return;
+    case wxID_DELETE:
+        editor->DeleteBack();
+        return;
+    default:
+        break;
+    }
 
-    } else if (event.GetId() == wxID_UNDO) {
+    if (event.GetId() == wxID_UNDO) {
         if (editor->GetCommandsProcessor().CanUndo()) {
             editor->Undo();
             editor->GetCommandsProcessor().CloseSciUndoAction();
@@ -63,16 +94,12 @@ void EditHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
         }
 
     } else if (event.GetId() == XRCID("label_current_state")) {
-        wxString label = wxGetTextFromUser("What would you like to call the current state?", "Label current state", "", editor);
+        wxString label = wxGetTextFromUser(_("What would you like to call the current state?"),
+                                           _("Label current state"), "", editor);
         if (!label.empty()) {
             editor->GetCommandsProcessor().SetUserLabel(label);
         }
 
-    } else if (event.GetId() == wxID_SELECTALL) {
-        editor->SelectAll();
-
-    } else if (event.GetId() == wxID_DUPLICATE) {
-        editor->SelectionDuplicate();
     } else if (event.GetId() == XRCID("delete_line_end")) {
         editor->DelLineRight();
 
@@ -89,7 +116,8 @@ void EditHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
         editor->LineCut();
 
     } else if (event.GetId() == XRCID("trim_trailing")) {
-        editor->TrimText(true, false);
+        // trim from the menu ignores the settings defined in `Settings -> Preferences -> Trim`
+        editor->TrimText(TRIM_APPEND_LF | TRIM_ENABLED);
 
     } else if (event.GetId() == XRCID("to_lower")) {
         editor->ChangeCase(true);
@@ -100,63 +128,61 @@ void EditHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
     } else if (event.GetId() == XRCID("transpose_lines")) {
         editor->LineTranspose();
 
-    } else if (event.GetId() == wxID_DELETE) {
-        editor->DeleteBack();
-
     } else if (event.GetId() == XRCID("move_line_down")) {
 
-        int curline  = editor->GetCurrentLine();
-        int lastline = editor->LineFromPosition(editor->GetLength()-1);
+        int curline = editor->GetCurrentLine();
+        int lastline = editor->LineFromPosition(editor->GetLength() - 1);
 
-        if (editor->GetSelection().empty()
-                ||  (editor->LineFromPos(editor->GetSelectionStart() == editor->LineFromPos(editor->GetSelectionEnd())))) {
+        if (editor->GetSelection().empty() ||
+            (editor->LineFromPos(editor->GetSelectionStart() == editor->LineFromPos(editor->GetSelectionEnd())))) {
             // No selection (or only a trivial 1-line one)
             if (curline != lastline) {
-                editor->LineDown();              
+                editor->LineDown();
                 editor->LineTranspose();
             }
 
         } else {
-            editor->MoveSelectedLinesDown();  // There is a selection, so we can move it direct
+            editor->MoveSelectedLinesDown(); // There is a selection, so we can move it direct
         }
 
     } else if (event.GetId() == XRCID("move_line_up")) {
 
-        if (editor->GetSelection().empty()
-                ||  (editor->LineFromPos(editor->GetSelectionStart() == editor->LineFromPos(editor->GetSelectionEnd())))) {
+        if (editor->GetSelection().empty() ||
+            (editor->LineFromPos(editor->GetSelectionStart() == editor->LineFromPos(editor->GetSelectionEnd())))) {
             // No selection (or only a trivial 1-line one)
             editor->LineTranspose();
             editor->LineUp();
 
         } else {
-            editor->MoveSelectedLinesUp();  // There is a selection, so we can move it direct
+            editor->MoveSelectedLinesUp(); // There is a selection, so we can move it direct
         }
 
     } else if (event.GetId() == XRCID("center_line_roll")) {
-        int here    = editor->GetCurrentLine();
-        int top     = editor->GetFirstVisibleLine();
-        int count   = editor->LinesOnScreen();
-        int center  = top + (count / 2);
+        int here = editor->GetCurrentLine();
+        int top = editor->GetFirstVisibleLine();
+        int count = editor->LinesOnScreen();
+        int center = top + (count / 2);
         if (here < center) {
             for (int lnIterator = 0; lnIterator < center - here; lnIterator++)
-                editor->LineScrollUp();   //roll up until we get to center
+                editor->LineScrollUp(); // roll up until we get to center
         } else if (here > center) {
             for (int lnIterator = 0; lnIterator < here - center; lnIterator++)
-                editor->LineScrollDown(); //roll down until we get to center
+                editor->LineScrollDown(); // roll down until we get to center
         }
 
-    } else if(event.GetId() == XRCID("convert_indent_to_spaces")) {
+    } else if (event.GetId() == XRCID("convert_indent_to_spaces")) {
         editor->ConvertIndentToSpaces();
-    } else if(event.GetId() == XRCID("convert_indent_to_tabs")) {
+    } else if (event.GetId() == XRCID("convert_indent_to_tabs")) {
         editor->ConvertIndentToTabs();
     }
 }
 
-void EditHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void EditHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
 
-    if (event.GetId() == wxID_COPY || event.GetId() == XRCID("trim_trailing") || event.GetId() == XRCID("to_lower") || event.GetId() == XRCID("to_upper")) {
+    if (event.GetId() == wxID_COPY || event.GetId() == XRCID("trim_trailing") || event.GetId() == XRCID("to_lower") ||
+        event.GetId() == XRCID("to_upper")) {
         event.Enable(editor);
 
     } else if (event.GetId() == wxID_CUT) {
@@ -185,10 +211,10 @@ void EditHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
 //------------------------------------
 // brace matching
 //------------------------------------
-void BraceMatchHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void BraceMatchHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
@@ -199,39 +225,34 @@ void BraceMatchHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &eve
     }
 }
 
-void BraceMatchHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void BraceMatchHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    event.Enable(editor &&editor->GetLength() > 0);
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    event.Enable(editor && editor->GetLength() > 0);
 }
 
-
 //------------------------------------
 // Find / Replace
 //------------------------------------
-void FindReplaceHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void FindReplaceHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( editor ) {
-        if ( event.GetId() == wxID_FIND ) {
-            clMainFrame::Get()->GetMainBook()->ShowQuickBar( editor->GetFirstSelection() );
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (editor) {
+        if (event.GetId() == XRCID("id_find")) {
+            clMainFrame::Get()->GetMainBook()->ShowQuickBar(editor->GetFirstSelection(), false);
+        } else if (event.GetId() == XRCID("id_replace")) {
+            clMainFrame::Get()->GetMainBook()->ShowQuickBar(editor->GetFirstSelection(), true);
 
-        } else if ( event.GetId() == wxID_REPLACE ) {
-            editor->DoFindAndReplace(true);
-
-        } else if(event.GetId() == XRCID("ID_QUICK_ADD_NEXT")) {
+        } else if (event.GetId() == XRCID("ID_QUICK_ADD_NEXT")) {
             editor->QuickAddNext();
-            
-        } else if(event.GetId() == XRCID("ID_QUICK_FIND_ALL")) {
+
+        } else if (event.GetId() == XRCID("ID_QUICK_FIND_ALL")) {
             editor->QuickFindAll();
         }
-
-    } else if ( event.GetId() == wxID_FIND ) {
-        clMainFrame::Get()->GetMainBook()->ShowQuickBarForPlugins();
     }
 }
 
-void FindReplaceHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void FindReplaceHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
     wxUnusedVar(owner);
     wxUnusedVar(event);
@@ -241,54 +262,26 @@ void FindReplaceHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &
 // goto linenumber
 //----------------------------------
 
-void GotoHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void GotoHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
     wxString msg;
     msg.Printf(_("Go to line number (1 - %i):"), editor->GetLineCount());
 
-    while ( 1 ) {
-        wxTextEntryDialog dlg(editor, msg, _("Go To Line"));
-        dlg.SetTextValidator(wxFILTER_NUMERIC);
-
-        if (dlg.ShowModal() == wxID_OK) {
-            wxString val = dlg.GetValue();
-            long line;
-            if (!val.ToLong(&line)) {
-                wxString err;
-                err.Printf(_("'%s' is not a valid line number"), val.GetData());
-                wxMessageBox (err, _("Go To Line"), wxOK | wxICON_INFORMATION);
-                continue;
-            }
-
-            if (line > editor->GetLineCount()) {
-                wxString err;
-                err.Printf(_("Please insert a line number in the range of (1 - %i)"), editor->GetLineCount());
-                wxMessageBox (err, _("Go To Line"), wxOK | wxICON_INFORMATION);
-                continue;
-            }
-
-            if (line > 0) {
-                editor->CenterLine(line-1);
-                break;
-            } else {
-                editor->GotoLine(0);
-                break;
-            }
-        } else {
-            // wxID_CANCEL
-            return;
-        }
+    wxNumberEntryDialog dlg(editor, msg, wxEmptyString, _("Go To Line"), 0, 1, editor->GetLineCount());
+    if (dlg.ShowModal() == wxID_OK) {
+        long line = dlg.GetValue();
+        editor->CenterLine(line - 1);
+        editor->SetActive();
     }
-    editor->SetActive();
 }
 
-void GotoHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void GotoHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
     wxUnusedVar(event);
     wxUnusedVar(owner);
@@ -297,10 +290,10 @@ void GotoHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
 //------------------------------------
 // Bookmarks
 //------------------------------------
-void BookmarkHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void BookmarkHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
@@ -311,26 +304,25 @@ void BookmarkHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event
     } else if (event.GetId() == XRCID("previous_bookmark")) {
         editor->FindPrevMarker();
     } else if (event.GetId() == XRCID("removeall_current_bookmarks")) {
-        editor->DelAllMarkers(0);   //  0 == only the currently-active type
+        editor->DelAllMarkers(0); //  0 == only the currently-active type
     } else if (event.GetId() == XRCID("removeall_bookmarks")) {
-        editor->DelAllMarkers(-1);  // -1 == all types
+        editor->DelAllMarkers(-1); // -1 == all types
     }
 }
 
-void BookmarkHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void BookmarkHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
     wxUnusedVar(owner);
     wxUnusedVar(event);
 }
 
-
 //------------------------------------
 // Go to definition
 //------------------------------------
-void GotoDefinitionHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void GotoDefinitionHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
     if (event.GetId() == XRCID("goto_definition")) {
@@ -338,9 +330,9 @@ void GotoDefinitionHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent
     }
 }
 
-void GotoDefinitionHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void GotoDefinitionHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
     if (event.GetId() == XRCID("goto_previous_definition")) {
         event.Enable(editor && editor->CanGotoPreviousDefintion());
     } else {
@@ -352,10 +344,10 @@ void GotoDefinitionHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEven
 // Word wrap handler
 //----------------------------------------------------
 
-void WordWrapHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void WordWrapHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         event.Enable(false);
         return;
     }
@@ -364,10 +356,10 @@ void WordWrapHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &eve
     event.Check(editor->GetWrapMode() != wxSTC_WRAP_NONE);
 }
 
-void WordWrapHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void WordWrapHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
@@ -377,24 +369,29 @@ void WordWrapHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event
 // Fold handler
 //----------------------------------------------------
 
-void FoldHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void FoldHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
-    if (event.GetId() == XRCID("toggle_fold")) editor->ToggleCurrentFold();
-     else if (event.GetId() == XRCID("fold_all_in_selection")) editor->ToggleAllFoldsInSelection();
-     else if (event.GetId() == XRCID("fold_topmost_in_selection")) editor->ToggleTopmostFoldsInSelection();
-     else editor->FoldAll();
+    if (event.GetId() == XRCID("toggle_fold"))
+        editor->ToggleCurrentFold();
+    else if (event.GetId() == XRCID("fold_all_in_selection"))
+        editor->ToggleAllFoldsInSelection();
+    else if (event.GetId() == XRCID("fold_topmost_in_selection"))
+        editor->ToggleTopmostFoldsInSelection();
+    else
+        editor->FoldAll();
 }
 
-void FoldHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event) // Used for ToggleAllFoldsInSelection() etc
+void FoldHandler::ProcessUpdateUIEvent(wxWindow* owner,
+                                       wxUpdateUIEvent& event) // Used for ToggleAllFoldsInSelection() etc
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         event.Enable(false);
         return;
     }
@@ -402,15 +399,16 @@ void FoldHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
     bool hasSelection = !editor->GetSelection().empty();
     if (hasSelection) {
         // Even if there is a selection, check it's not a trivial amount i.e. spans at least 2 lines
-        hasSelection = editor->LineFromPos(editor->GetSelectionStart()) != editor->LineFromPos(editor->GetSelectionEnd());
+        hasSelection =
+            editor->LineFromPos(editor->GetSelectionStart()) != editor->LineFromPos(editor->GetSelectionEnd());
     }
     event.Enable(hasSelection);
 }
 
-void DebuggerMenuHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &event)
+void DebuggerMenuHandler::ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event)
 {
-    LEditor *editor = dynamic_cast<LEditor*>(owner);
-    if ( !editor ) {
+    clEditor* editor = dynamic_cast<clEditor*>(owner);
+    if (!editor) {
         return;
     }
 
@@ -420,9 +418,8 @@ void DebuggerMenuHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &e
     if (event.GetId() == XRCID("insert_breakpoint")) {
         editor->ToggleBreakpoint();
     }
-    if ((event.GetId() == XRCID("insert_temp_breakpoint"))
-        || (event.GetId() == XRCID("insert_disabled_breakpoint"))
-        || (event.GetId() == XRCID("insert_cond_breakpoint"))) {
+    if ((event.GetId() == XRCID("insert_temp_breakpoint")) || (event.GetId() == XRCID("insert_disabled_breakpoint")) ||
+        (event.GetId() == XRCID("insert_cond_breakpoint"))) {
         editor->AddOtherBreakpointType(event);
     }
     if (event.GetId() == XRCID("delete_breakpoint")) {
@@ -443,28 +440,28 @@ void DebuggerMenuHandler::ProcessCommandEvent(wxWindow *owner, wxCommandEvent &e
 
     if (event.GetId() == XRCID("disable_all_breakpoints")) {
         clDebugEvent event(wxEVT_DBG_UI_DISABLE_ALL_BREAKPOINTS);
-        EventNotifier::Get()->ProcessEvent( event );
+        EventNotifier::Get()->ProcessEvent(event);
         ManagerST::Get()->GetBreakpointsMgr()->SetAllBreakpointsEnabledState(false);
     }
 
     if (event.GetId() == XRCID("enable_all_breakpoints")) {
-        clDebugEvent event(wxEVT_DBG_UI_ENABLE_ALL_BREAKPOINTS );
-        EventNotifier::Get()->ProcessEvent( event );
+        clDebugEvent event(wxEVT_DBG_UI_ENABLE_ALL_BREAKPOINTS);
+        EventNotifier::Get()->ProcessEvent(event);
         ManagerST::Get()->GetBreakpointsMgr()->SetAllBreakpointsEnabledState(true);
     }
 
     if (event.GetId() == XRCID("delete_all_breakpoints")) {
-        
+
         // First let the plugins do this thing
-        clDebugEvent event(wxEVT_DBG_UI_DELTE_ALL_BREAKPOINTS);
-        EventNotifier::Get()->AddPendingEvent( event );
-        
+        clDebugEvent event(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS);
+        EventNotifier::Get()->AddPendingEvent(event);
+
         // Now clear the manager
         ManagerST::Get()->GetBreakpointsMgr()->DelAllBreakpoints();
     }
 }
 
-void DebuggerMenuHandler::ProcessUpdateUIEvent(wxWindow *owner, wxUpdateUIEvent &event)
+void DebuggerMenuHandler::ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event)
 {
     wxUnusedVar(owner);
     wxUnusedVar(event);
