@@ -25,8 +25,8 @@
 #ifndef MENU_EVENT_HANDLERS_H
 #define MENU_EVENT_HANDLERS_H
 
-#include "wx/event.h"
-#include "smart_ptr.h"
+#include <memory>
+#include <wx/event.h>
 #include <wx/xrc/xmlres.h>
 
 /**
@@ -38,20 +38,22 @@ protected:
     int m_id;
 
 public:
-    MenuEventHandler(int id)
-        : m_id(id){};
-    virtual ~MenuEventHandler(){};
+    explicit MenuEventHandler(int id)
+        : m_id(id)
+    {
+    }
+    virtual ~MenuEventHandler() = default;
 
     // handle an event
     virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) = 0;
     virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) = 0;
 
     // Setters/Getters
-    const int& GetEventId() const { return m_id; }
-    void SetEventId(const int& id) { m_id = id; }
+    int GetEventId() const { return m_id; }
+    void SetEventId(int id) { m_id = id; }
 };
 
-typedef SmartPtr<MenuEventHandler> MenuEventHandlerPtr;
+using MenuEventHandlerPtr = std::shared_ptr<MenuEventHandler>;
 
 //-----------------------------------------------------------------
 // Define here a class per event/group
@@ -63,13 +65,15 @@ typedef SmartPtr<MenuEventHandler> MenuEventHandlerPtr;
 class EditHandler : public MenuEventHandler
 {
 public:
-    EditHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~EditHandler(){};
+    explicit EditHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~EditHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //------------------------------------
@@ -78,28 +82,32 @@ public:
 class BraceMatchHandler : public MenuEventHandler
 {
 public:
-    BraceMatchHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~BraceMatchHandler(){};
+    explicit BraceMatchHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~BraceMatchHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //------------------------------------
-// Find / Repalce
+// Find / Replace
 //------------------------------------
 class FindReplaceHandler : public MenuEventHandler
 {
 public:
-    FindReplaceHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~FindReplaceHandler(){};
+    explicit FindReplaceHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~FindReplaceHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //------------------------------------
@@ -108,13 +116,15 @@ public:
 class GotoHandler : public MenuEventHandler
 {
 public:
-    GotoHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~GotoHandler(){};
+    explicit GotoHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~GotoHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //------------------------------------
@@ -123,13 +133,15 @@ public:
 class BookmarkHandler : public MenuEventHandler
 {
 public:
-    BookmarkHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~BookmarkHandler(){};
+    explicit BookmarkHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~BookmarkHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //------------------------------------
@@ -138,13 +150,15 @@ public:
 class GotoDefinitionHandler : public MenuEventHandler
 {
 public:
-    GotoDefinitionHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~GotoDefinitionHandler(){};
+    explicit GotoDefinitionHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~GotoDefinitionHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //-------------------------------------------------
@@ -153,13 +167,15 @@ public:
 class WordWrapHandler : public MenuEventHandler
 {
 public:
-    WordWrapHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~WordWrapHandler(){};
+    explicit WordWrapHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~WordWrapHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //-------------------------------------------------
@@ -168,13 +184,15 @@ public:
 class FoldHandler : public MenuEventHandler
 {
 public:
-    FoldHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~FoldHandler(){};
+    explicit FoldHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~FoldHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 //-------------------------------------------------
@@ -183,13 +201,15 @@ public:
 class DebuggerMenuHandler : public MenuEventHandler
 {
 public:
-    DebuggerMenuHandler(int id)
-        : MenuEventHandler(id){};
-    virtual ~DebuggerMenuHandler(){};
+    explicit DebuggerMenuHandler(int id)
+        : MenuEventHandler(id)
+    {
+    }
+    ~DebuggerMenuHandler() override = default;
 
 public:
-    virtual void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event);
-    virtual void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event);
+    void ProcessCommandEvent(wxWindow* owner, wxCommandEvent& event) override;
+    void ProcessUpdateUIEvent(wxWindow* owner, wxUpdateUIEvent& event) override;
 };
 
 #endif // MENU_EVENT_HANDLERS_H
