@@ -22,55 +22,41 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <wx/xrc/xmlres.h>
-#include "globals.h"
-#include <wx/clntdata.h>
-#include "event_notifier.h"
 #include "openwindowspanel.h"
+
+#include "ColoursAndFontsManager.h"
+#include "clToolBar.h"
+#include "clToolBarButtonBase.h"
 #include "cl_config.h"
+#include "editor_config.h"
+#include "event_notifier.h"
 #include "globals.h"
-#include "pluginmanager.h"
-#include <wx/wupdlock.h>
-#include "macros.h"
-#include <wx/filename.h>
-#include <algorithm>
-#include <wx/stc/stc.h>
 #include "imanager.h"
+#include "macros.h"
+#include "pluginmanager.h"
+
+#include <algorithm>
+#include <wx/clntdata.h>
+#include <wx/filename.h>
+#include <wx/stc/stc.h>
+#include <wx/wupdlock.h>
+#include <wx/xrc/xmlres.h>
 
 BEGIN_EVENT_TABLE(OpenWindowsPanel, OpenWindowsPanelBase)
 EVT_MENU(XRCID("wxID_CLOSE_SELECTED"), OpenWindowsPanel::OnCloseSelectedFiles)
 EVT_MENU(XRCID("wxID_SAVE_SELECTED"), OpenWindowsPanel::OnSaveSelectedFiles)
 END_EVENT_TABLE()
 
-struct TabSorter {
-    bool operator()(const clTab& t1, const clTab& t2)
-    {
-        wxString file1, file2;
-        if(t1.isFile) {
-            file1 = t1.filename.GetFullName().Lower();
-        } else {
-            file1 = t1.text;
-        }
-
-        if(t2.isFile) {
-            file2 = t2.filename.GetFullName().Lower();
-        } else {
-            file2 = t2.text;
-        }
-        return file1.CmpNoCase(file2) < 0;
-    }
-};
-
 struct TabClientData : public wxClientData {
     clTab tab;
     bool isModified;
-    TabClientData() {}
+    TabClientData() = default;
     TabClientData(const clTab& t)
         : tab(t)
         , isModified(false)
     {
     }
-    virtual ~TabClientData() {}
+    ~TabClientData() override = default;
     bool IsFile() const { return tab.isFile; }
 };
 
@@ -80,20 +66,33 @@ OpenWindowsPanel::OpenWindowsPanel(wxWindow* parent, const wxString& caption)
     , m_mgr(PluginManager::Get())
     , m_initDone(false)
     , m_workspaceClosing(false)
-    , m_workspaceOpened(false)
 {
-    BitmapLoader bmpLoader;
-    m_bitmaps = bmpLoader.MakeStandardMimeMap();
+    // Disable the built in sorting, this control will take care of it
+    m_dvListCtrl->SetSortFunction(nullptr);
+    m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
+    m_toolbar = new clToolBarGeneric(this);
+    auto images = m_toolbar->GetBitmapsCreateIfNeeded();
+    m_toolbar->AddToggleButton(wxID_SORT_ASCENDING, images->Add("sort"), _("Sort"));
+    m_toolbar->Realize();
+    GetSizer()->Insert(0, m_toolbar, 0, wxEXPAND);
+
+    m_toolbar->Bind(wxEVT_TOOL, &OpenWindowsPanel::OnSortItems, this, wxID_SORT_ASCENDING);
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &OpenWindowsPanel::OnSortItemsUpdateUI, this, wxID_SORT_ASCENDING);
 
     clConfig cfg;
-    m_auibar->ToggleTool(XRCID("TabsSortTool"), cfg.Read(kConfigTabsPaneSortAlphabetically, true));
+    m_toolbar->ToggleTool(XRCID("TabsSortTool"), cfg.Read(kConfigTabsPaneSortAlphabetically, true));
 
     EventNotifier::Get()->Connect(wxEVT_INIT_DONE, wxCommandEventHandler(OpenWindowsPanel::OnInitDone), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_BITMAPS_UPDATED, &OpenWindowsPanel::OnThemeChanged, this);
     Bind(wxEVT_IDLE, &OpenWindowsPanel::OnIdle, this);
 }
 
 OpenWindowsPanel::~OpenWindowsPanel()
 {
+    m_toolbar->Unbind(wxEVT_TOOL, &OpenWindowsPanel::OnSortItems, this, wxID_SORT_ASCENDING);
+    m_toolbar->Unbind(wxEVT_UPDATE_UI, &OpenWindowsPanel::OnSortItemsUpdateUI, this, wxID_SORT_ASCENDING);
+    EventNotifier::Get()->Unbind(wxEVT_BITMAPS_UPDATED, &OpenWindowsPanel::OnThemeChanged, this);
+
     // clear list now, or wxGTK seems to crash on exit
     Clear();
     EventNotifier::Get()->Disconnect(wxEVT_INIT_DONE, wxCommandEventHandler(OpenWindowsPanel::OnInitDone), NULL, this);
@@ -111,7 +110,8 @@ OpenWindowsPanel::~OpenWindowsPanel()
 }
 
 #define CHECK_WORKSPACE_CLOSING() \
-    if(m_workspaceClosing) return
+    if (m_workspaceClosing)       \
+    return
 
 void OpenWindowsPanel::OnActivePageChanged(wxCommandEvent& e)
 {
@@ -128,7 +128,7 @@ void OpenWindowsPanel::OnActiveEditorChanged(wxCommandEvent& e)
     CHECK_WORKSPACE_CLOSING();
 
     PopulateView();
-    if(m_mgr->GetActiveEditor()) {
+    if (m_mgr->GetActiveEditor()) {
         DoSelectItem(m_mgr->GetActiveEditor());
     }
 }
@@ -147,35 +147,30 @@ void OpenWindowsPanel::OnCloseSelectedFiles(wxCommandEvent& e)
     wxDataViewItemArray items;
     m_dvListCtrl->GetSelections(items);
 
-    if(items.IsEmpty()) return;
+    if (items.IsEmpty()) {
+        return;
+    }
 
-    wxArrayString paths;  // list of files
-    wxArrayString others; // list of non files editors
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    // Close the page, it will be removed from the UI later
+    std::vector<wxFileName> files;
+    wxArrayString pages;
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(items.Item(i)));
-        if(data->IsFile()) {
-            paths.Add(data->tab.filename.GetFullPath());
-        } else {
-            others.Add(data->tab.text);
+        if (data && data->IsFile()) {
+            files.push_back(data->tab.filename);
+        } else if (data) {
+            pages.push_back(data->tab.text);
         }
-
-        // Delete the item data
-        wxDELETE(data);
-
-        // Remove the item from the list
-        int row = m_dvListCtrl->ItemToRow(items.Item(i));
-        m_dvListCtrl->DeleteItem(row);
     }
 
     // Close the files
-    for(size_t i = 0; i < paths.GetCount(); ++i) {
-        wxFileName fn(paths.Item(i));
-        m_mgr->ClosePage(fn);
+    for (size_t i = 0; i < files.size(); ++i) {
+        m_mgr->ClosePage(files[i]);
     }
 
-    // Close non file tabs
-    for(size_t i = 0; i < others.GetCount(); ++i) {
-        m_mgr->ClosePage(others.Item(i));
+    // Close non files editors
+    for (size_t i = 0; i < pages.size(); ++i) {
+        m_mgr->ClosePage(pages.Item(i));
     }
 }
 
@@ -185,9 +180,10 @@ void OpenWindowsPanel::OnSaveSelectedFiles(wxCommandEvent& e)
     wxDataViewItemArray items;
     m_dvListCtrl->GetSelections(items);
 
-    if(items.IsEmpty()) return;
+    if (items.IsEmpty())
+        return;
 
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         DoSaveItem(items.Item(i));
     }
 }
@@ -195,36 +191,24 @@ void OpenWindowsPanel::OnSaveSelectedFiles(wxCommandEvent& e)
 void OpenWindowsPanel::DoSaveItem(wxDataViewItem item)
 {
     TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    if(data) {
-        if(data->IsFile()) {
+    if (data) {
+        if (data->IsFile()) {
             IEditor* editor = m_mgr->FindEditor(data->tab.filename.GetFullPath());
-            if(editor) {
+            if (editor) {
                 editor->Save();
             }
         }
     }
 }
 
-void OpenWindowsPanel::DoCloseItem(wxDataViewItem item)
-{
-    TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    if(data) {
-        if(data->IsFile()) {
-            m_mgr->ClosePage(data->tab.filename);
-        } else {
-            m_mgr->ClosePage(data->tab.text);
-        }
-    }
-}
-
 void OpenWindowsPanel::DoSelectItem(IEditor* editor)
 {
     CHECK_PTR_RET(editor);
-    for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         wxDataViewItem item = m_dvListCtrl->RowToItem(i);
         TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-        if(data->IsFile()) {
-            if(editor->GetFileName() == data->tab.filename) {
+        if (data->IsFile()) {
+            if (editor->GetFileName() == data->tab.filename) {
                 m_dvListCtrl->Select(item);
                 break;
             }
@@ -234,7 +218,8 @@ void OpenWindowsPanel::DoSelectItem(IEditor* editor)
 
 void OpenWindowsPanel::OnSortItems(wxCommandEvent& event)
 {
-    if(event.IsChecked()) {
+    m_sortItems = event.IsChecked();
+    if (m_sortItems) {
         SortAlphabetically();
     } else {
         SortByEditorOrder();
@@ -246,7 +231,11 @@ void OpenWindowsPanel::OnSortItems(wxCommandEvent& event)
     clConfig::Get().Write(kConfigTabsPaneSortAlphabetically, event.IsChecked());
 }
 
-void OpenWindowsPanel::OnSortItemsUpdateUI(wxUpdateUIEvent& event) { event.Enable(m_dvListCtrl->GetItemCount()); }
+void OpenWindowsPanel::OnSortItemsUpdateUI(wxUpdateUIEvent& event)
+{
+    event.Enable(m_dvListCtrl->GetItemCount());
+    event.Check(m_sortItems);
+}
 
 void OpenWindowsPanel::SortAlphabetically()
 {
@@ -255,12 +244,15 @@ void OpenWindowsPanel::SortAlphabetically()
     m_mgr->GetAllTabs(tabs);
 
     // Sort editors
-    std::sort(tabs.begin(), tabs.end(), TabSorter());
+    std::sort(tabs.begin(), tabs.end(), [&](const clTab& t1, const clTab& t2) {
+        wxString file1 = GetDisplayName(t1);
+        wxString file2 = GetDisplayName(t2);
+        return file1.CmpNoCase(file2) < 0;
+    });
     Clear();
 
-    clTab::Vec_t::iterator iter = tabs.begin();
-    for(; iter != tabs.end(); ++iter) {
-        AppendEditor(*iter);
+    for (const auto& tab : tabs) {
+        AppendEditor(tab);
     }
 }
 
@@ -273,9 +265,8 @@ void OpenWindowsPanel::SortByEditorOrder()
     // Sort editors
     Clear();
 
-    clTab::Vec_t::iterator iter = tabs.begin();
-    for(; iter != tabs.end(); ++iter) {
-        AppendEditor(*iter);
+    for (const auto& tab : tabs) {
+        AppendEditor(tab);
     }
 }
 
@@ -288,7 +279,7 @@ void OpenWindowsPanel::OnTabActivated(wxDataViewEvent& event)
     CHECK_ITEM_RET(item);
 
     TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    if(data->IsFile()) {
+    if (data->IsFile()) {
         m_mgr->OpenFile(data->tab.filename.GetFullPath());
     } else {
         m_mgr->SelectPage(m_mgr->FindPage(data->tab.text));
@@ -300,7 +291,7 @@ void OpenWindowsPanel::OnTabSelected(wxDataViewEvent& event)
     event.Skip();
     CHECK_WORKSPACE_CLOSING();
 
-    if(::wxGetKeyState(WXK_CONTROL)) {
+    if (::wxGetKeyState(WXK_CONTROL)) {
         // multiple selection in progress
         return;
     }
@@ -308,11 +299,11 @@ void OpenWindowsPanel::OnTabSelected(wxDataViewEvent& event)
     wxDataViewItem item = event.GetItem();
     CHECK_ITEM_RET(item);
     TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    if(data->IsFile()) {
-        m_mgr->OpenFile(data->tab.filename.GetFullPath());
+    if (data->IsFile()) {
+        m_mgr->OpenFile(data->tab.filename.GetFullPath(), wxEmptyString, wxNOT_FOUND, OF_None);
     } else {
         wxWindow* page = m_mgr->FindPage(data->tab.text);
-        if(page) {
+        if (page) {
             m_mgr->SelectPage(page);
         }
     }
@@ -321,28 +312,28 @@ void OpenWindowsPanel::OnTabSelected(wxDataViewEvent& event)
 void OpenWindowsPanel::AppendEditor(const clTab& tab)
 {
     TabClientData* data = new TabClientData(tab);
-    wxVariant value = PrepareValue(tab);
+    bool is_modified = false;
+    wxVariant value = PrepareValue(tab, &is_modified);
 
     // the row index is the same as the row count (before we add the new entry)
     int itemIndex = m_dvListCtrl->GetItemCount();
 
     wxVector<wxVariant> cols;
     cols.push_back(value);
-    m_dvListCtrl->AppendItem(cols, (wxUIntPtr)data);
-    if(tab.isFile) {
-        m_editors.insert(std::make_pair(tab.filename.GetFullPath(), m_dvListCtrl->RowToItem(itemIndex)));
+    auto item = m_dvListCtrl->AppendItem(cols, (wxUIntPtr)data);
+    if (tab.isFile) {
+        m_editors.insert({tab.filename.GetFullPath(), m_dvListCtrl->RowToItem(itemIndex)});
     }
-}
 
-wxString OpenWindowsPanel::GetEditorPath(wxDataViewItem item)
-{
-    TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    return data->tab.text;
+    bool saved_before = false;
+    auto editor = clGetManager()->FindEditor(tab.filename.GetFullPath());
+    saved_before = editor && editor->GetCtrl()->CanUndo();
+    MarkItemModified(item, is_modified, saved_before);
 }
 
 void OpenWindowsPanel::Clear()
 {
-    for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         wxDataViewItem item = m_dvListCtrl->RowToItem(i);
         TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
         wxDELETE(data);
@@ -353,7 +344,7 @@ void OpenWindowsPanel::Clear()
 
 void OpenWindowsPanel::PopulateView()
 {
-    if(m_auibar->GetToolToggled(XRCID("TabsSortTool"))) {
+    if (m_sortItems) {
         SortAlphabetically();
     } else {
         SortByEditorOrder();
@@ -364,32 +355,27 @@ void OpenWindowsPanel::OnMenu(wxDataViewEvent& event)
 {
     wxDataViewItemArray items;
     m_dvListCtrl->GetSelections(items);
-    if(items.IsEmpty()) return;
+    if (items.IsEmpty())
+        return;
 
     wxMenu* menu;
-    if(items.GetCount() == 1) {
+    if (items.GetCount() == 1) {
         // single item
         menu = wxXmlResource::Get()->LoadMenu(wxT("editor_tab_right_click"));
     } else {
         menu = wxXmlResource::Get()->LoadMenu(wxT("tabs_multi_sels_menu"));
     }
-    PopupMenu(menu);
+    m_dvListCtrl->PopupMenu(menu);
     wxDELETE(menu);
 }
 
-bool OpenWindowsPanel::IsEditor(wxDataViewItem item) const
-{
-    TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-    return data->IsFile();
-}
-
 void OpenWindowsPanel::DoSelectItem(wxWindow* win)
 {
     CHECK_PTR_RET(win);
-    for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         wxDataViewItem item = m_dvListCtrl->RowToItem(i);
         TabClientData* data = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
-        if(data->tab.window == win) {
+        if (data->tab.window == win) {
             m_dvListCtrl->Select(item);
             break;
         }
@@ -419,7 +405,7 @@ void OpenWindowsPanel::OnIdle(wxIdleEvent& event)
 {
     event.Skip();
     static bool once = false;
-    if(!once && m_initDone && m_mgr->GetPageCount() && m_dvListCtrl->GetItemCount() == 0) {
+    if (!once && m_initDone && m_mgr->GetPageCount() && m_dvListCtrl->GetItemCount() == 0) {
         // populate the control
         once = true;
         PopulateView();
@@ -429,75 +415,116 @@ void OpenWindowsPanel::OnIdle(wxIdleEvent& event)
 void OpenWindowsPanel::OnEditorModified(clCommandEvent& event)
 {
     event.Skip();
-    if(!m_initDone) return;
+    if (!m_initDone)
+        return;
     IEditor* editor = m_mgr->FindEditor(event.GetFileName());
-    if(editor) {
-        DoMarkModify(event.GetFileName(), editor->IsModified());
+    if (editor) {
+        DoMarkModify(editor, event.GetFileName(), editor->IsEditorModified());
     }
 }
 
 void OpenWindowsPanel::OnEditorSaved(clCommandEvent& event)
 {
     event.Skip();
-    if(!m_initDone) return;
-    DoMarkModify(event.GetFileName(), false);
+    if (!m_initDone)
+        return;
+
+    DoMarkModify(clGetManager()->FindEditor(event.GetFileName()), event.GetFileName(), false);
 }
 
-void OpenWindowsPanel::DoMarkModify(const wxString& filename, bool b)
+void OpenWindowsPanel::DoMarkModify(IEditor* editor, const wxString& filename, bool b)
 {
     std::map<wxString, wxDataViewItem>::iterator iter = m_editors.find(filename);
-    if(iter == m_editors.end()) return;
+    if (iter == m_editors.end())
+        return;
+
     wxDataViewItem item = iter->second;
 
     wxBitmap bmp;
     TabClientData* cd = reinterpret_cast<TabClientData*>(m_dvListCtrl->GetItemData(item));
     const clTab& tab = cd->tab;
-    wxVariant value = PrepareValue(tab);
+    bool is_modified = false;
+    wxVariant value = PrepareValue(tab, &is_modified);
     m_dvListCtrl->SetValue(value, m_dvListCtrl->ItemToRow(item), 0);
+
+    // if we can do "undo" -> the file was saved
+    MarkItemModified(item, is_modified, editor && editor->GetCtrl()->CanUndo());
     m_dvListCtrl->Refresh();
 }
 
-wxVariant OpenWindowsPanel::PrepareValue(const clTab& tab)
+wxVariant OpenWindowsPanel::PrepareValue(const clTab& tab, bool* isModified)
 {
     wxString title;
-    wxStyledTextCtrl* editor(NULL);
-    if(tab.isFile) {
-        title = tab.filename.GetFullName();
-        editor = dynamic_cast<wxStyledTextCtrl*>(tab.window);
-    } else {
-        title = tab.text;
+    wxStyledTextCtrl* editor = nullptr;
+    *isModified = false;
+    title = GetDisplayName(tab);
+
+    if (tab.isFile) {
+        auto i_editor = clGetManager()->FindEditor(tab.filename.GetFullPath());
+        if (i_editor) {
+            editor = i_editor->GetCtrl();
+        }
     }
 
     FileExtManager::FileType ft = FileExtManager::GetType(title, FileExtManager::TypeText);
-    wxBitmap bmp;
-
-    // If the tab had an icon, use it, otherwise, use a bitmap by the file type
-    if(tab.bitmap.IsOk()) {
-        bmp = tab.bitmap;
-    } else if(m_bitmaps.count(ft)) {
-        bmp = m_bitmaps.find(ft)->second;
-    } else {
-        bmp = m_bitmaps.find(FileExtManager::TypeText)->second;
-    }
-
-    if(editor && editor->GetModify()) {
+    int imgId = clGetManager()->GetStdIcons()->GetMimeImageId(ft);
+    if (editor && editor->GetModify()) {
+        *isModified = true;
         title.Prepend("*");
     }
 
-    wxVariant value = ::MakeIconText(title, bmp);
+    wxVariant value = ::MakeBitmapIndexText(title, imgId);
     return value;
 }
 
-void OpenWindowsPanel::OnWorkspaceClosed(wxCommandEvent& event)
+void OpenWindowsPanel::OnWorkspaceClosed(clWorkspaceEvent& event)
 {
     event.Skip();
     m_workspaceClosing = false;
 }
 
-void OpenWindowsPanel::OnWorkspaceClosing(wxCommandEvent& event)
+void OpenWindowsPanel::OnWorkspaceClosing(clWorkspaceEvent& event)
 {
     event.Skip();
     Clear();
     m_workspaceClosing = true;
 }
 
+void OpenWindowsPanel::MarkItemModified(const wxDataViewItem& item, bool b, bool saved_before)
+{
+    auto lexer = ColoursAndFontsManager::Get().GetLexer("diff");
+    const auto& colours = m_dvListCtrl->GetColours();
+    if (b) {
+        m_dvListCtrl->SetItemTextColour(item, lexer->GetProperty(wxSTC_DIFF_DELETED).GetFgColour());
+    } else {
+        wxColour item_colour = colours.GetItemTextColour();
+        if (saved_before) {
+            item_colour = lexer->GetProperty(wxSTC_DIFF_ADDED).GetFgColour();
+        }
+        m_dvListCtrl->SetItemTextColour(item, item_colour);
+    }
+}
+
+void OpenWindowsPanel::OnThemeChanged(clCommandEvent& event)
+{
+    event.Skip();
+    m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
+    PopulateView();
+    m_dvListCtrl->Refresh();
+}
+
+wxString OpenWindowsPanel::GetDisplayName(const clTab& tab) const
+{
+    wxString title;
+    if (tab.isFile) {
+        const wxFileName& fn = tab.filename;
+        if (fn.GetDirCount() && EditorConfigST::Get()->GetOptions()->IsTabShowPath()) {
+            title = fn.GetDirs().Last() + wxFileName::GetPathSeparator() + fn.GetFullName();
+        } else {
+            title = tab.filename.GetFullName();
+        }
+    } else {
+        title = tab.text;
+    }
+    return title;
+}
\ No newline at end of file
