@@ -25,11 +25,15 @@
 #ifndef OUTPUT_PANE_H
 #define OUTPUT_PANE_H
 
+#include "Notebook.h"
+#include "clAuiBook.hpp"
+#include "cl_command_event.h"
+#include "shelltab.h"
+#include "wxTerminalCtrl/clBuiltinTerminalPane.hpp"
+
 #include <wx/panel.h>
 
-#include "shelltab.h"
-#include "cl_command_event.h"
-
+class BuildTab;
 class ClangOutputTab;
 class FindResultsTab;
 #if CL_USE_NEW_BUILD_TAB
@@ -42,7 +46,6 @@ class ShellTab;
 class TaskPanel;
 class OutputPaneBook;
 class FindUsageTab;
-
 /**
  * \ingroup LiteEditor
  * This class represents the default bottom pane in the editor
@@ -61,59 +64,33 @@ class FindUsageTab;
  */
 class OutputPane : public wxPanel
 {
-public:
-    static const wxString FIND_IN_FILES_WIN;
-    static const wxString BUILD_WIN;
-    static const wxString OUTPUT_WIN;
-    static const wxString OUTPUT_DEBUG;
-    static const wxString REPLACE_IN_FILES;
-    static const wxString TASKS;
-    static const wxString TRACE_TAB;
-    static const wxString SHOW_USAGE;
-    static const wxString CLANG_TAB;
-    
 protected:
     struct Tab {
         wxString m_label;
-        wxWindow* m_window;
-        wxBitmap m_bmp;
+        wxWindow* m_window = nullptr;
+        int m_bmpIndex = wxNOT_FOUND;
 
-        Tab(const wxString& label, wxWindow* win, const wxBitmap& bmp = wxNullBitmap)
+        Tab(const wxString& label, wxWindow* win, int bmpIndex = wxNOT_FOUND)
             : m_label(label)
             , m_window(win)
-            , m_bmp(bmp)
+            , m_bmpIndex(bmpIndex)
         {
         }
 
-        Tab()
-            : m_window(NULL)
-        {
-        }
+        Tab() = default;
     };
-    std::map<wxString, Tab> m_tabs;
-    
+    std::unordered_map<wxString, Tab> m_tabs;
+
 private:
     wxString m_caption;
-    wxLog* m_logTargetOld;
-
-    Notebook* m_book;
+    Notebook* m_book = nullptr;
     FindResultsTab* m_findResultsTab;
     ReplaceInFilesPanel* m_replaceResultsTab;
-
-#if CL_USE_NEW_BUILD_TAB
-    NewBuildTab* m_buildWin;
-#else
-    BuildTab* m_buildWin;
-#endif
-
+    // NewBuildTab* m_buildWin;
     ShellTab* m_outputWind;
-    TaskPanel* m_taskPanel;
     FindUsageTab* m_showUsageTab;
-
-#if HAS_LIBCLANG
-    ClangOutputTab* m_clangOutputTab;
-#endif
-
+    BuildTab* m_build_tab = nullptr;
+    clBuiltinTerminalPane* m_terminal = nullptr;
     bool m_buildInProgress;
 
 protected:
@@ -123,14 +100,16 @@ protected:
     void OnBuildEnded(clBuildEvent& e);
     void OnSettingsChanged(wxCommandEvent& event);
     void OnToggleTab(clCommandEvent& event);
-    
+    void OnOutputBookFileListMenu(clContextMenuEvent& event);
+    void OnPageChanged(wxBookCtrlEvent& event);
+
 public:
     /**
      * Constructor
      * \param parent parent window for this pane
      * \param caption the caption
      */
-    OutputPane(wxWindow* parent, const wxString& caption);
+    OutputPane(wxWindow* parent, const wxString& caption, long style);
 
     /**
      * @brief save the tab order
@@ -142,19 +121,25 @@ public:
      */
     virtual ~OutputPane();
 
+    /**
+     * @brief show or hide tab by name
+     */
+    void ShowTab(const wxString& name, bool show);
+
     Notebook* GetNotebook() { return m_book; }
     const wxString& GetCaption() const { return m_caption; }
 
     /**
      * @brief restore the tab order from the configuration file
      */
-    void ApplySavedTabOrder() const;
+    void ApplySavedTabOrder(bool update_ui) const;
 
     FindResultsTab* GetFindResultsTab() { return m_findResultsTab; }
     ReplaceInFilesPanel* GetReplaceResultsTab() { return m_replaceResultsTab; }
-    NewBuildTab* GetBuildTab() { return m_buildWin; }
+    BuildTab* GetBuildTab() { return m_build_tab; }
     ShellTab* GetOutputWindow() { return m_outputWind; }
     FindUsageTab* GetShowUsageTab() { return m_showUsageTab; }
+    clBuiltinTerminalPane* GetBuiltInTerminal() { return m_terminal; }
 };
 
 #endif // OUTPUT_PANE_H
