@@ -22,19 +22,22 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <wx/xrc/xmlres.h>
-#include "frame.h"
-#include "editor_config.h"
-#include "macros.h"
-#include "globals.h"
-#include "manager.h"
 #include "outputtabwindow.h"
-#include "output_pane.h"
-#include "pluginmanager.h"
-#include "quickfindbar.h"
+
+#include "StringUtils.h"
+#include "clSTCHelper.hpp"
+#include "clToolBar.h"
+#include "cl_config.h"
+#include "editor_config.h"
 #include "event_notifier.h"
-#include "lexer_configuration.h"
+#include "frame.h"
 #include "globals.h"
+#include "lexer_configuration.h"
+#include "macros.h"
+#include "manager.h"
+#include "output_pane.h"
+
+#include <wx/xrc/xmlres.h>
 
 BEGIN_EVENT_TABLE(OutputTabWindow, wxPanel)
 EVT_MENU(XRCID("scroll_on_output"), OutputTabWindow::OnOutputScrolls)
@@ -63,32 +66,30 @@ OutputTabWindow::OutputTabWindow(wxWindow* parent, wxWindowID id, const wxString
     , m_autoAppearErrors(false)
     , m_errorsFirstLine(false)
 {
-    m_styler.Reset(new clFindResultsStyler());
+    m_styler = std::make_unique<clFindResultsStyler>();
     CreateGUIControls();
-    wxTheApp->Connect(
-        wxID_COPY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL, this);
-    wxTheApp->Connect(
-        wxID_SELECTALL, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL, this);
+    wxTheApp->Connect(wxID_COPY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL,
+                      this);
+    wxTheApp->Connect(wxID_SELECTALL, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL,
+                      this);
     wxTheApp->Connect(wxID_COPY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(OutputTabWindow::OnEditUI), NULL, this);
     wxTheApp->Connect(wxID_SELECTALL, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(OutputTabWindow::OnEditUI), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(OutputTabWindow::OnThemeChanged), NULL, this);
-    m_themeHelper = new ThemeHandlerHelper(this);
+    EventNotifier::Get()->Connect(wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(OutputTabWindow::OnThemeChanged), NULL,
+                                  this);
 }
 
 OutputTabWindow::~OutputTabWindow()
 {
-    m_styler.Reset(NULL);
-    wxDELETE(m_themeHelper);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(OutputTabWindow::OnThemeChanged), NULL, this);
-    wxTheApp->Disconnect(
-        wxID_COPY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL, this);
-    wxTheApp->Disconnect(
-        wxID_SELECTALL, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL, this);
+    m_styler.reset(nullptr);
+    EventNotifier::Get()->Disconnect(wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(OutputTabWindow::OnThemeChanged),
+                                     NULL, this);
+    wxTheApp->Disconnect(wxID_COPY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit), NULL,
+                         this);
+    wxTheApp->Disconnect(wxID_SELECTALL, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(OutputTabWindow::OnEdit),
+                         NULL, this);
     wxTheApp->Disconnect(wxID_COPY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(OutputTabWindow::OnEditUI), NULL, this);
-    wxTheApp->Disconnect(
-        wxID_SELECTALL, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(OutputTabWindow::OnEditUI), NULL, this);
+    wxTheApp->Disconnect(wxID_SELECTALL, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(OutputTabWindow::OnEditUI), NULL,
+                         this);
 }
 
 void OutputTabWindow::DefineMarker(wxStyledTextCtrl* sci, int marker, int markerType, wxColor fore, wxColor back)
@@ -109,7 +110,7 @@ void OutputTabWindow::InitStyle(wxStyledTextCtrl* sci, int lexer, bool folding)
     }
 
     wxFont defFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    wxFont font = EditorConfigST::Get()->GetLexer("text")->GetFontForSyle(0);
+    wxFont font = EditorConfigST::Get()->GetLexer("text")->GetFontForStyle(0, sci);
     sci->StyleSetFont(0, font);
 
     sci->SetIndicatorCurrent(1);
@@ -118,8 +119,8 @@ void OutputTabWindow::InitStyle(wxStyledTextCtrl* sci, int lexer, bool folding)
 #else
     int facttor = 5;
 #endif
-    sci->IndicatorSetForeground(1, MakeColourLighter(wxT("GOLD"), facttor));
-    sci->IndicatorSetForeground(2, MakeColourLighter(wxT("RED"), 4));
+    sci->IndicatorSetForeground(1, DrawingUtils::LightColour(wxT("GOLD"), facttor));
+    sci->IndicatorSetForeground(2, DrawingUtils::LightColour(wxT("RED"), 4));
     sci->IndicatorSetStyle(1, wxSTC_INDIC_ROUNDBOX);
     sci->IndicatorSetStyle(2, wxSTC_INDIC_ROUNDBOX);
     sci->IndicatorSetUnder(1, true);
@@ -172,14 +173,15 @@ void OutputTabWindow::CreateGUIControls()
 
     m_vSizer = new wxBoxSizer(wxVERTICAL);
 
-// Create the default scintilla control
-#ifdef __WXGTK__
-    m_sci = new wxStyledTextCtrl(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxRAISED_BORDER);
-#else
+    // Create the default scintilla control
     m_sci = new wxStyledTextCtrl(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxBORDER_NONE);
+
+#if defined(__WXMSW__)
+    bool useDirect2D = clConfig::Get().Read("Editor/UseDirect2D", true);
+    m_sci->SetTechnology(useDirect2D ? wxSTC_TECHNOLOGY_DIRECTWRITE : wxSTC_TECHNOLOGY_DEFAULT);
 #endif
 
-    // We dont really want to collect undo in the output tabs...
+    // We don't really want to collect undo in the output tabs...
     m_sci->SetUndoCollection(false);
     m_sci->EmptyUndoBuffer();
 
@@ -187,31 +189,22 @@ void OutputTabWindow::CreateGUIControls()
 
     // Add the find bar
     mainSizer->Add(m_vSizer, 1, wxEXPAND | wxALL, 0);
-    BitmapLoader* bmpLoader = PluginManager::Get()->GetStdIcons();
 
     // Create the toolbar
-    m_tb = new wxAuiToolBar(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_PLAIN_BACKGROUND);
-    m_tb->SetToolBitmapSize(wxSize(16, 16));
+    m_tb = new clToolBar(this);
+    auto images = m_tb->GetBitmapsCreateIfNeeded();
+    m_tb->AddTool(XRCID("hold_pane_open"), _("Keep open"), images->Add("ToolPin"),
+                  _("Don't close this pane when an editor gets focus"), wxITEM_CHECK);
 
-    m_tb->AddTool(XRCID("hold_pane_open"),
-                  _("Keep open"),
-                  bmpLoader->LoadBitmap("ToolPin"),
-                  _("Don't close this pane when an editor gets focus"),
-                  wxITEM_CHECK);
-
-    m_tb->AddTool(XRCID("scroll_on_output"),
-                  _("Scroll on Output"),
-                  bmpLoader->LoadBitmap("link_editor"),
-                  _("Scroll on Output"),
+    m_tb->AddTool(XRCID("scroll_on_output"), _("Scroll on Output"), images->Add("link_editor"), _("Scroll on Output"),
                   wxITEM_CHECK);
     m_tb->ToggleTool(XRCID("scroll_on_output"), m_outputScrolls);
 
-    m_tb->AddTool(
-        XRCID("word_wrap_output"), _("Word Wrap"), bmpLoader->LoadBitmap("word_wrap"), _("Word Wrap"), wxITEM_CHECK);
+    m_tb->AddTool(XRCID("word_wrap_output"), _("Word Wrap"), images->Add("word_wrap"), _("Word Wrap"), wxITEM_CHECK);
 
-    m_tb->AddTool(XRCID("clear_all_output"), _("Clear All"), bmpLoader->LoadBitmap("clear"), _("Clear All"));
-    m_tb->AddTool(XRCID("collapse_all"), _("Fold All Results"), bmpLoader->LoadBitmap("fold"), _("Fold All Results"));
-    m_tb->AddTool(XRCID("repeat_output"), _("Repeat"), bmpLoader->LoadBitmap("debugger_restart"), _("Repeat"));
+    m_tb->AddTool(XRCID("clear_all_output"), _("Clear All"), images->Add("clear"), _("Clear All"));
+    m_tb->AddTool(XRCID("collapse_all"), _("Fold All Results"), images->Add("fold"), _("Fold All Results"));
+    m_tb->AddTool(XRCID("repeat_output"), _("Repeat"), images->Add("debugger_restart"), _("Repeat"));
 
     m_tb->Realize();
 
@@ -232,51 +225,40 @@ void OutputTabWindow::Clear()
     }
 }
 
-void OutputTabWindow::AppendText(const wxString& text)
+void OutputTabWindow::AppendText(const wxString& text, bool toggle_view)
 {
-    if(m_sci) {
-        if(m_autoAppear && m_sci->GetLength() == 0) {
-            ManagerST::Get()->ShowOutputPane(m_name);
-        }
+    CHECK_PTR_RET(m_sci);
+    if(toggle_view && m_autoAppear && m_sci->GetLength() == 0) {
+        ManagerST::Get()->ShowOutputPane(m_name, true, false);
+    }
 
-        //----------------------------------------------
-        // enable writing
-        m_sci->SetReadOnly(false);
+    //----------------------------------------------
+    // enable writing
+    m_sci->SetReadOnly(false);
 
-        if(m_outputScrolls) {
-            // the next 4 lines make sure that the caret is at last line
-            // and is visible
-            m_sci->SetSelectionEnd(m_sci->GetLength());
-            m_sci->SetSelectionStart(m_sci->GetLength());
-            m_sci->SetCurrentPos(m_sci->GetLength());
-            m_sci->EnsureCaretVisible();
-        }
-        
-        
-        // Strip any terminal escape chars from the buffer
-        wxString modText;
-        ::clStripTerminalColouring(text, modText);
-        
-        // add the text
-        m_sci->InsertText(m_sci->GetLength(), modText);
+    // Strip any terminal escape chars from the buffer
+    wxString modText;
+    StringUtils::StripTerminalColouring(text, modText);
 
-        if(m_outputScrolls) {
-            // the next 4 lines make sure that the caret is at last line
-            // and is visible
-            m_sci->SetSelectionEnd(m_sci->GetLength());
-            m_sci->SetSelectionStart(m_sci->GetLength());
-            m_sci->SetCurrentPos(m_sci->GetLength());
-            m_sci->EnsureCaretVisible();
-        }
+    // add the text
+    m_sci->InsertText(m_sci->GetLength(), modText);
 
-        // enable readonly mode
-        m_sci->SetReadOnly(true);
+    // enable readonly mode
+    m_sci->SetReadOnly(true);
+
+    if(m_outputScrolls) {
+        m_sci->ScrollToEnd();
+        clSTCHelper::SetCaretAt(m_sci, m_sci->GetLastPosition());
     }
 }
 
 void OutputTabWindow::OnOutputScrolls(wxCommandEvent& e) { m_outputScrolls = !m_outputScrolls; }
 
-void OutputTabWindow::OnOutputScrollsUI(wxUpdateUIEvent& e) { e.Enable(true); }
+void OutputTabWindow::OnOutputScrollsUI(wxUpdateUIEvent& e)
+{
+    e.Check(m_outputScrolls);
+    e.Enable(true);
+}
 
 void OutputTabWindow::OnClearAll(wxCommandEvent& e) { Clear(); }
 
@@ -285,11 +267,19 @@ void OutputTabWindow::OnClearAllUI(wxUpdateUIEvent& e) { e.Enable(m_sci && m_sci
 void OutputTabWindow::OnWordWrap(wxCommandEvent& e)
 {
     if(m_sci) {
-        m_sci->SetWrapMode(m_sci->GetWrapMode() == wxSTC_WRAP_WORD ? wxSTC_WRAP_NONE : wxSTC_WRAP_WORD);
+        m_sci->SetWrapMode(e.IsChecked() ? wxSTC_WRAP_WORD : wxSTC_WRAP_NONE);
     }
 }
 
-void OutputTabWindow::OnWordWrapUI(wxUpdateUIEvent& e) { e.Enable(true); }
+void OutputTabWindow::OnWordWrapUI(wxUpdateUIEvent& e)
+{
+    if(m_sci) {
+        e.Enable(true);
+        e.Check(m_sci->GetWrapMode() == wxSTC_WRAP_WORD);
+    } else {
+        e.Enable(false);
+    }
+}
 
 void OutputTabWindow::OnCollapseAll(wxCommandEvent& e)
 {
@@ -390,3 +380,15 @@ void OutputTabWindow::OnThemeChanged(wxCommandEvent& e)
         InitStyle(m_sci, m_sci->GetLexer(), m_sci->GetMarginWidth(4) == 6);
     }
 }
+
+void OutputTabWindow::ScrollToBottom()
+{
+    CHECK_PTR_RET(m_sci);
+
+    // the next 4 lines make sure that the caret is at last line
+    // and is visible
+    m_sci->SetSelectionEnd(m_sci->GetLength());
+    m_sci->SetSelectionStart(m_sci->GetLength());
+    m_sci->SetCurrentPos(m_sci->GetLength());
+    m_sci->EnsureCaretVisible();
+}
\ No newline at end of file
