@@ -24,10 +24,8 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "ps_build_events_page.h"
-#include "free_text_dialog.h"
-#include <wx/tokenzr.h>
-#include "macros.h"
-#include "globals.h"
+
+#include "StringUtils.h"
 
 PSBuildEventsPage::PSBuildEventsPage(wxWindow* parent, bool preEvents, ProjectSettingsDlg* dlg)
     : PSBuildEventsBasePage(parent)
@@ -36,9 +34,9 @@ PSBuildEventsPage::PSBuildEventsPage(wxWindow* parent, bool preEvents, ProjectSe
 {
 }
 
-void PSBuildEventsPage::OnCmdEvtVModified(wxCommandEvent& event)
+void PSBuildEventsPage::OnStcEvtVModified(wxStyledTextEvent& event)
 {
-    wxUnusedVar(event);
+    event.Skip();
     m_dlg->SetIsDirty(true);
 }
 
@@ -49,35 +47,31 @@ void PSBuildEventsPage::Load(BuildConfigPtr buildConf)
     BuildCommandList buildCmds;
     wxString text;
     if(m_isPreEvents) {
-        buildConf->GetPreBuildCommands(buildCmds);
+        buildCmds = buildConf->GetPreBuildCommands();
         text = _("Set the commands to run in the pre build stage");
 
     } else {
-        buildConf->GetPostBuildCommands(buildCmds);
+        buildCmds = buildConf->GetPostBuildCommands();
         text = _("Set the commands to run in the post build stage");
     }
     text << _("\nCommands starting with the hash sign ('#'), will not be executed");
     m_staticText11->SetLabel(text);
-    BuildCommandList::const_iterator iter = buildCmds.begin();
-    m_textCtrlBuildEvents->Clear();
-    for(; iter != buildCmds.end(); iter++) {
-        wxString cmdText = iter->GetCommand();
+    m_textCtrlBuildEvents->ClearAll();
+    for (const auto& buildCommand : buildCmds) {
+        wxString cmdText = buildCommand.GetCommand();
         cmdText.Trim().Trim(false);
-        if(iter->GetEnabled() == false && !cmdText.StartsWith(wxT("#"))) {
+        if (buildCommand.GetEnabled() == false && !cmdText.StartsWith(wxT("#"))) {
             cmdText.Prepend(wxT("#"));
         }
         cmdText.Append(wxT("\n"));
         m_textCtrlBuildEvents->AppendText(cmdText);
     }
-
-    m_textCtrlBuildEvents->Connect(
-        wxEVT_COMMAND_TEXT_UPDATED, wxCommandEventHandler(PSBuildEventsPage::OnCmdEvtVModified), NULL, this);
 }
 
 void PSBuildEventsPage::Save(BuildConfigPtr buildConf, ProjectSettingsPtr projSettingsPtr)
 {
     BuildCommandList cmds;
-    wxArrayString commands = ::SplitString(m_textCtrlBuildEvents->GetValue(), true);
+    wxArrayString commands = StringUtils::SplitString(m_textCtrlBuildEvents->GetValue(), true);
     for(size_t i = 0; i < commands.GetCount(); i++) {
         wxString command = commands.Item(i).Trim().Trim(false);
         bool enabled = !command.StartsWith(wxT("#"));
