@@ -22,19 +22,29 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <vector>
-#include <wx/xrc/xmlres.h>
-#include <wx/progdlg.h>
-
-#include "editor_config.h"
-#include "globals.h"
-#include "frame.h"
-#include "cl_editor.h"
-#include "manager.h"
 #include "replaceinfilespanel.h"
+
+#include "ColoursAndFontsManager.h"
 #include "clFileSystemEvent.h"
+#include "clStrings.h"
+#include "cl_command_event.h"
+#include "cl_editor.h"
+#include "codelite_events.h"
+#include "editor_config.h"
 #include "event_notifier.h"
+#include "file_logger.h"
+#include "frame.h"
+#include "globals.h"
 #include "macros.h"
+#include "manager.h"
+
+#include <vector>
+#include <wx/dcgraph.h>
+#include <wx/dcmemory.h>
+#include <wx/msgdlg.h>
+#include <wx/progdlg.h>
+#include <wx/renderer.h>
+#include <wx/xrc/xmlres.h>
 
 ReplaceInFilesPanel::ReplaceInFilesPanel(wxWindow* parent, int id, const wxString& name)
     : FindResultsTab(parent, id, name)
@@ -52,22 +62,16 @@ ReplaceInFilesPanel::ReplaceInFilesPanel(wxWindow* parent, int id, const wxStrin
     mark->Bind(wxEVT_BUTTON, &ReplaceInFilesPanel::OnMarkAll, this);
     mark->Bind(wxEVT_UPDATE_UI, &ReplaceInFilesPanel::OnMarkAllUI, this);
 
-    m_replaceWithText = new wxStaticText(this, wxID_ANY, _("Replace With:"));
-    horzSizer->Add(m_replaceWithText, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT | wxLEFT, 5);
-    m_replaceWithText->Bind(wxEVT_UPDATE_UI, &ReplaceInFilesPanel::OnReplaceWithComboUI, this);
-
-    m_replaceWith = new wxComboBox(this, wxID_ANY);
-    horzSizer->Add(m_replaceWith, 2, wxALIGN_CENTER_VERTICAL | wxRIGHT | wxLEFT, 5);
+    m_replaceWith = new clThemedComboBox(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, {});
+    m_replaceWith->SetHint(_("Replace with"));
+    horzSizer->Add(m_replaceWith, 1, wxALIGN_CENTER_VERTICAL | wxALL, 5);
     m_replaceWith->Bind(wxEVT_UPDATE_UI, &ReplaceInFilesPanel::OnReplaceWithComboUI, this);
 
-    wxButton* repl = new wxButton(this, wxID_ANY, _("&Replace Marked"));
+    wxButton* repl = new wxButton(this, wxID_ANY, _("Replace"));
     horzSizer->Add(repl, 0, wxRIGHT | wxLEFT | wxALIGN_CENTER_VERTICAL, 5);
     repl->Bind(wxEVT_BUTTON, &ReplaceInFilesPanel::OnReplace, this);
     repl->Bind(wxEVT_UPDATE_UI, &ReplaceInFilesPanel::OnReplaceUI, this);
 
-    m_progress = new wxGauge(this, wxID_ANY, 1, wxDefaultPosition, wxSize(-1, 15), wxGA_HORIZONTAL);
-    horzSizer->Add(m_progress, 1, wxALIGN_CENTER_VERTICAL | wxALL | wxGA_SMOOTH, 5);
-
     wxBoxSizer* vertSizer = new wxBoxSizer(wxVERTICAL);
     vertSizer->Add(horzSizer, 0, wxEXPAND | wxTOP | wxBOTTOM);
 
@@ -76,23 +80,16 @@ ReplaceInFilesPanel::ReplaceInFilesPanel(wxWindow* parent, int id, const wxStrin
     mainSizer->Detach(m_sci);
     vertSizer->Add(m_sci, 1, wxEXPAND | wxALL, 1);
 
-    m_tb->DeleteTool(XRCID("repeat_output"));
-    m_tb->DeleteTool(XRCID("recent_searches"));
+    m_tb->DeleteById(XRCID("repeat_output"));
+    m_tb->DeleteById(XRCID("recent_searches"));
     m_tb->Realize();
-
-#ifdef __WXMAC__
-    mainSizer->Insert(0, vertSizer, 1, wxEXPAND);
-#else
     mainSizer->Add(vertSizer, 1, wxEXPAND);
-#endif
-    mainSizer->Layout();
 
-    m_sci->SetMarginMask(4, 7 << 0x7 | wxSTC_MASK_FOLDERS);
-    DefineMarker(
-        m_sci, 0x7, wxSTC_MARK_SMALLRECT, wxColor(0x00, 0x80, 0x00), wxColor(0x00, 0xc0, 0x00));       // user selection
-    DefineMarker(m_sci, 0x8, wxSTC_MARK_CIRCLE, wxColor(0x80, 0x00, 0x00), wxColor(0xff, 0x00, 0x00)); // error occurred
-    DefineMarker(
-        m_sci, 0x9, wxSTC_MARK_EMPTY, wxColor(0x00, 0x00, 0x00), wxColor(0x00, 0x00, 0x00)); // replacement successful
+    m_progress = new wxGauge(this, wxID_ANY, 1, wxDefaultPosition, wxSize(-1, 15), wxGA_HORIZONTAL);
+    m_progress->Hide();
+    m_vSizer->Add(m_progress, wxSizerFlags().Expand().Border(wxALL, 5));
+
+    mainSizer->Layout();
 }
 
 void ReplaceInFilesPanel::OnSearchStart(wxCommandEvent& e)
@@ -100,17 +97,22 @@ void ReplaceInFilesPanel::OnSearchStart(wxCommandEvent& e)
     e.Skip();
     // set the "Replace With" field with the user value
     SearchData* data = (SearchData*)e.GetClientData();
-    m_replaceWith->ChangeValue(data->GetReplaceWith());
-
-    //
+    m_replaceWith->SetValue(data->GetReplaceWith());
     FindResultsTab::OnSearchStart(e);
+
+    // Make sure that the Output view & the "Replace" tab
+    // are visible
+    clCommandEvent event(wxEVT_SHOW_OUTPUT_TAB);
+    event.SetSelected(true).SetString(REPLACE_IN_FILES);
+    EventNotifier::Get()->AddPendingEvent(event);
 }
 
 void ReplaceInFilesPanel::OnSearchMatch(wxCommandEvent& e)
 {
     e.Skip();
     FindResultsTab::OnSearchMatch(e);
-    if(m_matchInfo.size() != 1 || !m_replaceWith->GetValue().IsEmpty()) return;
+    if(m_matchInfo.size() != 1 || !m_replaceWith->GetValue().IsEmpty())
+        return;
     m_replaceWith->SetValue(m_matchInfo.begin()->second.GetFindWhat());
     m_replaceWith->SetFocus();
 }
@@ -122,13 +124,13 @@ void ReplaceInFilesPanel::OnSearchEnded(wxCommandEvent& e)
     CHECK_PTR_RET(summary);
 
     // set the "Replace With" field with the user value
-    m_replaceWith->ChangeValue(summary->GetReplaceWith());
+    m_replaceWith->SetValue(summary->GetReplaceWith());
 
     FindResultsTab::OnSearchEnded(e);
     OnMarkAll(e);
 
     // Set the focus to the "Replace With" field
-    m_replaceWith->CallAfter(&wxComboBox::SetFocus);
+    m_replaceWith->CallAfter(&clThemedComboBox::SetFocus);
 }
 
 void ReplaceInFilesPanel::OnMarginClick(wxStyledTextEvent& e)
@@ -146,10 +148,10 @@ void ReplaceInFilesPanel::OnMarginClick(wxStyledTextEvent& e)
 
 void ReplaceInFilesPanel::OnMarkAll(wxCommandEvent& e)
 {
-    MatchInfo_t::const_iterator i = m_matchInfo.begin();
-    for(; i != m_matchInfo.end(); ++i) {
-        if(m_sci->MarkerGet(i->first) & 7 << 0x7) continue;
-        m_sci->MarkerAdd(i->first, 0x7);
+    for (const auto& p : m_matchInfo) {
+        if (m_sci->MarkerGet(p.first) & 7 << 0x7)
+            continue;
+        m_sci->MarkerAdd(p.first, 0x7);
     }
 }
 
@@ -160,17 +162,17 @@ void ReplaceInFilesPanel::OnUnmarkAllUI(wxUpdateUIEvent& e)
     e.Enable((m_sci->GetLength() > 0) && !m_searchInProgress);
 }
 
-void ReplaceInFilesPanel::DoSaveResults(
-    wxStyledTextCtrl* sci, std::map<int, SearchResult>::iterator begin, std::map<int, SearchResult>::iterator end)
+void ReplaceInFilesPanel::DoSaveResults(wxStyledTextCtrl* sci, MatchInfo_t::iterator begin, MatchInfo_t::iterator end)
 {
-    if(!sci || begin == end) return;
+    if(!sci || begin == end)
+        return;
     bool ok = true;
-    if(dynamic_cast<LEditor*>(sci) == NULL) {
+    if(dynamic_cast<clEditor*>(sci) == NULL) {
         // it's a temp editor, check if we have any changes to save
         if(sci->GetModify() && !WriteFileWithBackup(begin->second.GetFileName(), sci->GetText(), false)) {
             wxMessageBox(_("Failed to save file:\n") + begin->second.GetFileName(), _("CodeLite - Replace"),
-                wxICON_ERROR | wxOK);
-            wxLogMessage(wxT("Replace: Failed to write file ") + begin->second.GetFileName());
+                         wxICON_ERROR | wxOK);
+            clDEBUG() << "Replace: Failed to write file" << begin->second.GetFileName();
             ok = false;
         }
 
@@ -201,7 +203,7 @@ wxStyledTextCtrl* ReplaceInFilesPanel::DoGetEditor(const wxString& fileName)
     wxString content;
     if(!ReadFileWithConversion(fileName, content)) {
         wxMessageBox(_("Failed to open file:\n") + fileName, _("CodeLite - Replace"), wxICON_ERROR | wxOK);
-        wxLogMessage(wxT("Replace: Failed to read file ") + fileName);
+        clDEBUG() << "Replace: Failed to read file" << fileName;
         return NULL;
     }
 
@@ -211,12 +213,48 @@ wxStyledTextCtrl* ReplaceInFilesPanel::DoGetEditor(const wxString& fileName)
     return sci;
 }
 
+wxString ReplaceInFilesPanel::DoGetReplaceWith(const SearchResult& res) const
+{
+    const wxString& replaceWith = m_replaceWith->GetValue();
+    if(!(res.GetFlags() & wxSD_REGULAREXPRESSION)) {
+        // not a regular expression search, do nothing
+        return replaceWith;
+    }
+    // replace regular expression backrefs
+    wxString s;
+    for(size_t i = 0; i < replaceWith.length(); ++i) {
+        wxUniChar ch0 = replaceWith[i];
+        wxUniChar ch1 = '\0';
+        if(i + 1 < replaceWith.length()) {
+            ch1 = replaceWith[i + 1];
+        }
+        if(ch0 == '\\' && isdigit(ch1)) {
+            // regex backref (\0 ~ \9)
+            int backref = wxAtoi(ch1);
+            s << res.GetRegexCapture(backref);
+            ++i;
+        } else if(ch0 == '\\' && ch1 == '\\') {
+            // escaped backslash (\\)
+            s << '\\';
+            ++i;
+        } else {
+            s << ch0;
+        }
+    }
+    return s;
+}
+
 void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
 {
+    if(!m_progress->IsShown()) {
+        m_progress->Show();
+        GetSizer()->Layout();
+    }
+
     m_filesModified.clear();
     // FIX bug#2770561
-    int lineNumber(0);
-    LEditor* activeEditor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
+    int lineNumber = 0;
+    clEditor* activeEditor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
     if(activeEditor) {
         lineNumber = activeEditor->GetCurrentLine();
     }
@@ -231,7 +269,7 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
 
     wxString lastFile; // track offsets of pending substitutions caused by previous substitutions
     long lastLine = 0;
-    long delta = 0;
+    long delta = 0, deltaInChars = 0;
 
     // remembers first entry in the file being updated
     MatchInfo_t::iterator firstInFile = m_matchInfo.begin();
@@ -242,36 +280,43 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
     clMainFrame::Get()->GetMainBook()->SetUseBuffereLimit(false);
     MatchInfo_t::iterator i = firstInFile;
     for(; i != m_matchInfo.end(); ++i) {
+        SearchResult& res = i->second;
         m_progress->SetValue(m_progress->GetValue() + 1);
         m_progress->Update();
 
-        if(i->second.GetFileName() != lastFile) {
+        if(res.GetFileName() != lastFile) {
             // about to start a different file, save current results
             DoSaveResults(sci, firstInFile, i);
             firstInFile = i;
-            lastFile = i->second.GetFileName();
+            lastFile = res.GetFileName();
             lastLine = 0;
             sci = NULL;
         }
 
-        if(i->second.GetLineNumber() == lastLine) {
+        if(res.GetLineNumber() == lastLine) {
             // prior substitutions affected the location of this one
-            i->second.SetColumn(i->second.GetColumn() + delta);
+            res.SetColumn(res.GetColumn() + delta);
+            res.SetColumnInChars(res.GetColumnInChars() + deltaInChars);
         } else {
-            delta = 0;
+            delta = deltaInChars = 0;
         }
         if((m_sci->MarkerGet(i->first) & 1 << 0x7) == 0)
             // not selected for application
             continue;
 
+        wxString replaceText = DoGetReplaceWith(res);
+        int replaceLenInChars = (int)replaceText.Len();
+        int replaceLen = (int)StringUtils::UTF8Length(replaceText.ToStdWstring().c_str(), replaceLenInChars);
+
         // extract originally matched text for safety check later
-        wxString text = i->second.GetPattern().Mid(i->second.GetColumn() - delta, i->second.GetLen());
-        if(text == m_replaceWith->GetValue()) continue; // no change needed
+        wxString text = res.GetPattern().Mid(res.GetColumnInChars() - deltaInChars, res.GetLenInChars());
+        if(text == replaceText)
+            continue; // no change needed
 
         // need an editor for this file (try only once per file though)
         if(!sci && lastLine == 0) {
-            sci = DoGetEditor(i->second.GetFileName());
-            lastLine = i->second.GetLineNumber();
+            sci = DoGetEditor(res.GetFileName());
+            lastLine = res.GetLineNumber();
         }
         if(!sci) {
             // couldn't open file
@@ -279,29 +324,36 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
             continue;
         }
 
-        long pos = sci->PositionFromLine(i->second.GetLineNumber() - 1);
+        long pos = sci->PositionFromLine(res.GetLineNumber() - 1);
         if(pos < 0) {
             // invalid line number
             m_sci->MarkerAdd(i->first, 0x8);
             continue;
         }
-        pos += i->second.GetColumn();
+        pos += res.GetColumn();
 
-        sci->SetSelection(pos, pos + i->second.GetLen());
+        sci->SetSelection(pos, pos + res.GetLen());
         if(sci->GetSelectedText() != text) {
             // couldn't locate the original match (file may have been modified)
             m_sci->MarkerAdd(i->first, 0x8);
             continue;
         }
-        sci->ReplaceSelection(m_replaceWith->GetValue());
+        sci->ReplaceSelection(replaceText);
 
-        delta += m_replaceWith->GetValue().Length() - i->second.GetLen();
-        lastLine = i->second.GetLineNumber();
+        delta += replaceLen - res.GetLen();
+        deltaInChars += replaceLenInChars - res.GetLenInChars();
+        lastLine = res.GetLineNumber();
 
-        i->second.SetPattern(m_sci->GetLine(i->first)); // includes prior updates to same line
-        i->second.SetLen(m_replaceWith->GetValue().Length());
+        res.SetPattern(m_sci->GetLine(i->first)); // includes prior updates to same line
+        res.SetLen(replaceLen);
+        res.SetLenInChars(replaceLenInChars);
     }
+
+    // hide the progress bar
     m_progress->SetValue(0);
+    m_progress->Hide();
+    GetSizer()->Layout();
+
     DoSaveResults(sci, firstInFile, m_matchInfo.end());
 
     // Disable the 'buffer limit' feature during replace
@@ -315,12 +367,12 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
     lastFile.Clear();
     m_sci->MarkerDeleteAll(0x7);
     m_sci->SetReadOnly(false);
+    m_replaceWith->SetValue(wxEmptyString);
 
     std::vector<int> itemsToRemove;
-    i = m_matchInfo.begin();
-    for(; i != m_matchInfo.end(); i++) {
-        int line = i->first + delta;
-        if(i->second.GetFileName() != lastFile) {
+    for (const auto& p : m_matchInfo) {
+        int line = p.first + delta;
+        if (p.second.GetFileName() != lastFile) {
             if(lastLine == line - 2) {
                 // previous file's replacements are all done, so remove its filename line
                 m_sci->SetCurrentPos(m_sci->PositionFromLine(lastLine));
@@ -330,11 +382,11 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
             } else {
                 lastLine = line - 1;
             }
-            lastFile = i->second.GetFileName();
+            lastFile = p.second.GetFileName();
         }
 
         if(m_sci->MarkerGet(line) & 1 << 0x9) {
-            LEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(lastFile);
+            clEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(lastFile);
             if(editor && editor->GetModify()) {
                 updatedEditors.insert(lastFile);
             }
@@ -342,19 +394,19 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
             m_sci->MarkerDelete(line, 0x9);
             m_sci->SetCurrentPos(m_sci->PositionFromLine(line));
             m_sci->LineDelete();
-            itemsToRemove.push_back(i->first);
+            itemsToRemove.push_back(p.first);
             delta--;
-        } else if(line != i->first) {
+        } else if (line != p.first) {
             // need to adjust line number
-            m_matchInfo[line] = i->second;
-            itemsToRemove.push_back(i->first);
+            m_matchInfo[line] = p.second;
+            itemsToRemove.push_back(p.first);
         }
     }
 
     // update the match info map
-    for(std::vector<int>::size_type i = 0; i < itemsToRemove.size(); i++) {
-        MatchInfo_t::iterator iter = m_matchInfo.find(itemsToRemove.at(i));
-        if(iter != m_matchInfo.end()) {
+    for (const auto itemId : itemsToRemove) {
+        MatchInfo_t::iterator iter = m_matchInfo.find(itemId);
+        if (iter != m_matchInfo.end()) {
             m_matchInfo.erase(iter);
         }
     }
@@ -366,16 +418,16 @@ void ReplaceInFilesPanel::OnReplace(wxCommandEvent& e)
     }
 
     // Step 3: Notify user of changes to already opened files, ask to save
-    std::vector<std::pair<wxFileName, bool> > filesToSave;
-    for(std::set<wxString>::iterator i = updatedEditors.begin(); i != updatedEditors.end(); i++) {
-        filesToSave.push_back(std::make_pair(wxFileName(*i), true));
+    std::vector<std::pair<wxFileName, bool>> filesToSave;
+    for (const auto& editorPath : updatedEditors) {
+        filesToSave.push_back(std::make_pair(wxFileName(editorPath), true));
     }
-    if(!filesToSave.empty() &&
-        clMainFrame::Get()->GetMainBook()->UserSelectFiles(filesToSave, _("Save Modified Files"),
-            _("Some files are modified.\nChoose the files you would like to save."), true)) {
+    if(!filesToSave.empty() && clMainFrame::Get()->GetMainBook()->UserSelectFiles(
+                                   filesToSave, _("Save Modified Files"),
+                                   _("Some files are modified.\nChoose the files you would like to save."), true)) {
         for(size_t i = 0; i < filesToSave.size(); i++) {
             if(filesToSave[i].second) {
-                LEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(filesToSave[i].first.GetFullPath());
+                clEditor* editor = clMainFrame::Get()->GetMainBook()->FindEditor(filesToSave[i].first.GetFullPath());
                 if(editor) {
                     editor->SaveFile();
                 }
@@ -415,7 +467,7 @@ void ReplaceInFilesPanel::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
         return;
     }
 
-    if(EditorConfigST::Get()->GetOptions()->GetHideOutpuPaneOnUserClick()) {
+    if (EditorConfigST::Get()->GetOptions()->GetHideOutputPaneOnUserClick()) {
         e.Enable(true);
         e.Check(EditorConfigST::Get()->GetOptions()->GetHideOutputPaneNotIfReplace());
 
@@ -442,3 +494,27 @@ void ReplaceInFilesPanel::OnMouseDClick(wxStyledTextEvent& e)
         }
     }
 }
+
+void ReplaceInFilesPanel::SetStyles(wxStyledTextCtrl* sci)
+{
+    FindResultsTab::SetStyles(sci);
+
+    LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("c++");
+    if(!lexer) {
+        lexer = ColoursAndFontsManager::Get().GetLexer("text");
+    }
+    lexer->ApplyFont(m_replaceWith);
+
+    const StyleProperty& styleProperty = lexer->GetProperty(0);
+    wxColour bgColour = styleProperty.GetBgColour();
+
+#if wxCHECK_VERSION(3, 1, 0)
+    sci->SetMarginWidth(3, clGetSize(1, sci)); // separator margin
+    sci->SetMarginBackground(3, lexer->IsDark() ? bgColour.ChangeLightness(130) : bgColour.ChangeLightness(50));
+#else
+    sci->SetMarginWidth(3, 0); // separator margin
+#endif
+    sci->MarkerDefine(7, wxSTC_MARK_ARROW);
+    sci->MarkerSetBackground(7, lexer->IsDark() ? "WHITE" : "DARK GREY");
+    sci->MarkerSetForeground(7, lexer->IsDark() ? "WHITE" : "DARK GREY");
+}
