@@ -22,18 +22,21 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "precompiled_header.h"
-#include "editor_config.h"
-#include "ctags_manager.h"
 #include "setters_getters_dlg.h"
-#include "macros.h"
-#include "language.h"
-#include "wx/tokenzr.h"
-#include "pluginmanager.h"
+
 #include "bitmap_loader.h"
-#include "windowattrmanager.h"
 #include "cl_config.h"
+#include "ctags_manager.h"
+#include "editor_config.h"
 #include "fileutils.h"
+#include "globals.h"
+#include "language.h"
+#include "macros.h"
+#include "pluginmanager.h"
+#include "precompiled_header.h"
+#include "windowattrmanager.h"
+
+#include <wx/tokenzr.h>
 
 //----------------------------------------------------
 
@@ -46,15 +49,17 @@ SettersGettersDlg::SettersGettersDlg(wxWindow* parent)
     m_checkBoxForamtFileWhenDone->SetValue(m_settings.GetFlags() & SettersGetterData::FormatFileWhenDone);
     m_checkBoxReturnSelf->SetValue(m_settings.GetFlags() & SettersGetterData::SettersReturnReferenceToSelf);
     SetName("SettersGettersDlg");
-    WindowAttrManager::Load(this);
+    m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
+    ::clSetSmallDialogBestSizeAndPosition(this);
 }
 
-bool SettersGettersDlg::Init(const std::vector<TagEntryPtr>& tags, const wxFileName& file, int lineno)
+bool SettersGettersDlg::Init(const std::vector<TagEntryPtr>& tags, const std::vector<TagEntryPtr>& existing_functions,
+                             const wxFileName& file, int lineno)
 {
-    // convert the tags to string array
     m_file = file;
     m_lineno = lineno;
     m_members = tags;
+    m_existing_functions = existing_functions;
     return BuildTree() > 0;
 }
 
@@ -84,14 +89,11 @@ wxString SettersGettersDlg::GenerateFunctions()
 
 void SettersGettersDlg::GenerateGetters(wxString& code)
 {
-    wxDataViewItemArray funcs;
-    m_dataviewModel->GetChildren(wxDataViewItem(0), funcs);
-
-    for(size_t i = 0; i < funcs.GetCount(); ++i) {
+    for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         bool already_exists = false;
         wxString display_name;
-        SettersGettersTreeData* data = (SettersGettersTreeData*)m_dataviewModel->GetClientObject(funcs.Item(i));
-        if(data->m_kind == SettersGettersTreeData::Kind_Getter && data->m_checked) {
+        SettersGettersTreeData* data = GetItemData(i);
+        if(data && (data->m_kind == SettersGettersTreeData::Kind_Getter) && data->m_checked) {
             wxString getter_code = GenerateGetter(data->m_tag, already_exists, display_name);
             if(!already_exists) {
                 code << getter_code << "\n";
@@ -102,14 +104,11 @@ void SettersGettersDlg::GenerateGetters(wxString& code)
 
 void SettersGettersDlg::GenerateSetters(wxString& code)
 {
-    wxDataViewItemArray funcs;
-    m_dataviewModel->GetChildren(wxDataViewItem(0), funcs);
-
-    for(size_t i = 0; i < funcs.GetCount(); ++i) {
+    for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         bool already_exists = false;
         wxString display_name;
-        SettersGettersTreeData* data = (SettersGettersTreeData*)m_dataviewModel->GetClientObject(funcs.Item(i));
-        if((data->m_kind == SettersGettersTreeData::Kind_Setter) && data->m_checked) {
+        SettersGettersTreeData* data = GetItemData(i);
+        if(data && (data->m_kind == SettersGettersTreeData::Kind_Setter) && data->m_checked) {
             wxString setter_code = GenerateSetter(data->m_tag, already_exists, display_name);
             if(!already_exists) {
                 code << setter_code << "\n";
@@ -317,27 +316,16 @@ void SettersGettersDlg::UpdatePreview()
     m_code = GenerateFunctions();
 }
 
-void SettersGettersDlg::OnCheckAll(wxCommandEvent& e)
+void SettersGettersDlg::DoCheckAll(bool checked)
 {
-    wxDataViewItemArray funcs;
-    m_dataviewModel->GetChildren(wxDataViewItem(0), funcs);
-    for(size_t i = 0; i < funcs.GetCount(); ++i) {
-        wxVector<wxVariant> cols = m_dataviewModel->GetItemColumnsData(funcs.Item(i));
-        cols.at(0) = true;
-        m_dataviewModel->UpdateItem(funcs.Item(i), cols);
+    for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+        m_dvListCtrl->SetItemChecked(m_dvListCtrl->RowToItem(i), checked);
     }
 }
 
-void SettersGettersDlg::OnUncheckAll(wxCommandEvent& e)
-{
-    wxDataViewItemArray funcs;
-    m_dataviewModel->GetChildren(wxDataViewItem(0), funcs);
-    for(size_t i = 0; i < funcs.GetCount(); ++i) {
-        wxVector<wxVariant> cols = m_dataviewModel->GetItemColumnsData(funcs.Item(i));
-        cols.at(0) = false;
-        m_dataviewModel->UpdateItem(funcs.Item(i), cols);
-    }
-}
+void SettersGettersDlg::OnCheckAll(wxCommandEvent& e) { DoCheckAll(true); }
+
+void SettersGettersDlg::OnUncheckAll(wxCommandEvent& e) { DoCheckAll(false); }
 
 void SettersGettersDlg::OnUpdatePreview(wxCommandEvent& e)
 {
@@ -347,13 +335,12 @@ void SettersGettersDlg::OnUpdatePreview(wxCommandEvent& e)
 
 bool SettersGettersDlg::DoCheckExistance(const wxString& scope, const wxString& name, const wxString& method_signature)
 {
-    std::vector<TagEntryPtr> tmp_tags;
-    TagsManagerST::Get()->FindByNameAndScope(name, scope.IsEmpty() ? wxT("<global>") : scope, tmp_tags);
-    for(size_t i = 0; i < tmp_tags.size(); i++) {
-        TagEntryPtr t = tmp_tags.at(i);
+    wxString sig_two = TagsManagerST::Get()->NormalizeFunctionSig(method_signature);
+
+    for(size_t i = 0; i < m_existing_functions.size(); i++) {
+        TagEntryPtr t = m_existing_functions[i];
         wxString sig_one = TagsManagerST::Get()->NormalizeFunctionSig(t->GetSignature());
-        wxString sig_two = TagsManagerST::Get()->NormalizeFunctionSig(method_signature);
-        if(sig_one == sig_two) {
+        if((sig_one == sig_two) && name == t->GetName()) {
             return true;
         }
     }
@@ -376,10 +363,7 @@ wxString SettersGettersDlg::GenerateGetter(TagEntryPtr tag)
 
 int SettersGettersDlg::BuildTree()
 {
-    m_dataviewModel->Clear();
-    wxBitmap memberBmp = PluginManager::Get()->GetStdIcons()->LoadBitmap("cc/16/member_public");
-    wxBitmap funcBmp = PluginManager::Get()->GetStdIcons()->LoadBitmap("cc/16/function_public");
-
+    Clear();
     m_checkForDuplicateEntries = true;
 
     std::vector<TagEntryPtr> tmpTags = m_members;
@@ -395,7 +379,8 @@ int SettersGettersDlg::BuildTree()
 
         wxString getter = GenerateGetter(tmpTags.at(i), getter_exist, getter_display_name);
         wxString setter = GenerateSetter(tmpTags.at(i), setter_exist, setter_display_name);
-        if(getter_exist && setter_exist) continue;
+        if(getter_exist && setter_exist)
+            continue;
 
         m_members.push_back(tmpTags.at(i));
         Candidate candidate;
@@ -414,39 +399,30 @@ int SettersGettersDlg::BuildTree()
         wxVector<wxVariant> cols;
         if(!setter_exist) {
             cols.clear();
-            cols.push_back(false);
-            cols.push_back(SettersGettersModel::CreateIconTextVariant(setter_display_name, funcBmp));
-            m_dataviewModel->AppendItem(
-                wxDataViewItem(0),
-                cols,
-                new SettersGettersTreeData(tmpTags.at(i), SettersGettersTreeData::Kind_Setter, false));
+            cols.push_back(
+                ::MakeCheckboxVariant(setter_display_name, false,
+                                      clGetManager()->GetStdIcons()->GetImageIndex(BitmapLoader::kFunctionPublic)));
+            m_dvListCtrl->AppendItem(cols, (wxUIntPtr) new SettersGettersTreeData(
+                                               tmpTags.at(i), SettersGettersTreeData::Kind_Setter, false));
         }
 
         if(!getter_exist) {
             cols.clear();
-            cols.push_back(false);
-            cols.push_back(SettersGettersModel::CreateIconTextVariant(getter_display_name, funcBmp));
-            m_dataviewModel->AppendItem(
-                wxDataViewItem(0),
-                cols,
-                new SettersGettersTreeData(tmpTags.at(i), SettersGettersTreeData::Kind_Getter, false));
+            cols.push_back(
+                ::MakeCheckboxVariant(getter_display_name, false,
+                                      clGetManager()->GetStdIcons()->GetImageIndex(BitmapLoader::kFunctionPublic)));
+            m_dvListCtrl->AppendItem(cols, (wxUIntPtr) new SettersGettersTreeData(
+                                               tmpTags.at(i), SettersGettersTreeData::Kind_Getter, false));
         }
     }
 
     m_checkForDuplicateEntries = false;
-
-    if(m_members.empty() == false) {
-        wxString msg, title;
-        msg << _("Select the functions to generate from the list below");
-        title << _("Generate Setters/Getters for class '") << m_members.at(0)->GetParent() << _("'");
-        m_banner6->SetText(title, msg);
-    }
     return m_members.size();
 }
 
 void SettersGettersDlg::UpdateTree()
 {
-    m_dataviewModel->Clear();
+    Clear();
     std::vector<Candidate> candidates;
     if(m_searchCtrl->GetValue().IsEmpty()) {
         // show all
@@ -474,27 +450,24 @@ void SettersGettersDlg::UpdateTree()
         }
     }
 
-    wxBitmap funcBmp = PluginManager::Get()->GetStdIcons()->LoadBitmap("cc/16/function_public");
     for(size_t i = 0; i < candidates.size(); ++i) {
         const Candidate& candidate = candidates.at(i);
         if(candidate.suggestSetter) {
             wxVector<wxVariant> cols;
-            cols.push_back(false);
-            cols.push_back(SettersGettersModel::CreateIconTextVariant(candidate.setterName, funcBmp));
-            m_dataviewModel->AppendItem(
-                wxDataViewItem(0),
-                cols,
-                new SettersGettersTreeData(candidate.tag, SettersGettersTreeData::Kind_Setter, false));
+            cols.push_back(
+                ::MakeCheckboxVariant(candidate.setterName, false,
+                                      clGetManager()->GetStdIcons()->GetImageIndex(BitmapLoader::kFunctionPublic)));
+            m_dvListCtrl->AppendItem(cols, (wxUIntPtr) new SettersGettersTreeData(
+                                               candidate.tag, SettersGettersTreeData::Kind_Setter, false));
         }
 
         if(candidate.suggestGetter) {
             wxVector<wxVariant> cols;
-            cols.push_back(false);
-            cols.push_back(SettersGettersModel::CreateIconTextVariant(candidate.getterName, funcBmp));
-            m_dataviewModel->AppendItem(
-                wxDataViewItem(0),
-                cols,
-                new SettersGettersTreeData(candidate.tag, SettersGettersTreeData::Kind_Getter, false));
+            cols.push_back(
+                ::MakeCheckboxVariant(candidate.getterName, false,
+                                      clGetManager()->GetStdIcons()->GetImageIndex(BitmapLoader::kFunctionPublic)));
+            m_dvListCtrl->AppendItem(cols, (wxUIntPtr) new SettersGettersTreeData(
+                                               candidate.tag, SettersGettersTreeData::Kind_Getter, false));
         }
     }
 }
@@ -504,9 +477,12 @@ void SettersGettersDlg::OnButtonOk(wxCommandEvent& e) { e.Skip(); }
 SettersGettersDlg::~SettersGettersDlg()
 {
     size_t flags(0);
-    if(m_checkStartWithUppercase->IsChecked()) flags |= SettersGetterData::FunctionStartWithUpperCase;
-    if(m_checkBoxForamtFileWhenDone->IsChecked()) flags |= SettersGetterData::FormatFileWhenDone;
-    if(m_checkBoxReturnSelf->IsChecked()) flags |= SettersGetterData::SettersReturnReferenceToSelf;
+    if(m_checkStartWithUppercase->IsChecked())
+        flags |= SettersGetterData::FunctionStartWithUpperCase;
+    if(m_checkBoxForamtFileWhenDone->IsChecked())
+        flags |= SettersGetterData::FormatFileWhenDone;
+    if(m_checkBoxReturnSelf->IsChecked())
+        flags |= SettersGetterData::SettersReturnReferenceToSelf;
 
     m_settings.SetFlags(flags);
     clConfig::Get().WriteItem(&m_settings);
@@ -520,9 +496,11 @@ wxString SettersGettersDlg::GetGenCode()
 
 void SettersGettersDlg::OnValueChanged(wxDataViewEvent& event)
 {
-    wxVector<wxVariant> cols = m_dataviewModel->GetItemColumnsData(event.GetItem());
-    SettersGettersTreeData* data = (SettersGettersTreeData*)m_dataviewModel->GetClientObject(event.GetItem());
-    data->m_checked = cols.at(0).GetBool();
+    SettersGettersTreeData* data = GetItemData(event.GetItem());
+    if(!data) {
+        return;
+    }
+    data->m_checked = m_dvListCtrl->IsItemChecked(event.GetItem());
 }
 
 //----------------------------------------------------
@@ -534,12 +512,11 @@ SettersGetterData::SettersGetterData()
 {
 }
 
-SettersGetterData::~SettersGetterData() {}
-void SettersGetterData::FromJSON(const JSONElement& json) { m_flags = json.namedObject("m_flags").toSize_t(m_flags); }
+void SettersGetterData::FromJSON(const JSONItem& json) { m_flags = json.namedObject("m_flags").toSize_t(m_flags); }
 
-JSONElement SettersGetterData::ToJSON() const
+JSONItem SettersGetterData::ToJSON() const
 {
-    JSONElement element = JSONElement::createObject(GetName());
+    JSONItem element = JSONItem::createObject(GetName());
     element.addProperty("m_flags", m_flags);
     return element;
 }
@@ -549,3 +526,18 @@ void SettersGettersDlg::OnSettersReturnReference(wxCommandEvent& event)
     wxUnusedVar(event);
     UpdateTree();
 }
+
+SettersGettersTreeData* SettersGettersDlg::GetItemData(const wxDataViewItem& item)
+{
+    return reinterpret_cast<SettersGettersTreeData*>(m_dvListCtrl->GetItemData(item));
+}
+
+SettersGettersTreeData* SettersGettersDlg::GetItemData(size_t row) { return GetItemData(m_dvListCtrl->RowToItem(row)); }
+
+void SettersGettersDlg::Clear()
+{
+    m_dvListCtrl->DeleteAllItems([&](wxUIntPtr data) {
+        SettersGettersTreeData* d = reinterpret_cast<SettersGettersTreeData*>(data);
+        wxDELETE(d);
+    });
+}
