@@ -25,8 +25,13 @@
 #ifndef SHELLTAB_H
 #define SHELLTAB_H
 
+#include "OutputDebugStringThread.h"
+#include "clWorkspaceEvent.hpp"
 #include "outputtabwindow.h"
 
+#include <wx/combobox.h>
+
+class wxTerminal;
 class AsyncExeCmd;
 
 class ShellTab : public OutputTabWindow
@@ -59,30 +64,50 @@ protected:
 
 public:
     ShellTab(wxWindow* parent, wxWindowID id, const wxString& name);
-    virtual ~ShellTab();
+    virtual ~ShellTab() = default;
 };
 
 class OutputTab : public ShellTab
 {
+    OutputDebugStringThread* m_thread;
+    bool m_outputDebugStringActive;
+
+protected:
+    void DoSetCollecting(bool b);
+
 public:
     OutputTab(wxWindow* parent, wxWindowID id, const wxString& name);
     virtual ~OutputTab();
+
+    /**
+     * @brief Windows only. Report a string from a debuggee process which used the "OuptutDebugString" method
+     */
+    void OnOutputDebugString(clCommandEvent& event);
+
+    void OnDebugStarted(clDebugEvent& event);
+    void OnDebugStopped(clDebugEvent& event);
+    virtual void OnProcStarted(wxCommandEvent& e);
+    virtual void OnProcEnded(wxCommandEvent& e);
+    void OnWorkspaceClosed(clWorkspaceEvent& event);
 };
 
-class DebugTab : public ShellTab
+class DebugTab : public wxPanel
 {
+    wxTerminal* m_terminal;
+    clToolBar* m_toolbar;
+
 protected:
-    bool DoSendInput(const wxString& line);
-    void OnStopProc(wxCommandEvent& e);
     void OnUpdateUI(wxUpdateUIEvent& e);
-    virtual void OnHoldOpenUpdateUI(wxUpdateUIEvent& e);
-    virtual void OnEnableDbgLog(wxCommandEvent& event);
-    virtual void OnEnableDbgLogUI(wxUpdateUIEvent& event);
+    void OnHoldOpenUpdateUI(wxUpdateUIEvent& e);
+    void OnEnableDbgLog(wxCommandEvent& event);
+    void OnEnableDbgLogUI(wxUpdateUIEvent& event);
+    void OnCtrlC(clCommandEvent& event);
+    void OnExecuteCommand(clCommandEvent& event);
 
 public:
     DebugTab(wxWindow* parent, wxWindowID id, const wxString& name);
     virtual ~DebugTab();
-    wxAuiToolBar* GetToolBar() { return m_tb; }
+    clToolBar* GetToolBar() { return m_toolbar; }
     void AppendLine(const wxString& line);
 };
 
