@@ -22,51 +22,44 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "stringsearcher.h"
+#include "search_thread.h"
 #include "stringhighlighterjob.h"
+#include "stringsearcher.h"
 #include <vector>
 
-StringHighlighterJob::StringHighlighterJob(wxEvtHandler *parent, const wxChar *str, const wxChar *word, const wxChar* filename)
-		: Job(parent)
-		, m_str(str)
-		, m_word(word)
-		, m_filename(filename)
+StringHighlighterJob::StringHighlighterJob(const wxString& str, const wxString& word, int offset)
+    : m_str(str)
+    , m_word(word)
+    , m_offset(offset)
 {
 }
 
-StringHighlighterJob::~StringHighlighterJob()
+void StringHighlighterJob::Set(const wxString& str, const wxString& word, int offset)
 {
+    SetStr(str);
+    SetWord(word);
+    SetOffset(offset);
 }
 
-void StringHighlighterJob::Process(wxThread* thread)
+void StringHighlighterJob::Process()
 {
-	wxUnusedVar(thread);
-	if ( m_str.IsEmpty() || m_word.IsEmpty() ) {
-		return;
-	}
+    if(m_str.IsEmpty() || m_word.IsEmpty()) { return; }
 
-	int pos(0);
-	int match_len(0);
+    int pos(0);
+    int match_len(0);
 
-	// remove reverse search
-	int offset(0);
+    // remove reverse search
+    int offset(0);
 
-	// allocate result on the heap (will be freed by the caller)
-	StringHighlightOutput *results = new StringHighlightOutput;
+    const wchar_t* pin = m_str.c_str().AsWChar();
+    const wchar_t* pwo = m_word.c_str().AsWChar();
 
-	results->filename = m_filename.c_str();
-	results->matches  = new std::vector<std::pair<int, int> >;
-
-	while ( StringFindReplacer::Search(m_str, offset, m_word, wxSD_MATCHCASE | wxSD_MATCHWHOLEWORD, pos, match_len) ) {
-		// add result
-		std::pair<int, int> match;
-		match.first = pos;
-		match.second = match_len;
-
-		results->matches->push_back( match );
-		offset = pos + match_len;
-	}
-
-	// report the result back to parent
-	Post((void*) results);
+    while(StringFindReplacer::Search(pin, offset, pwo, wxSD_MATCHCASE | wxSD_MATCHWHOLEWORD, pos, match_len)) {
+        // add result pair(offset, len)
+        std::pair<int, int> match;
+        match.first = pos + m_offset; // add the offset
+        match.second = match_len;
+        m_output.matches.push_back(match);
+        offset = pos + match_len;
+    }
 }
