@@ -25,6 +25,7 @@
 
 #include "tabgroupdlg.h"
 #include "windowattrmanager.h"
+#include "manager.h"
 #include <wx/dirdlg.h>
 #include <wx/filedlg.h>
 #include <wx/dir.h>
@@ -46,8 +47,6 @@ LoadTabGroupDlg::LoadTabGroupDlg(wxWindow* parent, const wxString& path, const w
     WindowAttrManager::Load(this);
 }
 
-LoadTabGroupDlg::~LoadTabGroupDlg() {}
-
 void LoadTabGroupDlg::InsertListItem(const wxString& item)
 {
     if(item.IsEmpty() == false) {
@@ -91,10 +90,10 @@ SaveTabGroupDlg::SaveTabGroupDlg(wxWindow* parent, const wxArrayString& previous
 {
     SetName("SaveTabGroupDlg");
     WindowAttrManager::Load(this);
+    
+    m_radioBoxWorkspaceOrGlobal->Show(ManagerST::Get()->IsWorkspaceOpen());
 }
 
-SaveTabGroupDlg::~SaveTabGroupDlg() {}
-
 bool SaveTabGroupDlg::GetChoices(wxArrayInt& intArr) const
 {
     bool SomeChecked = false;
