@@ -23,20 +23,20 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include <wx/xml/xml.h>
-#include <wx/filename.h>
-#include <wx/dir.h>
-#include <wx/stdpaths.h>
-
-#include "manager.h"
-#include "xmlutils.h"
-#include "wx_xml_compatibility.h"
 #include "tabgroupmanager.h"
-#include "frame.h"
-#include "tabgroupspane.h"
-#include "workspace_pane.h"
-#include "event_notifier.h"
+
+#include "SideBar.hpp"
 #include "codelite_events.h"
+#include "event_notifier.h"
+#include "frame.h"
+#include "manager.h"
+#include "tabgroupspane.h"
+#include "xmlutils.h"
+
+#include <wx/dir.h>
+#include <wx/filename.h>
+#include <wx/stdpaths.h>
+#include <wx/xml/xml.h>
 
 TabgroupManager::~TabgroupManager()
 {
@@ -45,21 +45,22 @@ TabgroupManager::~TabgroupManager()
     EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &TabgroupManager::OnWorkspaceClosed, this);
 }
 
-vTabGrps& TabgroupManager::GetTabgroups()
+vTabGrps& TabgroupManager::GetTabgroups(bool isGlobal /*=false*/)
 {
-    if(m_tabgroups.empty()) {
-        LoadKnownTabgroups(); // Of course there might just not *be* any, but safer to try loading
+    vTabGrps& tabgrps = (isGlobal ? m_globalTabgroups : m_tabgroups);
+    if(tabgrps.empty()) {
+        LoadKnownTabgroups(isGlobal); // Of course there might just not *be* any, but safer to try loading
     }
-    return m_tabgroups;
+    return tabgrps;
 }
 
-bool TabgroupManager::FindTabgroup(const wxString& tabgroupname, wxArrayString& items)
+bool TabgroupManager::FindTabgroup(bool isGlobal, const wxString& tabgroupname, wxArrayString& items)
 {
     items.Empty();
-    vTabGrps::const_iterator iter = m_tabgroups.begin();
-    for(; iter != m_tabgroups.end(); ++iter) {
-        if(iter->first == tabgroupname) {
-            items = iter->second;
+    vTabGrps& tabgrps = (isGlobal ? m_globalTabgroups : m_tabgroups);
+    for (const auto& tabGroup : tabgrps) {
+        if (tabGroup.first == tabgroupname) {
+            items = tabGroup.second;
             return true;
         }
     }
@@ -68,26 +69,19 @@ bool TabgroupManager::FindTabgroup(const wxString& tabgroupname, wxArrayString&
 
 wxString TabgroupManager::GetTabgroupDirectory() { return m_tabgroupdir; }
 
-void TabgroupManager::SetTabgroupDirectory()
-{
-    wxFileName TabgrpPath = wxFileName::DirName(clCxxWorkspaceST::Get()->GetPrivateFolder() + wxT("/tabgroups/"));
-    if(!TabgrpPath.DirExists()) {
-        TabgrpPath.Mkdir(0777, wxPATH_MKDIR_FULL);
-    }
-    m_tabgroupdir = TabgrpPath.GetPath();
-}
-
-void TabgroupManager::LoadKnownTabgroups()
+void TabgroupManager::LoadKnownTabgroups(bool isGlobal /*=false*/)
 {
     wxArrayString Tabgrpfiles;
+    wxString tabgroupsDir = isGlobal ? clStandardPaths::Get().GetUserDataDir() + "/tabgroups" : GetTabgroupDirectory();
+
     // Load tabgroups from the tabgroup dir
-    wxDir::GetAllFiles(GetTabgroupDirectory(), &Tabgrpfiles, wxT("*.tabgroup"), wxDIR_FILES);
+    wxDir::GetAllFiles(tabgroupsDir, &Tabgrpfiles, wxT("*.tabgroup"), wxDIR_FILES);
     for(size_t n = 0; n < Tabgrpfiles.GetCount(); ++n) {
-        LoadTabgroupData(Tabgrpfiles.Item(n));
+        LoadTabgroupData(isGlobal, Tabgrpfiles.Item(n));
     }
 }
 
-void TabgroupManager::LoadTabgroupData(const wxString& tabgroup)
+void TabgroupManager::LoadTabgroupData(bool isGlobal, const wxString& tabgroup)
 {
     // 'tabgroup' is the filepath of the tabgroup to load
     if(tabgroup.IsEmpty()) {
@@ -105,12 +99,13 @@ void TabgroupManager::LoadTabgroupData(const wxString& tabgroup)
             tabnames.Add(ti.GetFileName());
         }
         std::pair<wxString, wxArrayString> TabgroupItem(tabgroup, tabnames);
-        m_tabgroups.push_back(TabgroupItem);
+        vTabGrps& tabgrps = (isGlobal ? m_globalTabgroups : m_tabgroups);
+        tabgrps.push_back(TabgroupItem);
     }
 }
 
-bool TabgroupManager::DoAddItemToTabgroup(
-    wxXmlDocument& doc, wxXmlNode* node, const wxString& filepath, const wxString& nextitemfilepath)
+bool TabgroupManager::DoAddItemToTabgroup(wxXmlDocument& doc, wxXmlNode* node, const wxString& filepath,
+                                          const wxString& nextitemfilepath)
 {
     wxXmlNode* TabInfoArrayNode = XmlUtils::FindFirstByTagName(doc.GetRoot(), wxT("TabInfoArray"));
     if(!TabInfoArrayNode) {
@@ -138,7 +133,7 @@ wxXmlNode* TabgroupManager::FindTabgroupItem(wxXmlDocument& doc, const wxString&
         wxXmlNode* TabInfoNode = TabInfoArrayNode->GetChildren();
         while(TabInfoNode) {
             wxXmlNode* child = XmlUtils::FindFirstByTagName(TabInfoNode, wxT("wxString"));
-            if(child && child->GetPropVal(wxT("Value"), wxEmptyString) == itemfilepath) {
+            if(child && child->GetAttribute(wxT("Value"), wxEmptyString) == itemfilepath) {
                 // Found it. Return the data in TabInfoNode
                 return TabInfoNode;
             }
@@ -149,15 +144,15 @@ wxXmlNode* TabgroupManager::FindTabgroupItem(wxXmlDocument& doc, const wxString&
     return NULL;
 }
 
-wxXmlNode* TabgroupManager::DoDeleteTabgroupItem(
-    wxXmlDocument& doc, const wxString& filepath, const wxString& itemfilepath)
+wxXmlNode* TabgroupManager::DoDeleteTabgroupItem(wxXmlDocument& doc, const wxString& filepath,
+                                                 const wxString& itemfilepath)
 {
     wxXmlNode* TabInfoArrayNode = XmlUtils::FindFirstByTagName(doc.GetRoot(), wxT("TabInfoArray"));
     if(TabInfoArrayNode) {
         wxXmlNode* TabInfoNode = TabInfoArrayNode->GetChildren();
         while(TabInfoNode) {
             wxXmlNode* child = XmlUtils::FindFirstByTagName(TabInfoNode, wxT("wxString"));
-            if(child && child->GetPropVal(wxT("Value"), wxEmptyString) == itemfilepath) {
+            if(child && child->GetAttribute(wxT("Value"), wxEmptyString) == itemfilepath) {
                 TabInfoArrayNode->RemoveChild(TabInfoNode);
                 doc.Save(filepath);
                 return TabInfoNode;
@@ -169,7 +164,7 @@ wxXmlNode* TabgroupManager::DoDeleteTabgroupItem(
     return NULL;
 }
 
-void TabgroupManager::OnWorkspaceLoaded(wxCommandEvent& evt)
+void TabgroupManager::OnWorkspaceLoaded(clWorkspaceEvent& evt)
 {
     evt.Skip();
     wxFileName fnWorkspaceFile(evt.GetString());
@@ -184,10 +179,10 @@ void TabgroupManager::OnWorkspaceLoaded(wxCommandEvent& evt)
 
     // Load the tabs directly from here and not by a handler to ensure that the pane
     // does not try to load the items before the manager is initialised properly
-    clMainFrame::Get()->GetWorkspacePane()->GetTabgroupsTab()->DisplayTabgroups();
+    clMainFrame::Get()->GetWorkspacePane()->GetTabgroupsTab()->DisplayTabgroups(false);
 }
 
-void TabgroupManager::OnWorkspaceClosed(wxCommandEvent& evt)
+void TabgroupManager::OnWorkspaceClosed(clWorkspaceEvent& evt)
 {
     evt.Skip();
     m_tabgroupdir.Clear();
