@@ -26,51 +26,38 @@
 #ifndef __tags_options_dlg__
 #define __tags_options_dlg__
 
-#include "tags_options_base_dlg.h"
+#include "clEditorEditEventsHandler.h"
 #include "serialized_object.h"
-#include "wx/filename.h"
+#include "tags_options_base_dlg.h"
 #include "tags_options_data.h"
 
+#include <wx/filename.h>
+
 ///////////////////////////////////////////////////////////////////////////////
-/// Class TagsOptionsDlg
+/// Class CodeCompletionSettingsDialog
 ///////////////////////////////////////////////////////////////////////////////
 class wxStyledTextCtrl;
-class TagsOptionsDlg : public TagsOptionsBaseDlg
+class CodeCompletionSettingsDialog : public TagsOptionsBaseDlg
 {
     TagsOptionsData m_data;
+    std::vector<clEditEventsHandler::Ptr_t> m_handlers;
 
     void SetFlag(CodeCompletionOpts flag, bool set);
     void SetColouringFlag(CodeCompletionColourOpts flag, bool set);
     void CopyData();
 
 protected:
-    virtual void OnColouringPropertyValueChanged(wxPropertyGridEvent& event);
-    virtual void OnSuggestCtags(wxCommandEvent& event);
-    wxArrayString GetCTagsSearchPaths() const;
-    void DoSuggest(wxStyledTextCtrl* textCtrl);
+    virtual void OnButtonCancel(wxCommandEvent& event);
+    virtual void OnButtonOk(wxCommandEvent& event);
+    void DoSetEditEventsHandler(wxWindow* win);
 
 protected:
-    virtual void OnAddExcludePath(wxCommandEvent& event);
-    virtual void OnAddSearchPath(wxCommandEvent& event);
     virtual void OnAutoShowWordAssitUI(wxUpdateUIEvent& event);
-    virtual void OnClangCCEnabledUI(wxUpdateUIEvent& event);
-    virtual void OnClearClangCache(wxCommandEvent& event);
-    virtual void OnClearClangCacheUI(wxUpdateUIEvent& event);
-    virtual void OnFileSelectedUI(wxUpdateUIEvent& event);
-    virtual void OnParse(wxCommandEvent& event);
-    virtual void OnSuggestSearchPaths(wxCommandEvent& event);
-    virtual void OnButtonOK(wxCommandEvent& event);
 
 public:
-    void Parse();
-
-public:
-    TagsOptionsDlg(wxWindow* parent, const TagsOptionsData& data);
-    virtual ~TagsOptionsDlg();
-    TagsOptionsData& GetData()
-    {
-        return m_data;
-    }
+    CodeCompletionSettingsDialog(wxWindow* parent, const TagsOptionsData& data);
+    virtual ~CodeCompletionSettingsDialog() = default;
+    TagsOptionsData& GetData() { return m_data; }
 };
 
 #endif //__tags_options_dlg__
