@@ -23,8 +23,10 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "threadlistpanel.h"
+
 #include "globals.h"
 #include "manager.h"
+
 #include <wx/wupdlock.h>
 
 class ThreadListClientData : public wxClientData
@@ -34,7 +36,7 @@ class ThreadListClientData : public wxClientData
 public:
     ThreadListClientData(const ThreadEntry& te) { m_threadEntry = te; }
 
-    virtual ~ThreadListClientData() {}
+    ~ThreadListClientData() override = default;
     const ThreadEntry& GetThreadEntry() const { return m_threadEntry; }
     ThreadEntry& GetThreadEntry() { return m_threadEntry; }
 };
@@ -44,16 +46,13 @@ ThreadListPanel::ThreadListPanel(wxWindow* parent)
 {
 }
 
-ThreadListPanel::~ThreadListPanel() {}
-
 void ThreadListPanel::OnItemActivated(wxDataViewEvent& event)
 {
-    if(!event.GetItem().IsOk()) return;
+    if(!event.GetItem().IsOk())
+        return;
 
-    wxVariant v;
     long threadId;
-    m_dvListCtrl->GetValue(v, m_dvListCtrl->ItemToRow(event.GetItem()), 0);
-    wxString str_id = v.GetString();
+    wxString str_id = m_dvListCtrl->GetItemText(event.GetItem(), 0);
     if(str_id.ToCLong(&threadId)) {
         Manager* mgr = ManagerST::Get();
         mgr->DbgSetThread(threadId);
@@ -67,7 +66,7 @@ void ThreadListPanel::PopulateList(const ThreadEntryArray& threads)
         // No need to repopulate the list, just set the active thread indicator
 
         // Loop over the table and set all threads to "NO"
-        for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+        for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
             ThreadListClientData* d = (ThreadListClientData*)m_dvListCtrl->GetItemData(m_dvListCtrl->RowToItem(i));
             d->GetThreadEntry().active = false;
             wxVariant v = "NO";
@@ -88,7 +87,7 @@ void ThreadListPanel::PopulateList(const ThreadEntryArray& threads)
 
         if(threadID != wxNOT_FOUND) {
             // Update the new active thread
-            for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+            for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
                 ThreadListClientData* d = (ThreadListClientData*)m_dvListCtrl->GetItemData(m_dvListCtrl->RowToItem(i));
                 if(d->GetThreadEntry().dbgid == threadID) {
                     d->GetThreadEntry().active = true;
@@ -99,15 +98,14 @@ void ThreadListPanel::PopulateList(const ThreadEntryArray& threads)
         }
 
     } else {
-        wxWindowUpdateLocker locker(m_dvListCtrl);
         Clear();
-
         // Replace the thread list
         m_threads.clear();
         m_threads.insert(m_threads.end(), threads.begin(), threads.end());
 
         int sel = wxNOT_FOUND;
-        if(m_threads.empty()) return;
+        if(m_threads.empty())
+            return;
 
         for(int i = (int)(m_threads.size() - 1); i >= 0; --i) {
             const ThreadEntry& entry = m_threads.at(i);
@@ -129,18 +127,18 @@ void ThreadListPanel::PopulateList(const ThreadEntryArray& threads)
             cols.push_back(entry.line);
             m_dvListCtrl->AppendItem(cols, (wxUIntPtr) new ThreadListClientData(entry));
         }
-
+        m_dvListCtrl->Update();
         // Ensure that the active thread is visible
         if(sel != wxNOT_FOUND) {
             wxDataViewItem item = m_dvListCtrl->RowToItem(sel);
-            m_dvListCtrl->EnsureVisible(item, 0);
+            m_dvListCtrl->EnsureVisible(item);
         }
     }
 }
 
 void ThreadListPanel::Clear()
 {
-    for(int i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
+    for(size_t i = 0; i < m_dvListCtrl->GetItemCount(); ++i) {
         ThreadListClientData* d = (ThreadListClientData*)m_dvListCtrl->GetItemData(m_dvListCtrl->RowToItem(i));
         delete d;
     }
