@@ -24,34 +24,37 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "workspacesettingsdlg.h"
+#include "ColoursAndFontsManager.h"
 #include "code_completion_page.h"
-#include "localworkspace.h"
 #include "environmentconfig.h"
-#include "evnvarlist.h"
-#include "windowattrmanager.h"
-#include <wx/dirdlg.h>
-#include <map>
-#include <wx/tokenzr.h>
+#include "envvarlist.h"
 #include "globals.h"
+#include "localworkspace.h"
+#include "windowattrmanager.h"
+#include <map>
+#include <wx/dirdlg.h>
+#include <wx/tokenzr.h>
 
 WorkspaceSettingsDlg::WorkspaceSettingsDlg(wxWindow* parent, LocalWorkspace* localWorkspace)
     : WorkspaceSettingsBase(parent)
     , m_localWorkspace(localWorkspace)
 {
-    m_ccPage = new CodeCompletionPage(m_notebook1, CodeCompletionPage::TypeWorkspace);
-    m_notebook1->AddPage(m_ccPage, wxT("Code Completion"), false);
+    auto lexer = ColoursAndFontsManager::Get().GetLexer("text");
+    lexer->Apply(m_textCtrlWspEnvVars);
 
-    EvnVarList vars;
+    m_ccPage = new CodeCompletionPage(m_notebook1, CodeCompletionPage::TypeWorkspace);
+    m_notebook1->AddPage(m_ccPage, _("Code Completion"), false);
+
+    EnvVarList vars;
     EnvironmentConfig::Instance()->ReadObject(wxT("Variables"), &vars);
-    std::map<wxString, wxString> envSets = vars.GetEnvVarSets();
+    const wxStringMap_t& envSets = vars.GetEnvVarSets();
     wxString activePage = vars.GetActiveSet();
     m_choiceEnvSets->Clear();
 
-    std::map<wxString, wxString>::iterator iter = envSets.begin();
     int useActiveSetIndex = m_choiceEnvSets->Append(wxGetTranslation(USE_GLOBAL_SETTINGS));
 
-    for(; iter != envSets.end(); iter++) {
-        m_choiceEnvSets->Append(iter->first);
+    for (const auto& p : envSets) {
+        m_choiceEnvSets->Append(p.first);
     }
 
     // select the current workspace active set name
@@ -77,56 +80,19 @@ WorkspaceSettingsDlg::WorkspaceSettingsDlg(wxWindow* parent, LocalWorkspace* loc
         EnvironmentConfig::Instance()->SetSettings(vars);
     }
 
-    wxString envvars = clCxxWorkspaceST::Get()->GetEnvironmentVariabels();
+    wxString envvars = clCxxWorkspaceST::Get()->GetEnvironmentVariables();
     envvars.Trim().Trim(false);
 
     m_textCtrlWspEnvVars->SetValue(envvars);
-    SetName("WorkspaceSettingsDlg");
-    WindowAttrManager::Load(this);
+    ::clSetDialogBestSizeAndPosition(this);
 }
 
-WorkspaceSettingsDlg::~WorkspaceSettingsDlg() {}
-
-// void WorkspaceSettingsDlg::OnAddIncludePath( wxCommandEvent& event )
-//{
-//	wxUnusedVar(event);
-//	wxString new_path = wxDirSelector(_("Add Parser Search Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition,
-//this);
-//	if (new_path.IsEmpty() == false) {
-//		wxString curpaths = m_textCtrlIncludePaths->GetValue();
-//		curpaths.Trim().Trim(false);
-//		if(curpaths.IsEmpty()) {
-//			curpaths << wxT("\n");
-//		}
-//		curpaths << new_path;
-//		m_textCtrlIncludePaths->SetValue(curpaths);
-//	}
-//}
-//
-// void WorkspaceSettingsDlg::OnAddExcludePath( wxCommandEvent& event )
-//{
-//	wxUnusedVar(event);
-//	wxString new_path = wxDirSelector(_("Add Parser Exclude Path:"), wxT(""), wxDD_DEFAULT_STYLE, wxDefaultPosition,
-//this);
-//	if (new_path.IsEmpty() == false) {
-//		wxString curpaths = m_textCtrlExcludePaths->GetValue();
-//		curpaths.Trim().Trim(false);
-//		if(curpaths.IsEmpty()) {
-//			curpaths << wxT("\n");
-//		}
-//		curpaths << new_path;
-//		m_textCtrlExcludePaths->SetValue(curpaths);
-//	}
-//}
-//
-wxArrayString WorkspaceSettingsDlg::GetExcludePaths() const { return wxArrayString(); }
-
 wxArrayString WorkspaceSettingsDlg::GetIncludePaths() const { return m_ccPage->GetIncludePaths(); }
 
 void WorkspaceSettingsDlg::OnButtonOK(wxCommandEvent& event)
 {
     m_localWorkspace->SetActiveEnvironmentSet(m_choiceEnvSets->GetStringSelection());
-    clCxxWorkspaceST::Get()->SetEnvironmentVariabels(m_textCtrlWspEnvVars->GetValue());
+    clCxxWorkspaceST::Get()->SetEnvironmentVariables(m_textCtrlWspEnvVars->GetValue());
     m_ccPage->Save();
     event.Skip();
 }
