@@ -22,7 +22,10 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "workspacetab.h"
+
 #include "DefaultWorkspacePage.h"
+#include "SideBar.hpp"
 #include "clFileOrFolderDropTarget.h"
 #include "clToolBarButtonBase.h"
 #include "clTreeCtrlPanel.h"
@@ -39,13 +42,13 @@
 #include "plugin.h"
 #include "pluginmanager.h"
 #include "project_settings_dlg.h"
-#include "workspace_pane.h"
-#include "workspacetab.h"
+
 #include <algorithm>
 #include <wx/button.h>
 #include <wx/combobox.h>
 #include <wx/dcbuffer.h>
 #include <wx/sizer.h>
+#include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
 
 static bool SortPinnedProjects(clRowEntry* a, clRowEntry* b)
@@ -62,47 +65,27 @@ WorkspaceTab::WorkspaceTab(wxWindow* parent, const wxString& caption)
     , m_dlg(NULL)
     , m_view(NULL)
 {
-    SetBackgroundStyle(wxBG_STYLE_PAINT);
-    m_panelCxx->SetBackgroundStyle(wxBG_STYLE_PAINT);
-
     long link = EditorConfigST::Get()->GetInteger(wxT("LinkWorkspaceViewToEditor"), 1);
     m_isLinkedToEditor = link ? true : false;
 
     CreateGUIControls();
     ConnectEvents();
-    m_themeHelper = NULL; // new ThemeHandlerHelper(this);
     SetDropTarget(new clFileOrFolderDropTarget(this));
     Bind(wxEVT_DND_FOLDER_DROPPED, &WorkspaceTab::OnFolderDropped, this);
-    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_BUILD_CONFIG_CHANGED, &WorkspaceTab::OnConfigChanged, this);
 
-    m_panelCxx->Bind(wxEVT_PAINT, [&](wxPaintEvent& e) {
-        wxAutoBufferedPaintDC dc(m_panelCxx);
-        dc.SetBrush(clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-        dc.SetPen(clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-        dc.DrawRectangle(m_panelCxx->GetClientRect());
-    });
-
-    EventNotifier::Get()->Bind(wxEVT_SYS_COLOURS_CHANGED, [&](clCommandEvent& event) {
-        event.Skip();
-        Refresh();
-        m_panelCxx->Refresh();
-    });
     m_bitmaps.push_back(clGetManager()->GetStdIcons()->LoadBitmap("project"));
     m_dvListCtrlPinnedProjects->SetBitmaps(&m_bitmaps);
 }
 
 WorkspaceTab::~WorkspaceTab()
 {
-    wxDELETE(m_themeHelper);
     wxTheApp->Disconnect(XRCID("show_in_workspace"), wxEVT_COMMAND_MENU_SELECTED,
                          wxCommandEventHandler(WorkspaceTab::OnShowFile), NULL, this);
     wxTheApp->Disconnect(XRCID("show_in_workspace"), wxEVT_UPDATE_UI,
                          wxUpdateUIEventHandler(WorkspaceTab::OnShowFileUI), NULL, this);
 
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceLoaded),
-                                     NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceClosed),
-                                     NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_LOADED, &WorkspaceTab::OnWorkspaceLoaded, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &WorkspaceTab::OnWorkspaceClosed, this);
     EventNotifier::Get()->Disconnect(wxEVT_PROJ_ADDED, clCommandEventHandler(WorkspaceTab::OnProjectAdded), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_PROJ_REMOVED, clCommandEventHandler(WorkspaceTab::OnProjectRemoved), NULL,
                                      this);
@@ -110,17 +93,10 @@ WorkspaceTab::~WorkspaceTab()
                                      wxCommandEventHandler(WorkspaceTab::OnActiveEditorChanged), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(WorkspaceTab::OnEditorClosing), NULL,
                                      this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                     wxCommandEventHandler(WorkspaceTab::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_ACTIVE_PROJECT_CHANGED,
-                                     clProjectSettingsEventHandler(WorkspaceTab::OnActiveProjectChanged), NULL, this);
 
-    wxTheApp->Disconnect(XRCID("configuration_manager"), wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(WorkspaceTab::OnConfigurationManager), NULL, this);
     wxTheApp->Disconnect(XRCID("configuration_manager"), wxEVT_UPDATE_UI,
                          wxUpdateUIEventHandler(WorkspaceTab::OnProjectSettingsUI), NULL, this);
 
-    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_BUILD_CONFIG_CHANGED, &WorkspaceTab::OnConfigChanged, this);
     EventNotifier::Get()->Unbind(wxEVT_BUILD_STARTED, &WorkspaceTab::OnBuildStarted, this);
     EventNotifier::Get()->Unbind(wxEVT_BUILD_ENDED, &WorkspaceTab::OnBuildEnded, this);
     EventNotifier::Get()->Unbind(wxEVT_PROGRAM_STARTED, &WorkspaceTab::OnProgramStarted, this);
@@ -144,7 +120,7 @@ WorkspaceTab::~WorkspaceTab()
 void WorkspaceTab::CreateGUIControls()
 {
     int index = m_simpleBook->FindPage(m_panelCxx);
-    if(index != wxNOT_FOUND) {
+    if (index != wxNOT_FOUND) {
         // set the C++ workspace view name to fit its workspace type
         //// Construct the tree
         m_simpleBook->SetPageText(index, clCxxWorkspaceST::Get()->GetWorkspaceType());
@@ -153,20 +129,14 @@ void WorkspaceTab::CreateGUIControls()
     m_view->AddPage(new DefaultWorkspacePage(m_simpleBook), _("Default"));
     m_view->SelectPage(_("Default"));
     m_view->SetDefaultPage(_("Default"));
-    BitmapLoader* bmps = clGetManager()->GetStdIcons();
-    m_toolbar580->AddTool(XRCID("ID_TOOL_LINK_EDITOR"), _("Link Editor"), bmps->LoadBitmap("link_editor"), "",
-                          wxITEM_CHECK);
-    m_toolbar580->AddTool(XRCID("ID_TOOL_COLLAPSE_ALL"), _("Collapse All"), bmps->LoadBitmap("fold"));
-    m_toolbar580->AddTool(XRCID("ID_TOOL_GOTO_ACTIVE_PROJECT"), _("Goto Active Project"), bmps->LoadBitmap("home"));
+    auto images = m_toolbar580->GetBitmapsCreateIfNeeded();
+    m_toolbar580->AddTool(XRCID("ID_TOOL_LINK_EDITOR"), _("Link Editor"), images->Add("link_editor"), "", wxITEM_CHECK);
+    m_toolbar580->AddTool(XRCID("ID_TOOL_COLLAPSE_ALL"), _("Collapse All"), images->Add("fold"));
+    m_toolbar580->AddTool(XRCID("ID_TOOL_GOTO_ACTIVE_PROJECT"), _("Goto Active Project"), images->Add("home"));
     m_toolbar580->AddTool(XRCID("ID_TOOL_ACTIVE_PROJECT_SETTINGS"),
                           _("Open selected project settings. If there is no project selected, open the parent project "
                             "of the selected item in the tree"),
-                          bmps->LoadBitmap("cog"));
-    m_toolbar580->AddSpacer();
-    m_toolbar580->AddTool(XRCID("ID_BUILD_PROJECT"), _("Build Active Project"), bmps->LoadBitmap("build"),
-                          _("Build Active Project"), wxITEM_DROPDOWN);
-    m_toolbar580->AddTool(XRCID("ID_EXECUTE_NO_DEBUG"), _("Run Active Project"), bmps->LoadBitmap("execute"),
-                          _("Run Active Project"));
+                          images->Add("cog"));
     m_toolbar580->Realize();
 }
 
@@ -182,7 +152,7 @@ void WorkspaceTab::FreezeThaw(bool freeze /*=true*/)
     wxCHECK_RET(!(!freeze && !frozen), wxT("Trying to thaw a warm workspace tab"));
     frozen = freeze;
 
-    if(freeze) {
+    if (freeze) {
         was_linked = m_isLinkedToEditor;
         m_isLinkedToEditor = false;
     } else {
@@ -197,10 +167,9 @@ void WorkspaceTab::ConnectEvents()
                       wxCommandEventHandler(WorkspaceTab::OnShowFile), NULL, this);
     wxTheApp->Connect(XRCID("show_in_workspace"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(WorkspaceTab::OnShowFileUI),
                       NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceLoaded), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(WorkspaceTab::OnWorkspaceClosed), NULL,
-                                  this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_LOADED, &WorkspaceTab::OnWorkspaceLoaded, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &WorkspaceTab::OnWorkspaceClosed, this);
+
     EventNotifier::Get()->Connect(wxEVT_PROJ_ADDED, clCommandEventHandler(WorkspaceTab::OnProjectAdded), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_PROJ_REMOVED, clCommandEventHandler(WorkspaceTab::OnProjectRemoved), NULL,
                                   this);
@@ -208,12 +177,6 @@ void WorkspaceTab::ConnectEvents()
                                   wxCommandEventHandler(WorkspaceTab::OnActiveEditorChanged), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(WorkspaceTab::OnEditorClosing), NULL,
                                   this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                  wxCommandEventHandler(WorkspaceTab::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_ACTIVE_PROJECT_CHANGED,
-                                  clProjectSettingsEventHandler(WorkspaceTab::OnActiveProjectChanged), NULL, this);
-    wxTheApp->Connect(XRCID("configuration_manager"), wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(WorkspaceTab::OnConfigurationManager), NULL, this);
     wxTheApp->Connect(XRCID("configuration_manager"), wxEVT_UPDATE_UI,
                       wxUpdateUIEventHandler(WorkspaceTab::OnProjectSettingsUI), NULL, this);
     m_toolbar580->Bind(wxEVT_TOOL, &WorkspaceTab::OnCollapseAll, this, XRCID("ID_TOOL_COLLAPSE_ALL"));
@@ -239,7 +202,7 @@ void WorkspaceTab::OnLinkEditor(wxCommandEvent& e)
 {
     m_isLinkedToEditor = e.IsChecked();
     EditorConfigST::Get()->SetInteger(wxT("LinkWorkspaceViewToEditor"), m_isLinkedToEditor ? 1 : 0);
-    if(m_isLinkedToEditor) {
+    if (m_isLinkedToEditor) {
         OnActiveEditorChanged(e);
     }
 }
@@ -247,7 +210,7 @@ void WorkspaceTab::OnLinkEditor(wxCommandEvent& e)
 void WorkspaceTab::OnCollapseAll(wxCommandEvent& e)
 {
     wxUnusedVar(e);
-    if(!m_fileView->GetRootItem().IsOk())
+    if (!m_fileView->GetRootItem().IsOk())
         return;
     m_fileView->CollapseAll();
 
@@ -259,9 +222,9 @@ void WorkspaceTab::OnCollapseAll(wxCommandEvent& e)
 
     wxArrayTreeItemIds arr;
     size_t count = m_fileView->GetSelections(arr);
-    if(count == 1) {
+    if (count == 1) {
         wxTreeItemId sel = arr.Item(0);
-        if(sel.IsOk()) {
+        if (sel.IsOk()) {
             m_fileView->EnsureVisible(sel);
         }
     }
@@ -273,16 +236,16 @@ void WorkspaceTab::OnGoHome(wxCommandEvent& e)
 {
     wxUnusedVar(e);
     wxString activeProject = ManagerST::Get()->GetActiveProjectName();
-    if(activeProject.IsEmpty())
+    if (activeProject.IsEmpty())
         return;
     m_fileView->ExpandToPath(activeProject, wxFileName());
 
     wxArrayTreeItemIds arr;
     size_t count = m_fileView->GetSelections(arr);
 
-    if(count == 1) {
+    if (count == 1) {
         wxTreeItemId sel = arr.Item(0);
-        if(sel.IsOk() && m_fileView->ItemHasChildren(sel))
+        if (sel.IsOk() && m_fileView->ItemHasChildren(sel))
             m_fileView->Expand(sel);
     }
     ManagerST::Get()->ShowWorkspacePane(m_caption);
@@ -305,7 +268,7 @@ void WorkspaceTab::OnProjectSettingsUI(wxUpdateUIEvent& e)
 void WorkspaceTab::OnShowFile(wxCommandEvent& e)
 {
     clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
-    if(editor && !editor->GetProject().IsEmpty()) {
+    if (editor && !editor->GetProject().IsEmpty()) {
         m_fileView->ExpandToPath(editor->GetProject(), editor->GetFileName());
         ManagerST::Get()->ShowWorkspacePane(m_caption);
     }
@@ -321,36 +284,23 @@ void WorkspaceTab::OnShowFileUI(wxUpdateUIEvent& e)
 void WorkspaceTab::OnActiveEditorChanged(wxCommandEvent& e)
 {
     e.Skip();
-    if(m_isLinkedToEditor) {
+    if (m_isLinkedToEditor) {
         MainBook* mainbook = clMainFrame::Get()->GetMainBook();
         clEditor* editor = mainbook->GetActiveEditor();
-        if(editor && !editor->GetProject().IsEmpty()) {
-            m_fileView->ExpandToPath(editor->GetProject(), editor->GetFileName());
-        }
-
-        Notebook* book = clMainFrame::Get()->GetWorkspacePane()->GetNotebook();
-        if(book) {
-            size_t index = book->GetPageIndex("wxCrafter");
-            if(index == (size_t)book->GetSelection()) {
-                book->SetSelection(0); // The most likely to be wanted
-            }
+        if (editor && !editor->GetProject().IsEmpty()) {
+            m_fileView->CallAfter(&FileViewTree::ExpandToPath, editor->GetProject(), editor->GetFileName());
         }
     }
 }
 
-void WorkspaceTab::OnWorkspaceLoaded(wxCommandEvent& e)
+void WorkspaceTab::OnWorkspaceLoaded(clWorkspaceEvent& e)
 {
     e.Skip();
-    if(ManagerST::Get()->IsWorkspaceOpen()) {
-        m_configChangeCtrl->Enable(true);
-        DoWorkspaceConfig();
-        DoUpdateChoiceWithProjects();
-
+    if (ManagerST::Get()->IsWorkspaceOpen()) {
         // Tree construction
         m_fileView->BuildTree();
         CallAfter(&WorkspaceTab::DoGoHome);
         SendCmdEvent(wxEVT_FILE_VIEW_INIT_DONE);
-
         // Load the C++ pinned projects list
         LoadCxxPinnedProjects();
     }
@@ -358,18 +308,26 @@ void WorkspaceTab::OnWorkspaceLoaded(wxCommandEvent& e)
 
 void WorkspaceTab::OnEditorClosing(wxCommandEvent& e) { e.Skip(); }
 
-void WorkspaceTab::OnWorkspaceClosed(wxCommandEvent& e)
+void WorkspaceTab::OnWorkspaceClosed(clWorkspaceEvent& e)
 {
     e.Skip();
-    m_configChangeCtrl->Clear();
-    m_configChangeCtrl->Enable(false);
+    wxWindowUpdateLocker locker{ this };
+
+    SaveCxxPinnedProjects();
+    m_cxxPinnedProjects.clear();
     m_fileView->DeleteAllItems();
 
+    m_splitterPageTreeView->GetSizer()->Detach(m_fileView);
+    m_fileView->Destroy();
+
+    m_fileView = new FileViewTree(m_splitterPageTreeView, wxID_ANY, wxDefaultPosition,
+                                  wxDLG_UNIT(m_splitterPageTreeView, wxSize(-1, -1)),
+                                  wxTR_MULTIPLE | wxTR_NO_LINES | wxTR_HAS_BUTTONS);
+    m_splitterPageTreeView->GetSizer()->Add(m_fileView, 1, wxEXPAND, WXC_FROM_DIP(5));
+    m_splitterPageTreeView->GetSizer()->Layout();
+
     // Clear the pinned projects view
     m_dvListCtrlPinnedProjects->DeleteAllItems();
-    SaveCxxPinnedProjects();
-    m_cxxPinnedProjects.clear();
-
     SendCmdEvent(wxEVT_FILE_VIEW_INIT_DONE);
 }
 
@@ -378,10 +336,9 @@ void WorkspaceTab::OnProjectAdded(clCommandEvent& e)
     e.Skip();
     const wxString& projName = e.GetString();
     m_fileView->BuildTree();
-    if(!projName.IsEmpty()) {
+    if (!projName.IsEmpty()) {
         m_fileView->ExpandToPath(projName, wxFileName());
     }
-    DoUpdateChoiceWithProjects();
     SendCmdEvent(wxEVT_FILE_VIEW_REFRESHED);
 }
 
@@ -390,7 +347,6 @@ void WorkspaceTab::OnProjectRemoved(clCommandEvent& e)
     e.Skip();
     m_fileView->BuildTree();
     CallAfter(&WorkspaceTab::DoGoHome);
-    DoUpdateChoiceWithProjects();
     SendCmdEvent(wxEVT_FILE_VIEW_REFRESHED);
 }
 
@@ -401,58 +357,17 @@ struct wxStringSorter {
     }
 };
 
-void WorkspaceTab::DoWorkspaceConfig()
-{
-    // Update the workspace configuration
-    BuildMatrixPtr matrix = clCxxWorkspaceST::Get()->GetBuildMatrix();
-    std::list<WorkspaceConfigurationPtr> confs = matrix->GetConfigurations();
-
-    confs.sort(wxStringSorter());
-    wxArrayString configurations;
-    std::for_each(confs.begin(), confs.end(),
-                  [&](WorkspaceConfigurationPtr conf) { configurations.push_back(conf->GetName()); });
-
-    m_configChangeCtrl->SetConfigurations(configurations);
-    wxString activeConfig = configurations.IsEmpty() ? "" : matrix->GetSelectedConfigurationName();
-    m_configChangeCtrl->SetActiveConfiguration(activeConfig);
-
-    clMainFrame::Get()->SelectBestEnvSet();
-}
-
-void WorkspaceTab::OnWorkspaceConfig(wxCommandEvent& e)
-{
-    e.Skip();
-    DoWorkspaceConfig();
-}
-
-void WorkspaceTab::OnConfigurationManager(wxCommandEvent& e)
-{
-    wxUnusedVar(e);
-    ConfigurationManagerDlg dlg(EventNotifier::Get()->TopFrame());
-    dlg.ShowModal();
-
-    BuildMatrixPtr matrix = ManagerST::Get()->GetWorkspaceBuildMatrix();
-    m_configChangeCtrl->SetActiveConfiguration(matrix->GetSelectedConfigurationName());
-}
-
 void WorkspaceTab::OnLinkEditorUI(wxUpdateUIEvent& event)
 {
     event.Enable(ManagerST::Get()->IsWorkspaceOpen());
     event.Check(m_isLinkedToEditor);
 }
 
-void WorkspaceTab::DoUpdateChoiceWithProjects()
-{
-    if(clCxxWorkspaceST::Get()->IsOpen()) {
-        m_configChangeCtrl->SetActiveProject(ManagerST::Get()->GetActiveProjectName());
-    }
-}
-
 void WorkspaceTab::OnWorkspaceOpenUI(wxUpdateUIEvent& event) { event.Enable(ManagerST::Get()->IsWorkspaceOpen()); }
 
 void WorkspaceTab::OpenProjectSettings(const wxString& project)
 {
-    if(m_dlg) {
+    if (m_dlg) {
         m_dlg->Raise();
         return;
     }
@@ -464,7 +379,7 @@ void WorkspaceTab::OpenProjectSettings(const wxString& project)
     // Allow plugins to process this event first
     clCommandEvent openEvent(wxEVT_CMD_OPEN_PROJ_SETTINGS);
     openEvent.SetString(project);
-    if(EventNotifier::Get()->ProcessEvent(openEvent)) {
+    if (EventNotifier::Get()->ProcessEvent(openEvent)) {
         return;
     }
 
@@ -491,104 +406,58 @@ void WorkspaceTab::OpenProjectSettings(const wxString& project)
 
     // Mark this project as modified
     ProjectPtr proj = ManagerST::Get()->GetProject(projectName);
-    if(proj) {
+    if (proj) {
         proj->SetModified(true);
     }
 }
 
 void WorkspaceTab::ProjectSettingsDlgClosed() { m_dlg = NULL; }
 
-void WorkspaceTab::OnActiveProjectChanged(clProjectSettingsEvent& e)
-{
-    e.Skip();
-
-    // Update the choice control
-    m_configChangeCtrl->SetActiveProject(e.GetProjectName());
-}
-
 void WorkspaceTab::DoGoHome()
 {
     wxString activeProject = ManagerST::Get()->GetActiveProjectName();
-    if(activeProject.IsEmpty())
+    if (activeProject.IsEmpty())
         return;
     m_fileView->ExpandToPath(activeProject, wxFileName());
 
     wxArrayTreeItemIds arr;
     size_t count = m_fileView->GetSelections(arr);
 
-    if(count == 1) {
+    if (count == 1) {
         wxTreeItemId sel = arr.Item(0);
-        if(sel.IsOk() && m_fileView->ItemHasChildren(sel))
+        if (sel.IsOk() && m_fileView->ItemHasChildren(sel))
             m_fileView->Expand(sel);
     }
     // ManagerST::Get()->ShowWorkspacePane(m_caption);
 }
 
-void WorkspaceTab::DoConfigChanged(const wxString& newConfigName)
-{
-    wxBusyCursor bc;
-    BuildMatrixPtr matrix = ManagerST::Get()->GetWorkspaceBuildMatrix();
-    matrix->SetSelectedConfigurationName(newConfigName);
-    ManagerST::Get()->SetWorkspaceBuildMatrix(matrix);
-
-    // Set the focus to the active editor if any
-    clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
-    if(editor) {
-        editor->SetActive();
-    }
-
-    ManagerST::Get()->UpdateParserPaths(true);
-}
-
 void WorkspaceTab::OnFolderDropped(clCommandEvent& event)
 {
     // pass it on to the tree view
     m_fileView->CallAfter(&FileViewTree::FolderDropped, event.GetStrings());
 }
 
-void WorkspaceTab::OnConfigChanged(clCommandEvent& e)
-{
-    e.Skip();
-    wxString selection = e.GetString();
-    if(selection == OPEN_CONFIG_MGR_STR) {
-        e.Skip(false);
-        wxCommandEvent e(wxEVT_MENU, XRCID("configuration_manager"));
-        e.SetEventObject(this);
-        ProcessEvent(e);
-        return;
-    }
-    DoConfigChanged(selection);
-}
-
-void WorkspaceTab::OnPaint(wxPaintEvent& event)
-{
-    wxAutoBufferedPaintDC dc(this);
-    dc.SetBrush(clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-    dc.SetPen(clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-    dc.DrawRectangle(GetClientRect());
-}
-
 void WorkspaceTab::LoadCxxPinnedProjects()
 {
     m_cxxPinnedProjects.clear();
     clCxxWorkspaceST::Get()->GetLocalWorkspace()->GetPinnedProjects(m_cxxPinnedProjects);
 
     // We got the pinned projects loaded, update the view
-    if(m_cxxPinnedProjects.empty()) {
+    if (m_cxxPinnedProjects.empty()) {
         // hide the to view
-        if(m_splitter->IsSplit()) {
+        if (m_splitter->IsSplit()) {
             m_splitter->Unsplit(m_splitterPagePinnedProjects);
         }
     } else {
         // ensure the view is visible
-        if(!m_splitter->IsSplit()) {
+        if (!m_splitter->IsSplit()) {
             m_splitter->SplitHorizontally(m_splitterPagePinnedProjects, m_splitterPageTreeView, 150);
             m_splitter->CallAfter(&wxSplitterWindow::UpdateSize);
         }
 
         m_dvListCtrlPinnedProjects->DeleteAllItems();
         m_dvListCtrlPinnedProjects->SetSortFunction(nullptr);
-        for(const wxString& project : m_cxxPinnedProjects) {
+        for (const wxString& project : m_cxxPinnedProjects) {
             wxVector<wxVariant> V;
             V.push_back(::MakeBitmapIndexText(project, 0));
             m_dvListCtrlPinnedProjects->AppendItem(V);
@@ -606,7 +475,7 @@ void WorkspaceTab::SaveCxxPinnedProjects()
 void WorkspaceTab::OnPinnedCxxProjectContextMenu(wxDataViewEvent& event)
 {
     wxDataViewItem item = event.GetItem();
-    if(!item.IsOk()) {
+    if (!item.IsOk()) {
         return;
     }
     SyncPinnedProjectsView(event.GetItem());
@@ -618,18 +487,18 @@ void WorkspaceTab::OnPinnedCxxProjectContextMenu(wxDataViewEvent& event)
 void WorkspaceTab::OnPinnedCxxProjectSelected(wxDataViewEvent& event)
 {
     // we MUST sync the views, otherwise, the context menu wont work
-    // since it reliese on the current selection in the tree
+    // since it relies on the current selection in the tree
     SyncPinnedProjectsView(event.GetItem());
 }
 
 void WorkspaceTab::AddPinnedProject(const wxString& project)
 {
-    if(m_cxxPinnedProjects.Index(project) != wxNOT_FOUND) {
+    if (m_cxxPinnedProjects.Index(project) != wxNOT_FOUND) {
         return;
     }
     m_cxxPinnedProjects.Add(project);
 
-    // Store the pinned projehcts
+    // Store the pinned projects
     SaveCxxPinnedProjects();
 
     // Refresh the view
@@ -638,7 +507,7 @@ void WorkspaceTab::AddPinnedProject(const wxString& project)
 
 void WorkspaceTab::SyncPinnedProjectsView(const wxDataViewItem& item)
 {
-    if(!item.IsOk()) {
+    if (!item.IsOk()) {
         return;
     }
 
@@ -654,12 +523,12 @@ void WorkspaceTab::ShowPinnedProjectMenu(const wxString& project)
     // Build the rest of the menu
     m_fileView->CreateProjectContextMenu(menu, project, false);
     menu.Bind(wxEVT_MENU, [&](wxCommandEvent& menuEvent) {
-        if(menuEvent.GetId() == XRCID("unpin_project")) {
+        if (menuEvent.GetId() == XRCID("unpin_project")) {
             wxDataViewItem item = m_dvListCtrlPinnedProjects->GetSelection();
-            if(item.IsOk()) {
+            if (item.IsOk()) {
                 m_dvListCtrlPinnedProjects->DeleteItem(m_dvListCtrlPinnedProjects->ItemToRow(item));
                 int where = m_cxxPinnedProjects.Index(project);
-                if(where != wxNOT_FOUND) {
+                if (where != wxNOT_FOUND) {
                     m_cxxPinnedProjects.RemoveAt(where);
                     SaveCxxPinnedProjects();
                     CallAfter(&WorkspaceTab::LoadCxxPinnedProjects);
@@ -677,30 +546,18 @@ void WorkspaceTab::OnBuildStarted(clBuildEvent& event)
 {
     event.Skip();
     m_buildInProgress = true;
-    auto button = m_toolbar580->FindById(XRCID("ID_BUILD_PROJECT"));
-    if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("stop"));
-        button->SetLabel(_("Stop Current Build"));
-        m_toolbar580->Refresh();
-    }
 }
 
 void WorkspaceTab::OnBuildEnded(clBuildEvent& event)
 {
     event.Skip();
     m_buildInProgress = false;
-    auto button = m_toolbar580->FindById(XRCID("ID_BUILD_PROJECT"));
-    if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("build"));
-        button->SetLabel(_("Build Active Project"));
-        m_toolbar580->Refresh();
-    }
 }
 
 void WorkspaceTab::OnBuildActiveProject(wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    if(m_buildInProgress) {
+    if (m_buildInProgress) {
         wxCommandEvent stopEvent(wxEVT_TOOL, XRCID("stop_active_project_build"));
         stopEvent.SetEventObject(m_toolbar580);
         EventNotifier::Get()->TopFrame()->GetEventHandler()->AddPendingEvent(stopEvent);
@@ -714,7 +571,7 @@ void WorkspaceTab::OnBuildActiveProject(wxCommandEvent& event)
 void WorkspaceTab::OnExecuteNoDebug(wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    if(!m_runInProgress) {
+    if (!m_runInProgress) {
         wxCommandEvent runEvent(wxEVT_TOOL, XRCID("execute_no_debug"));
         runEvent.SetEventObject(m_toolbar580);
         EventNotifier::Get()->TopFrame()->GetEventHandler()->AddPendingEvent(runEvent);
@@ -728,8 +585,8 @@ void WorkspaceTab::OnExecuteNoDebug(wxCommandEvent& event)
 void WorkspaceTab::OnBuildActiveProjectDropdown(wxCommandEvent& event)
 {
     wxUnusedVar(event);
-    // we dont allow showing the dropdown during build process
-    if(m_buildInProgress) {
+    // we don't allow showing the dropdown during build process
+    if (m_buildInProgress) {
         return;
     }
     clMainFrame::Get()->ShowBuildMenu(m_toolbar580, XRCID("ID_BUILD_PROJECT"));
@@ -739,22 +596,10 @@ void WorkspaceTab::OnProgramStarted(clExecuteEvent& event)
 {
     event.Skip();
     m_runInProgress = true;
-    auto button = m_toolbar580->FindById(XRCID("ID_EXECUTE_NO_DEBUG"));
-    if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("stop"));
-        button->SetLabel(_("Stop running program"));
-        m_toolbar580->Refresh();
-    }
 }
 
 void WorkspaceTab::OnProgramStopped(clExecuteEvent& event)
 {
     event.Skip();
     m_runInProgress = false;
-    auto button = m_toolbar580->FindById(XRCID("ID_EXECUTE_NO_DEBUG"));
-    if(button) {
-        button->SetBmp(clGetManager()->GetStdIcons()->LoadBitmap("execute"));
-        button->SetLabel(_("Run active project"));
-        m_toolbar580->Refresh();
-    }
 }
