@@ -24,14 +24,14 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "macbundler.h"
-#include "wx/xrc/xmlres.h"
-#include "wx/textfile.h"
-#include "workspace.h"
-#include "windowattrmanager.h"
-#include "wx/msgdlg.h"
-#include "wx/wx.h"
 
-static MacBundler* thePlugin = NULL;
+#include "windowattrmanager.h"
+#include "workspace.h"
+
+#include <wx/msgdlg.h>
+#include <wx/textfile.h>
+#include <wx/wx.h>
+#include <wx/xrc/xmlres.h>
 
 // TODO: accept file drops
 class IconPicker : public wxPanel
@@ -52,15 +52,15 @@ public:
     {
         m_image_path = path;
 
-        if(path.EndsWith(wxT(".icns"))) {
+        if (path.EndsWith(wxT(".icns"))) {
             wxExecute(wxT("sips -s format png '") + path + wxT("' --out /tmp/tmpicon.png"), wxEXEC_SYNC);
             path = wxT("/tmp/tmpicon.png");
         }
 
         m_image.LoadFile(path, wxBITMAP_TYPE_ANY);
 
-        if(m_image.IsOk()) {
-            if(m_image.GetWidth() > 50 or m_image.GetHeight() > 50) {
+        if (m_image.IsOk()) {
+            if (m_image.GetWidth() > 50 or m_image.GetHeight() > 50) {
                 wxImage tmp = m_image.ConvertToImage();
                 tmp.Rescale(50, 50, wxIMAGE_QUALITY_HIGH);
                 m_image = wxBitmap(tmp);
@@ -80,7 +80,7 @@ public:
     {
         wxPaintDC dc(this);
 
-        if(m_image.IsOk()) {
+        if (m_image.IsOk()) {
             dc.DrawBitmap(m_image, 10, 10, false);
         }
     }
@@ -88,7 +88,7 @@ public:
     void doubleClick(wxMouseEvent& evt)
     {
         wxString filename = wxFileSelector(_("Choose the icon file"));
-        if(not filename.IsEmpty()) {
+        if (not filename.IsEmpty()) {
             setImage(filename);
         }
     }
@@ -117,7 +117,6 @@ class BundleConfigDialog : public wxDialog
     wxTextCtrl* m_icon_file;
     wxTextCtrl* m_identifier;
     wxTextCtrl* m_signature;
-    IManager* m_pluginManager;
 
     wxString m_project_name;
 
@@ -129,7 +128,6 @@ public:
                    wxDefaultPosition,
                    wxDefaultSize,
                    wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
-        , m_pluginManager(manager)
     {
         m_accepted = false;
 
@@ -211,7 +209,7 @@ public:
         WindowAttrManager::Load(this);
     }
 
-    virtual ~BundleConfigDialog() {}
+    virtual ~BundleConfigDialog() = default;
 
     void onOk(wxCommandEvent& evt)
     {
@@ -238,15 +236,17 @@ public:
 
     bool getResults(wxArrayString& out, bool* createInfoPlistFile, bool* createIcon)
     {
-        if(not m_accepted) return false;
+        if (not m_accepted)
+            return false;
 
         *createInfoPlistFile = m_info_plist_cb->IsChecked();
         *createIcon = m_icon_cb->IsChecked();
 
         const wxArrayString& items = m_choices_widget->GetStrings();
         const int count = items.GetCount();
-        for(int n = 0; n < count; n++) {
-            if(m_choices_widget->IsChecked(n)) out.Add(items[n]);
+        for (int n = 0; n < count; n++) {
+            if (m_choices_widget->IsChecked(n))
+                out.Add(items[n]);
         }
 
         return true;
@@ -258,7 +258,7 @@ public:
 
     void writeInfoPlistFile(wxTextFile& file)
     {
-        if(not file.Exists()) {
+        if (not file.Exists()) {
             wxMessageBox(_("Cannot access or create file!"));
             return;
         }
@@ -291,7 +291,7 @@ public:
         file.AddLine(wxT("</dict>"));
         file.AddLine(wxT("</plist>"));
 
-        if(not file.Write()) {
+        if (not file.Write()) {
             wxMessageBox(_("Failed to write Info.plist file!"));
             return;
         }
@@ -299,20 +299,14 @@ public:
 };
 
 // Define the plugin entry point
-CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
-{
-    if(thePlugin == NULL) {
-        thePlugin = new MacBundler(manager);
-    }
-    return thePlugin;
-}
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager) { return new MacBundler(manager); }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
     static PluginInfo info;
     info.SetAuthor(wxT("Auria"));
     info.SetName(wxT("MacBundler"));
-    info.SetDescription(wxT("MacBundler : manage OS X app bundles"));
+    info.SetDescription(_("MacBundler : manage OS X app bundles"));
     info.SetVersion(wxT("v0.1"));
     return &info;
 }
@@ -326,18 +320,16 @@ MacBundler::MacBundler(IManager* manager)
     m_shortName = wxT("MacBundler");
 }
 
-MacBundler::~MacBundler() {}
-
 void MacBundler::onBundleInvoked_active(wxCommandEvent& evt)
 {
     wxString activeProject = m_mgr->GetWorkspace()->GetActiveProjectName();
 
-    if(activeProject == wxEmptyString) {
+    if (activeProject == wxEmptyString) {
         wxMessageBox(_("No project is active, cannot continue."));
     } else {
         wxString error;
         ProjectPtr project = m_mgr->GetWorkspace()->FindProjectByName(activeProject, error);
-        if(!project) {
+        if (!project) {
             wxMessageBox(_("Cannot retrieve active project, cannot continue."));
         } else {
             showSettingsDialogFor(project);
@@ -347,16 +339,18 @@ void MacBundler::onBundleInvoked_active(wxCommandEvent& evt)
 
 void MacBundler::onBundleInvoked_selected(wxCommandEvent& evt)
 {
-    if(not m_mgr->GetWorkspace() or not m_mgr->IsWorkspaceOpen()) return;
+    if (not m_mgr->GetWorkspace() or not m_mgr->IsWorkspaceOpen())
+        return;
 
     TreeItemInfo item = m_mgr->GetSelectedTreeItemInfo(TreeFileView);
-    if(item.m_itemType == ProjectItem::TypeProject) {
+    if (item.m_itemType == ProjectItem::TypeProject) {
 
         wxString project_name(item.m_text);
         wxString err_msg;
 
         ProjectPtr proj = m_mgr->GetWorkspace()->FindProjectByName(project_name, err_msg);
-        if(not proj) return;
+        if (not proj)
+            return;
 
         showSettingsDialogFor(proj);
     } else {
@@ -372,7 +366,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
     ProjectSettingsCookie cookie;
 
     ProjectSettingsPtr settings = project->GetSettings();
-    if(not settings) {
+    if (not settings) {
         wxMessageBox(_("Cannot continue, impossible to access project settings."));
         return;
     }
@@ -381,13 +375,11 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
     wxArrayString choices;
 
     // TODO: allow putting the rules in the config root and not in every target
-    BuildConfigPtr buildConfig = settings->GetFirstBuildConfiguration(cookie);
-    while(buildConfig) {
+    for (auto buildConfig = settings->GetFirstBuildConfiguration(cookie); buildConfig;
+         buildConfig = settings->GetNextBuildConfiguration(cookie)) {
 
         configs[buildConfig->GetName()] = buildConfig;
         choices.Add(buildConfig->GetName());
-
-        buildConfig = settings->GetNextBuildConfiguration(cookie);
     }
 
     bool accepted = false;
@@ -404,18 +396,18 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
         accepted = configDlg.getResults(targetsToSet, &generateInfoPlistFile, &generateIcon);
         iconName = configDlg.getIconDestName();
 
-        if(accepted and generateInfoPlistFile) {
+        if (accepted and generateInfoPlistFile) {
             wxFileName projPath = project->GetFileName();
             projPath.SetFullName(wxT(""));
             const wxString projectDirName = projPath.GetFullPath();
             const wxString infoPlistFile = projectDirName + wxT("/Info.plist");
 
-            if(wxFileExists(infoPlistFile)) {
+            if (wxFileExists(infoPlistFile)) {
                 int out = wxMessageBox(wxString::Format(_("The following file:\n%s\nalready exists, overwrite it?\n"),
                                                         infoPlistFile.c_str()),
                                        _("Warning"),
                                        wxYES_NO);
-                if(out == wxYES) {
+                if (out == wxYES) {
                     wxTextFile file;
                     file.Open(infoPlistFile);
                     file.Clear();
@@ -424,7 +416,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
                 }
             } else {
                 wxTextFile file;
-                if(not file.Create(infoPlistFile)) {
+                if (not file.Create(infoPlistFile)) {
                     wxMessageBox(_("Could not create Info.plist file\n") + infoPlistFile);
                 } else {
                     configDlg.writeInfoPlistFile(file);
@@ -432,7 +424,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
                 }
             }
 
-            if(wxFileExists(infoPlistFile)) {
+            if (wxFileExists(infoPlistFile)) {
                 // FIXME: if the file was already present, it will be added again and appear twice in the file tree
                 wxArrayString paths;
                 paths.Add(infoPlistFile);
@@ -441,9 +433,9 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
             }
         } // nend if create info.plist
 
-        if(accepted and generateIcon) {
+        if (accepted and generateIcon) {
             wxString iconSourcePath = configDlg.getIconSource();
-            if(not iconSourcePath.IsEmpty()) {
+            if (not iconSourcePath.IsEmpty()) {
                 // sips doesn't like double slashes in path names
                 iconSourcePath.Replace(wxT("//"), wxT("/"));
 
@@ -457,8 +449,8 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
 
                 std::cout << "Copying icon '" << iconSourcePath.mb_str() << "' to project\n";
 
-                if(iconSourcePath.EndsWith(wxT(".icns"))) {
-                    if(not wxCopyFile(iconSourcePath, iconFileDest)) {
+                if (iconSourcePath.EndsWith(wxT(".icns"))) {
+                    if (not wxCopyFile(iconSourcePath, iconFileDest)) {
                         wxMessageBox(_("Sorry, could not copy icon"));
                     }
                 } else {
@@ -466,24 +458,25 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
                         wxT("sips -s format icns '") + iconSourcePath + wxT("' --out '") + iconFileDest + wxT("'");
                     std::cout << cmd.mb_str() << std::endl;
                     wxExecute(cmd, wxEXEC_SYNC);
-                    if(not wxFileExists(iconFileDest)) {
+                    if (not wxFileExists(iconFileDest)) {
                         wxMessageBox(_("Sorry, could not convert selected icon to icns format"));
                     }
                 }
 
                 // FIXME: if the file was already present, it will be added again and appear twice in the file tree
-                if(wxFileExists(iconFileDest)) {
+                if (wxFileExists(iconFileDest)) {
                     wxArrayString paths;
                     paths.Add(iconFileDest);
                     m_mgr->CreateVirtualDirectory(project->GetName(), wxT("osx"));
                     m_mgr->AddFilesToVirtualFolder(project->GetName() + wxT(":osx"), paths);
                 }
             } // end if icon not null
-        }     // end if generate icon
+        } // end if generate icon
     }
-    if(!accepted) return;
+    if (!accepted)
+        return;
 
-    for(int n = 0; n < targetsToSet.GetCount(); n++) {
+    for (int n = 0; n < targetsToSet.GetCount(); n++) {
         BuildConfigPtr buildConfig = configs[targetsToSet[n]];
 
         wxString outputFileName = buildConfig->GetOutputFileName();
@@ -491,7 +484,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
         buildConfig->SetOutputFileName(wxT("$(IntermediateDirectory)/") + output);
         buildConfig->SetCommand(wxT("./") + output);
 
-        if(generateInfoPlistFile or generateIcon) {
+        if (generateInfoPlistFile or generateIcon) {
             // get existing custom makefile targets, if any
             wxString customPreBuild = buildConfig->GetPreBuildCustom();
 
@@ -505,7 +498,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
             deps = deps.Trim();
             deps = deps.Trim(false);
 
-            if(generateInfoPlistFile) {
+            if (generateInfoPlistFile) {
                 // augment existing rules with new rules to manage Info.plist file
                 deps.Append(wxT(" $(IntermediateDirectory)/$(ProjectName).app/Contents/Info.plist"));
                 rules.Append(wxString(wxT("\n## rule to copy the Info.plist file into the bundle\n")) +
@@ -513,7 +506,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
                              wxT("\tmkdir -p '$(IntermediateDirectory)/$(ProjectName).app/Contents' && cp -f "
                                  "Info.plist '$(IntermediateDirectory)/$(ProjectName).app/Contents/Info.plist'"));
             }
-            if(generateIcon) {
+            if (generateIcon) {
                 // augment existing rules with new rules to manage Info.plist file
                 deps.Append(wxT(" $(IntermediateDirectory)/$(ProjectName).app/Contents/Resources/") + iconName);
                 rules.Append(
@@ -549,51 +542,7 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
     project->SetSettings(settings);
 }
 
-clToolBar* MacBundler::CreateToolBar(wxWindow* parent)
-{
-    return NULL;
-
-    // Create the toolbar to be used by the plugin
-    // clToolBar *tb(NULL);
-
-    /*
-            // You can use the below code a snippet:
-            // First, check that CodeLite allows plugin to register plugins
-            if (m_mgr->AllowToolbar()) {
-                    // Support both toolbars icon size
-                    int size = m_mgr->GetToolbarIconSize();
-
-                    // Allocate new toolbar, which will be freed later by CodeLite
-                    tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE_PLUGIN);
-
-                    // Set the toolbar size
-                    tb->SetToolBitmapSize(wxSize(size, size));
-
-                    // Add tools to the plugins toolbar. You must provide 2 sets of icons: 24x24 and 16x16
-                    if (size == 24) {
-                            tb->AddTool(XRCID("new_plugin"), wxT("New CodeLite Plugin Project"),
-       wxXmlResource::Get()->LoadBitmap(wxT("plugin24")), wxT("New Plugin Wizard..."));
-                            tb->AddTool(XRCID("new_class"), wxT("Create New Class"),
-       wxXmlResource::Get()->LoadBitmap(wxT("class24")), wxT("New Class..."));
-                            tb->AddTool(XRCID("new_wx_project"), wxT("New wxWidget Project"),
-       wxXmlResource::Get()->LoadBitmap(wxT("new_wx_project24")), wxT("New wxWidget Project"));
-                    } else {
-                            tb->AddTool(XRCID("new_plugin"), wxT("New CodeLite Plugin Project"),
-       wxXmlResource::Get()->LoadBitmap(wxT("plugin16")), wxT("New Plugin Wizard..."));
-                            tb->AddTool(XRCID("new_class"), wxT("Create New Class"),
-       wxXmlResource::Get()->LoadBitmap(wxT("class16")), wxT("New Class..."));
-                            tb->AddTool(XRCID("new_wx_project"), wxT("New wxWidget Project"),
-       wxXmlResource::Get()->LoadBitmap(wxT("new_wx_project16")), wxT("New wxWidget Project"));
-                    }
-                    // And finally, we must call 'Realize()'
-                    tb->Realize();
-            }
-
-            // return the toolbar, it can be NULL if CodeLite does not allow plugins to register toolbars
-            // or in case the plugin simply does not require toolbar
-    */
-    // return tb;
-}
+void MacBundler::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void MacBundler::CreatePluginMenu(wxMenu* pluginsMenu)
 {
@@ -632,8 +581,8 @@ void MacBundler::CreatePluginMenu(wxMenu* pluginsMenu)
 
 void MacBundler::HookPopupMenu(wxMenu* menu, MenuType type)
 {
-    if(type == MenuTypeFileView_Project) {
-        if(!menu->FindItem(XRCID("MACBUNDLER_PROJECT_MENU"))) {
+    if (type == MenuTypeFileView_Project) {
+        if (!menu->FindItem(XRCID("MACBUNDLER_PROJECT_MENU"))) {
             menu->Append(
                 XRCID("MACBUNDLER_PROJECT_MENU"), _("Make this project output a bundle"), wxEmptyString, wxITEM_NORMAL);
             m_mgr->GetTheApp()->Connect(XRCID("MACBUNDLER_PROJECT_MENU"),
