@@ -23,43 +23,37 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include <set>
-#include <wx/app.h>
-#include <wx/wupdlock.h>
-#include "event_notifier.h"
-#include <wx/settings.h>
-#include "outline_settings.h"
-#include "iconfigtool.h"
+#include "outline.h"
+
+#include "cl_command_event.h"
+#include "codelite_events.h"
+#include "ctags_manager.h"
 #include "detachedpanesinfo.h"
-#include <wx/menu.h>
-#include <wx/log.h>
-#include <wx/tokenzr.h>
+#include "event_notifier.h"
+#include "fileextmanager.h"
+#include "iconfigtool.h"
 #include "macros.h"
 #include "workspace.h"
-#include "ctags_manager.h"
-#include "outline.h"
-#include "fileextmanager.h"
+
+#include <set>
+#include <wx/app.h>
 #include <wx/busyinfo.h>
+#include <wx/log.h>
+#include <wx/menu.h>
+#include <wx/settings.h>
+#include <wx/tokenzr.h>
 #include <wx/utils.h>
+#include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
-#include "parse_thread.h"
-#include "outline_symbol_tree.h"
-#include "codelite_events.h"
-#include "cl_command_event.h"
 
 //--------------------------------------------
 // Plugin Interface
 //--------------------------------------------
 
-static SymbolViewPlugin* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new SymbolViewPlugin(manager);
-    }
-    return thePlugin;
+    return new SymbolViewPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -84,68 +78,20 @@ SymbolViewPlugin::SymbolViewPlugin(IManager* manager)
     m_longName = _("Outline Plugin");
     m_shortName = wxT("Outline");
 
-    OutlineSettings os;
-    os.Load();
-
-    Notebook* book = m_mgr->GetWorkspacePaneNotebook();
-    if(IsPaneDetached()) {
-        // Make the window child of the main panel (which is the grand parent of the notebook)
-        DockablePane* cp =
-            new DockablePane(book->GetParent()->GetParent(), book, _("Outline"), false, wxNullBitmap, wxSize(200, 200));
-        m_view = new OutlineTab(cp, m_mgr);
-        cp->SetChildNoReparent(m_view);
-
-    } else {
-        m_view = new OutlineTab(book, m_mgr);
-        book->AddPage(m_view, _("Outline"), false);
-    }
-    EventNotifier::Get()->Bind(wxEVT_SHOW_WORKSPACE_TAB, &SymbolViewPlugin::OnToggleTab, this);
+    m_view = new OutlineTab(m_mgr->BookGet(PaneId::SIDE_BAR));
+    m_mgr->BookAddPage(PaneId::SIDE_BAR, m_view, _("Outline"), "outline-button");
     m_mgr->AddWorkspaceTab(_("Outline"));
 }
 
-SymbolViewPlugin::~SymbolViewPlugin() { thePlugin = NULL; }
-
-clToolBar* SymbolViewPlugin::CreateToolBar(wxWindow* parent) { return NULL; }
+void SymbolViewPlugin::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void SymbolViewPlugin::CreatePluginMenu(wxMenu* pluginsMenu) { wxUnusedVar(pluginsMenu); }
 
 void SymbolViewPlugin::UnPlug()
 {
-    EventNotifier::Get()->Unbind(wxEVT_SHOW_WORKSPACE_TAB, &SymbolViewPlugin::OnToggleTab, this);
-    int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(m_view);
-    if(where != wxNOT_FOUND) {
-        // this window might be floating
-        m_mgr->GetWorkspacePaneNotebook()->RemovePage(where);
-    }
-
-    m_view->Destroy();
-    m_view = NULL;
-}
-
-bool SymbolViewPlugin::IsPaneDetached()
-{
-    DetachedPanesInfo dpi;
-    m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    wxArrayString detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(_("Outline")) != wxNOT_FOUND;
-}
-
-int SymbolViewPlugin::DoFindTabIndex() { return m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(m_view); }
-
-void SymbolViewPlugin::OnToggleTab(clCommandEvent& event)
-{
-    if(event.GetString() != _("Outline")) {
-        event.Skip();
-        return;
-    }
-
-    if(event.IsSelected()) {
-        // show it
-        m_mgr->GetWorkspacePaneNotebook()->InsertPage(0, m_view, _("Outline"), true);
-    } else {
-        int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(_("Outline"));
-        if(where != wxNOT_FOUND) {
-            m_mgr->GetWorkspacePaneNotebook()->RemovePage(where);
-        }
+    if (!m_mgr->BookDeletePage(PaneId::SIDE_BAR, m_view)) {
+        // failed to delete, delete it manually
+        m_view->Destroy();
     }
+    m_view = nullptr;
 }
