@@ -26,39 +26,38 @@
 #ifndef __SymbolView__
 #define __SymbolView__
 
+#include "clTabTogglerHelper.h"
+#include "cl_command_event.h"
+#include "dockablepane.h"
+#include "globals.h"
+#include "outline_tab.h"
+#include "plugin.h"
+#include "windowstack.h"
+
 #include <map>
 #include <queue>
 #include <wx/choice.h>
-#include "outline_tab.h"
 #include <wx/imaglist.h>
-#include <wx/treectrl.h>
 #include <wx/splitter.h>
-#include "plugin.h"
-#include "dockablepane.h"
-#include "windowstack.h"
-#include "globals.h"
-#include "cl_command_event.h"
+#include <wx/treectrl.h>
 
 class SymbolViewPlugin : public IPlugin
 {
 protected:
-    OutlineTab* m_view;
-    bool IsPaneDetached();
-    int DoFindTabIndex();
-    void OnToggleTab(clCommandEvent& event);
+    OutlineTab* m_view = nullptr;
 
 public:
     //--------------------------------------------
     // Constructors/Destructors
     //--------------------------------------------
     SymbolViewPlugin(IManager* manager);
-    ~SymbolViewPlugin();
+    ~SymbolViewPlugin() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void UnPlug() override;
 };
 #endif // Outline
