@@ -26,7 +26,7 @@
 #ifndef COMPILERSDETECTORMANAGER_H
 #define COMPILERSDETECTORMANAGER_H
 
-#include <ICompilerLocator.h>
+#include "ICompilerLocator.h"
 #include "codelite_exports.h"
 #include "compiler.h"
 
@@ -37,7 +37,7 @@ class WXDLLIMPEXP_SDK CompilersDetectorManager
 
 public:
     CompilersDetectorManager();
-    virtual ~CompilersDetectorManager();
+    virtual ~CompilersDetectorManager() = default;
 
     /**
      * @brief return true if the locator found at least one instance
@@ -62,6 +62,8 @@ public:
 
     void MSWFixClangToolChain(CompilerPtr compiler,
                               const ICompilerLocator::CompilerVec_t& allCompilers = ICompilerLocator::CompilerVec_t());
+
+    wxString GetRealCXXPath(const CompilerPtr compiler) const;
 };
 
 #endif // COMPILERSDETECTORMANAGER_H
