@@ -26,15 +26,20 @@
 #if USE_SFTP
 
 #include "SFTPBrowserDlg.h"
-#include "sftp_settings.h"
-#include "ssh_account_info.h"
-#include <wx/msgdlg.h>
-#include "windowattrmanager.h"
-#include "fileextmanager.h"
-#include "my_sftp_tree_model.h"
+
 #include "SSHAccountManagerDlg.h"
+#include "environmentconfig.h"
+#include "fileextmanager.h"
 #include "globals.h"
 #include "imanager.h"
+#include "sftp_settings.h"
+#include "ssh/ssh_account_info.h"
+#include "windowattrmanager.h"
+
+#include <wx/app.h>
+#include <wx/busyinfo.h>
+#include <wx/msgdlg.h>
+#include <wx/utils.h>
 
 // ================================================================================
 // ================================================================================
@@ -50,7 +55,7 @@ public:
         , m_fullpath(fullpath)
     {
         wxFileName fn;
-        if(m_attribute->IsFolder()) {
+        if (m_attribute->IsFolder()) {
             fn = wxFileName(fullpath, "", wxPATH_UNIX);
             fn.Normalize();
             m_fullpath = fn.GetPath(false, wxPATH_UNIX);
@@ -61,7 +66,7 @@ public:
         }
     }
 
-    virtual ~SFTPBrowserEntryClientData() {}
+    virtual ~SFTPBrowserEntryClientData() = default;
 
     const wxString& GetDisplayName() const { return GetAttribute()->GetName(); }
     void SetAttribute(const SFTPAttribute::Ptr_t& attribute) { this->m_attribute = attribute; }
@@ -73,87 +78,105 @@ public:
 // ================================================================================
 // ================================================================================
 
-SFTPBrowserDlg::SFTPBrowserDlg(wxWindow* parent, const wxString& title, const wxString& filter, size_t flags)
+SFTPBrowserDlg::SFTPBrowserDlg(wxWindow* parent, const wxString& title, const wxString& filter, size_t flags,
+                               const wxString& selectedAccount)
     : SFTPBrowserBaseDlg(parent)
     , m_sftp(NULL)
     , m_filter(filter)
     , m_flags(flags)
 {
-    m_dataviewModel = new MySFTPTreeModel();
-    m_dataview->AssociateModel(m_dataviewModel.get());
-
     SetLabel(title);
-
-    m_bitmaps = clGetManager()->GetStdIcons()->MakeStandardMimeMap();
-
     SFTPSettings settings;
     settings.Load();
-
+    m_dataview->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
     const SSHAccountInfo::Vect_t& accounts = settings.GetAccounts();
-    SSHAccountInfo::Vect_t::const_iterator iter = accounts.begin();
-    for(; iter != accounts.end(); ++iter) {
-        m_choiceAccount->Append(iter->GetAccountName());
+    int selection = wxNOT_FOUND;
+    for (const auto& account : accounts) {
+        int index = m_choiceAccount->Append(account.GetAccountName());
+        if (!selectedAccount.empty() && selectedAccount == account.GetAccountName()) {
+            selection = index;
+        }
     }
 
-    if(!m_choiceAccount->IsEmpty()) {
-        m_choiceAccount->SetSelection(0);
-    }
+    clBitmapList* images = new clBitmapList;
+    m_toolbar->AddTool(wxID_NEW, _("Create new folder"), images->Add("plus"));
+    m_toolbar->AddTool(XRCID("ID_CD_UP"), _("Parent folder"), images->Add("up"));
+    m_toolbar->AddTool(XRCID("ID_SSH_ACCOUNT_MANAGER"), _("Open SSH account manager"), images->Add("user"));
+    m_toolbar->AssignBitmaps(images);
+    m_toolbar->Realize();
 
+    m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnCdUp, this, XRCID("ID_CD_UP"));
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &SFTPBrowserDlg::OnConnectedUI, this, XRCID("ID_CD_UP"));
+
+    m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnNewFolder, this, wxID_NEW);
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &SFTPBrowserDlg::OnConnectedUI, this, wxID_NEW);
+
+    m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnSSHAccountManager, this, XRCID("ID_SSH_ACCOUNT_MANAGER"));
+
+    wxString last_location = clConfig::Get().Read("SFTPBrowserDlg/location", wxString());
+    wxString last_account = clConfig::Get().Read("SFTPBrowserDlg/account", wxString());
+
+    if (selection != wxNOT_FOUND) {
+        m_choiceAccount->SetSelection(selection);
+        m_choiceAccount->Enable(false); // don't allow the user to change the account selection
+    } else {
+        if (!last_location.empty()) {
+            m_textCtrlRemoteFolder->ChangeValue(last_location);
+        }
+        int where = m_choiceAccount->FindString(last_account);
+        if (where != wxNOT_FOUND) {
+            m_choiceAccount->SetSelection(where);
+        } else if (!m_choiceAccount->IsEmpty()) {
+            m_choiceAccount->SetSelection(0);
+        }
+    }
+    CallAfter(&SFTPBrowserDlg::DoSetLocationFocus);
     SetName("SFTPBrowserDlg");
     WindowAttrManager::Load(this);
 }
 
-SFTPBrowserDlg::~SFTPBrowserDlg() {}
+SFTPBrowserDlg::~SFTPBrowserDlg()
+{
+    clConfig::Get().Write("SFTPBrowserDlg/location", m_textCtrlRemoteFolder->GetValue());
+    clConfig::Get().Write("SFTPBrowserDlg/account", m_choiceAccount->GetStringSelection());
+}
+
+void SFTPBrowserDlg::DoSetLocationFocus()
+{
+    // set the insertion point to the end of the text control
+    m_textCtrlRemoteFolder->SetInsertionPointEnd();
+    m_textCtrlRemoteFolder->SetFocus();
+}
 
 void SFTPBrowserDlg::OnRefresh(wxCommandEvent& event)
 {
-    DoCloseSession();
-    wxString accountName = m_choiceAccount->GetStringSelection();
-
-    SFTPSettings settings;
-    settings.Load();
-
-    SSHAccountInfo account;
-    if(!settings.GetAccount(accountName, account)) {
-        ::wxMessageBox(
-            wxString() << _("Could not find account: ") << accountName, "codelite", wxICON_ERROR | wxOK, this);
-        return;
-    }
-
-    clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(), account.GetPort()));
-    try {
-        wxString message;
-        ssh->Connect();
-        if(!ssh->AuthenticateServer(message)) {
-            if(::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
-                ssh->AcceptServerAuthentication();
-            }
-        }
-
-        ssh->Login();
-        m_sftp.reset(new clSFTP(ssh));
-        m_sftp->Initialize();
-
-        DoDisplayEntriesForPath();
-
-    } catch(clException& e) {
-        ::wxMessageBox(e.What(), "codelite", wxICON_ERROR | wxOK, this);
-        DoCloseSession();
-    }
+    wxUnusedVar(event);
+    CallAfter(&SFTPBrowserDlg::DoBrowse);
 }
 
-void SFTPBrowserDlg::OnRefreshUI(wxUpdateUIEvent& event) { event.Enable(!m_textCtrlRemoteFolder->IsEmpty()); }
+void SFTPBrowserDlg::OnRefreshUI(wxUpdateUIEvent& event) { event.Enable(true); }
 
 void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
 {
+    wxBusyCursor bc;
     try {
         wxString folder;
         SFTPAttribute::List_t attributes;
-        if(path.IsEmpty()) {
+        if (path.IsEmpty()) {
             folder = m_textCtrlRemoteFolder->GetValue();
+            if (folder.IsEmpty()) {
+                folder = "/";
+            } else {
+                // if the path contains file name, remmove it
+                wxFileName fn(folder);
+                if (fn.GetFullName().Contains(".")) {
+                    folder = fn.GetPath(wxPATH_UNIX);
+                }
+            }
+            folder.Replace("\\", "/");
             attributes = m_sftp->List(folder, m_flags, m_filter);
 
-        } else if(path == "..") {
+        } else if (path == "..") {
             // cd up
             attributes = m_sftp->CdUp(m_flags, m_filter);
             m_textCtrlRemoteFolder->ChangeValue(m_sftp->GetCurrentFolder());
@@ -164,38 +187,40 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
             attributes = m_sftp->List(folder, m_flags, m_filter);
         }
 
-        SFTPAttribute::List_t::iterator iter = attributes.begin();
-        for(; iter != attributes.end(); ++iter) {
-
+        BitmapLoader* loader = clGetManager()->GetStdIcons();
+        for (SFTPAttribute::Ptr_t attr : attributes) {
             // Set the columns Name (icontext) | Type (text) | Size (text)
             wxVector<wxVariant> cols;
 
             // determine the bitmap type
-            wxBitmap bmp = m_bitmaps[FileExtManager::TypeText];
+            int imgid = loader->GetMimeImageId(FileExtManager::TypeText);
             wxString fullname;
-            fullname << folder << "/" << (*iter)->GetName();
+            fullname << folder << "/" << attr->GetName();
 
-            if((*iter)->IsFolder()) {
-                bmp = m_bitmaps[FileExtManager::TypeFolder];
+            if (attr->IsSymlink()) {
+                if (attr->IsFolder()) {
+                    imgid = loader->GetMimeImageId(FileExtManager::TypeFolderSymlink);
+                } else {
+                    imgid = loader->GetMimeImageId(FileExtManager::TypeFileSymlink);
+                }
             } else {
-                wxFileName fn(fullname);
-                FileExtManager::FileType type = FileExtManager::GetType(fn.GetFullName());
-                if(m_bitmaps.count(type)) {
-                    bmp = m_bitmaps[type];
+                if (attr->IsFolder()) {
+                    imgid = loader->GetMimeImageId(FileExtManager::TypeFolder);
+                } else {
+                    wxFileName fn(fullname);
+                    imgid = loader->GetMimeImageId(fn.GetFullName());
                 }
             }
+            cols.push_back(::MakeBitmapIndexText(attr->GetName(), imgid));
+            cols.push_back(attr->GetTypeAsString());
+            cols.push_back(wxString() << attr->GetSize());
 
-            cols.push_back(SFTPTreeModel::CreateIconTextVariant((*iter)->GetName(), bmp));
-            cols.push_back((*iter)->GetTypeAsString());
-            cols.push_back(wxString() << (*iter)->GetSize());
-
-            SFTPBrowserEntryClientData* cd = new SFTPBrowserEntryClientData((*iter), fullname);
-            m_dataviewModel->AppendItem(wxDataViewItem(0), cols, cd);
+            SFTPBrowserEntryClientData* cd = new SFTPBrowserEntryClientData(attr, fullname);
+            m_dataview->AppendItem(cols, (wxUIntPtr)cd);
         }
-        m_dataview->Refresh();
         m_dataview->SetFocus();
 
-    } catch(clException& e) {
+    } catch (const clException& e) {
         ::wxMessageBox(e.What(), "SFTP", wxICON_ERROR | wxOK);
         DoCloseSession();
     }
@@ -203,45 +228,44 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
 
 void SFTPBrowserDlg::DoCloseSession()
 {
-    m_sftp.reset(NULL);
-    m_dataviewModel->Clear();
+    m_sftp.reset();
+    ClearView();
 }
 
 void SFTPBrowserDlg::OnItemActivated(wxDataViewEvent& event)
 {
-    if(!m_sftp) {
+    if (!m_sftp) {
         DoCloseSession();
         return;
     }
 
-    SFTPBrowserEntryClientData* cd =
-        dynamic_cast<SFTPBrowserEntryClientData*>(m_dataviewModel->GetClientObject(event.GetItem()));
-    if(cd && cd->GetAttribute()->IsFolder()) {
+    SFTPBrowserEntryClientData* cd = DoGetItemData(event.GetItem());
+    if (cd && cd->GetAttribute()->IsFolder()) {
         m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
-        m_dataviewModel->Clear();
+        ClearView();
         DoDisplayEntriesForPath();
     }
 }
 
 void SFTPBrowserDlg::OnTextEnter(wxCommandEvent& event)
 {
-    if(!m_sftp) {
+    if (!m_sftp) {
         OnRefresh(event);
     } else {
-        m_dataviewModel->Clear();
+        ClearView();
         DoDisplayEntriesForPath();
     }
 }
 void SFTPBrowserDlg::OnOKUI(wxUpdateUIEvent& event)
 {
     wxString selection = m_textCtrlRemoteFolder->GetValue();
-    if(m_filter.IsEmpty()) { // folder / files - and there is a selection
+    if (m_filter.IsEmpty()) { // folder / files - and there is a selection
         event.Enable(!selection.IsEmpty());
 
-    } else if(!(m_flags & clSFTP::SFTP_BROWSE_FILES)) { // folders only
+    } else if (!(m_flags & clSFTP::SFTP_BROWSE_FILES)) { // folders only
         event.Enable(!selection.IsEmpty());
 
-    } else if(!selection.IsEmpty() && (m_flags & clSFTP::SFTP_BROWSE_FILES) && ::wxMatchWild(m_filter, selection)) {
+    } else if (!selection.IsEmpty() && (m_flags & clSFTP::SFTP_BROWSE_FILES) && ::wxMatchWild(m_filter, selection)) {
         event.Enable(true);
 
     } else {
@@ -251,11 +275,10 @@ void SFTPBrowserDlg::OnOKUI(wxUpdateUIEvent& event)
 
 SFTPBrowserEntryClientData* SFTPBrowserDlg::DoGetItemData(const wxDataViewItem& item) const
 {
-    if(!item.IsOk()) {
+    if (!item.IsOk()) {
         return NULL;
     }
-
-    SFTPBrowserEntryClientData* cd = dynamic_cast<SFTPBrowserEntryClientData*>(m_dataviewModel->GetClientObject(item));
+    SFTPBrowserEntryClientData* cd = reinterpret_cast<SFTPBrowserEntryClientData*>(m_dataview->GetItemData(item));
     return cd;
 }
 
@@ -264,7 +287,7 @@ wxString SFTPBrowserDlg::GetPath() const { return m_textCtrlRemoteFolder->GetVal
 void SFTPBrowserDlg::OnItemSelected(wxDataViewEvent& event)
 {
     SFTPBrowserEntryClientData* cd = DoGetItemData(m_dataview->GetSelection());
-    if(cd) {
+    if (cd) {
         m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
     }
 }
@@ -275,7 +298,7 @@ void SFTPBrowserDlg::Initialize(const wxString& account, const wxString& path)
 {
     m_textCtrlRemoteFolder->ChangeValue(path);
     int where = m_choiceAccount->FindString(account);
-    if(where != wxNOT_FOUND) {
+    if (where != wxNOT_FOUND) {
         m_choiceAccount->SetSelection(where);
     }
 }
@@ -285,8 +308,8 @@ void SFTPBrowserDlg::OnKeyDown(wxKeyEvent& event)
     event.Skip();
     wxChar ch = (wxChar)event.GetKeyCode();
 
-    if(::wxIsprint(ch)) {
-        if(!m_textCtrlInlineSearch->IsShown()) {
+    if (::wxIsprint(ch)) {
+        if (!m_textCtrlInlineSearch->IsShown()) {
             m_textCtrlInlineSearch->SetFocus();
             m_textCtrlInlineSearch->Clear();
 #ifdef __WXMSW__
@@ -302,30 +325,24 @@ void SFTPBrowserDlg::OnKeyDown(wxKeyEvent& event)
 void SFTPBrowserDlg::OnInlineSearch()
 {
     wxString text = m_textCtrlInlineSearch->GetValue();
-    wxDataViewItemArray children;
-    m_dataviewModel->GetChildren(wxDataViewItem(0), children);
-
-    for(size_t i = 0; i < children.GetCount(); ++i) {
-        SFTPBrowserEntryClientData* cd = DoGetItemData(children.Item(i));
-        if(cd && cd->GetDisplayName().StartsWith(text)) {
-            m_dataview->Select(children.Item(i));
-            m_dataview->EnsureVisible(children.Item(i));
-            break;
-        }
+    wxDataViewItem matchedItem = m_dataview->FindNext(wxDataViewItem(nullptr), text);
+    if (matchedItem.IsOk()) {
+        m_dataview->Select(matchedItem);
+        m_dataview->EnsureVisible(matchedItem);
     }
 }
 
 void SFTPBrowserDlg::OnInlineSearchEnter()
 {
     wxDataViewItem item = m_dataview->GetSelection();
-    if(!item.IsOk()) {
+    if (!item.IsOk()) {
         return;
     }
 
-    SFTPBrowserEntryClientData* cd = dynamic_cast<SFTPBrowserEntryClientData*>(m_dataviewModel->GetClientObject(item));
-    if(cd && cd->GetAttribute()->IsFolder()) {
+    SFTPBrowserEntryClientData* cd = DoGetItemData(item);
+    if (cd && cd->GetAttribute()->IsFolder()) {
         m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
-        m_dataviewModel->Clear();
+        ClearView();
         DoDisplayEntriesForPath();
         m_dataview->SetFocus();
     }
@@ -351,38 +368,34 @@ void SFTPBrowserDlg::OnTextUpdated(wxCommandEvent& event)
 
 void SFTPBrowserDlg::OnCdUp(wxCommandEvent& event)
 {
-    m_dataviewModel->Clear();
+    ClearView();
     DoDisplayEntriesForPath("..");
 }
 
-void SFTPBrowserDlg::OnCdUpUI(wxUpdateUIEvent& event) { event.Enable(m_sftp); }
+void SFTPBrowserDlg::OnConnectedUI(wxUpdateUIEvent& event) { event.Enable(m_sftp.get()); }
 
 void SFTPBrowserDlg::OnSSHAccountManager(wxCommandEvent& event)
 {
     SSHAccountManagerDlg dlg(this);
-    if(dlg.ShowModal() == wxID_OK) {
-
-        SFTPSettings settings;
-        settings.Load().SetAccounts(dlg.GetAccounts());
-        settings.Save();
-
+    if (dlg.ShowModal() == wxID_OK) {
         // Update the selections at the top
+        SFTPSettings settings;
+        settings.Load();
         wxString curselection = m_choiceAccount->GetStringSelection();
 
         m_choiceAccount->Clear();
         const SSHAccountInfo::Vect_t& accounts = settings.GetAccounts();
-        if(accounts.empty()) {
+        if (accounts.empty()) {
             DoCloseSession();
             return;
 
         } else {
-            SSHAccountInfo::Vect_t::const_iterator iter = accounts.begin();
-            for(; iter != accounts.end(); ++iter) {
-                m_choiceAccount->Append(iter->GetAccountName());
+            for (const auto& account : accounts) {
+                m_choiceAccount->Append(account.GetAccountName());
             }
 
             int where = m_choiceAccount->FindString(curselection);
-            if(where == wxNOT_FOUND) {
+            if (where == wxNOT_FOUND) {
                 // Our previous session is no longer available, close the session
                 DoCloseSession();
                 where = 0;
@@ -392,4 +405,75 @@ void SFTPBrowserDlg::OnSSHAccountManager(wxCommandEvent& event)
         }
     }
 }
+
+void SFTPBrowserDlg::ClearView()
+{
+    for (size_t i = 0; i < m_dataview->GetItemCount(); ++i) {
+        SFTPBrowserEntryClientData* cd = DoGetItemData(m_dataview->RowToItem(i));
+        wxDELETE(cd);
+    }
+    m_dataview->DeleteAllItems();
+}
+
+void SFTPBrowserDlg::DoBrowse()
+{
+    wxBusyCursor bc;
+    DoCloseSession();
+    wxString accountName = m_choiceAccount->GetStringSelection();
+
+    SFTPSettings settings;
+    settings.Load();
+
+    SSHAccountInfo account;
+    if (!settings.GetAccount(accountName, account)) {
+        ::wxMessageBox(wxString() << _("Could not find account: ") << accountName, "CodeLite", wxICON_ERROR | wxOK,
+                       this);
+        return;
+    }
+
+    clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(), account.GetKeyFiles(),
+                               account.GetPort()));
+    try {
+        wxString message;
+        EnvSetter env;
+        ssh->Open();
+        if (!ssh->AuthenticateServer(message)) {
+            if (::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
+                ssh->AcceptServerAuthentication();
+            }
+        }
+
+        ssh->Login();
+        m_sftp.reset(new clSFTP(ssh));
+        m_sftp->Initialize();
+
+        DoDisplayEntriesForPath();
+
+    } catch (const clException& e) {
+        ::wxMessageBox(e.What(), "CodeLite", wxICON_ERROR | wxOK, this);
+        DoCloseSession();
+    }
+}
+
+void SFTPBrowserDlg::OnNewFolder(wxCommandEvent& event)
+{
+    wxUnusedVar(event);
+    CHECK_PTR_RET(m_sftp);
+
+    wxString name = clGetTextFromUser(_("Create new folder"), _("Name:"));
+    if (name.empty()) {
+        return;
+    }
+
+    try {
+        wxString path;
+        path << m_sftp->GetCurrentFolder() << "/" << name;
+        m_sftp->CreateDir(path);
+        ClearView();
+        DoDisplayEntriesForPath();
+    } catch (const clException& e) {
+        ::wxMessageBox(e.What(), "CodeLite", wxICON_ERROR | wxOK, this);
+    }
+}
+
 #endif // USE_SFTP
