@@ -25,14 +25,18 @@
 #ifndef BUILD_CONFIGURATION_H
 #define BUILD_CONFIGURATION_H
 
-#include "configuration_object.h"
+#include "AsyncProcess/asyncprocess.h"
 #include "build_config_common.h"
-#include <wx/arrstr.h>
-#include <wx/string.h>
+#include "builder/builder.h"
+#include "codelite_exports.h"
+#include "compiler.h"
+#include "configuration_object.h"
+
 #include <list>
 #include <map>
-#include "compiler.h"
-#include "codelite_exports.h"
+#include <memory>
+#include <wx/arrstr.h>
+#include <wx/string.h>
 
 #ifndef WXDLLIMPEXP_LE_SDK
 #ifdef WXMAKINGDLL_LE_SDK
@@ -44,6 +48,7 @@
 #endif // WXMAKINGDLL_LE_SDK
 #endif
 
+class Project;
 class WXDLLIMPEXP_LE_SDK BuildCommand
 {
     wxString m_command;
@@ -60,14 +65,21 @@ public:
         : m_command(command)
         , m_enabled(enabled)
     {
+        // trim any whitespaces
+        m_command.Trim().Trim(false);
     }
 
-    ~BuildCommand() {}
+    ~BuildCommand() = default;
 
     const wxString& GetCommand() const { return m_command; }
+
     bool GetEnabled() const { return m_enabled; }
+
     void SetCommand(const wxString& command) { m_command = command; }
+
     void SetEnabled(bool enabled) { m_enabled = enabled; }
+
+    bool IsOk() const { return !m_command.empty(); }
 };
 
 typedef std::list<BuildCommand> BuildCommandList;
@@ -83,6 +95,7 @@ public:
     enum ePCHPolicy {
         kPCHPolicyReplace = 0,
         kPCHPolicyAppend = 1,
+        kPCHJustInclude = 2,
     };
 
 private:
@@ -139,14 +152,17 @@ private:
     wxString m_ccPCH;
     bool m_clangC11;
     bool m_clangC14;
+    bool m_clangC17;
     wxArrayString m_debuggerSearchPaths;
     bool m_isGUIProgram;
     bool m_isProjectEnabled;
     ePCHPolicy m_pchPolicy;
+    wxString m_buildSystem;
+    wxString m_buildSystemArguments;
 
 public:
     BuildConfig(wxXmlNode* node);
-    virtual ~BuildConfig();
+    virtual ~BuildConfig() = default;
     wxXmlNode* ToXml() const;
     BuildConfig* Clone() const;
 
@@ -168,6 +184,8 @@ public:
     bool IsClangC11() const { return m_clangC11; }
     void SetClangC14(bool clangC14) { this->m_clangC14 = clangC14; }
     bool IsClangC14() const { return m_clangC14; }
+    void SetClangC17(bool clangC17) { this->m_clangC17 = clangC17; }
+    bool IsClangC17() const { return m_clangC17; }
     void SetClangCcPCH(const wxString& ccPCH) { this->m_ccPCH = ccPCH; }
     const wxString& GetClangCcPCH() const { return m_ccPCH; }
     void SetCcSearchPaths(const wxString& ccSearchPaths) { this->m_ccSearchPaths = ccSearchPaths; }
@@ -211,11 +229,12 @@ public:
     const wxString& GetLinkOptions() const { return m_commonConfig.GetLinkOptions(); }
     wxString GetLibraries() const;
     wxString GetLibPath() const;
-    void GetPreBuildCommands(BuildCommandList& cmds) { cmds = m_preBuildCommands; }
-    void GetPostBuildCommands(BuildCommandList& cmds) { cmds = m_postBuildCommands; }
+    const BuildCommandList& GetPreBuildCommands() const { return m_preBuildCommands; }
+    const BuildCommandList& GetPostBuildCommands() const { return m_postBuildCommands; }
     const wxString& GetName() const { return m_name; }
     bool IsCompilerRequired() const { return m_compilerRequired; }
     bool IsLinkerRequired() const { return m_linkerRequired; }
+    wxString GetOutputDirectory() const;
     wxString GetOutputFileName() const;
     wxString GetIntermediateDirectory() const;
     const wxString& GetCommand() const { return m_command; }
@@ -272,8 +291,8 @@ public:
     }
     const wxString& GetCustomBuildWorkingDir() const { return m_customBuildWorkingDir; }
 
-    void SetPauseWhenExecEnds(const bool& pauseWhenExecEnds) { this->m_pauseWhenExecEnds = pauseWhenExecEnds; }
-    const bool& GetPauseWhenExecEnds() const { return m_pauseWhenExecEnds; }
+    void SetPauseWhenExecEnds(bool pauseWhenExecEnds) { this->m_pauseWhenExecEnds = pauseWhenExecEnds; }
+    bool GetPauseWhenExecEnds() const { return m_pauseWhenExecEnds; }
 
     void SetMakeGenerationCommand(const wxString& makeGenerationCommand)
     {
@@ -305,8 +324,8 @@ public:
     }
     const wxString& GetDebuggerStartupCmds() const { return m_debuggerStartupCmds; }
 
-    void SetIsDbgRemoteTarget(const bool& isDbgRemoteTarget) { this->m_isDbgRemoteTarget = isDbgRemoteTarget; }
-    const bool& GetIsDbgRemoteTarget() const { return m_isDbgRemoteTarget; }
+    void SetIsDbgRemoteTarget(bool isDbgRemoteTarget) { this->m_isDbgRemoteTarget = isDbgRemoteTarget; }
+    bool GetIsDbgRemoteTarget() const { return m_isDbgRemoteTarget; }
 
     void SetDbgHostName(const wxString& dbgHostName) { this->m_dbgHostName = dbgHostName; }
     void SetDbgHostPort(const wxString& dbgHostPort) { this->m_dbgHostPort = dbgHostPort; }
@@ -314,8 +333,8 @@ public:
     const wxString& GetDbgHostName() const { return m_dbgHostName; }
     const wxString& GetDbgHostPort() const { return m_dbgHostPort; }
 
-    void SetIsDbgRemoteExtended(const bool& isDbgRemoteExtended) { this->m_isDbgRemoteExtended = isDbgRemoteExtended; }
-    const bool& GetIsDbgRemoteExtended() const { return m_isDbgRemoteExtended; }
+    void SetIsDbgRemoteExtended(bool isDbgRemoteExtended) { this->m_isDbgRemoteExtended = isDbgRemoteExtended; }
+    bool GetIsDbgRemoteExtended() const { return m_isDbgRemoteExtended; }
 
     void SetCustomTargets(const BuildConfig::StringMap_t& customTargets) { this->m_customTargets = customTargets; }
     const BuildConfig::StringMap_t& GetCustomTargets() const { return m_customTargets; }
@@ -345,8 +364,31 @@ public:
     void SetEnvVarSet(const wxString& envVarSet) { this->m_envVarSet = envVarSet; }
     const wxString& GetDbgEnvSet() const { return m_dbgEnvSet; }
     const wxString& GetEnvVarSet() const { return m_envVarSet; }
+
+    void SetBuildSystem(const wxString& buildSystem) { this->m_buildSystem = buildSystem; }
+    const wxString& GetBuildSystem() const { return m_buildSystem; }
+    void SetBuildSystemArguments(const wxString& buildSystemArguments)
+    {
+        this->m_buildSystemArguments = buildSystemArguments;
+    }
+    const wxString& GetBuildSystemArguments() const { return m_buildSystemArguments; }
+
+    /**
+     * @brief return the build defined for this build configuration
+     * @return
+     */
+    BuilderPtr GetBuilder();
+
+    /**
+     * @brief build environment list for this build configuration
+     * taking into consideration:
+     * - the build configuration env
+     * - workspace env
+     * - global env
+     */
+    clEnvList_t GetEnvironment(Project* project = nullptr) const;
 };
 
-typedef SmartPtr<BuildConfig> BuildConfigPtr;
+using BuildConfigPtr = std::shared_ptr<BuildConfig>;
 
 #endif // BUILD_CONFIGURATION_H
