@@ -22,23 +22,24 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "BuilderGnuMakeMSYS.hpp"
-#include "builder.h"
-#include "builder_NMake.h"
-#include "builder_gnumake.h"
-#include "builder_gnumake_default.h"
-#include "builder_gnumake_onestep.h"
 #include "buildmanager.h"
 
+#include "builder/BuilderGnuMakeMSYS.hpp"
+#include "builder/builder.h"
+#include "builder/builder_NMake.h"
+#include "builder/builder_gnumake.h"
+#include "builder/builder_gnumake_default.h"
+#include "builder/builder_gnumake_onestep.h"
+
 BuildManager::BuildManager()
 {
     // register all builders here
-    AddBuilder(new BuilderGnuMake());
-    AddBuilder(new BuilderGNUMakeClassic());
-    AddBuilder(new BuilderGnuMakeOneStep());
+    AddBuilder(std::make_shared<BuilderGnuMake>());
+    AddBuilder(std::make_shared<BuilderGNUMakeClassic>());
+    AddBuilder(std::make_shared<BuilderGnuMakeOneStep>());
 #ifdef __WXMSW__
-    AddBuilder(new BuilderNMake());
-    AddBuilder(new BuilderGnuMakeMSYS());
+    AddBuilder(std::make_shared<BuilderNMake>());
+    AddBuilder(std::make_shared<BuilderGnuMakeMSYS>());
 #endif
 }
 
@@ -62,19 +63,15 @@ void BuildManager::RemoveBuilder(const wxString& name)
 
 void BuildManager::GetBuilders(std::list<wxString>& list)
 {
-    auto iter = m_builders.begin();
-    for(; iter != m_builders.end(); ++iter) {
-        list.push_back(iter->second->GetName());
+    for (const auto& [_, builder] : m_builders) {
+        list.push_back(builder->GetName());
     }
 }
 
 BuilderPtr BuildManager::GetBuilder(const wxString& name)
 {
-    auto iter = m_builders.begin();
-    for(; iter != m_builders.end(); ++iter) {
-        if(iter->first == name) {
-            return iter->second;
-        }
+    if (auto iter = m_builders.find(name); iter != m_builders.end()) {
+        return iter->second;
     }
 
     // return the default builder
