@@ -4,6 +4,7 @@
 #include "codelite_exports.h"
 #include "macros.h"
 #include "wxStringHash.h"
+
 #include <wx/sharedptr.h>
 #include <wx/string.h>
 
@@ -17,7 +18,7 @@ public:
 
 public:
     clBacktickCache(const wxString& directory);
-    virtual ~clBacktickCache();
+    virtual ~clBacktickCache() = default;
 
     void Save();
 
