@@ -26,42 +26,50 @@
 #ifndef CLDEBUGGERTERMINAL_H
 #define CLDEBUGGERTERMINAL_H
 
-#include <wx/string.h>
 #include "codelite_exports.h"
 
+#include <wx/defs.h>
+#include <wx/string.h>
+
 class WXDLLIMPEXP_SDK clDebuggerTerminalPOSIX
 {
     wxString m_title;
     wxString m_tty;
-    long     m_pid;
+    long m_pid = wxNOT_FOUND;
 
 public:
-    clDebuggerTerminalPOSIX();
-    virtual ~clDebuggerTerminalPOSIX();
+    clDebuggerTerminalPOSIX() = default;
+    virtual ~clDebuggerTerminalPOSIX() = default;
 
     /**
      * @brief launch the terminal. Check the IsValid() after this call
      */
-    void Launch(const wxString &title);
+    void Launch(const wxString& title);
 
     /**
      * @brief is this a valid terminal?
-     * @return
      */
     bool IsValid() const;
 
     /**
-     * @brief return the associated pty for this terminal
+     * @brief return the associated tty for this terminal
      */
-    const wxString& GetTty() const {
-        return m_tty;
-    }
+    const wxString& GetTty() const { return m_tty; }
 
     /**
      * @brief terminate the process associated with the terminal and clear the object
      * making it ready for another use
      */
     void Clear();
+
+    //! Make a console title for debugging an exe.
+    static wxString MakeExeTitle(const wxString& exePath, const wxString& args);
+
+    //! Make a console title for debugging a core file.
+    static wxString MakeCoreTitle(const wxString& coreFile);
+
+    //! Make a console title for debugging a running process.
+    static wxString MakePidTitle(int pid);
 };
 
 #endif // CLDEBUGGERTERMINAL_H
