@@ -5,6 +5,7 @@
 #include "clCustomScrollBar.h"
 #include "codelite_exports.h"
 #include "wxCustomControls.hpp"
+
 #include <wx/scrolbar.h>
 
 class WXDLLIMPEXP_SDK clScrollBar : public wxScrollBar
@@ -16,7 +17,7 @@ protected:
 public:
     clScrollBar(wxWindow* parent, wxWindowID id, const wxPoint& pos = wxDefaultPosition,
                 const wxSize& size = wxDefaultSize, long style = wxSB_VERTICAL);
-    virtual ~clScrollBar();
+    virtual ~clScrollBar() = default;
     void SetScrollbar(int position, int thumbSize, int range, int pageSize, bool refresh = true);
     bool ShouldShow() const { return (m_thumb_size < m_range_size); }
     /**
