@@ -23,24 +23,29 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "compile_request.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "ICompilerLocator.h"
+#include "build_config.h"
+#include "build_settings_config.h"
+#include "buildmanager.h"
+#include "cl_command_event.h"
+#include "compiler.h"
+#include "dirsaver.h"
+#include "environmentconfig.h"
+#include "event_notifier.h"
+#include "globals.h"
+#include "imanager.h"
+#include "macromanager.h"
+#include "macros.h"
+#include "plugin.h"
+#include "workspace.h"
+
 #include <wx/app.h>
 #include <wx/log.h>
-#include "event_notifier.h"
-#include "asyncprocess.h"
-#include "imanager.h"
-#include "macros.h"
-#include "compiler.h"
-#include "build_settings_config.h"
-#include "globals.h"
-#include "build_config.h"
-#include "environmentconfig.h"
-#include "buildmanager.h"
-#include "wx/process.h"
-#include "workspace.h"
-#include "dirsaver.h"
-#include "plugin.h"
-#include "cl_command_event.h"
-#include "ICompilerLocator.h"
+#include <wx/msgdlg.h>
+#include <wx/process.h>
+#include <wx/regex.h>
 
 CompileRequest::CompileRequest(const QueueCommand& buildInfo,
                                const wxString& fileName,
@@ -48,7 +53,6 @@ CompileRequest::CompileRequest(const QueueCommand& buildInfo,
                                bool preprocessOnly)
     : ShellCommand(buildInfo)
     , m_fileName(fileName)
-    , m_premakeOnly(runPremakeOnly)
     , m_preprocessOnly(preprocessOnly)
 {
 }
@@ -66,38 +70,35 @@ void CompileRequest::Process(IManager* manager)
     wxStringMap_t om;
 
     BuildSettingsConfig* bsc(manager ? manager->GetBuildSettingsConfigManager() : BuildSettingsConfigST::Get());
-    BuildManager* bm(manager ? manager->GetBuildManager() : BuildManagerST::Get());
     clCxxWorkspace* w(manager ? manager->GetWorkspace() : clCxxWorkspaceST::Get());
     EnvironmentConfig* env(manager ? manager->GetEnv() : EnvironmentConfig::Instance());
 
     ProjectPtr proj = w->FindProjectByName(m_info.GetProject(), errMsg);
-    if(!proj) {
+    if (!proj) {
         AppendLine(_("Cant find project: ") + m_info.GetProject());
         return;
     }
 
     wxString pname(proj->GetName());
-    // BuilderPtr builder = bm->GetBuilder(wxT("GNU makefile for g++/gcc"));
-    BuilderPtr builder = bm->GetSelectedBuilder();
-    if(m_fileName.IsEmpty() == false) {
-        // we got a complie request of a single file
-        cmd = m_preprocessOnly ?
-                  builder->GetPreprocessFileCmd(m_info.GetProject(), m_info.GetConfiguration(), m_fileName, errMsg) :
-                  builder->GetSingleFileCmd(m_info.GetProject(), m_info.GetConfiguration(), m_fileName);
-    } else if(m_info.GetProjectOnly()) {
-
-        switch(m_info.GetKind()) {
-        case QueueCommand::kRebuild:
-            cmd = builder->GetPORebuildCommand(m_info.GetProject(), m_info.GetConfiguration());
-            break;
-        default:
-        case QueueCommand::kBuild:
-            cmd = builder->GetPOBuildCommand(m_info.GetProject(), m_info.GetConfiguration());
-            break;
+    const wxArrayString unresolvedVars = proj->GetUnresolvedMacros(m_info.GetConfiguration());
+    if (!unresolvedVars.IsEmpty()) {
+        // We can't continue
+        wxString msg;
+        msg << _("The following environment variables are used in the project, but are not defined:\n");
+        for (size_t i = 0; i < unresolvedVars.size(); ++i) {
+            msg << unresolvedVars.Item(i) << "\n";
+        }
+        msg << _("Build anyway?");
+        wxStandardID res = ::PromptForYesNoDialogWithCheckbox(msg,
+                                                              "UnresolvedMacros",
+                                                              _("Yes"),
+                                                              _("No"),
+                                                              _("Remember my answer and don't ask me again"),
+                                                              wxYES_NO | wxICON_WARNING | wxYES_DEFAULT);
+        if (res != wxID_YES) {
+            ::wxMessageBox(_("Build Cancelled!"), "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
+            return;
         }
-
-    } else {
-        cmd = builder->GetBuildCommand(m_info.GetProject(), m_info.GetConfiguration());
     }
 
     // Notify plugins that a compile process is going to start
@@ -105,7 +106,7 @@ void CompileRequest::Process(IManager* manager)
     event.SetProjectName(pname);
     event.SetConfigurationName(m_info.GetConfiguration());
 
-    if(EventNotifier::Get()->ProcessEvent(event)) {
+    if (EventNotifier::Get()->ProcessEvent(event)) {
 
         // the build is being handled by some plugin, no need to build it
         // using the standard way
@@ -114,22 +115,40 @@ void CompileRequest::Process(IManager* manager)
 
     // Send the EVENT_STARTED : even if this event is sent, next event will
     // be post, so no way to be sure the the build process has not started
-    SendStartMsg();
+    BuildConfigPtr bldConf = w->GetProjBuildConf(m_info.GetProject(), m_info.GetConfiguration());
+    SendStartMsg(bldConf ? bldConf->GetCompilerType() : wxString());
 
     // if we require to run the makefile generation command only, replace the 'cmd' with the
     // generation command line
-    BuildConfigPtr bldConf = w->GetProjBuildConf(m_info.GetProject(), m_info.GetConfiguration());
-    if(m_premakeOnly && bldConf) {
-        BuildConfigPtr bldConf = w->GetProjBuildConf(m_info.GetProject(), m_info.GetConfiguration());
-        if(bldConf) {
-            cmd = bldConf->GetMakeGenerationCommand();
+    if (bldConf) {
+        // BuilderPtr builder = bm->GetBuilder("Default");
+        BuilderPtr builder = bldConf->GetBuilder();
+        wxString args = bldConf->GetBuildSystemArguments();
+        if (m_fileName.IsEmpty() == false) {
+            // we got a complie request of a single file
+            cmd = m_preprocessOnly
+                      ? builder->GetPreprocessFileCmd(
+                            m_info.GetProject(), m_info.GetConfiguration(), args, m_fileName, errMsg)
+                      : builder->GetSingleFileCmd(m_info.GetProject(), m_info.GetConfiguration(), args, m_fileName);
+        } else if (m_info.GetProjectOnly()) {
+
+            switch (m_info.GetKind()) {
+            case QueueCommand::kRebuild:
+                cmd = builder->GetPORebuildCommand(m_info.GetProject(), m_info.GetConfiguration(), args);
+                break;
+            default:
+            case QueueCommand::kBuild:
+                cmd = builder->GetPOBuildCommand(m_info.GetProject(), m_info.GetConfiguration(), args);
+                break;
+            }
+
+        } else {
+            cmd = builder->GetBuildCommand(m_info.GetProject(), m_info.GetConfiguration(), args);
         }
-    }
 
-    if(bldConf) {
         wxString cmpType = bldConf->GetCompilerType();
         CompilerPtr cmp = bsc->GetCompiler(cmpType);
-        if(cmp) {
+        if (cmp) {
             // Add the 'bin' folder of the compiler to the PATH environment variable
             wxString scxx = cmp->GetTool("CXX");
             scxx.Trim().Trim(false);
@@ -139,9 +158,9 @@ void CompileRequest::Process(IManager* manager)
             wxFileName cxx(scxx);
             wxString pathvar;
             pathvar << cxx.GetPath() << clPATH_SEPARATOR;
-            
+
             // If we have an additional path, add it as well
-            if(!cmp->GetPathVariable().IsEmpty()) {
+            if (!cmp->GetPathVariable().IsEmpty()) {
                 pathvar << cmp->GetPathVariable() << clPATH_SEPARATOR;
             }
             pathvar << "$PATH";
@@ -149,9 +168,9 @@ void CompileRequest::Process(IManager* manager)
         }
     }
 
-    if(cmd.IsEmpty()) {
+    if (cmd.IsEmpty()) {
         // if we got an error string, use it
-        if(errMsg.IsEmpty() == false) {
+        if (errMsg.IsEmpty() == false) {
             AppendLine(errMsg);
         } else {
             AppendLine(_("Command line is empty. Build aborted."));
@@ -159,9 +178,7 @@ void CompileRequest::Process(IManager* manager)
         return;
     }
 
-    WrapInShell(cmd);
     DirSaver ds;
-
     DoSetWorkingDirectory(proj, false, m_fileName.IsEmpty() == false);
 
     // expand the variables of the command
@@ -169,36 +186,36 @@ void CompileRequest::Process(IManager* manager)
 
     // print the build command
     AppendLine(cmd + wxT("\n"));
-    if(m_info.GetProjectOnly() || m_fileName.IsEmpty() == false) {
+    if (m_info.GetProjectOnly() || m_fileName.IsEmpty() == false) {
         // set working directory
         DoSetWorkingDirectory(proj, false, m_fileName.IsEmpty() == false);
     }
 
     // print the prefix message of the build start. This is important since the parser relies
     // on this message
-    if(m_info.GetProjectOnly() || m_fileName.IsEmpty() == false) {
+    if (m_info.GetProjectOnly() || m_fileName.IsEmpty() == false) {
         wxString configName(m_info.GetConfiguration());
 
         // also, send another message to the main frame, indicating which project is being built
         // and what configuration
         wxString text;
-        text << wxGetTranslation(BUILD_PROJECT_PREFIX) << m_info.GetProject() << wxT(" - ") << configName << wxT(" ]");
-        if(m_fileName.IsEmpty()) {
+        text << BUILD_PROJECT_PREFIX << m_info.GetProject() << wxT(" - ") << configName << wxT(" ]");
+        if (m_fileName.IsEmpty()) {
             text << wxT("----------\n");
-        } else if(m_preprocessOnly) {
+        } else if (m_preprocessOnly) {
             text << wxT(" (Preprocess Single File)----------\n");
         } else {
             text << wxT(" (Single File Build)----------\n");
         }
         AppendLine(text);
     }
-    
+
     // Avoid Unicode chars coming from the compiler by setting LC_ALL to "C"
     om["LC_ALL"] = "C";
-    
+    om["TERM"] = "xterm-256color"; // this will allow coloured output from the compiler
+
     EnvSetter envir(env, &om, proj->GetName(), m_info.GetConfiguration());
-    m_proc = CreateAsyncProcess(this, cmd);
-    if(!m_proc) {
+    if (!StartProcess(cmd, IProcessCreateDefault | IProcessWrapInShell)) {
         wxString message;
         message << _("Failed to start build process, command: ") << cmd << _(", process terminated with exit code: 0");
         AppendLine(message);
