@@ -25,13 +25,19 @@
 #ifndef COMPILER_H
 #define COMPILER_H
 
-#include "configuration_object.h"
-#include "smart_ptr.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "GCCMetadata.hpp"
 #include "codelite_exports.h"
-#include <map>
+#include "configuration_object.h"
+
 #include <list>
-#include <wx/arrstr.h>
+#include <map>
+#include <memory>
 #include <vector>
+#include <wx/arrstr.h>
+#include <wx/clntdata.h>
+#include <wx/regex.h>
+#include <wx/string.h>
 
 /**
  * \ingroup LiteEditor
@@ -47,7 +53,7 @@
 class WXDLLIMPEXP_SDK Compiler : public ConfObject
 {
 public:
-    enum { eErrorPattern, eWarningPattern };
+    enum eSeverity { kSevError, kSevWarning, kSevNote };
 
     enum CmpFileKind { CmpFileKindSource, CmpFileKindResource };
 
@@ -68,17 +74,32 @@ public:
         wxString lineNumberIndex;
         wxString fileNameIndex;
         wxString columnIndex;
+        std::shared_ptr<wxRegEx> re;
+    };
+
+    /// If a file matches a regular expression, this structure
+    /// will hold the information about it
+    struct PatternMatch : public wxClientData {
+        wxString file_path;
+        Compiler::eSeverity sev = kSevError;
+        int line_number = wxNOT_FOUND;
+        int column = wxNOT_FOUND;
+    };
+
+    struct LinkLine {
+        wxString lineFromFile;
+        wxString line;
     };
 
     enum eRegexType { kRegexVC = 0, kRegexGNU };
     typedef std::list<CmpInfoPattern> CmpListInfoPattern;
 
 private:
-    void AddCmpFileType(const wxString& extension, CmpFileKind type, const wxString& compile_line);
-    void
-    AddPattern(int type, const wxString& pattern, int fileNameIndex, int lineNumberIndex, int colIndex = wxNOT_FOUND);
-    void AddDefaultGnuComplierOptions();
+    void AddPattern(int type, const wxString& pattern, int fileNameIndex, int lineNumberIndex,
+                    int colIndex = wxNOT_FOUND);
+    void AddDefaultGnuCompilerOptions();
     void AddDefaultGnuLinkerOptions();
+    void AddDefaultGnuCompilerLinkerOptions();
 
 protected:
     wxString m_name;
@@ -95,24 +116,33 @@ protected:
     wxString m_globalIncludePath;
     wxString m_globalLibPath;
     wxString m_pathVariable;
-    bool m_generateDependeciesFile;
+    bool m_generateDependenciesFile;
     bool m_readObjectFilesFromList;
     bool m_objectNameIdenticalToFileName;
     wxString m_compilerFamily;
     bool m_isDefault;
     wxString m_installationPath;
-    wxArrayString m_compilerBuiltinDefinitions;
+    std::map<wxString, LinkLine> m_linkerLines;
 
 private:
-    wxString GetGCCVersion() const;
-    wxString GetIncludePath(const wxString& pathSuffix) const;
-    wxArrayString POSIXGetIncludePaths() const;
+    bool IsMatchesPattern(CmpInfoPattern& pattern, eSeverity severity, const wxString& line,
+                          PatternMatch* match_result) const;
 
 public:
     typedef std::map<wxString, wxString>::const_iterator ConstIterator;
 
     Compiler(wxXmlNode* node, Compiler::eRegexType regexType = Compiler::kRegexGNU);
-    virtual ~Compiler();
+    virtual ~Compiler() = default;
+
+    /**
+     * @brief attempt to parse line and provide details about the parsed data
+     */
+    bool Matches(const wxString& line, PatternMatch* match_result);
+
+    /**
+     * @brief return { "PATH", "/compiler/bin:$PATH"} pair
+     */
+    void CreatePathEnv(clEnvList_t* env_list);
 
     /**
      * @brief return the compiler default include paths
@@ -140,12 +170,10 @@ public:
 
     void AddCompilerOption(const wxString& name, const wxString& desc);
     void AddLinkerOption(const wxString& name, const wxString& desc);
+    void AddCompilerLinkerOption(const wxString& name, const wxString& desc);
 
-    /**
-     * @brief return list of builtin macros for this compiler instance
-     * @return
-     */
-    const wxArrayString& GetBuiltinMacros();
+    wxString GetLinkLine(const wxString& type, bool inputFromFile) const;
+    void SetLinkLine(const wxString& type, const wxString& line, bool inputFromFile);
 
     //---------------------------------------------------
     // setters/getters
@@ -183,6 +211,8 @@ public:
     }
 
     const std::map<wxString, Compiler::CmpFileTypeInfo>& GetFileTypes() const { return m_fileTypes; }
+    const std::map<wxString, LinkLine>& GetLinkerLines() const { return m_linkerLines; }
+    void SetLinkerLines(const std::map<wxString, LinkLine>& lines) { m_linkerLines = lines; }
 
     const CmpCmdLineOptions& GetCompilerOptions() const { return m_compilerOptions; }
 
@@ -192,25 +222,35 @@ public:
 
     void SetLinkerOptions(const CmpCmdLineOptions& cmpOptions) { m_linkerOptions = cmpOptions; }
 
-    void SetGenerateDependeciesFile(const bool& generateDependeciesFile)
+    void SetGenerateDependenciesFile(bool generateDependenciesFile)
     {
-        this->m_generateDependeciesFile = generateDependeciesFile;
+        this->m_generateDependenciesFile = generateDependenciesFile;
     }
-    const bool& GetGenerateDependeciesFile() const { return m_generateDependeciesFile; }
+    bool GetGenerateDependenciesFile() const { return IsGnuCompatibleCompiler() && m_generateDependenciesFile; }
     void SetReadObjectFilesFromList(bool readObjectFilesFromList)
     {
         this->m_readObjectFilesFromList = readObjectFilesFromList;
     }
     bool GetReadObjectFilesFromList() const { return m_readObjectFilesFromList; }
+    void AddCmpFileType(const wxString& extension, CmpFileKind type, const wxString& compile_line);
     bool GetCmpFileType(const wxString& extension, Compiler::CmpFileTypeInfo& ft);
     void SetObjectNameIdenticalToFileName(bool objectNameIdenticalToFileName)
     {
         this->m_objectNameIdenticalToFileName = objectNameIdenticalToFileName;
     }
     bool GetObjectNameIdenticalToFileName() const { return m_objectNameIdenticalToFileName; }
+    /**
+     * @brief return the compiler metadata info
+     */
+    GCCMetadata GetMetadata() const;
+
+    /**
+     * @brief does this compiler support metadata object?
+     */
+    bool HasMetadata() const;
 };
 
-typedef SmartPtr<Compiler> CompilerPtr;
-typedef std::vector<CompilerPtr> CompilerPtrVec_t;
+using CompilerPtr = std::shared_ptr<Compiler>;
+using CompilerPtrVec_t = std::vector<CompilerPtr>;
 
 #endif // COMPILER_H
