@@ -25,12 +25,13 @@
 #ifndef CONFIGURATION_MAPPING_H
 #define CONFIGURATION_MAPPING_H
 
-#include "wx/string.h"
-#include "wx/xml/xml.h"
-#include "list"
-#include "smart_ptr.h"
 #include "codelite_exports.h"
 
+#include <list>
+#include <memory>
+#include <wx/string.h>
+#include <wx/xml/xml.h>
+
 class WXDLLIMPEXP_SDK ConfigMappingEntry
 {
 public:
@@ -50,7 +51,7 @@ public:
     {
     }
 
-    virtual ~ConfigMappingEntry() {}
+    virtual ~ConfigMappingEntry() = default;
 };
 
 class WXDLLIMPEXP_SDK WorkspaceConfiguration
@@ -61,48 +62,51 @@ public:
 private:
     wxString m_name;
     ConfigMappingList m_mappingList;
-    bool m_isSelected;
+    wxString m_environmentVariables;
 
 public:
-    void RenameProject(const wxString &oldname, const wxString &newname);
+    void RenameProject(const wxString& oldname, const wxString& newname);
     WorkspaceConfiguration();
     WorkspaceConfiguration(wxXmlNode* node);
-    WorkspaceConfiguration(const wxString& name, bool selected);
-    virtual ~WorkspaceConfiguration();
+    WorkspaceConfiguration(const wxString& name);
+    virtual ~WorkspaceConfiguration() = default;
     wxXmlNode* ToXml() const;
 
-    void SetSelected(bool selected) { m_isSelected = selected; }
-    bool IsSelected() const { return m_isSelected; }
     const wxString& GetName() const { return m_name; }
     const ConfigMappingList& GetMapping() const { return m_mappingList; }
     void SetConfigMappingList(const ConfigMappingList& mapList) { m_mappingList = mapList; }
     void SetName(const wxString& name) { m_name = name; }
+    const wxString& GetEnvironmentVariables() const { return m_environmentVariables; }
+    void SetEnvironmentVariables(const wxString& environmentVariables)
+    {
+        this->m_environmentVariables = environmentVariables;
+    }
 };
 
-typedef SmartPtr<WorkspaceConfiguration> WorkspaceConfigurationPtr;
+using WorkspaceConfigurationPtr = std::shared_ptr<WorkspaceConfiguration>;
 
 class WXDLLIMPEXP_SDK BuildMatrix
 {
     std::list<WorkspaceConfigurationPtr> m_configurationList;
+    wxString m_selectedConfiguration;
 
 protected:
     WorkspaceConfigurationPtr FindConfiguration(const wxString& name) const;
+    void SelectFirstConfiguration();
 
 public:
-    void RenameProject(const wxString &oldname, const wxString &newname);
-    
-    BuildMatrix(wxXmlNode* node);
-    virtual ~BuildMatrix();
+    BuildMatrix(wxXmlNode* node, const wxString& selectedConfiguration);
+    virtual ~BuildMatrix() = default;
     wxXmlNode* ToXml() const;
-    const std::list<WorkspaceConfigurationPtr>& GetConfigurations() const { return m_configurationList; };
+    const std::list<WorkspaceConfigurationPtr>& GetConfigurations() const { return m_configurationList; }
     void RemoveConfiguration(const wxString& configName);
     void SetConfiguration(WorkspaceConfigurationPtr conf);
     wxString GetProjectSelectedConf(const wxString& configName, const wxString& project) const;
-    wxString GetSelectedConfigurationName() const;
+    wxString GetSelectedConfigurationName() const { return m_selectedConfiguration; }
     void SetSelectedConfigurationName(const wxString& name);
     WorkspaceConfigurationPtr GetConfigurationByName(const wxString& name) const;
 };
 
-typedef SmartPtr<BuildMatrix> BuildMatrixPtr;
+using BuildMatrixPtr = std::shared_ptr<BuildMatrix>;
 
 #endif // CONFIGURATION_MAPPING_H
