@@ -23,22 +23,19 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "configurationtoolbase.h"
-#include "editor_config.h"
-#include "xmlutils.h"
-#include "serialized_object.h"
-#include <wx/stdpaths.h>
-#include "wx/filename.h"
-#include "wx/ffile.h"
+
 #include "cl_standard_paths.h"
-#include "globals.h"
+#include "serialized_object.h"
+#include "xmlutils.h"
+
+#include <wx/ffile.h>
+#include <wx/filename.h>
 
 ConfigurationToolBase::ConfigurationToolBase()
     : m_fileName(wxEmptyString)
 {
 }
 
-ConfigurationToolBase::~ConfigurationToolBase() {}
-
 bool ConfigurationToolBase::Load(const wxString& fileName)
 {
     // Try to open the file from the user data settings first
@@ -65,8 +62,9 @@ bool ConfigurationToolBase::WriteObject(const wxString& name, SerializedObject*
         return false;
     }
 
-    if(!XmlUtils::StaticWriteObject(m_doc.GetRoot(), name, obj)) return false;
-    return ::SaveXmlToFile(&m_doc, m_fileName);
+    if(!XmlUtils::StaticWriteObject(m_doc.GetRoot(), name, obj))
+        return false;
+    return XmlUtils::SaveXmlToFile(&m_doc, m_fileName);
 }
 
 bool ConfigurationToolBase::ReadObject(const wxString& name, SerializedObject* obj)
