@@ -25,17 +25,18 @@
 #ifndef LITEEDITOR_EDITOR_CONFIG_H
 #define LITEEDITOR_EDITOR_CONFIG_H
 
-#include "singleton.h"
-#include <wx/filename.h>
-#include <vector>
-#include "wx/xml/xml.h"
+#include "cl_config.h"
+#include "codelite_exports.h"
 #include "lexer_configuration.h"
 #include "optionsconfig.h"
-#include "map"
-#include "serialized_object.h"
 #include "plugin.h"
-#include "codelite_exports.h"
-#include "cl_config.h"
+#include "serialized_object.h"
+#include "singleton.h"
+
+#include <map>
+#include <vector>
+#include <wx/filename.h>
+#include <wx/xml/xml.h>
 
 enum {
     View_Show_Workspace_Tab = 0x00000001,
@@ -45,21 +46,27 @@ enum {
     View_Show_Default = View_Show_Workspace_Tab | View_Show_Explorer_Tab | View_Show_Tabs_Tab | View_Show_Tabgroups_Tab
 };
 
+// Helper macro for getting the correct wxMBConv object from the user settings
+#define clMBConv(converter)                                                                                  \
+    wxCSConv __fontEncConv(EditorConfigST::Get()->GetOptions()->GetFileFontEncoding());                      \
+    bool __useBuiltIn = (EditorConfigST::Get()->GetOptions()->GetFileFontEncoding() == wxFONTENCODING_UTF8); \
+    wxMBConv* converter = (__useBuiltIn ? (wxMBConv*)&wxConvUTF8 : (wxMBConv*)&__fontEncConv);
+
 class WXDLLIMPEXP_SDK SimpleLongValue : public SerializedObject
 {
     long m_value;
 
 public:
-    SimpleLongValue();
-    ~SimpleLongValue();
+    SimpleLongValue() = default;
+    ~SimpleLongValue() = default;
 
     void DeSerialize(Archive& arch);
     void Serialize(Archive& arch);
 
     // Setters
-    void SetValue(const long& value) { this->m_value = value; }
+    void SetValue(long value) { this->m_value = value; }
     // Getters
-    const long& GetValue() const { return m_value; }
+    long GetValue() const { return m_value; }
 };
 
 class WXDLLIMPEXP_SDK SimpleStringValue : public SerializedObject
@@ -67,8 +74,8 @@ class WXDLLIMPEXP_SDK SimpleStringValue : public SerializedObject
     wxString m_value;
 
 public:
-    SimpleStringValue();
-    ~SimpleStringValue();
+    SimpleStringValue() = default;
+    ~SimpleStringValue() = default;
 
     void DeSerialize(Archive& arch);
     void Serialize(Archive& arch);
@@ -82,8 +89,8 @@ class WXDLLIMPEXP_SDK SimpleRectValue : public SerializedObject
     wxRect m_rect;
 
 public:
-    SimpleRectValue();
-    ~SimpleRectValue();
+    SimpleRectValue() = default;
+    ~SimpleRectValue() = default;
 
     void DeSerialize(Archive& arch);
     void Serialize(Archive& arch);
@@ -153,18 +160,6 @@ public:
      */
     LexerConf::Ptr_t GetLexerForFile(const wxString& filename);
 
-    /**
-     * Get the outputview's foreground colour, which is global to a theme
-     * \return the colour as a wxString
-     */
-    wxString GetCurrentOutputviewFgColour() const;
-
-    /**
-     * Get the outputview's background colour, which is global to a theme
-     * \return the colour as a wxString
-     */
-    wxString GetCurrentOutputviewBgColour() const;
-
     /**
      * Test if this configuration is loaded properly
      * \return true of a file is loaded into the configuration manager false otherwise
@@ -182,33 +177,6 @@ public:
      */
     void SetOptions(OptionsConfigPtr opts);
 
-    /**
-     * Return the database that should be used by the editor
-     * \return
-     */
-    wxString GetTagsDatabase() const;
-
-    /**
-     * Set tags database to be use by editor (in addition to the workspace one)
-     * \param &dbName
-     */
-    void SetTagsDatabase(const wxString& dbName);
-
-    /**
-     * Store in the current LexersInfo, the outputview's foreground colour as it's global to a theme
-     */
-    void SetCurrentOutputviewFgColour(const wxString& colourstring);
-
-    /**
-     * Store in the current LexersInfo, the outputview's background colour as it's global to a theme
-     */
-    void SetCurrentOutputviewBgColour(const wxString& colourstring);
-
-    /**
-     * save lexers settings
-     */
-    void SaveLexers();
-
     /**
      * get an array of recently opened items e.g. workspaces
      * \param files  [output] a place holder for the output
@@ -237,26 +205,17 @@ public:
      */
     virtual bool ReadObject(const wxString& name, SerializedObject* obj);
 
-    /**
-     * Return the configuration version
-     */
-    wxString GetRevision() const;
-
-    /**
-     * Set the current configuration revision
-     */
-    void SetRevision(const wxString& rev);
     void SetInstallDir(const wxString& instlDir);
 
     /**
-     * \brief convinience methods to store a single long value
+     * \brief convenience methods to store a single long value
      * \param name variable name
      * \param value value to store
      */
     void SetInteger(const wxString& name, long value);
 
     /**
-     * \brief convinience methods to retrieve a single long value stored using
+     * \brief convenience methods to retrieve a single long value stored using
      * the 'SaveLongValue()' method
      * \param name variable name
      * \param value value
@@ -266,7 +225,7 @@ public:
 
     /**
      * \brief get string from the configuration identified by key
-     * \param key key identifiying the string
+     * \param key key identifying the string
      * \return wxEmptyString or the value
      */
     wxString GetString(const wxString& key, const wxString& defaultValue = "");
@@ -295,7 +254,6 @@ public:
 private:
     EditorConfig();
     virtual ~EditorConfig();
-    wxXmlNode* GetLexerNode(const wxString& lexer);
 };
 
 class WXDLLIMPEXP_SDK EditorConfigST
