@@ -22,24 +22,31 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "open_resource_dialog.h"
 
+#include "ColoursAndFontsManager.h"
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
+#include "LSP/LSPManager.hpp"
 #include "bitmap_loader.h"
-#include "clFileSystemWorkspace.hpp"
+#include "clWorkspaceManager.h"
+#include "codelite_events.h"
 #include "ctags_manager.h"
 #include "editor_config.h"
 #include "event_notifier.h"
+#include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
 #include "ieditor.h"
 #include "imanager.h"
-#include "open_resource_dialog.h"
+#include "macros.h"
 #include "project.h"
 #include "window_locker.h"
 #include "windowattrmanager.h"
 #include "workspace.h"
+
 #include <algorithm>
-#include <codelite_events.h>
 #include <vector>
+#include <wx/event.h>
 #include <wx/filefn.h>
 #include <wx/imaglist.h>
 #include <wx/wupdlock.h>
@@ -49,70 +56,79 @@ BEGIN_EVENT_TABLE(OpenResourceDialog, OpenResourceDialogBase)
 EVT_TIMER(XRCID("OR_TIMER"), OpenResourceDialog::OnTimer)
 END_EVENT_TABLE()
 
+wxDEFINE_EVENT(wxEVT_OPEN_RESOURCE_FILE_SELECTED, clCommandEvent);
+
 OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, const wxString& initialSelection)
     : OpenResourceDialogBase(parent)
     , m_manager(manager)
     , m_needRefresh(false)
     , m_lineNumber(wxNOT_FOUND)
 {
+    m_dataview->SetSortFunction(nullptr);
     m_dataview->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
+    auto lexer = ColoursAndFontsManager::Get().GetLexer("text");
+    if (lexer) {
+        m_dataview->SetDefaultFont(lexer->GetFontForStyle(0, m_dataview));
+    }
+    EventNotifier::Get()->Bind(wxEVT_LSP_WORKSPACE_SYMBOLS, &OpenResourceDialog::OnWorkspaceSymbols, this);
 
     // initialize the file-type hash
-    m_fileTypeHash["class"] = BitmapLoader::kClass;
-    m_fileTypeHash["struct"] = BitmapLoader::kStruct;
-    m_fileTypeHash["namespace"] = BitmapLoader::kNamespace;
-    m_fileTypeHash["variable"] = BitmapLoader::kMemberPublic;
-    m_fileTypeHash["typedef"] = BitmapLoader::kTypedef;
-    m_fileTypeHash["member_private"] = BitmapLoader::kMemberPrivate;
-    m_fileTypeHash["member_public"] = BitmapLoader::kMemberPublic;
-    m_fileTypeHash["member_protected"] = BitmapLoader::kMemberProtected;
-    m_fileTypeHash["member_protected"] = BitmapLoader::kMemberProtected;
-    m_fileTypeHash["member"] = BitmapLoader::kMemberPublic;
-    m_fileTypeHash["function"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["function_private"] = BitmapLoader::kFunctionPrivate;
-    m_fileTypeHash["function_public"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["function_protected"] = BitmapLoader::kFunctionProtected;
-    m_fileTypeHash["prototype"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["prototype_public"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["prototype_private"] = BitmapLoader::kFunctionPrivate;
-    m_fileTypeHash["prototype_protected"] = BitmapLoader::kFunctionProtected;
-    m_fileTypeHash["method"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["method_public"] = BitmapLoader::kFunctionPublic;
-    m_fileTypeHash["method_private"] = BitmapLoader::kFunctionPrivate;
-    m_fileTypeHash["method_protected"] = BitmapLoader::kFunctionProtected;
-    m_fileTypeHash["macro"] = BitmapLoader::kMacro;
-    m_fileTypeHash["enum"] = BitmapLoader::kEnum;
-    m_fileTypeHash["enumerator"] = BitmapLoader::kEnumerator;
+    m_fileTypeHash[LSP::kSK_Class] = BitmapLoader::kClass;
+    m_fileTypeHash[LSP::kSK_Struct] = BitmapLoader::kStruct;
+    m_fileTypeHash[LSP::kSK_Namespace] = BitmapLoader::kNamespace;
+    m_fileTypeHash[LSP::kSK_Variable] = BitmapLoader::kMemberPublic;
+    m_fileTypeHash[LSP::kSK_TypeParameter] = BitmapLoader::kTypedef;
+    m_fileTypeHash[LSP::kSK_Property] = BitmapLoader::kMemberPublic;
+    m_fileTypeHash[LSP::kSK_Function] = BitmapLoader::kFunctionPublic;
+    m_fileTypeHash[LSP::kSK_Method] = BitmapLoader::kFunctionPublic;
+    m_fileTypeHash[LSP::kSK_Constructor] = BitmapLoader::kFunctionPublic;
+    m_fileTypeHash[LSP::kSK_TypeParameter] = BitmapLoader::kMacro;
+    m_fileTypeHash[LSP::kSK_Enum] = BitmapLoader::kEnum;
+    m_fileTypeHash[LSP::kSK_EnumMember] = BitmapLoader::kEnumerator;
 
     m_timer = new wxTimer(this, XRCID("OR_TIMER"));
 
     m_textCtrlResourceName->SetFocus();
     SetLabel(_("Open resource..."));
-
     SetName("OpenResourceDialog");
-    WindowAttrManager::Load(this);
 
     // load all files from the workspace
-    if(::clIsCxxWorkspaceOpened()) {
-        if(m_manager->IsWorkspaceOpen()) {
+    if (::clIsCxxWorkspaceOpened()) {
+        if (m_manager->IsWorkspaceOpen()) {
             wxArrayString projects;
             m_manager->GetWorkspace()->GetProjectList(projects);
 
-            for(size_t i = 0; i < projects.GetCount(); i++) {
+            for (size_t i = 0; i < projects.GetCount(); i++) {
                 ProjectPtr p = m_manager->GetWorkspace()->GetProject(projects.Item(i));
-                if(p) {
+                if (p) {
                     const Project::FilesMap_t& files = p->GetFiles();
                     // convert std::vector to wxArrayString
-                    std::for_each(files.begin(), files.end(), [&](const Project::FilesMap_t::value_type& vt) {
-                        wxFileName fn(vt.second->GetFilename());
+                    for (const auto& p : files) {
+                        wxFileName fn(p.second->GetFilename());
                         m_files.insert(std::make_pair(fn.GetFullName(), fn.GetFullPath()));
-                    });
+                    }
                 }
             }
-        } else if(clFileSystemWorkspace::Get().IsOpen()) {
+        } else if (clFileSystemWorkspace::Get().IsOpen()) {
             const std::vector<wxFileName>& files = clFileSystemWorkspace::Get().GetFiles();
-            for(const wxFileName& fn : files) {
-                m_files.insert({ fn.GetFullName(), fn.GetFullPath() });
+            for (const wxFileName& fn : files) {
+                m_files.insert({fn.GetFullName(), fn.GetFullPath()});
+            }
+        }
+    } else if (clWorkspaceManager::Get().IsWorkspaceOpened()) {
+        // the workspace API to get list of files
+        wxArrayString files;
+        clWorkspaceManager::Get().GetWorkspace()->GetWorkspaceFiles(files);
+        wxStringSet_t unique_files;
+        m_files.reserve(files.size());
+        for (const auto& file : files) {
+            if (unique_files.count(file) == 0) {
+                unique_files.insert(file);
+                wxFileName fn(file);
+                // keep the file as-is do not "format" it by calling
+                // fn.GetFullPath() since we might be on Windows and we display
+                // Linux path style files
+                m_files.insert({fn.GetFullName(), file});
             }
         }
     }
@@ -120,19 +136,30 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     wxString lastStringTyped = clConfig::Get().Read("OpenResourceDialog/SearchString", wxString());
     // Set the initial selection
     // We use here 'SetValue' so an event will get fired and update the control
-    if(!initialSelection.IsEmpty()) {
-        m_textCtrlResourceName->SetValue(initialSelection);
-        m_textCtrlResourceName->SelectAll();
-    } else if(!lastStringTyped.IsEmpty()) {
-        m_textCtrlResourceName->SetValue(lastStringTyped);
-        m_textCtrlResourceName->SelectAll();
+    bool filter_results{false};
+    if (!initialSelection.IsEmpty()) {
+        m_textCtrlResourceName->ChangeValue(initialSelection);
+        CallAfter(&OpenResourceDialog::OnSelectAllText);
+        filter_results = true;
+    } else if (!lastStringTyped.IsEmpty()) {
+        m_textCtrlResourceName->ChangeValue(lastStringTyped);
+        CallAfter(&OpenResourceDialog::OnSelectAllText);
+        filter_results = true;
+    }
+
+    if (filter_results) {
+        // Trigger list filtering
+        wxTimerEvent dummy_event{*m_timer};
+        OnTimer(dummy_event);
     }
 
     bool showFiles = clConfig::Get().Read("OpenResourceDialog/ShowFiles", true);
     bool showSymbols = clConfig::Get().Read("OpenResourceDialog/ShowSymbols", true);
     m_checkBoxFiles->SetValue(showFiles);
     m_checkBoxShowSymbols->SetValue(showSymbols);
+
     ::clSetDialogBestSizeAndPosition(this);
+    MSWSetWindowDarkTheme(this);
 }
 
 OpenResourceDialog::~OpenResourceDialog()
@@ -140,6 +167,8 @@ OpenResourceDialog::~OpenResourceDialog()
     m_timer->Stop();
     wxDELETE(m_timer);
 
+    EventNotifier::Get()->Unbind(wxEVT_LSP_WORKSPACE_SYMBOLS, &OpenResourceDialog::OnWorkspaceSymbols, this);
+
     // Store current values
     clConfig::Get().Write("OpenResourceDialog/ShowFiles", m_checkBoxFiles->IsChecked());
     clConfig::Get().Write("OpenResourceDialog/ShowSymbols", m_checkBoxShowSymbols->IsChecked());
@@ -169,89 +198,82 @@ void OpenResourceDialog::OnEntryActivated(wxDataViewEvent& event)
     CHECK_ITEM_RET(event.GetItem());
     OpenResourceDialogItemData* data =
         reinterpret_cast<OpenResourceDialogItemData*>(m_dataview->GetItemData(event.GetItem()));
-    if(data) {
+    if (data) {
         EndModal(wxID_OK);
     }
 }
 
 void OpenResourceDialog::DoPopulateList()
 {
+    Clear();
     wxString name = m_textCtrlResourceName->GetValue();
     name.Trim().Trim(false);
-    if(name.IsEmpty()) {
+    if (name.empty()) {
         return;
     }
 
-    Clear();
-
     // First add the workspace files
     long nLineNumber;
+    long nColumn;
     wxString modFilter;
-    GetLineNumberFromFilter(name, modFilter, nLineNumber);
+    GetLineAndColumnFromFilter(name, modFilter, nLineNumber, nColumn);
     name.swap(modFilter);
 
+    clDEBUG() << "Open resource:" << name << ":" << nLineNumber << ":" << nColumn << endl;
     m_lineNumber = nLineNumber;
+    m_column = nColumn;
 
     // Prepare the user filter
     m_userFilters.Clear();
     m_userFilters = ::wxStringTokenize(name, " \t", wxTOKEN_STRTOK);
-    for(size_t i = 0; i < m_userFilters.GetCount(); ++i) {
+    for (size_t i = 0; i < m_userFilters.GetCount(); ++i) {
         m_userFilters.Item(i).MakeLower();
     }
 
     // Build the filter class
-    if(m_checkBoxFiles->IsChecked()) {
+    if (m_checkBoxFiles->IsChecked()) {
         DoPopulateWorkspaceFile();
     }
-    if(m_checkBoxShowSymbols->IsChecked() && (nLineNumber == -1)) {
-        DoPopulateTags();
+
+    if (m_checkBoxShowSymbols->IsChecked() && (nLineNumber == -1)) {
+        LSP::Manager::GetInstance().WorkspaceSymbols(name);
     }
 }
 
-void OpenResourceDialog::DoPopulateTags()
+void OpenResourceDialog::OnWorkspaceSymbols(LSPEvent& event) { DoPopulateTags(event.GetSymbolsInformation()); }
+
+void OpenResourceDialog::DoPopulateTags(const std::vector<LSP::SymbolInformation>& symbols)
 {
     // Next, add the tags
-    TagEntryPtrVector_t tags;
-    if(m_userFilters.IsEmpty())
+    if (m_userFilters.IsEmpty() || symbols.empty()) {
         return;
-    m_manager->GetTagsManager()->GetTagsByPartialNames(m_userFilters, tags);
-    for(size_t i = 0; i < tags.size(); i++) {
-        TagEntryPtr tag = tags.at(i);
+    }
 
-        // Filter out non relevanting entries
-        if(!m_filters.IsEmpty() && m_filters.Index(tag->GetKind()) == wxNOT_FOUND)
-            continue;
-
-        if(!MatchesFilter(tag->GetFullDisplayName())) {
+    for (const LSP::SymbolInformation& symbol : symbols) {
+        if (!MatchesFilter(symbol.GetName())) {
             continue;
         }
 
-        wxString name(tag->GetName());
-
         // keep the fullpath
-        wxString fullname;
-        if(tag->IsMethod()) {
-            fullname = wxString::Format(wxT("%s::%s%s"), tag->GetScope().c_str(), tag->GetName().c_str(),
-                                        tag->GetSignature().c_str());
-            DoAppendLine(tag->GetName(), fullname, (tag->GetKind() == wxT("function")),
-                         new OpenResourceDialogItemData(tag->GetFile(), tag->GetLine(), tag->GetPattern(),
-                                                        tag->GetName(), tag->GetScope()),
-                         DoGetTagImg(tag));
-        } else {
-
-            fullname = wxString::Format(wxT("%s::%s"), tag->GetScope().c_str(), tag->GetName().c_str());
-            DoAppendLine(tag->GetName(), fullname, false,
-                         new OpenResourceDialogItemData(tag->GetFile(), tag->GetLine(), tag->GetPattern(),
-                                                        tag->GetName(), tag->GetScope()),
-                         DoGetTagImg(tag));
-        }
+        DoAppendLine(symbol.GetName(),
+                     symbol.GetContainerName(),
+                     false,
+                     new OpenResourceDialogItemData(symbol.GetLocation().GetPath(),
+                                                    symbol.GetLocation().GetRange().GetEnd().GetLine() + 1,
+                                                    wxEmptyString,
+                                                    symbol.GetName(),
+                                                    symbol.GetContainerName()),
+                     DoGetTagImg(symbol));
     }
+
     wxString filter = (m_userFilters.GetCount() == 1) ? m_userFilters.Item(0) : "";
-    if(!filter.IsEmpty()) {
+    if (!filter.IsEmpty()) {
         wxDataViewItem matchedItem =
-            m_dataview->FindNext(wxDataViewItem(nullptr), filter, 0,
+            m_dataview->FindNext(wxDataViewItem(nullptr),
+                                 filter,
+                                 0,
                                  wxDV_SEARCH_ICASE | wxDV_SEARCH_METHOD_EXACT | wxDV_SEARCH_INCLUDE_CURRENT_ITEM);
-        if(matchedItem.IsOk()) {
+        if (matchedItem.IsOk()) {
             DoSelectItem(matchedItem);
         }
     }
@@ -260,23 +282,27 @@ void OpenResourceDialog::DoPopulateTags()
 void OpenResourceDialog::DoPopulateWorkspaceFile()
 {
     // do we need to include files?
-    if(!m_filters.IsEmpty() && m_filters.Index(KIND_FILE) == wxNOT_FOUND)
+    if (!m_filters.IsEmpty() && m_filters.Index(KIND_FILE) == wxNOT_FOUND) {
         return;
+    }
 
-    if(!m_userFilters.IsEmpty()) {
+    if (!m_userFilters.empty()) {
 
         std::unordered_multimap<wxString, wxString>::iterator iter = m_files.begin();
         const int maxFileSize = 100;
         int counter = 0;
-        for(; (iter != m_files.end()) && (counter < maxFileSize); iter++) {
+        for (; (iter != m_files.end()) && (counter < maxFileSize); iter++) {
             const wxString& fullpath = iter->second;
-            if(!MatchesFilter(fullpath))
+            if (!MatchesFilter(fullpath)) {
                 continue;
+            }
 
             wxFileName fn(iter->second);
             int imgId = clGetManager()->GetStdIcons()->GetMimeImageId(fn.GetFullName());
-            DoAppendLine(fn.GetFullName(), fn.GetFullPath(), false,
-                         new OpenResourceDialogItemData(fn.GetFullPath(), -1, wxT(""), fn.GetFullName(), wxT("")),
+            DoAppendLine(fn.GetFullName(),
+                         iter->second,
+                         false,
+                         new OpenResourceDialogItemData(iter->second, -1, "", fn.GetFullName(), ""),
                          imgId);
             ++counter;
         }
@@ -295,48 +321,62 @@ void OpenResourceDialog::Clear()
 
 void OpenResourceDialog::OpenSelection(const OpenResourceDialogItemData& selection, IManager* manager)
 {
+    wxUnusedVar(manager);
+
     // send event to the plugins to see if they want
     // to open this file
     wxString file_path = selection.m_file;
     clCommandEvent activateEvent(wxEVT_TREE_ITEM_FILE_ACTIVATED);
     activateEvent.SetFileName(file_path);
-    if(EventNotifier::Get()->ProcessEvent(activateEvent))
+    if (EventNotifier::Get()->ProcessEvent(activateEvent)) {
         return;
-
-    if(manager && manager->OpenFile(selection.m_file, wxEmptyString, selection.m_line - 1)) {
-        IEditor* editor = manager->GetActiveEditor();
-        if(editor && !selection.m_name.IsEmpty() && !selection.m_pattern.IsEmpty()) {
-            editor->FindAndSelectV(selection.m_pattern, selection.m_name);
-        }
     }
+
+    clDEBUG() << "Opening editor:" << selection.m_file << ":" << selection.m_line << ":" << selection.m_column << endl;
+
+    auto callback = [=](IEditor* editor) {
+        editor->GetCtrl()->ClearSelections();
+        editor->CenterLine(selection.m_line - 1, selection.m_column);
+    };
+    clGetManager()->OpenFileAndAsyncExecute(selection.m_file, std::move(callback));
 }
 
 void OpenResourceDialog::OnKeyDown(wxKeyEvent& event)
 {
     event.Skip();
-    if(m_dataview->IsEmpty()) {
+    if (m_dataview->IsEmpty()) {
         return;
     }
 
-    if(event.GetKeyCode() == WXK_DOWN || event.GetKeyCode() == WXK_UP || event.GetKeyCode() == WXK_NUMPAD_UP ||
-       event.GetKeyCode() == WXK_NUMPAD_DOWN) {
-        event.Skip(false);
+    wxChar ch = event.GetUnicodeKey();
+    wxChar key_code = event.GetKeyCode();
+    int modifier_key = event.GetModifiers();
+    bool control_down = (modifier_key == wxMOD_CONTROL);
+    bool line_down =
+        (key_code == WXK_DOWN) || (key_code == WXK_NUMPAD_DOWN) || (control_down && (ch == 'J' || ch == 'N'));
+    bool page_down = (key_code == WXK_PAGEDOWN) || (control_down && (ch == 'D'));
+    bool line_up = (key_code == WXK_UP) || (key_code == WXK_NUMPAD_UP) || (control_down && (ch == 'K' || ch == 'P'));
+    bool page_up = (key_code == WXK_PAGEUP) || (control_down && (ch == 'U'));
 
-        if(GetDataview()->GetSelectedItemsCount() == 0) {
-            // Just select the first entry
-            DoSelectItem(GetDataview()->RowToItem(0));
+    event.Skip(false);
+    if (GetDataview()->GetSelectedItemsCount() == 0) {
+        // Just select the first entry
+        DoSelectItem(GetDataview()->RowToItem(0));
+        event.Skip();
+    } else {
+        if (line_down) {
+            GetDataview()->LineDown();
+        } else if (line_up) {
+            GetDataview()->LineUp();
+        } else if (page_down) {
+            GetDataview()->PageDown();
+        } else if (page_up) {
+            GetDataview()->PageUp();
         } else {
-            // fire char hook event to the DV control
-            // so it will handle the keyboard movement itself
-            wxKeyEvent charHook = event;
-            charHook.SetEventObject(m_dataview);
-            charHook.SetEventType(wxEVT_CHAR_HOOK);
-            GetDataview()->GetEventHandler()->ProcessEvent(charHook);
+            event.Skip();
         }
-
-        // Set the focus back to the text control
-        m_textCtrlResourceName->CallAfter(&wxTextCtrl::SetFocus);
     }
+    m_textCtrlResourceName->CallAfter(&clThemedTextCtrl::SetFocus);
 }
 
 void OpenResourceDialog::OnOK(wxCommandEvent& event) { event.Skip(); }
@@ -353,21 +393,21 @@ void OpenResourceDialog::DoSelectItem(const wxDataViewItem& item)
     GetDataview()->Refresh();
 }
 
-void OpenResourceDialog::DoAppendLine(const wxString& name, const wxString& fullname, bool boldFont,
-                                      OpenResourceDialogItemData* clientData, int imgid)
+void OpenResourceDialog::DoAppendLine(
+    const wxString& name, const wxString& fullname, bool boldFont, OpenResourceDialogItemData* clientData, int imgid)
 {
     wxString prefix;
     clientData->m_impl = boldFont;
     wxVector<wxVariant> cols;
     cols.push_back(::MakeBitmapIndexText(prefix + name, imgid));
-    cols.push_back(clientData->m_impl ? wxString("X") : wxString());
+    cols.push_back(clientData->m_impl ? wxString(wxT("\u274C")) : wxString());
     cols.push_back(fullname);
     m_dataview->AppendItem(cols, (wxUIntPtr)clientData);
 }
 
-void OpenResourceDialog::OnTimer(wxTimerEvent& event)
+void OpenResourceDialog::OnTimer([[maybe_unused]] wxTimerEvent& event)
 {
-    if(m_needRefresh) {
+    if (m_needRefresh) {
         DoPopulateList();
     }
 
@@ -375,37 +415,26 @@ void OpenResourceDialog::OnTimer(wxTimerEvent& event)
 
     // If there is only 1 item in the resource window then highlight it.
     // This allows the user to hit ENTER immediately after to open the item, nice shortcut.
-    if(m_dataview && m_dataview->GetItemCount() == 1) {
+    if (m_dataview && m_dataview->GetItemCount() == 1) {
         DoSelectItem(m_dataview->RowToItem(0));
     }
 }
 
-int OpenResourceDialog::DoGetTagImg(TagEntryPtr tag)
+int OpenResourceDialog::DoGetTagImg(const LSP::SymbolInformation& symbol)
 {
-    wxString kind = tag->GetKind();
-    wxString access = tag->GetAccess();
-
-    // Build the access string
-    wxString accessString;
-    accessString << kind;
-    if(!access.IsEmpty()) {
-        accessString << "_" << access;
-    }
-
     int imgId = BitmapLoader::kMemberPublic; // The default
-    if(m_fileTypeHash.count(accessString)) {
-        imgId = m_fileTypeHash[accessString];
+    if (m_fileTypeHash.count(symbol.GetKind())) {
+        imgId = m_fileTypeHash[symbol.GetKind()];
     }
     return clGetManager()->GetStdIcons()->GetImageIndex(imgId);
 }
 
 bool OpenResourceDialog::MatchesFilter(const wxString& name)
 {
-    wxString filter = m_textCtrlResourceName->GetValue();
-    if(filter.Contains(':') == true) {
-        filter = filter.BeforeLast(':');
-    }
-    return FileUtils::FuzzyMatch(filter, name);
+    wxString mod_filter;
+    long line_number, column_number;
+    GetLineAndColumnFromFilter(m_textCtrlResourceName->GetValue(), mod_filter, line_number, column_number);
+    return FileUtils::FuzzyMatch(mod_filter, name);
 }
 
 void OpenResourceDialog::OnCheckboxfilesCheckboxClicked(wxCommandEvent& event) { DoPopulateList(); }
@@ -420,32 +449,59 @@ std::vector<OpenResourceDialogItemData*> OpenResourceDialog::GetSelections() con
     std::vector<OpenResourceDialogItemData*> selections;
     wxDataViewItemArray items;
     m_dataview->GetSelections(items);
-    if(items.IsEmpty()) {
+    if (items.IsEmpty()) {
         return selections;
     }
 
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    selections.reserve(items.size());
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         OpenResourceDialogItemData* data = GetItemData(items.Item(i));
-        if(data) {
-            if(m_lineNumber != wxNOT_FOUND) {
+        if (data) {
+            if (m_lineNumber != wxNOT_FOUND) {
                 data->m_line = m_lineNumber;
             }
+
+            if (m_column != wxNOT_FOUND) {
+                data->m_column = m_column;
+            }
             selections.push_back(data);
         }
     }
     return selections;
 }
 
-void OpenResourceDialog::GetLineNumberFromFilter(const wxString& filter, wxString& modFilter, long& lineNumber)
+void OpenResourceDialog::GetLineAndColumnFromFilter(const wxString& filter,
+                                                    wxString& modFilter,
+                                                    long& lineNumber,
+                                                    long& column)
 {
     modFilter = filter;
-    lineNumber = -1;
-    static wxRegEx reNumber(":([0-9]+)", wxRE_ADVANCED);
-    if(reNumber.IsValid() && reNumber.Matches(modFilter)) {
-        wxString strLineNumber;
-        strLineNumber = reNumber.GetMatch(modFilter, 1);
-        strLineNumber.ToCLong(&lineNumber);
-        reNumber.Replace(&modFilter, "");
+    lineNumber = wxNOT_FOUND;
+    column = wxNOT_FOUND;
+
+    wxString tmpstr = filter;
+    tmpstr.Replace("\\", "/");
+
+    const int sep_last = tmpstr.Find('/', true);
+    const std::size_t col_first = tmpstr.find(':', (sep_last == wxNOT_FOUND ? 0 : sep_last));
+    if (col_first == wxString::npos) {
+        return;
+    }
+
+    modFilter = tmpstr.substr(0, col_first);
+    wxString remainder = tmpstr.substr(col_first);
+
+    auto parts = ::wxStringTokenize(remainder, ":", wxTOKEN_STRTOK);
+    if (!parts.empty()) {
+        // line number
+        parts.Item(0).ToCLong(&lineNumber);
+        parts.RemoveAt(0);
+    }
+
+    if (!parts.empty()) {
+        // column number
+        parts.Item(0).ToCLong(&column);
+        parts.RemoveAt(0);
     }
 }
 
@@ -453,3 +509,5 @@ OpenResourceDialogItemData* OpenResourceDialog::GetItemData(const wxDataViewItem
 {
     return reinterpret_cast<OpenResourceDialogItemData*>(m_dataview->GetItemData(item));
 }
+
+void OpenResourceDialog::OnSelectAllText() { m_textCtrlResourceName->SelectAll(); }
