@@ -22,18 +22,14 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "cl_defs.h"
+#include "optionsconfig.h"
+
+#include "StringUtils.h"
 #include "editor_config.h"
 #include "macros.h"
-#include "optionsconfig.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
-#include <wx/fontmap.h>
-#include <wx/intl.h>
 
-#ifdef __WXMSW__
-#include <wx/msw/uxtheme.h>
-#endif
+#include <wx/fontmap.h>
 
 const wxString defaultBookmarkLabels = wxString(';', CL_N0_OF_BOOKMARK_TYPES - 1) + "Find";
 
@@ -44,8 +40,8 @@ wxString SetDefaultBookmarkColours()
     // one
     const wxString arr[] = { "#FF0080", "#0000FF", "#FF0000", "#00FF00", "#FFFF00" };
     wxString output;
-    for(size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
-        if(n < sizeof(arr) / sizeof(wxString)) {
+    for (size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
+        if (n < sizeof(arr) / sizeof(wxString)) {
             output << arr[n] << ';';
         } else {
             output << "#FF0080" << ';';
@@ -56,42 +52,40 @@ wxString SetDefaultBookmarkColours()
 }
 
 OptionsConfig::OptionsConfig(wxXmlNode* node)
-    : m_displayFoldMargin(true)
+    : m_displayFoldMargin(false)
     , m_underlineFoldLine(false)
     , m_scrollBeyondLastLine(true)
-    , m_foldStyle("Flatten Tree Square Headers")
+    , m_foldStyle("Arrows")
     , m_displayBookmarkMargin(true)
     , m_bookmarkShape(wxT("Small Arrow"))
     , m_bookmarkBgColours(SetDefaultBookmarkColours())
     , m_bookmarkFgColours(SetDefaultBookmarkColours())
     , m_bookmarkLabels(defaultBookmarkLabels)
     , m_highlightCaretLine(true)
-    , m_clearHighlitWordsOnFind(true)
+    , m_highlightCaretLineWithColour(true)
+    , m_clearHighlightedWordsOnFind(true)
     , m_displayLineNumbers(true)
     , m_relativeLineNumbers(false)
     , m_showIndentationGuidelines(true)
     , m_caretLineColour(wxT("LIGHT BLUE"))
-    , m_indentUsesTabs(true)
+    , m_indentUsesTabs(false)
     , m_indentWidth(4)
     , m_tabWidth(4)
     , m_iconsSize(16)
-    , m_showWhitspaces(0 /*wxSCI_WS_INVISIBLE*/)
+    , m_showWhitespaces(0 /*wxSCI_WS_INVISIBLE*/)
     , m_foldCompact(false)
     , m_foldAtElse(false)
     , m_foldPreprocessor(false)
-    , m_edgeMode(0 /*wxSCI_EDGE_NONE*/)
-    , m_edgeColumn(120)
-    , m_edgeColour(wxColour(wxT("LIGHT GREY")))
     , m_highlightMatchedBraces(true)
     , m_foldBgColour(wxColour(240, 240, 240))
-    , m_autoAdjustHScrollBarWidth(false)
+    , m_autoAdjustHScrollBarWidth(true)
     , m_caretWidth(2)
     , m_caretBlinkPeriod(500)
     , m_copyLineEmptySelection(true)
     , m_programConsoleCommand(TERMINAL_CMD)
     , m_eolMode(wxT("Default"))
-    , m_hideChangeMarkerMargin(true)
-    , m_hideOutpuPaneOnUserClick(false)
+    , m_trackEditorChanges(false)
+    , m_hideOutputPaneOnUserClick(false)
     , m_hideOutputPaneNotIfBuild(false)
     , m_hideOutputPaneNotIfSearch(true)
     , m_hideOutputPaneNotIfReplace(false)
@@ -115,6 +109,7 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
     , m_caretLineAlpha(15)
     , m_dontAutoFoldResults(true)
     , m_dontOverrideSearchStringWithSelection(false)
+    , m_findNextOrPreviousUseSelection(true)
     , m_showDebugOnRun(true)
     , m_caretUseCamelCase(true)
     , m_wordWrap(false)
@@ -122,24 +117,24 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
     , m_preferredLocale(wxT("en_US"))
     , m_useLocale(0)
     , m_trimOnlyModifiedLines(true)
-    , m_options(Opt_AutoCompleteCurlyBraces | Opt_NavKey_Shift | Opt_FoldHighlightActiveBlock | Opt_TabStyleMinimal)
-    , m_options2(0)
-    , m_workspaceTabsDirection(wxUP)
+    , m_workspaceTabsDirection(wxLEFT)
     , m_outputTabsDirection(wxUP)
     , m_indentedComments(false)
-#ifdef __WXOSX__
-    , m_nbTabHeight(nbTabHt_Tiny)
-#else
     , m_nbTabHeight(nbTabHt_Short)
-#endif
     , m_webSearchPrefix(wxT("https://www.google.com/search?q="))
     , m_smartParen(true)
 {
+    m_options.set(Opt_AutoCompleteCurlyBraces);
+    m_options.set(Opt_NavKey_Shift);
+    m_options.set(Opt_FoldHighlightActiveBlock);
+    m_options.set(Opt_TabStyleMinimal);
+    m_options.set(Opt_HideDockingWindowCaption);
+
     m_debuggerMarkerLine = DrawingUtils::LightColour("LIME GREEN", 8.0);
     m_mswTheme = false;
     // set the default font name to be wxFONTENCODING_UTF8
     SetFileFontEncoding(wxFontMapper::GetEncodingName(wxFONTENCODING_UTF8));
-    if(node) {
+    if (node) {
         SetFileFontEncoding(
             XmlUtils::ReadString(node, wxT("FileFontEncoding"), wxFontMapper::GetEncodingName(wxFONTENCODING_UTF8)));
 
@@ -152,11 +147,15 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
             XmlUtils::ReadString(node, wxT("BookmarkBgColours"), ""); // No default; we'll deal with this later
         m_bookmarkFgColours = XmlUtils::ReadString(node, wxT("BookmarkFgColours"), "");
         m_bookmarkLabels = XmlUtils::ReadString(node, wxT("BookmarkLabels"), defaultBookmarkLabels);
-        m_clearHighlitWordsOnFind = XmlUtils::ReadBool(node, wxT("ClearHighlitWordsOnFind"), m_clearHighlitWordsOnFind);
+        m_clearHighlightedWordsOnFind =
+            XmlUtils::ReadBool(node, wxT("ClearHighlitWordsOnFind"), m_clearHighlightedWordsOnFind);
         m_highlightCaretLine = XmlUtils::ReadBool(node, wxT("HighlightCaretLine"), m_highlightCaretLine);
+        m_highlightCaretLineWithColour =
+            XmlUtils::ReadBool(node, "HighlightCaretLineWithColour", m_highlightCaretLineWithColour);
         m_displayLineNumbers = XmlUtils::ReadBool(node, wxT("ShowLineNumber"), m_displayLineNumbers);
         m_relativeLineNumbers = XmlUtils::ReadBool(node, wxT("RelativeLineNumber"), m_relativeLineNumbers);
-        m_highlightCurLineNumber = XmlUtils::ReadBool(node, wxT("HighlightCurLineNumber"), m_highlightCurLineNumber);
+        m_lineNumberHighlightCurrent =
+            XmlUtils::ReadBool(node, wxT("LineNumbersHighlightCurrent"), m_lineNumberHighlightCurrent);
         m_showIndentationGuidelines = XmlUtils::ReadBool(node, wxT("IndentationGuides"), m_showIndentationGuidelines);
         m_caretLineColour =
             XmlUtils::ReadString(node, wxT("CaretLineColour"), m_caretLineColour.GetAsString(wxC2S_HTML_SYNTAX));
@@ -164,13 +163,10 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_indentWidth = XmlUtils::ReadLong(node, wxT("IndentWidth"), m_indentWidth);
         m_tabWidth = XmlUtils::ReadLong(node, wxT("TabWidth"), m_tabWidth);
         m_iconsSize = XmlUtils::ReadLong(node, wxT("ToolbarIconSize"), m_iconsSize);
-        m_showWhitspaces = XmlUtils::ReadLong(node, wxT("ShowWhitespaces"), m_showWhitspaces);
+        m_showWhitespaces = XmlUtils::ReadLong(node, wxT("ShowWhitespaces"), m_showWhitespaces);
         m_foldCompact = XmlUtils::ReadBool(node, wxT("FoldCompact"), m_foldCompact);
         m_foldAtElse = XmlUtils::ReadBool(node, wxT("FoldAtElse"), m_foldAtElse);
         m_foldPreprocessor = XmlUtils::ReadBool(node, wxT("FoldPreprocessor"), m_foldPreprocessor);
-        m_edgeMode = XmlUtils::ReadLong(node, wxT("EdgeMode"), m_edgeMode);
-        m_edgeColumn = XmlUtils::ReadLong(node, wxT("EdgeColumn"), m_edgeColumn);
-        m_edgeColour = XmlUtils::ReadString(node, wxT("EdgeColour"), m_edgeColour.GetAsString(wxC2S_HTML_SYNTAX));
         m_highlightMatchedBraces = XmlUtils::ReadBool(node, wxT("HighlightMatchedBraces"), m_highlightMatchedBraces);
         m_foldBgColour = XmlUtils::ReadString(node, wxT("FoldBgColour"), m_foldBgColour.GetAsString(wxC2S_HTML_SYNTAX));
         m_autoAdjustHScrollBarWidth =
@@ -179,11 +175,14 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_caretWidth = XmlUtils::ReadLong(node, wxT("CaretWidth"), m_caretWidth);
         m_copyLineEmptySelection = XmlUtils::ReadBool(node, wxT("CopyLineEmptySelection"), m_copyLineEmptySelection);
         m_smartParen = XmlUtils::ReadBool(node, wxT("SmartParen"), m_smartParen);
+        m_showRightMarginIndicator = XmlUtils::ReadBool(node, wxT("ShowRightMargin"), m_showRightMarginIndicator);
+        m_rightMarginColumn = XmlUtils::ReadLong(node, wxT("RightMarginnColumn"), m_rightMarginColumn);
+
         m_programConsoleCommand = XmlUtils::ReadString(node, wxT("ConsoleCommand"), m_programConsoleCommand);
         m_eolMode = XmlUtils::ReadString(node, wxT("EOLMode"), m_eolMode);
-        m_hideChangeMarkerMargin = XmlUtils::ReadBool(node, wxT("HideChangeMarkerMargin"));
+        m_trackEditorChanges = XmlUtils::ReadBool(node, wxT("TrackEditorChanges"));
         m_scrollBeyondLastLine = XmlUtils::ReadBool(node, wxT("ScrollBeyondLastLine"), m_scrollBeyondLastLine);
-        m_hideOutpuPaneOnUserClick = XmlUtils::ReadBool(node, wxT("HideOutputPaneOnUserClick"));
+        m_hideOutputPaneOnUserClick = XmlUtils::ReadBool(node, wxT("HideOutputPaneOnUserClick"));
         m_hideOutputPaneNotIfBuild = XmlUtils::ReadBool(node, wxT("HideOutputPaneNotIfBuild"));
         m_hideOutputPaneNotIfSearch = XmlUtils::ReadBool(node, wxT("HideOutputPaneNotIfSearch"));
         m_hideOutputPaneNotIfReplace = XmlUtils::ReadBool(node, wxT("HideOutputPaneNotIfReplace"));
@@ -204,8 +203,10 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_disableSemicolonShift = XmlUtils::ReadBool(node, wxT("DisableSemicolonShift"), m_disableSemicolonShift);
         m_caretLineAlpha = XmlUtils::ReadLong(node, wxT("CaretLineAlpha"), m_caretLineAlpha);
         m_dontAutoFoldResults = XmlUtils::ReadBool(node, wxT("DontAutoFoldResults"), m_dontAutoFoldResults);
-        m_dontOverrideSearchStringWithSelection = XmlUtils::ReadBool(node, wxT("DontOverrideSearchStringWithSelection"),
-                                                                     m_dontOverrideSearchStringWithSelection);
+        m_dontOverrideSearchStringWithSelection = XmlUtils::ReadBool(
+            node, wxT("DontOverrideSearchStringWithSelection"), m_dontOverrideSearchStringWithSelection);
+        m_findNextOrPreviousUseSelection = XmlUtils::ReadBool(
+            node, wxT("FindNextOrPreviousUseSelection"), m_findNextOrPreviousUseSelection);
         m_showDebugOnRun = XmlUtils::ReadBool(node, wxT("ShowDebugOnRun"), m_showDebugOnRun);
         m_caretUseCamelCase = XmlUtils::ReadBool(node, wxT("m_caretUseCamelCase"), m_caretUseCamelCase);
         m_wordWrap = XmlUtils::ReadBool(node, wxT("m_wordWrap"), m_wordWrap);
@@ -215,10 +216,13 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_preferredLocale = XmlUtils::ReadString(node, wxT("m_preferredLocale"), m_preferredLocale);
         m_useLocale = XmlUtils::ReadBool(node, wxT("m_useLocale"), m_useLocale);
         m_trimOnlyModifiedLines = XmlUtils::ReadBool(node, wxT("m_trimOnlyModifiedLines"), m_trimOnlyModifiedLines);
-        m_options = XmlUtils::ReadLong(node, wxT("m_options"), m_options);
-        m_options2 = XmlUtils::ReadLong(node, wxT("m_options2"), m_options2);
-        m_debuggerMarkerLine = XmlUtils::ReadString(node, wxT("m_debuggerMarkerLine"),
-                                                    m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
+
+        wxString options;
+        if (XmlUtils::ReadStringIfExists(node, "options_bits", options)) {
+            m_options.from_string(options);
+        }
+        m_debuggerMarkerLine = XmlUtils::ReadString(
+            node, wxT("m_debuggerMarkerLine"), m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
         m_indentedComments = XmlUtils::ReadBool(node, wxT("IndentedComments"), m_indentedComments);
 
         // These hacks will likely be changed in the future. If so, we'll be able to remove the #include
@@ -235,149 +239,130 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_outputTabsDirection =
             (wxDirection)XmlUtils::ReadLong(node, "OutputTabsDirection", (int)m_outputTabsDirection);
         m_workspaceTabsDirection =
-            (wxDirection)XmlUtils::ReadLong(node, "WorkspaceTabsDirection", (int)m_workspaceTabsDirection);
-#ifdef __WXOSX__
-        if(m_workspaceTabsDirection == wxLEFT) { m_workspaceTabsDirection = wxTOP; }
-        if(m_workspaceTabsDirection == wxRIGHT) { m_workspaceTabsDirection = wxBOTTOM; }
-#endif
-
+            (wxDirection)XmlUtils::ReadLong(node, "SidebarButtonsPosition", (int)m_workspaceTabsDirection);
         m_webSearchPrefix = XmlUtils::ReadString(node, wxT("m_webSearchPrefix"), m_webSearchPrefix);
     }
 
     // Transitional calls. These checks are relevant for 2 years i.e. until the beginning of 2016
-    if(m_bookmarkFgColours.empty()) {
+    if (m_bookmarkFgColours.empty()) {
         // This must be the first time with multiple BMs, so rescue any old user-set value
         m_bookmarkFgColours = SetDefaultBookmarkColours();
         wxString oldcolour = XmlUtils::ReadString(node, "BookmarkFgColour", "#FF0080");
         SetBookmarkFgColour(oldcolour, 0);
     }
-    if(m_bookmarkBgColours.empty()) {
+    if (m_bookmarkBgColours.empty()) {
         m_bookmarkBgColours = SetDefaultBookmarkColours();
         wxString oldcolour = XmlUtils::ReadString(node, "BookmarkBgColour", "#FF0080");
         SetBookmarkBgColour(oldcolour, 0);
     }
 }
 
-OptionsConfig::~OptionsConfig(void) {}
-
 wxXmlNode* OptionsConfig::ToXml() const
 {
     wxXmlNode* n = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Options"));
-    n->AddProperty(wxT("DisplayFoldMargin"), BoolToString(m_displayFoldMargin));
-    n->AddProperty(wxT("UnderlineFoldedLine"), BoolToString(m_underlineFoldLine));
-    n->AddProperty(wxT("FoldStyle"), m_foldStyle);
-    n->AddProperty(wxT("DisplayBookmarkMargin"), BoolToString(m_displayBookmarkMargin));
-    n->AddProperty(wxT("BookmarkShape"), m_bookmarkShape);
-    n->AddProperty(wxT("BookmarkBgColours"), m_bookmarkBgColours);
-    n->AddProperty(wxT("BookmarkFgColours"), m_bookmarkFgColours);
-    n->AddProperty(wxT("BookmarkLabels"), m_bookmarkLabels);
-    n->AddProperty(wxT("ClearHighlitWordsOnFind"), BoolToString(m_clearHighlitWordsOnFind));
-    n->AddProperty(wxT("HighlightCaretLine"), BoolToString(m_highlightCaretLine));
-    n->AddProperty(wxT("ShowLineNumber"), BoolToString(m_displayLineNumbers));
-    n->AddProperty(wxT("RelativeLineNumber"), BoolToString(m_relativeLineNumbers));
-    n->AddProperty("HighlightCurLineNumber", BoolToString(m_highlightCurLineNumber));
-    n->AddProperty(wxT("IndentationGuides"), BoolToString(m_showIndentationGuidelines));
-    n->AddProperty(wxT("CaretLineColour"), m_caretLineColour.GetAsString(wxC2S_HTML_SYNTAX));
-    n->AddProperty(wxT("IndentUsesTabs"), BoolToString(m_indentUsesTabs));
-    n->AddProperty(wxT("FoldCompact"), BoolToString(m_foldCompact));
-    n->AddProperty(wxT("FoldAtElse"), BoolToString(m_foldAtElse));
-    n->AddProperty(wxT("FoldPreprocessor"), BoolToString(m_foldPreprocessor));
-    n->AddProperty(wxT("HighlightMatchedBraces"), BoolToString(m_highlightMatchedBraces));
-    n->AddProperty(wxT("FoldBgColour"), m_foldBgColour.GetAsString(wxC2S_HTML_SYNTAX));
-    n->AddProperty(wxT("AutoAdjustHScrollBarWidth"), BoolToString(m_autoAdjustHScrollBarWidth));
-    n->AddProperty(wxT("HideChangeMarkerMargin"), BoolToString(m_hideChangeMarkerMargin));
-    n->AddProperty(wxT("ScrollBeyondLastLine"), BoolToString(m_scrollBeyondLastLine));
-    n->AddProperty(wxT("HideOutputPaneOnUserClick"), BoolToString(m_hideOutpuPaneOnUserClick));
-    n->AddProperty(wxT("HideOutputPaneNotIfBuild"), BoolToString(m_hideOutputPaneNotIfBuild));
-    n->AddProperty(wxT("HideOutputPaneNotIfSearch"), BoolToString(m_hideOutputPaneNotIfSearch));
-    n->AddProperty(wxT("HideOutputPaneNotIfReplace"), BoolToString(m_hideOutputPaneNotIfReplace));
-    n->AddProperty(wxT("HideOutputPaneNotIfReferences"), BoolToString(m_hideOutputPaneNotIfReferences));
-    n->AddProperty(wxT("HideOutputPaneNotIfOutput"), BoolToString(m_hideOutputPaneNotIfOutput));
-    n->AddProperty(wxT("HideOutputPaneNotIfTrace"), BoolToString(m_hideOutputPaneNotIfTrace));
-    n->AddProperty(wxT("HideOutputPaneNotIfTasks"), BoolToString(m_hideOutputPaneNotIfTasks));
-    n->AddProperty(wxT("HideOutputPaneNotIfBuildQ"), BoolToString(m_hideOutputPaneNotIfBuildQ));
-    n->AddProperty(wxT("HideOutputPaneNotIfCppCheck"), BoolToString(m_hideOutputPaneNotIfCppCheck));
-    n->AddProperty(wxT("HideOutputPaneNotIfSvn"), BoolToString(m_hideOutputPaneNotIfSvn));
-    n->AddProperty(wxT("HideOutputPaneNotIfCscope"), BoolToString(m_hideOutputPaneNotIfCscope));
-    n->AddProperty(wxT("HideOutputPaneNotIfGit"), BoolToString(m_hideOutputPaneNotIfGit));
-    n->AddProperty(wxT("HideOutputPaneNotIfDebug"), BoolToString(m_hideOutputPaneNotIfDebug));
-    n->AddProperty(wxT("HideOutputPaneNotIfMemCheck"), BoolToString(m_hideOutputPaneNotIfMemCheck));
-    n->AddProperty(wxT("FindBarAtBottom"), BoolToString(m_findBarAtBottom));
-    n->AddProperty(wxT("ShowReplaceBar"), BoolToString(m_showReplaceBar));
-    n->AddProperty(wxT("DisableSmartIndent"), BoolToString(m_disableSmartIndent));
-    n->AddProperty(wxT("DisableSemicolonShift"), BoolToString(m_disableSemicolonShift));
-    n->AddProperty(wxT("DontAutoFoldResults"), BoolToString(m_dontAutoFoldResults));
-    n->AddProperty(wxT("DontOverrideSearchStringWithSelection"), BoolToString(m_dontOverrideSearchStringWithSelection));
-    n->AddProperty(wxT("ShowDebugOnRun"), BoolToString(m_showDebugOnRun));
-    n->AddProperty(wxT("ConsoleCommand"), m_programConsoleCommand);
-    n->AddProperty(wxT("EOLMode"), m_eolMode);
-    n->AddProperty(wxT("m_caretUseCamelCase"), BoolToString(m_caretUseCamelCase));
-    n->AddProperty(wxT("m_wordWrap"), BoolToString(m_wordWrap));
-    n->AddProperty(wxT("m_dockingStyle"), wxString::Format(wxT("%d"), m_dockingStyle));
-    n->AddProperty(wxT("m_nbTabHeight"), wxString::Format(wxT("%d"), m_nbTabHeight));
-    n->AddProperty(wxT("m_mswTheme"), BoolToString(m_mswTheme));
-    n->AddProperty(wxT("m_preferredLocale"), m_preferredLocale);
-    n->AddProperty(wxT("m_useLocale"), BoolToString(m_useLocale));
-    n->AddProperty(wxT("m_trimOnlyModifiedLines"), BoolToString(m_trimOnlyModifiedLines));
-    n->AddProperty(wxT("m_debuggerMarkerLine"), m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
-    n->AddProperty(wxT("OutputTabsDirection"), wxString() << (int)m_outputTabsDirection);
-    n->AddProperty(wxT("WorkspaceTabsDirection"), wxString() << (int)m_workspaceTabsDirection);
-    n->AddProperty(wxT("IndentedComments"), BoolToString(m_indentedComments));
-    n->AddProperty(wxT("CopyLineEmptySelection"), BoolToString(m_copyLineEmptySelection));
-    n->AddProperty(wxT("SmartParen"), BoolToString(m_smartParen));
+    n->AddAttribute(wxT("DisplayFoldMargin"), BoolToString(m_displayFoldMargin));
+    n->AddAttribute(wxT("UnderlineFoldedLine"), BoolToString(m_underlineFoldLine));
+    n->AddAttribute(wxT("FoldStyle"), m_foldStyle);
+    n->AddAttribute(wxT("DisplayBookmarkMargin"), BoolToString(m_displayBookmarkMargin));
+    n->AddAttribute(wxT("BookmarkShape"), m_bookmarkShape);
+    n->AddAttribute(wxT("BookmarkBgColours"), m_bookmarkBgColours);
+    n->AddAttribute(wxT("BookmarkFgColours"), m_bookmarkFgColours);
+    n->AddAttribute(wxT("BookmarkLabels"), m_bookmarkLabels);
+    n->AddAttribute(wxT("ClearHighlitWordsOnFind"), BoolToString(m_clearHighlightedWordsOnFind));
+    n->AddAttribute(wxT("HighlightCaretLine"), BoolToString(m_highlightCaretLine));
+    n->AddAttribute(wxT("HighlightCaretLineWithColour"), BoolToString(m_highlightCaretLineWithColour));
+    n->AddAttribute(wxT("ShowLineNumber"), BoolToString(m_displayLineNumbers));
+    n->AddAttribute(wxT("RelativeLineNumber"), BoolToString(m_relativeLineNumbers));
+    n->AddAttribute(wxT("LineNumbersHighlightCurrent"), BoolToString(m_lineNumberHighlightCurrent));
+    n->AddAttribute(wxT("IndentationGuides"), BoolToString(m_showIndentationGuidelines));
+    n->AddAttribute(wxT("CaretLineColour"), m_caretLineColour.GetAsString(wxC2S_HTML_SYNTAX));
+    n->AddAttribute(wxT("IndentUsesTabs"), BoolToString(m_indentUsesTabs));
+    n->AddAttribute(wxT("FoldCompact"), BoolToString(m_foldCompact));
+    n->AddAttribute(wxT("FoldAtElse"), BoolToString(m_foldAtElse));
+    n->AddAttribute(wxT("FoldPreprocessor"), BoolToString(m_foldPreprocessor));
+    n->AddAttribute(wxT("HighlightMatchedBraces"), BoolToString(m_highlightMatchedBraces));
+    n->AddAttribute(wxT("FoldBgColour"), m_foldBgColour.GetAsString(wxC2S_HTML_SYNTAX));
+    n->AddAttribute(wxT("AutoAdjustHScrollBarWidth"), BoolToString(m_autoAdjustHScrollBarWidth));
+    n->AddAttribute(wxT("TrackEditorChanges"), BoolToString(m_trackEditorChanges));
+    n->AddAttribute(wxT("ScrollBeyondLastLine"), BoolToString(m_scrollBeyondLastLine));
+    n->AddAttribute(wxT("HideOutputPaneOnUserClick"), BoolToString(m_hideOutputPaneOnUserClick));
+    n->AddAttribute(wxT("HideOutputPaneNotIfBuild"), BoolToString(m_hideOutputPaneNotIfBuild));
+    n->AddAttribute(wxT("HideOutputPaneNotIfSearch"), BoolToString(m_hideOutputPaneNotIfSearch));
+    n->AddAttribute(wxT("HideOutputPaneNotIfReplace"), BoolToString(m_hideOutputPaneNotIfReplace));
+    n->AddAttribute(wxT("HideOutputPaneNotIfReferences"), BoolToString(m_hideOutputPaneNotIfReferences));
+    n->AddAttribute(wxT("HideOutputPaneNotIfOutput"), BoolToString(m_hideOutputPaneNotIfOutput));
+    n->AddAttribute(wxT("HideOutputPaneNotIfTrace"), BoolToString(m_hideOutputPaneNotIfTrace));
+    n->AddAttribute(wxT("HideOutputPaneNotIfTasks"), BoolToString(m_hideOutputPaneNotIfTasks));
+    n->AddAttribute(wxT("HideOutputPaneNotIfBuildQ"), BoolToString(m_hideOutputPaneNotIfBuildQ));
+    n->AddAttribute(wxT("HideOutputPaneNotIfCppCheck"), BoolToString(m_hideOutputPaneNotIfCppCheck));
+    n->AddAttribute(wxT("HideOutputPaneNotIfSvn"), BoolToString(m_hideOutputPaneNotIfSvn));
+    n->AddAttribute(wxT("HideOutputPaneNotIfCscope"), BoolToString(m_hideOutputPaneNotIfCscope));
+    n->AddAttribute(wxT("HideOutputPaneNotIfGit"), BoolToString(m_hideOutputPaneNotIfGit));
+    n->AddAttribute(wxT("HideOutputPaneNotIfDebug"), BoolToString(m_hideOutputPaneNotIfDebug));
+    n->AddAttribute(wxT("HideOutputPaneNotIfMemCheck"), BoolToString(m_hideOutputPaneNotIfMemCheck));
+    n->AddAttribute(wxT("FindBarAtBottom"), BoolToString(m_findBarAtBottom));
+    n->AddAttribute(wxT("ShowReplaceBar"), BoolToString(m_showReplaceBar));
+    n->AddAttribute(wxT("DisableSmartIndent"), BoolToString(m_disableSmartIndent));
+    n->AddAttribute(wxT("DisableSemicolonShift"), BoolToString(m_disableSemicolonShift));
+    n->AddAttribute(wxT("DontAutoFoldResults"), BoolToString(m_dontAutoFoldResults));
+    n->AddAttribute(wxT("DontOverrideSearchStringWithSelection"),
+                    BoolToString(m_dontOverrideSearchStringWithSelection));
+    n->AddAttribute(wxT("FindNextOrPreviousUseSelection"),
+                    BoolToString(m_findNextOrPreviousUseSelection));
+    n->AddAttribute(wxT("ShowDebugOnRun"), BoolToString(m_showDebugOnRun));
+    n->AddAttribute(wxT("ConsoleCommand"), m_programConsoleCommand);
+    n->AddAttribute(wxT("EOLMode"), m_eolMode);
+    n->AddAttribute(wxT("m_caretUseCamelCase"), BoolToString(m_caretUseCamelCase));
+    n->AddAttribute(wxT("m_wordWrap"), BoolToString(m_wordWrap));
+    n->AddAttribute(wxT("m_dockingStyle"), wxString::Format(wxT("%d"), m_dockingStyle));
+    n->AddAttribute(wxT("m_nbTabHeight"), wxString::Format(wxT("%d"), m_nbTabHeight));
+    n->AddAttribute(wxT("m_mswTheme"), BoolToString(m_mswTheme));
+    n->AddAttribute(wxT("m_preferredLocale"), m_preferredLocale);
+    n->AddAttribute(wxT("m_useLocale"), BoolToString(m_useLocale));
+    n->AddAttribute(wxT("m_trimOnlyModifiedLines"), BoolToString(m_trimOnlyModifiedLines));
+    n->AddAttribute(wxT("m_debuggerMarkerLine"), m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
+    n->AddAttribute(wxT("OutputTabsDirection"), wxString() << (int)m_outputTabsDirection);
+    n->AddAttribute(wxT("SidebarButtonsPosition"), wxString() << (int)m_workspaceTabsDirection);
+    n->AddAttribute(wxT("IndentedComments"), BoolToString(m_indentedComments));
+    n->AddAttribute(wxT("CopyLineEmptySelection"), BoolToString(m_copyLineEmptySelection));
+    n->AddAttribute(wxT("SmartParen"), BoolToString(m_smartParen));
+    n->AddAttribute(wxT("ShowRightMargin"), BoolToString(m_showRightMarginIndicator));
+    n->AddAttribute(wxT("RightMarginnColumn"), wxString() << m_rightMarginColumn);
 
     wxString tmp;
     tmp << m_indentWidth;
-    n->AddProperty(wxT("IndentWidth"), tmp);
+    n->AddAttribute(wxT("IndentWidth"), tmp);
 
     tmp.clear();
     tmp << m_tabWidth;
-    n->AddProperty(wxT("TabWidth"), tmp);
+    n->AddAttribute(wxT("TabWidth"), tmp);
 
     tmp.clear();
     tmp << m_iconsSize;
-    n->AddProperty(wxT("ToolbarIconSize"), tmp);
+    n->AddAttribute(wxT("ToolbarIconSize"), tmp);
 
     tmp.clear();
-    tmp << m_showWhitspaces;
-    n->AddProperty(wxT("ShowWhitespaces"), tmp);
-
-    tmp.clear();
-    tmp << m_edgeMode;
-    n->AddProperty(wxT("EdgeMode"), tmp);
-
-    tmp.clear();
-    tmp << m_edgeColumn;
-    n->AddProperty(wxT("EdgeColumn"), tmp);
-
-    n->AddProperty(wxT("EdgeColour"), m_edgeColour.GetAsString(wxC2S_HTML_SYNTAX));
+    tmp << m_showWhitespaces;
+    n->AddAttribute(wxT("ShowWhitespaces"), tmp);
 
     tmp.clear();
     tmp << m_caretWidth;
-    n->AddProperty(wxT("CaretWidth"), tmp);
+    n->AddAttribute(wxT("CaretWidth"), tmp);
 
     tmp.clear();
     tmp << m_caretBlinkPeriod;
-    n->AddProperty(wxT("CaretBlinkPeriod"), tmp);
+    n->AddAttribute(wxT("CaretBlinkPeriod"), tmp);
 
     tmp.clear();
     tmp << m_caretLineAlpha;
-    n->AddProperty(wxT("CaretLineAlpha"), tmp);
+    n->AddAttribute(wxT("CaretLineAlpha"), tmp);
 
     tmp.clear();
     tmp = wxFontMapper::GetEncodingName(m_fileFontEncoding);
-    n->AddProperty(wxT("FileFontEncoding"), tmp);
-
-    tmp.Clear();
-    tmp << m_options;
-    n->AddProperty(wxT("m_options"), tmp);
-
-    tmp.Clear();
-    tmp << m_options2;
-    n->AddProperty(wxT("m_options2"), tmp);
-
-    n->AddProperty(wxT("m_webSearchPrefix"), m_webSearchPrefix);
+    n->AddAttribute(wxT("FileFontEncoding"), tmp);
 
+    n->AddAttribute(wxT("options_bits"), m_options.to_string());
+    n->AddAttribute(wxT("m_webSearchPrefix"), m_webSearchPrefix);
     return n;
 }
 
@@ -385,18 +370,20 @@ void OptionsConfig::SetFileFontEncoding(const wxString& strFileFontEncoding)
 {
     this->m_fileFontEncoding = wxFontMapper::Get()->CharsetToEncoding(strFileFontEncoding, false);
 
-    if(wxFONTENCODING_SYSTEM == this->m_fileFontEncoding) { this->m_fileFontEncoding = wxFONTENCODING_UTF8; }
+    if (wxFONTENCODING_SYSTEM == this->m_fileFontEncoding) {
+        this->m_fileFontEncoding = wxFONTENCODING_UTF8;
+    }
 }
 
 wxString OptionsConfig::GetEOLAsString() const
 {
-    if(GetEolMode() == wxT("Unix (LF)")) {
+    if (GetEolMode() == wxT("Unix (LF)")) {
         return "\n";
 
-    } else if(GetEolMode() == wxT("Mac (CR)")) {
+    } else if (GetEolMode() == wxT("Mac (CR)")) {
         return "\r";
 
-    } else if(GetEolMode() == wxT("Windows (CRLF)")) {
+    } else if (GetEolMode() == wxT("Windows (CRLF)")) {
         return "\r\n";
 
     } else {
@@ -408,7 +395,9 @@ wxColour OptionsConfig::GetBookmarkFgColour(size_t index) const
 {
     wxColour col;
     wxArrayString arr = wxSplit(m_bookmarkFgColours, ';');
-    if(index < arr.GetCount()) { return wxColour(arr.Item(index)); }
+    if (index < arr.GetCount()) {
+        return wxColour(arr.Item(index));
+    }
 
     return col;
 }
@@ -416,7 +405,7 @@ wxColour OptionsConfig::GetBookmarkFgColour(size_t index) const
 void OptionsConfig::SetBookmarkFgColour(wxColour c, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkFgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = c.GetAsString(wxC2S_HTML_SYNTAX);
         m_bookmarkFgColours = wxJoin(arr, ';');
     }
@@ -426,7 +415,9 @@ wxColour OptionsConfig::GetBookmarkBgColour(size_t index) const
 {
     wxColour col;
     wxArrayString arr = wxSplit(m_bookmarkBgColours, ';');
-    if(index < arr.GetCount()) { return wxColour(arr.Item(index)); }
+    if (index < arr.GetCount()) {
+        return wxColour(arr.Item(index));
+    }
 
     return col;
 }
@@ -434,7 +425,7 @@ wxColour OptionsConfig::GetBookmarkBgColour(size_t index) const
 void OptionsConfig::SetBookmarkBgColour(wxColour c, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkBgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = c.GetAsString(wxC2S_HTML_SYNTAX);
         m_bookmarkBgColours = wxJoin(arr, ';');
     }
@@ -443,7 +434,9 @@ void OptionsConfig::SetBookmarkBgColour(wxColour c, size_t index)
 wxString OptionsConfig::GetBookmarkLabel(size_t index) const
 {
     wxArrayString arr = wxSplit(m_bookmarkLabels, ';');
-    if(index < arr.GetCount()) { return arr.Item(index); }
+    if (index < arr.GetCount()) {
+        return arr.Item(index);
+    }
 
     return "";
 }
@@ -451,7 +444,7 @@ wxString OptionsConfig::GetBookmarkLabel(size_t index) const
 void OptionsConfig::SetBookmarkLabel(const wxString& label, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkLabels, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = label;
         m_bookmarkLabels = wxJoin(arr, ';');
     }
@@ -459,40 +452,37 @@ void OptionsConfig::SetBookmarkLabel(const wxString& label, size_t index)
 
 void OptionsConfig::UpdateFromEditorConfig(const clEditorConfigSection& section)
 {
-    if(section.IsInsertFinalNewlineSet()) { this->SetAppendLF(section.IsInsertFinalNewline()); }
-    if(section.IsSetEndOfLineSet()) {
+    if (section.IsInsertFinalNewlineSet()) {
+        this->SetAppendLF(section.IsInsertFinalNewline());
+    }
+    if (section.IsSetEndOfLineSet()) {
         // Convert .editorconfig to CodeLite strings
         wxString eolMode = "Unix (LF)"; // default
-        if(section.GetEndOfLine() == "crlf") {
+        if (section.GetEndOfLine() == "crlf") {
             eolMode = "Windows (CRLF)";
-        } else if(section.GetEndOfLine() == "cr") {
+        } else if (section.GetEndOfLine() == "cr") {
             eolMode = "Mac (CR)";
         }
         this->SetEolMode(eolMode);
     }
-    if(section.IsTabWidthSet()) { this->SetTabWidth(section.GetTabWidth()); }
-    if(section.IsIndentStyleSet()) { this->SetIndentUsesTabs(section.GetIndentStyle() == "tab"); }
-    if(section.IsTabWidthSet()) { this->SetTabWidth(section.GetTabWidth()); }
-    if(section.IsIndentSizeSet()) { this->SetIndentWidth(section.GetIndentSize()); }
-    if(section.IsCharsetSet()) {
+    if (section.IsTabWidthSet()) {
+        this->SetTabWidth(section.GetTabWidth());
+    }
+    if (section.IsIndentStyleSet()) {
+        this->SetIndentUsesTabs(section.GetIndentStyle() == "tab");
+    }
+    if (section.IsTabWidthSet()) {
+        this->SetTabWidth(section.GetTabWidth());
+    }
+    if (section.IsIndentSizeSet()) {
+        this->SetIndentWidth(section.GetIndentSize());
+    }
+    if (section.IsCharsetSet()) {
         // TODO: fix the locale here
     }
 }
 
-bool OptionsConfig::IsTabColourDark() const
-{
-#if USE_AUI_NOTEBOOK
-    return false;
-#else
-    return HasOption(Opt_TabColourDark);
-#endif
-}
-
-bool OptionsConfig::IsTabColourMatchesTheme() const
-{
-#if USE_AUI_NOTEBOOK
-    return true;
-#else
-    return !HasOption(Opt_TabColourPersistent);
-#endif
-}
+bool OptionsConfig::IsTabColourDark() const { return HasOption(Opt_TabColourDark); }
+bool OptionsConfig::IsTabColourMatchesTheme() const { return !HasOption(Opt_TabColourPersistent); }
+void OptionsConfig::EnableOption(size_t flag, bool b) { m_options.set(flag, b); }
+bool OptionsConfig::HasOption(size_t flag) const { return m_options.test(flag); }
