@@ -26,49 +26,62 @@
 #ifndef OPTIONS_CONFIG_H
 #define OPTIONS_CONFIG_H
 
-#include "wx/string.h"
-#include "wx/xml/xml.h"
-#include "wx/colour.h"
-#include "wx/font.h"
-#include "configuration_object.h"
+#include "clBitset.hpp"
+#include "clEditorConfig.h"
 #include "codelite_exports.h"
+#include "configuration_object.h"
+
+#include <memory>
+#include <wx/colour.h>
+#include <wx/font.h>
+#include <wx/string.h>
+#include <wx/xml/xml.h>
 
 class WXDLLIMPEXP_SDK OptionsConfig : public ConfObject
 {
 public:
     enum {
-        Opt_Unused10 = 0x00000001,
-        Opt_Unused11 = 0x00000002,
-        Opt_Unused12 = 0x00000004,
-        Opt_AutoCompleteCurlyBraces = 0x00000008,
-        Opt_AutoCompleteNormalBraces = 0x00000010,
-        Opt_SmartAddFiles = 0x00000020,
-        Opt_IconSet_FreshFarm = 0x00000040,
-        Opt_IconSet_Classic = 0x00000100,
-        Opt_AutoCompleteDoubleQuotes = 0x00000200,
-        Opt_NavKey_Shift = 0x00000400, // (No longer actively used)
-        Opt_NavKey_Alt = 0x00000800,
-        Opt_NavKey_Control = 0x00001000,
-        Opt_IconSet_Classic_Dark = 0x00002000,
-        Opt_Mark_Debugger_Line = 0x00004000,
-        Opt_TabNoXButton = 0x00008000,
-        Opt_TabColourPersistent = 0x00010000,
-        Opt_Unused3 = 0x00020000,
-        Opt_Use_CodeLite_Terminal = 0x00040000,
-        Opt_Unused6 = 0x00080000,
-        Opt_Unused5 = 0x00100000,
-        Opt_AllowCaretAfterEndOfLine = 0x00200000,
-        Opt_HideDockingWindowCaption = 0x00400000,
-        Opt_WrapQuotes = 0x00800000,
-        Opt_WrapBrackets = 0x01000000,
-        Opt_WrapCmdWithDoubleQuotes = 0x02000000,
-        Opt_FoldHighlightActiveBlock = 0x04000000,
-        Opt_EnsureCaptionsVisible = 0x08000000,
-        Opt_DisableMouseCtrlZoom = 0x10000000,
-        Opt_UseBlockCaret =   0x20000000,
-        Opt_TabStyleMinimal = 0x40000000,
+        Opt_Unused10,
+        Opt_Unused11,
+        Opt_Unused12,
+        Opt_AutoCompleteCurlyBraces,
+        Opt_AutoCompleteNormalBraces,
+        Opt_SmartAddFiles,
+        Opt_IconSet_FreshFarm,
+        Opt_TabStyleTRAPEZOID,
+        Opt_IconSet_Classic,
+        Opt_AutoCompleteDoubleQuotes,
+        Opt_NavKey_Shift,
+        Opt_NavKey_Alt,
+        Opt_NavKey_Control,
+        Opt_IconSet_Classic_Dark,
+        Opt_Mark_Debugger_Line,
+        Opt_TabNoXButton,
+        Opt_TabColourPersistent,
+        Opt_TabColourDark,
+        Opt_Use_CodeLite_Terminal,
+        Opt_Unused14,
+        Opt_Unused15,
+        Opt_AllowCaretAfterEndOfLine,
+        Opt_HideDockingWindowCaption,
+        Opt_WrapQuotes,
+        Opt_WrapBrackets,
+        Opt_WrapCmdWithDoubleQuotes,
+        Opt_FoldHighlightActiveBlock,
+        Opt_EnsureCaptionsVisible,
+        Opt_DisableMouseCtrlZoom,
+        Opt_UseBlockCaret,
+        Opt_TabStyleMinimal,
+        Opt_TabNoPath,
+        Opt2_MouseScrollSwitchTabs,
+        Opt2_SortTabsDropdownAlphabetically,
+        Opt2_PlaceNavBarAtTheTop,
+        Opt2_DisableCtrlTabForTabSwitching,
+        Opt2_SortNavBarDropdown,
     };
 
+    enum { nbTabHt_Tiny = 1, nbTabHt_Short, nbTabHt_Medium, nbTabHt_Tall };
+
 protected:
     bool m_displayFoldMargin;
     bool m_underlineFoldLine;
@@ -80,8 +93,10 @@ protected:
     wxString m_bookmarkFgColours;
     wxString m_bookmarkLabels;
     bool m_highlightCaretLine;
-    bool m_clearHighlitWordsOnFind;
+    bool m_highlightCaretLineWithColour;
+    bool m_clearHighlightedWordsOnFind;
     bool m_displayLineNumbers;
+    bool m_relativeLineNumbers;
     bool m_showIndentationGuidelines;
     wxColour m_caretLineColour;
     bool m_indentUsesTabs;
@@ -89,22 +104,20 @@ protected:
     int m_tabWidth;
     int m_iconsSize;
     wxFontEncoding m_fileFontEncoding;
-    int m_showWhitspaces;
+    int m_showWhitespaces;
     bool m_foldCompact;
     bool m_foldAtElse;
     bool m_foldPreprocessor;
-    int m_edgeMode;
-    int m_edgeColumn;
-    wxColour m_edgeColour;
     bool m_highlightMatchedBraces;
     wxColour m_foldBgColour;
     bool m_autoAdjustHScrollBarWidth;
     int m_caretWidth;
     int m_caretBlinkPeriod;
+    bool m_copyLineEmptySelection;
     wxString m_programConsoleCommand;
     wxString m_eolMode;
-    bool m_hideChangeMarkerMargin;
-    bool m_hideOutpuPaneOnUserClick;
+    bool m_trackEditorChanges;
+    bool m_hideOutputPaneOnUserClick;
     bool m_hideOutputPaneNotIfBuild;
     bool m_hideOutputPaneNotIfSearch;
     bool m_hideOutputPaneNotIfReplace;
@@ -127,6 +140,8 @@ protected:
     bool m_disableSemicolonShift;
     int m_caretLineAlpha;
     bool m_dontAutoFoldResults;
+    bool m_dontOverrideSearchStringWithSelection;
+    bool m_findNextOrPreviousUseSelection;
     bool m_showDebugOnRun;
     bool m_caretUseCamelCase;
     bool m_dontTrimCaretLine;
@@ -136,29 +151,27 @@ protected:
     wxString m_preferredLocale;
     bool m_useLocale;
     bool m_trimOnlyModifiedLines;
-    size_t m_options;
+    clBitset m_options;
     wxColour m_debuggerMarkerLine;
     wxDirection m_workspaceTabsDirection; // Up/Down/Left/Right
     wxDirection m_outputTabsDirection;    // Up/Down
     bool m_indentedComments;
+    int m_nbTabHeight; // Should notebook tabs be too tall, too short or...
+    wxString m_webSearchPrefix;
+    bool m_smartParen = true;
+    bool m_lineNumberHighlightCurrent = false;
+    bool m_showRightMarginIndicator = false;
+    int m_rightMarginColumn = 120;
 
 public:
     // Helpers
-    void EnableOption(size_t flag, bool b)
-    {
-        if(b) {
-            m_options |= flag;
-        } else {
-            m_options &= ~flag;
-        }
-    }
-
-    bool HasOption(size_t flag) const { return m_options & flag; }
+    void EnableOption(size_t flag, bool b);
+    bool HasOption(size_t flag) const;
 
 public:
-    OptionsConfig() {}
+    OptionsConfig() = default;
     OptionsConfig(wxXmlNode* node);
-    virtual ~OptionsConfig(void);
+    virtual ~OptionsConfig() = default;
 
     void SetOutputTabsDirection(const wxDirection& outputTabsDirection)
     {
@@ -174,13 +187,27 @@ public:
     //-------------------------------------
     // Setters/Getters
     //-------------------------------------
+
+    void SetSmartParen(bool smartParen) { this->m_smartParen = smartParen; }
+    bool IsSmartParen() const { return m_smartParen; }
     void SetTabColourMatchesTheme(bool b) { EnableOption(Opt_TabColourPersistent, !b); }
-    bool IsTabColourMatchesTheme() const { return !HasOption(Opt_TabColourPersistent); }
+    bool IsTabColourMatchesTheme() const;
+    void SetTabColourDark(bool b) { EnableOption(Opt_TabColourDark, b); }
+    bool IsTabColourDark() const;
     void SetTabHasXButton(bool b) { EnableOption(Opt_TabNoXButton, !b); }
     bool IsTabHasXButton() const { return !HasOption(Opt_TabNoXButton); }
-
-    void SetOptions(size_t options) { this->m_options = options; }
-    size_t GetOptions() const { return m_options; }
+    void SetTabShowPath(bool b) { EnableOption(Opt_TabNoPath, !b); }
+    bool IsTabShowPath() const { return !HasOption(Opt_TabNoPath); }
+    bool IsMouseScrollSwitchTabs() const { return HasOption(Opt2_MouseScrollSwitchTabs); }
+    void SetMouseScrollSwitchTabs(bool b) { EnableOption(Opt2_MouseScrollSwitchTabs, b); }
+    bool IsSortTabsDropdownAlphabetically() const { return HasOption(Opt2_SortTabsDropdownAlphabetically); }
+    void SetSortTabsDropdownAlphabetically(bool b) { EnableOption(Opt2_SortTabsDropdownAlphabetically, b); }
+    bool IsNavBarTop() const { return HasOption(Opt2_PlaceNavBarAtTheTop); }
+    void SetNavBarTop(bool b) { EnableOption(Opt2_PlaceNavBarAtTheTop, b); }
+    bool IsCtrlTabEnabled() const { return !HasOption(Opt2_DisableCtrlTabForTabSwitching); }
+    void SetCtrlTabEnabled(bool b) { EnableOption(Opt2_DisableCtrlTabForTabSwitching, !b); }
+    bool IsSortNavBarDropdown() const { return HasOption(Opt2_SortNavBarDropdown); }
+    void SetSortNavBarDropdown(bool b) { EnableOption(Opt2_SortNavBarDropdown, b); }
     void SetTrimOnlyModifiedLines(bool trimOnlyModifiedLines) { this->m_trimOnlyModifiedLines = trimOnlyModifiedLines; }
     bool GetTrimOnlyModifiedLines() const { return m_trimOnlyModifiedLines; }
     void SetPreferredLocale(const wxString& preferredLocale) { this->m_preferredLocale = preferredLocale; }
@@ -195,101 +222,108 @@ public:
     bool GetCaretUseCamelCase() const { return m_caretUseCamelCase; }
     void SetDontAutoFoldResults(bool dontAutoFoldResults) { this->m_dontAutoFoldResults = dontAutoFoldResults; }
     bool GetDontAutoFoldResults() const { return m_dontAutoFoldResults; }
+    void SetDontOverrideSearchStringWithSelection(bool dontOverrideSearchStringWithSelection)
+    {
+        m_dontOverrideSearchStringWithSelection = dontOverrideSearchStringWithSelection;
+    }
+    bool GetDontOverrideSearchStringWithSelection() const { return m_dontOverrideSearchStringWithSelection; }
+    void SetFindNextOrPreviousUseSelection(bool findNextOrPreviousUseSelection)
+    {
+        m_findNextOrPreviousUseSelection = findNextOrPreviousUseSelection;
+    }
+    bool GetFindNextOrPreviousUseSelection() const { return m_findNextOrPreviousUseSelection; }
     void SetShowDebugOnRun(bool showDebugOnRun) { this->m_showDebugOnRun = showDebugOnRun; }
     bool GetShowDebugOnRun() const { return m_showDebugOnRun; }
     bool GetDisableSemicolonShift() const { return m_disableSemicolonShift; }
     void SetDisableSemicolonShift(bool disableSemicolonShift) { this->m_disableSemicolonShift = disableSemicolonShift; }
     void SetDisableSmartIndent(bool disableSmartIndent) { this->m_disableSmartIndent = disableSmartIndent; }
     bool GetDisableSmartIndent() const { return m_disableSmartIndent; }
-    void SetTrimLine(const bool& trimLine) { this->m_TrimLine = trimLine; }
-    const bool& GetTrimLine() const { return m_TrimLine; }
-    void SetAppendLF(const bool& appendLF) { this->m_AppendLF = appendLF; }
-    const bool& GetAppendLF() const { return m_AppendLF; }
-    void SetFindBarAtBottom(const bool& findBarAtBottom) { this->m_findBarAtBottom = findBarAtBottom; }
-    const bool& GetFindBarAtBottom() const { return m_findBarAtBottom; }
+    void SetTrimLine(bool trimLine) { this->m_TrimLine = trimLine; }
+    bool GetTrimLine() const { return m_TrimLine; }
+    void SetAppendLF(bool appendLF) { this->m_AppendLF = appendLF; }
+    bool GetAppendLF() const { return m_AppendLF; }
+    void SetFindBarAtBottom(bool findBarAtBottom) { this->m_findBarAtBottom = findBarAtBottom; }
+    bool GetFindBarAtBottom() const { return m_findBarAtBottom; }
     void SetShowReplaceBar(bool show) { m_showReplaceBar = show; }
     bool GetShowReplaceBar() const { return m_showReplaceBar; }
-    void SetHideOutpuPaneOnUserClick(const bool& hideOutpuPaneOnUserClick)
+    void SetHideOutputPaneOnUserClick(bool hideOutputPaneOnUserClick)
     {
-        this->m_hideOutpuPaneOnUserClick = hideOutpuPaneOnUserClick;
+        this->m_hideOutputPaneOnUserClick = hideOutputPaneOnUserClick;
     }
-    const bool& GetHideOutpuPaneOnUserClick() const { return m_hideOutpuPaneOnUserClick; }
-    void SetHideOutputPaneNotIfBuild(const bool& HideOutpuPaneNotIfBuild)
+    bool GetHideOutputPaneOnUserClick() const { return m_hideOutputPaneOnUserClick; }
+    void SetHideOutputPaneNotIfBuild(bool HideOutputPaneNotIfBuild)
     {
-        this->m_hideOutputPaneNotIfBuild = HideOutpuPaneNotIfBuild;
+        this->m_hideOutputPaneNotIfBuild = HideOutputPaneNotIfBuild;
     }
-    const bool& GetHideOutputPaneNotIfBuild() const { return m_hideOutputPaneNotIfBuild; }
-    void SetHideOutputPaneNotIfSearch(const bool& HideOutpuPaneNotIfSearch)
+    bool GetHideOutputPaneNotIfBuild() const { return m_hideOutputPaneNotIfBuild; }
+    void SetHideOutputPaneNotIfSearch(bool HideOutputPaneNotIfSearch)
     {
-        this->m_hideOutputPaneNotIfSearch = HideOutpuPaneNotIfSearch;
+        this->m_hideOutputPaneNotIfSearch = HideOutputPaneNotIfSearch;
     }
-    const bool& GetHideOutputPaneNotIfSearch() const { return m_hideOutputPaneNotIfSearch; }
-    void SetHideOutputPaneNotIfReplace(const bool& HideOutpuPaneNotIfReplace)
+    bool GetHideOutputPaneNotIfSearch() const { return m_hideOutputPaneNotIfSearch; }
+    void SetHideOutputPaneNotIfReplace(bool HideOutputPaneNotIfReplace)
     {
-        this->m_hideOutputPaneNotIfReplace = HideOutpuPaneNotIfReplace;
+        this->m_hideOutputPaneNotIfReplace = HideOutputPaneNotIfReplace;
     }
-    const bool& GetHideOutputPaneNotIfReplace() const { return m_hideOutputPaneNotIfReplace; }
-    void SetHideOutputPaneNotIfReferences(const bool& HideOutpuPaneNotIfReferences)
+    bool GetHideOutputPaneNotIfReplace() const { return m_hideOutputPaneNotIfReplace; }
+    void SetHideOutputPaneNotIfReferences(bool HideOutputPaneNotIfReferences)
     {
-        this->m_hideOutputPaneNotIfReferences = HideOutpuPaneNotIfReferences;
+        this->m_hideOutputPaneNotIfReferences = HideOutputPaneNotIfReferences;
     }
-    const bool& GetHideOutputPaneNotIfReferences() const { return m_hideOutputPaneNotIfReferences; }
-    void SetHideOutputPaneNotIfOutput(const bool& HideOutpuPaneNotIfOutput)
+    bool GetHideOutputPaneNotIfReferences() const { return m_hideOutputPaneNotIfReferences; }
+    void SetHideOutputPaneNotIfOutput(bool HideOutputPaneNotIfOutput)
     {
-        this->m_hideOutputPaneNotIfOutput = HideOutpuPaneNotIfOutput;
+        this->m_hideOutputPaneNotIfOutput = HideOutputPaneNotIfOutput;
     }
-    const bool& GetHideOutputPaneNotIfOutput() const { return m_hideOutputPaneNotIfOutput; }
-    void SetHideOutputPaneNotIfTrace(const bool& HideOutpuPaneNotIfTrace)
+    bool GetHideOutputPaneNotIfOutput() const { return m_hideOutputPaneNotIfOutput; }
+    void SetHideOutputPaneNotIfTrace(bool HideOutputPaneNotIfTrace)
     {
-        this->m_hideOutputPaneNotIfTrace = HideOutpuPaneNotIfTrace;
+        this->m_hideOutputPaneNotIfTrace = HideOutputPaneNotIfTrace;
     }
-    const bool& GetHideOutputPaneNotIfTrace() const { return m_hideOutputPaneNotIfTrace; }
-    void SetHideOutputPaneNotIfTasks(const bool& HideOutpuPaneNotIfTasks)
+    bool GetHideOutputPaneNotIfTrace() const { return m_hideOutputPaneNotIfTrace; }
+    void SetHideOutputPaneNotIfTasks(bool HideOutputPaneNotIfTasks)
     {
-        this->m_hideOutputPaneNotIfTasks = HideOutpuPaneNotIfTasks;
+        this->m_hideOutputPaneNotIfTasks = HideOutputPaneNotIfTasks;
     }
-    const bool& GetHideOutputPaneNotIfTasks() const { return m_hideOutputPaneNotIfTasks; }
-    void SetHideOutputPaneNotIfBuildQ(const bool& HideOutpuPaneNotIfBuildQ)
+    bool GetHideOutputPaneNotIfTasks() const { return m_hideOutputPaneNotIfTasks; }
+    void SetHideOutputPaneNotIfBuildQ(bool HideOutputPaneNotIfBuildQ)
     {
-        this->m_hideOutputPaneNotIfBuildQ = HideOutpuPaneNotIfBuildQ;
+        this->m_hideOutputPaneNotIfBuildQ = HideOutputPaneNotIfBuildQ;
     }
-    const bool& GetHideOutputPaneNotIfBuildQ() const { return m_hideOutputPaneNotIfBuildQ; }
-    void SetHideOutputPaneNotIfCppCheck(const bool& HideOutpuPaneNotIfCppCheck)
+    bool GetHideOutputPaneNotIfBuildQ() const { return m_hideOutputPaneNotIfBuildQ; }
+    void SetHideOutputPaneNotIfCppCheck(bool HideOutputPaneNotIfCppCheck)
     {
-        this->m_hideOutputPaneNotIfCppCheck = HideOutpuPaneNotIfCppCheck;
+        this->m_hideOutputPaneNotIfCppCheck = HideOutputPaneNotIfCppCheck;
     }
-    const bool& GetHideOutputPaneNotIfCppCheck() const { return m_hideOutputPaneNotIfCppCheck; }
-    void SetHideOutputPaneNotIfSvn(const bool& HideOutpuPaneNotIfSvn)
+    bool GetHideOutputPaneNotIfCppCheck() const { return m_hideOutputPaneNotIfCppCheck; }
+    void SetHideOutputPaneNotIfSvn(bool HideOutputPaneNotIfSvn)
     {
-        this->m_hideOutputPaneNotIfSvn = HideOutpuPaneNotIfSvn;
+        this->m_hideOutputPaneNotIfSvn = HideOutputPaneNotIfSvn;
     }
-    const bool& GetHideOutputPaneNotIfSvn() const { return m_hideOutputPaneNotIfSvn; }
-    void SetHideOutputPaneNotIfCscope(const bool& HideOutpuPaneNotIfCscope)
+    bool GetHideOutputPaneNotIfSvn() const { return m_hideOutputPaneNotIfSvn; }
+    void SetHideOutputPaneNotIfCscope(bool HideOutputPaneNotIfCscope)
     {
-        this->m_hideOutputPaneNotIfCscope = HideOutpuPaneNotIfCscope;
+        this->m_hideOutputPaneNotIfCscope = HideOutputPaneNotIfCscope;
     }
-    const bool& GetHideOutputPaneNotIfCscope() const { return m_hideOutputPaneNotIfCscope; }
-    void SetHideOutputPaneNotIfGit(const bool& HideOutpuPaneNotIfGit)
+    bool GetHideOutputPaneNotIfCscope() const { return m_hideOutputPaneNotIfCscope; }
+    void SetHideOutputPaneNotIfGit(bool HideOutputPaneNotIfGit)
     {
-        this->m_hideOutputPaneNotIfGit = HideOutpuPaneNotIfGit;
+        this->m_hideOutputPaneNotIfGit = HideOutputPaneNotIfGit;
     }
-    const bool& GetHideOutputPaneNotIfGit() const { return m_hideOutputPaneNotIfGit; }
-    void SetHideOutputPaneNotIfDebug(const bool& HideOutpuPaneNotIfDebug)
+    bool GetHideOutputPaneNotIfGit() const { return m_hideOutputPaneNotIfGit; }
+    void SetHideOutputPaneNotIfDebug(bool HideOutputPaneNotIfDebug)
     {
-        this->m_hideOutputPaneNotIfDebug = HideOutpuPaneNotIfDebug;
+        this->m_hideOutputPaneNotIfDebug = HideOutputPaneNotIfDebug;
     }
-    const bool& GetHideOutputPaneNotIfDebug() const { return m_hideOutputPaneNotIfDebug; }
-    void SetHideOutputPaneNotIfMemCheck(const bool& HideOutpuPaneNotIfMemCheck)
+    bool GetHideOutputPaneNotIfDebug() const { return m_hideOutputPaneNotIfDebug; }
+    void SetHideOutputPaneNotIfMemCheck(bool HideOutputPaneNotIfMemCheck)
     {
-        this->m_hideOutputPaneNotIfMemCheck = HideOutpuPaneNotIfMemCheck;
-    }
-    const bool& GetHideOutputPaneNotIfMemCheck() const { return m_hideOutputPaneNotIfMemCheck; }
-    void SetHideChangeMarkerMargin(bool hideChangeMarkerMargin)
-    {
-        this->m_hideChangeMarkerMargin = hideChangeMarkerMargin;
+        this->m_hideOutputPaneNotIfMemCheck = HideOutputPaneNotIfMemCheck;
     }
+    bool GetHideOutputPaneNotIfMemCheck() const { return m_hideOutputPaneNotIfMemCheck; }
 
-    bool GetHideChangeMarkerMargin() const { return m_hideChangeMarkerMargin; }
+    void SetTrackChanges(bool b) { this->m_trackEditorChanges = b; }
+    bool IsTrackChanges() const { return m_trackEditorChanges; }
 
     bool GetIndentedComments() const { return m_indentedComments; }
     bool GetDisplayFoldMargin() const { return m_displayFoldMargin; }
@@ -304,10 +338,13 @@ public:
 
     wxString GetBookmarkLabel(size_t index) const;
 
-    bool GetClearHighlitWordsOnFind() const { return m_clearHighlitWordsOnFind; }
+    bool GetClearHighlightedWordsOnFind() const { return m_clearHighlightedWordsOnFind; }
 
     bool GetHighlightCaretLine() const { return m_highlightCaretLine; }
+    bool IsHighlightCaretLineWithColour() const { return m_highlightCaretLineWithColour; }
+    void SetHighlightCaretLineWithColour(bool b) { m_highlightCaretLineWithColour = b; }
     bool GetDisplayLineNumbers() const { return m_displayLineNumbers; }
+    bool GetRelativeLineNumbers() const { return m_relativeLineNumbers; }
     bool GetShowIndentationGuidelines() const { return m_showIndentationGuidelines; }
     wxColour GetCaretLineColour() const { return m_caretLineColour; }
 
@@ -324,49 +361,49 @@ public:
 
     void SetBookmarkLabel(const wxString& label, size_t index);
 
-    void SetClearHighlitWordsOnFind(bool b) { m_clearHighlitWordsOnFind = b; }
+    void SetClearHighlightedWordsOnFind(bool b) { m_clearHighlightedWordsOnFind = b; }
 
     void SetHighlightCaretLine(bool b) { m_highlightCaretLine = b; }
     void SetDisplayLineNumbers(bool b) { m_displayLineNumbers = b; }
+    void SetRelativeLineNumbers(bool b) { m_relativeLineNumbers = b; }
     void SetShowIndentationGuidelines(bool b) { m_showIndentationGuidelines = b; }
     void SetCaretLineColour(wxColour c) { m_caretLineColour = c; }
 
-    void SetIndentUsesTabs(const bool& indentUsesTabs) { this->m_indentUsesTabs = indentUsesTabs; }
-    const bool& GetIndentUsesTabs() const { return m_indentUsesTabs; }
-    void SetIndentWidth(const int& indentWidth) { this->m_indentWidth = indentWidth; }
-    const int& GetIndentWidth() const { return m_indentWidth; }
-    void SetTabWidth(const int& tabWidth) { this->m_tabWidth = tabWidth; }
-    const int& GetTabWidth() const { return m_tabWidth; }
+    void SetIndentUsesTabs(bool indentUsesTabs) { this->m_indentUsesTabs = indentUsesTabs; }
+    bool GetIndentUsesTabs() const { return m_indentUsesTabs; }
+    void SetIndentWidth(int indentWidth) { this->m_indentWidth = indentWidth; }
+    int GetIndentWidth() const { return m_indentWidth; }
+    void SetTabWidth(int tabWidth) { this->m_tabWidth = tabWidth; }
+    int GetTabWidth() const { return m_tabWidth; }
 
-    void SetIconsSize(const int& iconsSize) { this->m_iconsSize = iconsSize; }
-    const int& GetIconsSize() const { return m_iconsSize; }
+    void SetIconsSize(int iconsSize) { this->m_iconsSize = iconsSize; }
+    int GetIconsSize() const { return m_iconsSize; }
 
     void SetFileFontEncoding(const wxString& strFileFontEncoding);
     wxFontEncoding GetFileFontEncoding() const { return m_fileFontEncoding; }
 
-    void SetShowWhitspaces(const int& showWhitspaces) { this->m_showWhitspaces = showWhitspaces; }
-    const int& GetShowWhitspaces() const { return m_showWhitspaces; }
+    void SetShowWhitespaces(int showWhitespaces) { this->m_showWhitespaces = showWhitespaces; }
+    int GetShowWhitespaces() const { return m_showWhitespaces; }
 
-    void SetFoldAtElse(const bool& foldAtElse) { this->m_foldAtElse = foldAtElse; }
-    void SetFoldCompact(const bool& foldCompact) { this->m_foldCompact = foldCompact; }
-    const bool& GetFoldAtElse() const { return m_foldAtElse; }
-    const bool& GetFoldCompact() const { return m_foldCompact; }
-    void SetFoldPreprocessor(const bool& foldPreprocessor) { this->m_foldPreprocessor = foldPreprocessor; }
-    const bool& GetFoldPreprocessor() const { return m_foldPreprocessor; }
+    void SetFoldAtElse(bool foldAtElse) { this->m_foldAtElse = foldAtElse; }
+    void SetFoldCompact(bool foldCompact) { this->m_foldCompact = foldCompact; }
+    bool GetFoldAtElse() const { return m_foldAtElse; }
+    bool GetFoldCompact() const { return m_foldCompact; }
+    void SetFoldPreprocessor(bool foldPreprocessor) { this->m_foldPreprocessor = foldPreprocessor; }
+    bool GetFoldPreprocessor() const { return m_foldPreprocessor; }
 
-    void SetEdgeColour(const wxColour& edgeColour) { this->m_edgeColour = edgeColour; }
-    void SetEdgeColumn(int edgeColumn) { this->m_edgeColumn = edgeColumn; }
-    void SetEdgeMode(int edgeMode) { this->m_edgeMode = edgeMode; }
-
-    const wxColour& GetEdgeColour() const { return m_edgeColour; }
-    int GetEdgeColumn() const { return m_edgeColumn; }
-    int GetEdgeMode() const { return m_edgeMode; }
-
-    void SetHighlightMatchedBraces(const bool& highlightMatchedBraces)
+    void SetShowRightMarginIndicator(bool showRightMarginIndicator)
+    {
+        this->m_showRightMarginIndicator = showRightMarginIndicator;
+    }
+    void SetRightMarginColumn(int rightMarginColumn) { this->m_rightMarginColumn = rightMarginColumn; }
+    bool IsShowRightMarginIndicator() const { return m_showRightMarginIndicator; }
+    int GetRightMarginColumn() const { return m_rightMarginColumn; }
+    void SetHighlightMatchedBraces(bool highlightMatchedBraces)
     {
         this->m_highlightMatchedBraces = highlightMatchedBraces;
     }
-    const bool& GetHighlightMatchedBraces() const { return m_highlightMatchedBraces; }
+    bool GetHighlightMatchedBraces() const { return m_highlightMatchedBraces; }
 
     void SetAutoAddMatchedCurlyBraces(bool autoAddMatchedBraces)
     {
@@ -384,15 +421,21 @@ public:
     bool IsHighlightFoldWhenActive() const { return HasOption(Opt_FoldHighlightActiveBlock); }
     void SetFoldBgColour(const wxColour& foldBgColour) { this->m_foldBgColour = foldBgColour; }
     const wxColour& GetFoldBgColour() const { return m_foldBgColour; }
-    void SetAutoAdjustHScrollBarWidth(const bool& autoAdjustHScrollBarWidth)
+    void SetAutoAdjustHScrollBarWidth(bool autoAdjustHScrollBarWidth)
     {
         this->m_autoAdjustHScrollBarWidth = autoAdjustHScrollBarWidth;
     }
-    const bool& GetAutoAdjustHScrollBarWidth() const { return m_autoAdjustHScrollBarWidth; }
-    void SetCaretBlinkPeriod(const int& caretBlinkPeriod) { this->m_caretBlinkPeriod = caretBlinkPeriod; }
-    void SetCaretWidth(const int& caretWidth) { this->m_caretWidth = caretWidth; }
-    const int& GetCaretBlinkPeriod() const { return m_caretBlinkPeriod; }
-    const int& GetCaretWidth() const { return m_caretWidth; }
+    bool GetAutoAdjustHScrollBarWidth() const { return m_autoAdjustHScrollBarWidth; }
+    void SetCaretBlinkPeriod(int caretBlinkPeriod) { this->m_caretBlinkPeriod = caretBlinkPeriod; }
+    void SetCaretWidth(int caretWidth) { this->m_caretWidth = caretWidth; }
+    int GetCaretBlinkPeriod() const { return m_caretBlinkPeriod; }
+    int GetCaretWidth() const { return m_caretWidth; }
+
+    void SetCopyLineEmptySelection(const bool copyLineEmptySelection)
+    {
+        m_copyLineEmptySelection = copyLineEmptySelection;
+    }
+    bool GetCopyLineEmptySelection() const { return m_copyLineEmptySelection; }
 
     void SetProgramConsoleCommand(const wxString& programConsoleCommand)
     {
@@ -421,11 +464,24 @@ public:
     bool IsWrapSelectionBrackets() const { return HasOption(Opt_WrapBrackets); }
     void SetWrapSelectionWithQuotes(bool b) { return EnableOption(Opt_WrapQuotes, b); }
     void SetWrapSelectionBrackets(bool b) { return EnableOption(Opt_WrapBrackets, b); }
+    void SetNotebookTabHeight(int nbTabHeight) { m_nbTabHeight = nbTabHeight; }
+    int GetNotebookTabHeight() const { return m_nbTabHeight; }
 
     void MSWWrapCmdWithDoubleQuotes(bool b) { EnableOption(Opt_WrapCmdWithDoubleQuotes, b); }
     bool MSWIsWrapCmdWithDoubleQuotes() const { return true; }
     bool IsMouseZoomEnabled() const { return !HasOption(Opt_DisableMouseCtrlZoom); }
     void SetMouseZoomEnabled(bool b) { EnableOption(Opt_DisableMouseCtrlZoom, !b); }
+
+    const wxString& GetWebSearchPrefix() const { return m_webSearchPrefix; }
+    void SetWebSearchPrefix(const wxString& webSearchPrefix) { this->m_webSearchPrefix = webSearchPrefix; }
+
+    void UpdateFromEditorConfig(const clEditorConfigSection& section);
+
+    void SetLineNumberHighlightCurrent(bool lineNumberHighlightCurrent)
+    {
+        this->m_lineNumberHighlightCurrent = lineNumberHighlightCurrent;
+    }
+    bool IsLineNumberHighlightCurrent() const { return m_lineNumberHighlightCurrent; }
     /**
      * Return an XML representation of this object
      * \return XML node
@@ -433,6 +489,6 @@ public:
     wxXmlNode* ToXml() const;
 };
 
-typedef SmartPtr<OptionsConfig> OptionsConfigPtr;
+using OptionsConfigPtr = std::shared_ptr<OptionsConfig>;
 
 #endif // OPTIONS_CONFIG_H
