@@ -27,22 +27,19 @@
 
 #include "JSON.h"
 #include "codelite_exports.h"
-#include "localworkspace.h"
 #include "macros.h"
-#include "optionsconfig.h"
 #include "project_settings.h"
-#include "serialized_object.h"
-#include "smart_ptr.h"
-#include "wx/filename.h"
-#include "wx/string.h"
-#include "wx/treectrl.h"
-#include "xmlutils.h"
+#include "tree.h"
+
 #include <list>
-#include <queue>
+#include <memory>
 #include <set>
-#include <tree.h>
+#include <unordered_map>
 #include <vector>
+#include <wx/filename.h>
 #include <wx/sharedptr.h>
+#include <wx/string.h>
+#include <wx/treebase.h>
 #include <wx/xml/xml.h>
 
 #define PROJECT_TYPE_STATIC_LIBRARY "Static Library"
@@ -74,7 +71,7 @@ public:
     wxString m_key;
     wxString m_displayName;
     wxString m_file;
-    int m_kind;
+    int m_kind = TypeProject;
 
 public:
     //---------------------------------------------------------------
@@ -88,30 +85,12 @@ public:
     {
     }
 
-    ProjectItem()
-        : m_key(wxEmptyString)
-        , m_displayName(wxEmptyString)
-        , m_file(wxEmptyString)
-        , m_kind(TypeProject)
-    {
-    }
+    ProjectItem() = default;
 
-    virtual ~ProjectItem() {}
+    virtual ~ProjectItem() = default;
 
-    ProjectItem(const ProjectItem& item) { *this = item; }
-
-    ProjectItem& operator=(const ProjectItem& item)
-    {
-        if(this == &item) {
-            return *this;
-        }
-
-        m_key = item.m_key;
-        m_displayName = item.m_displayName;
-        m_file = item.m_file;
-        m_kind = item.m_kind;
-        return *this;
-    }
+    ProjectItem(const ProjectItem&) = default;
+    ProjectItem& operator=(const ProjectItem&) = default;
 
     //-----------------------------------------
     // Setters / Getters
@@ -138,16 +117,16 @@ public:
 };
 
 // useful typedefs
-typedef Tree<wxString, ProjectItem> ProjectTree;
-typedef SmartPtr<ProjectTree> ProjectTreePtr;
-typedef TreeNode<wxString, ProjectItem> ProjectTreeNode;
+using ProjectTree = Tree<wxString, ProjectItem>;
+using ProjectTreePtr = std::shared_ptr<ProjectTree>;
+using ProjectTreeNode = TreeNode<wxString, ProjectItem>;
 
 class Project;
 class clCxxWorkspace;
 
-typedef SmartPtr<Project> ProjectPtr;
-typedef std::set<wxFileName> FileNameSet_t;
-typedef std::vector<wxFileName> FileNameVector_t;
+using ProjectPtr = std::shared_ptr<Project>;
+using FileNameSet_t = std::set<wxFileName>;
+using FileNameVector_t = std::vector<wxFileName>;
 
 // -----------------------------------------
 // File meta data
@@ -157,17 +136,13 @@ class WXDLLIMPEXP_SDK clProjectFile
     wxString m_filename;
     wxString m_virtualFolder;
     wxString m_filenameRelpath;
-    size_t m_flags;
+    size_t m_flags = 0;
     wxStringSet_t m_excludeConfigs;
-    wxXmlNode* m_xmlNode;
+    wxXmlNode* m_xmlNode = nullptr;
 
 public:
-    clProjectFile()
-        : m_flags(0)
-        , m_xmlNode(nullptr)
-    {
-    }
-    ~clProjectFile() {}
+    clProjectFile() = default;
+    ~clProjectFile() = default;
 
     void SetExcludeConfigs(Project* project, const wxStringSet_t& excludeConfigs);
     void SetExcludeConfigs(Project* project, const wxArrayString& excludeConfigs);
@@ -185,7 +160,7 @@ public:
     void SetFlags(size_t flags) { this->m_flags = flags; }
     size_t GetFlags() const { return m_flags; }
     /**
-     * @brief return true if this file should be execluded from the build of a specific configuration
+     * @brief return true if this file should be excluded from the build of a specific configuration
      */
     bool IsExcludeFromConfiguration(const wxString& config) const { return m_excludeConfigs.count(config); }
     void Rename(Project* project, const wxString& newName);
@@ -196,8 +171,8 @@ public:
      */
     void Delete(Project* project, bool deleteXml = false);
 
-    typedef wxSharedPtr<clProjectFile> Ptr_t;
-    typedef std::vector<clProjectFile::Ptr_t> Vec_t;
+    using Ptr_t = wxSharedPtr<clProjectFile>;
+    using Vec_t = std::vector<clProjectFile::Ptr_t>;
 };
 
 class WXDLLIMPEXP_SDK clProjectFolder
@@ -206,11 +181,11 @@ private:
     wxString m_fullpath;
     wxString m_name;
     wxStringSet_t m_files;
-    wxXmlNode* m_xmlNode;
+    wxXmlNode* m_xmlNode = nullptr;
 
 public:
-    typedef wxSharedPtr<clProjectFolder> Ptr_t;
-    typedef std::vector<clProjectFolder> Vect_t;
+    using Ptr_t = wxSharedPtr<clProjectFolder>;
+    using Vect_t = std::vector<clProjectFolder>;
 
 public:
     clProjectFolder(const wxString& fullpath, wxXmlNode* node)
@@ -258,7 +233,7 @@ public:
     bool IsFolderExists(Project* project, const wxString& name) const;
 
     /**
-     * @brief reutrn child folder. Can be nullptr
+     * @brief return child folder. Can be nullptr
      */
     clProjectFolder::Ptr_t GetChild(Project* project, const wxString& name) const;
 
@@ -300,10 +275,9 @@ public:
  */
 class WXDLLIMPEXP_SDK Project
 {
-
 public:
-    typedef std::unordered_map<wxString, clProjectFile::Ptr_t> FilesMap_t;
-    typedef std::unordered_map<wxString, clProjectFolder::Ptr_t> FoldersMap_t;
+    using FilesMap_t = std::unordered_map<wxString, clProjectFile::Ptr_t>;
+    using FoldersMap_t = std::unordered_map<wxString, clProjectFolder::Ptr_t>;
 
     friend class clCxxWorkspace;
     friend class clProjectFolder;
@@ -313,11 +287,11 @@ private:
     wxXmlDocument m_doc;
     wxFileName m_fileName;
     wxString m_projectPath;
-    bool m_tranActive;
-    bool m_isModified;
-    time_t m_modifyTime;
-    clCxxWorkspace* m_workspace;
-    ProjectSettingsPtr m_settings;
+    bool m_tranActive = false;
+    bool m_isModified = false;
+    time_t m_modifyTime{};
+    clCxxWorkspace* m_workspace = nullptr;
+    ProjectSettingsPtr m_settings = std::make_shared<ProjectSettings>(nullptr);
     wxString m_iconPath; /// Not serializable
     wxArrayString m_cachedIncludePaths;
     wxString m_workspaceFolder; // The folder in which this project is contained. Separated by "/"
@@ -335,15 +309,10 @@ private:
     void DoUpdateProjectSettings();
     void DoBuildCacheFromXml();
     clProjectFile::Ptr_t FileFromXml(wxXmlNode* node, const wxString& vd);
-    wxArrayString DoGetCompilerOptions(bool cxxOptions, bool clearCache = false, bool noDefines = true,
-                                       bool noIncludePaths = true);
-    wxArrayString DoGetUnPreProcessors(bool clearCache, const wxString& cmpOptions);
+    wxArrayString DoGetCompilerOptions(bool cxxOptions, bool noDefines, bool noIncludePaths);
 
     clProjectFolder::Ptr_t GetRootFolder();
 
-    /// Upgrade the project settings to match the new builder system
-    void UpgradeBuildSystem();
-
 public:
     /**
      * @brief return list of files that are excluded from *any* build configuration
@@ -395,21 +364,21 @@ public:
     void ClearIncludePathCache();
 
     /**
-     * @brief a project was renamed - update our dependeices if needed
+     * @brief a project was renamed - update our dependencies if needed
      */
     void ProjectRenamed(const wxString& oldname, const wxString& newname);
     void SetIconPath(const wxString& iconPath) { this->m_iconPath = iconPath; }
     const wxString& GetIconPath() const { return m_iconPath; }
     /**
-     * @brief return set of compilers used by this project for the active build configuraion
+     * @brief return set of compilers used by this project for the active build configuration
      */
-    void GetCompilers(wxStringSet_t& compilers);
+    void GetCompilers(wxStringSet_t& compilers) const;
 
     /**
-     * @brief replace compilers by name. compilers contains a map of the "olbd" compiler
+     * @brief replace compilers by name. compilers contains a map of the "old" compiler
      * name and the new compiler name
      */
-    void ReplaceCompilers(wxStringMap_t& compilers);
+    void ReplaceCompilers(const wxStringMap_t& compilers);
 
     /**
      * @brief the const version of the above
@@ -438,26 +407,20 @@ public:
     //--------------------------------------------------
 
     // default constructor
-    Project();
-    virtual ~Project();
+    Project() = default;
+    virtual ~Project() = default;
 
     /**
      * @brief return list of macros used in the configuration which could not be resolved
      * by CodeLite
      */
-    void GetUnresolvedMacros(const wxString& configName, wxArrayString& vars) const;
+    wxArrayString GetUnresolvedMacros(const wxString& configName) const;
 
     /**
      * \return project name
      */
     wxString GetName() const;
 
-    /**
-     * \brief return the project description as appears in the XML file
-     * \return project description
-     */
-    wxString GetDescription() const;
-
     //-----------------------------------
     // Project operations
     //-----------------------------------
@@ -487,7 +450,7 @@ public:
     bool AddFile(const wxString& fileName, const wxString& virtualDir = wxEmptyString);
 
     /**
-     * Add file to the project - dont check for file duplication, this
+     * Add file to the project - don't check for file duplication
      * \param fileName file full name and path
      * \param virtualDir owner virtual directory, if the virtual directory does not exist, a new one will be created
      *        and the file will be placed under it
@@ -503,14 +466,6 @@ public:
      */
     bool RemoveFile(const wxString& fileName, const wxString& virtualDir = wxEmptyString);
 
-    /**
-     * Rename file from the project
-     * \param fileName file full path
-     * \param virtualDir owner virtual directory
-     * \return true on success, false otherwise
-     */
-    bool RenameFile(const wxString& oldName, const wxString& virtualDir, const wxString& newName);
-
     /**
      * \brief change the name of a virtual folder
      * \param oldVdPath full path of the virtual folder
@@ -536,9 +491,9 @@ public:
     /**
      * Return list of files by a virtual directory
      * \param vdFullPath virtual directory
-     * \param files [output] list of files under this vdFullPath. The files format are in absolute path!
+     * \return list of files under this vdFullPath. The files format are in absolute path!
      */
-    void GetFilesByVirtualDir(const wxString& vdFullPath, wxArrayString& files, bool recurse = false);
+    wxArrayString GetFilesByVirtualDir(const wxString& vdFullPath, bool recurse = false);
 
     /**
      * Save project settings
@@ -555,7 +510,7 @@ public:
     /**
      * @brief return the files as vector
      */
-    void GetFilesAsVector(clProjectFile::Vec_t& files) const;
+    clProjectFile::Vec_t GetFilesAsVector() const;
 
     /**
      * @brief return the files as vector of wxFileName
@@ -572,16 +527,6 @@ public:
      */
     void GetFilesAsStringArray(wxArrayString& files, bool absPath = true) const;
 
-    /**
-     * Return a node pointing to any project-wide editor preferences
-     */
-    wxXmlNode* GetProjectEditorOptions() const;
-
-    /**
-     * Add or update local project options
-     */
-    void SetProjectEditorOptions(LocalOptionsConfigPtr opts);
-
     /**
      * Return the project build settings object by name
      */
@@ -601,15 +546,20 @@ public:
      * Get the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when
      * reconciling with filesystem reality
      */
-    void GetReconciliationData(wxString& toplevelDir, wxString& extensions, wxArrayString& ignoreFiles,
-                               wxArrayString& excludePaths, wxArrayString& regexes);
+    void GetReconciliationData(wxString& toplevelDir,
+                               wxString& extensions,
+                               wxArrayString& ignoreFiles,
+                               wxArrayString& excludePaths,
+                               wxArrayString& regexes);
 
     /**
      * Set the project's file toplevel directory, extensions, ignorefiles, exclude paths and regexes for use when
      * reconciling with filesystem reality
      */
-    void SetReconciliationData(const wxString& toplevelDir, const wxString& extensions,
-                               const wxArrayString& ignoreFiles, const wxArrayString& excludePaths,
+    void SetReconciliationData(const wxString& toplevelDir,
+                               const wxString& extensions,
+                               const wxArrayString& ignoreFiles,
+                               const wxArrayString& excludePaths,
                                wxArrayString& regexes);
     //-----------------------------------
     // visual operations
@@ -644,7 +594,7 @@ public:
     /**
      * \brief return true of the project was modified (in terms of files removed/added)
      */
-    bool IsModified();
+    bool IsModified() const;
 
     /**
      * \brief
@@ -652,8 +602,8 @@ public:
     void SetModified(bool mod);
 
     // Transaction support to reduce overhead of disk writing
-    void BeginTranscation() { m_tranActive = true; }
-    void CommitTranscation() { Save(); }
+    void BeginTransaction() { m_tranActive = true; }
+    void CommitTransaction() { Save(); }
     bool InTransaction() const { return m_tranActive; }
 
     wxString GetVDByFileName(const wxString& file);
@@ -664,22 +614,6 @@ public:
      */
     TreeNode<wxString, VisualWorkspaceNode>* GetVirtualDirectories(TreeNode<wxString, VisualWorkspaceNode>* workspace);
 
-    /**
-     * @brief return the user saved information for custom data
-     * @param name the object key
-     * @param obj [output] container for the output
-     * @return true on success.
-     */
-    bool GetUserData(const wxString& name, SerializedObject* obj);
-
-    /**
-     * @brief save user data in the project settings
-     * @param name the name under which the data is to be saved
-     * @param obj the data
-     * @return true on success.
-     */
-    bool SetUserData(const wxString& name, SerializedObject* obj);
-
     /**
      * @brief set the project internal type (usually used to indicate internal types for the project
      * like 'GUI' or 'UnitTest++' etc.
@@ -692,10 +626,6 @@ public:
      */
     wxString GetProjectInternalType() const;
 
-    /**
-     * @brief return the project icon index (used by the NewProjectDialog)
-     */
-    wxString GetProjectIconName() const;
     /**
      * @brief return the plugins' data. This data is copied when using 'save project as template' functionality
      * @param plugin plugin name
@@ -712,9 +642,8 @@ public:
 
     /**
      * @brief get all plugins data as map of plugin=value pair
-     * @param pluginsDataMap [output]
      */
-    void GetAllPluginsData(std::map<wxString, wxString>& pluginsDataMap);
+    std::map<wxString, wxString> GetAllPluginsData() const;
 
     /**
      * @brief set all plugins data as map of plugin=value pair
@@ -751,29 +680,17 @@ public:
      * The PreProcessors returned are from the build configuration
      * that matches the current workspace configuration
      */
-    wxArrayString GetPreProcessors(bool clearCache = false);
+    wxArrayString GetPreProcessors();
 
     /**
-     * @brief return the C++ Undefined Pre preprocessors
-     * These are the defined by -U__SOMETHING__
+     * @brief return the compiler. Optionally omit the defines/include paths
      */
-    wxArrayString GetCxxUnPreProcessors(bool clearCache = false);
+    wxArrayString GetCXXCompilerOptions(bool noDefines = true, bool noIncludePaths = true);
 
     /**
-     * @brief return the C Undefined Pre preprocessors
-     * These are the defined by -U__SOMETHING__
+     * @brief return the C compiler. Optionally omit the defines/include paths
      */
-    wxArrayString GetCUnPreProcessors(bool clearCache = false);
-
-    /**
-     * @brief return the compiler. Optionally ommit the defines/include paths
-     */
-    wxArrayString GetCXXCompilerOptions(bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
-
-    /**
-     * @brief return the C compiler. Optionally ommit the defines/include paths
-     */
-    wxArrayString GetCCompilerOptions(bool clearCache = false, bool noDefines = true, bool noIncludePaths = true);
+    wxArrayString GetCCompilerOptions(bool noDefines = true, bool noIncludePaths = true);
 
     /**
      * @brief return the compilation line for a C++ file in the project. This function returns the same
@@ -781,34 +698,13 @@ public:
      * file
      * name which can later be replaced by the caller with the actual file name
      */
-    wxString GetCompileLineForCXXFile(const wxStringMap_t& compilersGlobalPaths, BuildConfigPtr buildConf,
-                                      const wxString& filenamePlaceholder = "$FileName", size_t flags = kCxxFile);
+    wxString GetCompileLineForCXXFile(const wxStringMap_t& compilersGlobalPaths,
+                                      BuildConfigPtr buildConf,
+                                      const wxString& filenamePlaceholder = "$FileName",
+                                      size_t flags = kCxxFile);
 
     void ClearAllVirtDirs();
 
-    /**
-     * @brief sets the flags of a file
-     * @param fileName the fullpath of the file
-     * @param virtualDirPath virtual folder path (a:b:c)
-     * @param flags the flags to set
-     */
-    void SetFileFlags(const wxString& fileName, const wxString& virtualDirPath, size_t flags);
-
-    /**
-     * @brief return the flags for a specific file in the project
-     * @param fileName the fullpath of the file
-     * @param virtualDirPath virtual folder path (a:b:c)
-     * @return the virtual flags of a file or if the file does not exists, return 0
-     */
-    size_t GetFileFlags(const wxString& fileName, const wxString& virtualDirPath);
-
-    /**
-     * @brief return list of configurations for whom the current file is excluded from the build
-     * @param fileName the fullpath of the file
-     * @param virtualDirPath virtual folder path (a:b:c)
-     */
-    const wxStringSet_t& GetExcludeConfigForFile(const wxString& filename) const;
-
     /**
      * @brief set the exclude config list for a file
      * @param fileName the fullpath of the file
@@ -835,7 +731,8 @@ public:
     /**
      * @brief add this project files into the 'compile_commands' json object
      */
-    void CreateCompileCommandsJSON(JSONItem& compile_commands, const wxStringMap_t& compilersGlobalPaths,
+    void CreateCompileCommandsJSON(JSONItem& compile_commands,
+                                   const wxStringMap_t& compilersGlobalPaths,
                                    bool createCompileFlagsTxt);
 
     /**
@@ -860,9 +757,6 @@ private:
      */
     void AssociateToWorkspace(clCxxWorkspace* workspace);
 
-    wxString DoFormatVirtualFolderName(const wxXmlNode* node) const;
-
-    void DoDeleteVDFromCache(const wxString& vd);
     wxArrayString DoBacktickToIncludePath(const wxString& backtick);
     wxArrayString DoBacktickToPreProcessors(const wxString& backtick);
     wxString DoExpandBacktick(const wxString& backtick);
@@ -896,7 +790,7 @@ class WXDLLIMPEXP_SDK ProjectData
 {
 public:
     wxString m_name;           //< project name
-    wxString m_path;           //< project directoy
+    wxString m_path;           //< project directory
     ProjectPtr m_srcProject;   //< source project
     wxString m_cmpType;        //< Project compiler type
     wxString m_debuggerType;   //< Selected debugger
@@ -925,7 +819,7 @@ class WXDLLIMPEXP_SDK FilewViewTreeItemData : public wxTreeItemData
     ProjectItem m_item;
 
 public:
-    FilewViewTreeItemData(const ProjectItem& item)
+    explicit FilewViewTreeItemData(const ProjectItem& item)
         : m_item(item)
     {
     }
@@ -936,4 +830,9 @@ public:
     void SetFile(const wxString& file) { m_item.SetFile(file); }
 };
 
+/**
+ * @return list of projects available based on the installed templates
+ */
+WXDLLIMPEXP_SDK std::list<ProjectPtr> GetProjectTemplateList();
+
 #endif // PROJECT_H
