@@ -23,10 +23,10 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "project_settings.h"
-#include "xmlutils.h"
-#include "project.h"
+
 #include "macros.h"
-#include "wx_xml_compatibility.h"
+#include "project.h"
+#include "xmlutils.h"
 
 ProjectSettings::ProjectSettings(wxXmlNode* node)
 {
@@ -39,15 +39,15 @@ ProjectSettings::ProjectSettings(wxXmlNode* node)
                 wxString configName = XmlUtils::ReadString(child, wxT("Name"));
                 m_configs.insert(std::pair<wxString, BuildConfigPtr>(configName, new BuildConfig(child)));
             } else if(child->GetName() == wxT("GlobalSettings")) {
-                m_globalSettings = new BuildConfigCommon(child, wxT("GlobalSettings"));
+                m_globalSettings = std::make_shared<BuildConfigCommon>(child, wxT("GlobalSettings"));
             }
             child = child->GetNext();
         }
     } else {
         // create new settings with default values
-        m_projectType = Project::EXECUTABLE;
-        BuildConfig *conf(NULL);
-        
+        m_projectType = PROJECT_TYPE_EXECUTABLE;
+        BuildConfig* conf(NULL);
+
         conf = new BuildConfig(NULL);
         conf->SetName("Debug");
         conf->SetOutputFileName("$(IntermediateDirectory)/$(ProjectName)");
@@ -57,13 +57,11 @@ ProjectSettings::ProjectSettings(wxXmlNode* node)
 
     // Create global settings if it's not been loaded or by default
     if(!m_globalSettings) {
-        // wxLogMessage(wxT("ProjectSettings : Create global settings because it doesn't exists"));
-        m_globalSettings = new BuildConfigCommon(NULL, wxT("GlobalSettings"));
+        // clLogMessage(wxT("ProjectSettings : Create global settings because it doesn't exists"));
+        m_globalSettings = std::make_shared<BuildConfigCommon>(nullptr, wxT("GlobalSettings"));
     }
 }
 
-ProjectSettings::~ProjectSettings() {}
-
 ProjectSettings* ProjectSettings::Clone() const
 {
     wxXmlNode* node = ToXml();
@@ -75,11 +73,10 @@ ProjectSettings* ProjectSettings::Clone() const
 wxXmlNode* ProjectSettings::ToXml() const
 {
     wxXmlNode* node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Settings"));
-    node->AddProperty(wxT("Type"), m_projectType);
+    node->AddAttribute(wxT("Type"), m_projectType);
     node->AddChild(m_globalSettings->ToXml());
-    std::map<wxString, BuildConfigPtr>::const_iterator iter = m_configs.begin();
-    for(; iter != m_configs.end(); iter++) {
-        node->AddChild(iter->second->ToXml());
+    for (const auto& [_, config] : m_configs) {
+        node->AddChild(config->ToXml());
     }
     return node;
 }
@@ -163,11 +160,13 @@ BuildConfigPtr ProjectSettings::GetNextBuildConfiguration(ProjectSettingsCookie&
 
 void ProjectSettings::SetBuildConfiguration(const BuildConfigPtr bc)
 {
-    if(!bc) return;
+    if(!bc)
+        return;
 
     // delete the old build configuration pointer if any
     std::map<wxString, BuildConfigPtr>::iterator iter = m_configs.find(bc->GetName());
-    if(iter != m_configs.end()) m_configs.erase(iter);
+    if(iter != m_configs.end())
+        m_configs.erase(iter);
 
     // replace with the new one
     m_configs[bc->GetName()] = bc;
