@@ -28,16 +28,19 @@
 #if USE_SFTP
 
 #include "cl_config.h" // Base class: clConfigItem
-#include "ssh_account_info.h"
+#include "ssh/ssh_account_info.h"
 
 class WXDLLIMPEXP_SDK SFTPSettings : public clConfigItem
 {
     SSHAccountInfo::Vect_t m_accounts;
     wxString m_sshClient;
 
+private:
+    void MSWImportPuTTYAccounts();
+
 public:
     SFTPSettings();
-    virtual ~SFTPSettings();
+    virtual ~SFTPSettings() = default;
 
     void SetAccounts(const SSHAccountInfo::Vect_t& accounts) { this->m_accounts = accounts; }
     const SSHAccountInfo::Vect_t& GetAccounts() const { return m_accounts; }
@@ -54,8 +57,8 @@ public:
     SFTPSettings& Save();
 
 public:
-    virtual void FromJSON(const JSONElement& json);
-    virtual JSONElement ToJSON() const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON() const;
 };
 #endif // USE_SFTP
 #endif // SFTPSETTINGS_H
