@@ -23,10 +23,13 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "stringsearcher.h"
-#include <wx/regex.h>
+
+#include "StringUtils.h"
+#include "search_thread.h"
+
 #include <algorithm>
 #include <string>
-#include "globals.h"
+#include <wx/regex.h>
 
 static std::wstring Reverse(const std::wstring& str)
 {
@@ -62,10 +65,10 @@ wxString StringFindReplacer::GetString(const wxString& input, int from, bool sea
     }
 }
 
-bool StringFindReplacer::DoWildcardSearch(
-    const wxString& input, int startOffset, const wxString& find_what, size_t flags, int& pos, int& matchLen)
+bool StringFindReplacer::DoWildcardSearch(const wxString& input, int startOffset, const wxString& find_what,
+                                          size_t flags, int& pos, int& matchLen)
 {
-    // Conver the wildcard to regex
+    // Convert the wildcard to regex
     wxString regexPattern = find_what;
 
     // Escape braces
@@ -76,7 +79,7 @@ bool StringFindReplacer::DoWildcardSearch(
     regexPattern.Replace("{", "\\{");
     regexPattern.Replace("}", "\\}");
 
-    // Covnert match syntax to regular expression
+    // Convert match syntax to regular expression
     regexPattern.Replace("?", "."); // Any character
     regexPattern.Replace("*",
                          "[^\\n]*?"); // Non greedy wildcard '*', but don't allow matches to go beyond a single line
@@ -84,8 +87,8 @@ bool StringFindReplacer::DoWildcardSearch(
     return DoRESearch(input, startOffset, regexPattern, flags, pos, matchLen);
 }
 
-bool StringFindReplacer::DoRESearch(
-    const wxString& input, int startOffset, const wxString& find_what, size_t flags, int& pos, int& matchLen)
+bool StringFindReplacer::DoRESearch(const wxString& input, int startOffset, const wxString& find_what, size_t flags,
+                                    int& pos, int& matchLen)
 {
     wxString str = GetString(input, startOffset, flags & wxSD_SEARCH_BACKWARD ? true : false);
     if(str.IsEmpty()) {
@@ -99,11 +102,12 @@ bool StringFindReplacer::DoRESearch(
 #endif
     wxRegEx re;
     bool matchCase = flags & wxSD_MATCHCASE ? true : false;
-    if(!matchCase) re_flags |= wxRE_ICASE;
+    if(!matchCase)
+        re_flags |= wxRE_ICASE;
     re_flags |= wxRE_NEWLINE; // Handle \n as a special character
     re.Compile(find_what, re_flags);
 
-    // incase we are scanning NOT backwared, set the offset
+    // incase we are scanning NOT backward, set the offset
     if(!(flags & wxSD_SEARCH_BACKWARD)) {
         pos = startOffset;
     }
@@ -144,8 +148,8 @@ bool StringFindReplacer::DoRESearch(
     return false;
 }
 
-bool StringFindReplacer::DoSimpleSearch(
-    const wchar_t* pinput, int startOffset, const wchar_t* pfind_what, size_t flags, int& pos, int& matchLen)
+bool StringFindReplacer::DoSimpleSearch(const wchar_t* pinput, int startOffset, const wchar_t* pfind_what, size_t flags,
+                                        int& pos, int& matchLen)
 {
 #if wxVERSION_NUMBER >= 2900
     std::wstring input(pinput);
@@ -186,7 +190,7 @@ bool StringFindReplacer::DoSimpleSearch(
     std::wstring find_str(find_what);
     size_t offset(0);
 
-    // incase we are scanning backwared, revert the strings
+    // incase we are scanning backward, revert the strings
     if(flags & wxSD_SEARCH_BACKWARD) {
         find_str = Reverse(find_str);
         str = Reverse(str);
@@ -205,7 +209,7 @@ bool StringFindReplacer::DoSimpleSearch(
     while(upos != std::wstring::npos) {
         if(flags & wxSD_MATCHWHOLEWORD) {
             // full word match
-            // test that the characeter at upos - 1 & the character at upos + find_str.Len() are not
+            // test that the character at upos - 1 & the character at upos + find_str.Len() are not
             // valid word char [a-zA-Z0-9_]
             if(upos > 0) {
                 if(isalpha(str[upos - 1]) || isdigit(str[upos - 1]) || (int)str[upos - 1] == (int)'_') {
@@ -253,24 +257,19 @@ bool StringFindReplacer::DoSimpleSearch(
     return false;
 }
 
-bool StringFindReplacer::Search(const wchar_t* input,
-                                int startOffset,
-                                const wchar_t* find_what,
-                                size_t flags,
-                                int& pos,
-                                int& matchLen,
-                                int& posInChars,
-                                int& matchLenInChars)
+bool StringFindReplacer::Search(const wchar_t* input, int startOffset, const wchar_t* find_what, size_t flags, int& pos,
+                                int& matchLen, int& posInChars, int& matchLenInChars)
 {
     // adjust startOffset due to it is in bytes but should be in chars
     int iSO = startOffset;
     bool isUTF8 = false;
     if(iSO) {
-        int utfLen = clUTF8Length(input, iSO);
+        int utfLen = StringUtils::UTF8Length(input, iSO);
         isUTF8 = (utfLen != iSO);
     }
 
-    while(isUTF8 && (iSO > 0) && ((int)clUTF8Length(input, iSO) > startOffset)) iSO--;
+    while (isUTF8 && (iSO > 0) && ((int)StringUtils::UTF8Length(input, iSO) > startOffset))
+        iSO--;
     startOffset = iSO;
 
     bool bResult = false;
@@ -287,18 +286,18 @@ bool StringFindReplacer::Search(const wchar_t* input,
 
     // correct search Pos and Length owing to non plain ASCII multibyte characters
     if(bResult) {
-        pos = clUTF8Length(input, posInChars);
+        pos = StringUtils::UTF8Length(input, posInChars);
         if(flags & wxSD_REGULAREXPRESSION) {
-            matchLen = clUTF8Length(input, posInChars + matchLenInChars) - pos;
+            matchLen = StringUtils::UTF8Length(input, posInChars + matchLenInChars) - pos;
         } else {
-            matchLen = clUTF8Length(find_what, matchLenInChars);
+            matchLen = StringUtils::UTF8Length(find_what, matchLenInChars);
         }
     }
     return bResult;
 }
 
-bool StringFindReplacer::Search(
-    const wchar_t* input, int startOffset, const wchar_t* find_what, size_t flags, int& pos, int& matchLen)
+bool StringFindReplacer::Search(const wchar_t* input, int startOffset, const wchar_t* find_what, size_t flags, int& pos,
+                                int& matchLen)
 {
     int posInChars(0), matchLenInChars(0);
     return StringFindReplacer::Search(input, startOffset, find_what, flags, pos, matchLen, posInChars, matchLenInChars);
