@@ -25,53 +25,62 @@
 #ifndef WORKSPACE_H
 #define WORKSPACE_H
 
-#include "singleton.h"
-#include "wx/string.h"
-#include <wx/xml/xml.h>
-#include "wx/filename.h"
-#include "project.h"
-#include <map>
-#include "json_node.h"
-#include <wx/event.h>
-#include <cl_command_event.h>
 #include "IWorkspace.h"
-#include "configuration_mapping.h"
-#include "optionsconfig.h"
-#include "localworkspace.h"
+#include "JSON.h"
+#include "clWorkspaceManager.h"
+#include "cl_command_event.h"
 #include "codelite_exports.h"
+#include "configuration_mapping.h"
+#include "localworkspace.h"
+#include "optionsconfig.h"
+#include "project.h"
+#include "singleton.h"
+#include "wxStringHash.h"
 
-#define WORKSPACE_XML_VERSION "10.0.0"
+#include <map>
+#include <wx/event.h>
+#include <wx/filename.h>
+#include <wx/string.h>
+#include <wx/xml/xml.h>
+
+#define CURRENT_WORKSPACE_VERSION 11000
+#define CURRENT_WORKSPACE_VERSION_STR wxString("11000")
+#define DEFAULT_CURRENT_WORKSPACE_VERSION 10000
+#define DEFAULT_CURRENT_WORKSPACE_VERSION_STR wxString("10000")
 
 /*!
  * \brief
  * Workspace manager class
  *
  */
-class CompileCommandsCreateor;
-class WXDLLIMPEXP_SDK clCxxWorkspace : public IWorkspace
+class LocalWorkspace;
+class WXDLLIMPEXP_SDK clCxxWorkspace : public LocalWorkspaceCommon
 {
     friend class clCxxWorkspaceST;
-    friend class CompileCommandsCreateor;
 
 public:
-    virtual void GetProjectFiles(const wxString& projectName, wxArrayString& files) const;
-    virtual void GetWorkspaceFiles(wxArrayString& files) const;
-    virtual wxString GetFilesMask() const;
-    virtual bool IsBuildSupported() const;
-    virtual bool IsProjectSupported() const;
-    virtual wxString GetProjectFromFile(const wxFileName& filename) const;
+    void GetProjectFiles(const wxString& projectName, wxArrayString& files) const override;
+    void GetWorkspaceFiles(wxArrayString& files) const override;
+    wxString GetFilesMask() const override;
+    bool IsBuildSupported() const override;
+    bool IsProjectSupported() const override;
+    wxString GetProjectFromFile(const wxFileName& filename) const override;
+    void SetProjectActive(const wxString& project) override;
+    wxString GetDebuggerName() const override;
 
 public:
-    typedef std::map<wxString, ProjectPtr> ProjectMap_t;
+    typedef std::unordered_map<wxString, ProjectPtr> ProjectMap_t;
 
 protected:
     wxXmlDocument m_doc;
     wxFileName m_fileName;
-    clCxxWorkspace::ProjectMap_t m_projects;
+    ProjectMap_t m_projects;
     wxString m_startupDir;
     time_t m_modifyTime;
     bool m_saveOnExit;
     BuildMatrixPtr m_buildMatrix;
+    LocalWorkspace* m_localWorkspace = nullptr;
+    wxStringMap_t m_backticks;
 
 public:
     /// Constructor
@@ -84,8 +93,19 @@ public:
      */
     wxString GetVersion() const;
 
+    /**
+     * @brief return the local workspace settings associated with this workspace
+     * @return
+     */
+    LocalWorkspace* GetLocalWorkspace() const { return m_localWorkspace; }
+
+    // Backtick cache
+    bool HasBacktick(const wxString& backtick) const;
+    bool GetBacktickValue(const wxString& backtick, wxString& value) const;
+    void SetBacktickValue(const wxString& backtick, const wxString& value);
+    void ClearBacktickCache();
+
 private:
-    
     void DoUpdateBuildMatrix();
     /**
      * @brief mark all projects as non-active
@@ -122,6 +142,11 @@ private:
 
     void DoVisitWorkspaceFolders(wxXmlNode* parent, const wxString& curpath, wxArrayString& paths) const;
 
+    /**
+     * @brief user clicked on a build output line with file:line
+     */
+    void OnBuildHotspotClicked(clBuildEvent& event);
+
 public:
     /**
      * @brief move 'projectName' to folder. Create the folder if it does not exists
@@ -149,10 +174,14 @@ public:
     wxArrayString GetWorkspaceFolders() const;
 
     /**
-     * @brief createa 'compile_commands' json object for the workspace projects (only the enabled ones)
+     * @brief create 'compile_commands' json object for the workspace projects (only the enabled ones)
+     * or compile_flags.txt file
      */
-    void CreateCompileCommandsJSON(JSONElement& compile_commands) const;
-    wxFileName GetFileName() const { return GetWorkspaceFileName(); }
+    cJSON* CreateCompileCommandsJSON(bool createCompileFlagsTxt, wxArrayString* generated_paths) const;
+
+    wxString GetFileName() const override { return GetWorkspaceFileName().GetFullPath(); }
+    wxString GetDir() const override { return GetWorkspaceFileName().GetPath(); }
+
     void SetStartupDir(const wxString& startupDir) { this->m_startupDir = startupDir; }
     const wxString& GetStartupDir() const { return m_startupDir; }
 
@@ -165,7 +194,7 @@ public:
      * @brief replace compilers for all projects and build configurations
      * @param compilers a map of compilers where the key is the old compiler and the value is the new compiler
      */
-    void ReplaceCompilers(wxStringMap_t& compilers);
+    void ReplaceCompilers(const wxStringMap_t& compilers);
 
     /**
      * Returns the workspace file name
@@ -192,22 +221,13 @@ public:
      * Open an existing workspace
      *
      * \param fileName
-     * Workspace file name (including extesion)
+     * Workspace file name (including extension)
      *
      * \returns
      * true on success false otherwise
      */
     bool OpenWorkspace(const wxString& fileName, wxString& errMsg);
 
-    /**
-     * @brief this function opens the workspace, but does not open the tags
-     * completion database etc. It only loads the XML and then adds all the
-     * projects XML. It is mainly needed when you just need to explore the
-     * workspace from a secondary thread with no events / UI to get in the
-     * way
-     */
-    bool OpenReadOnly(const wxString& fileName, wxString& errMsg);
-
     /**
      * Close the currently opened workspace
      */
@@ -230,22 +250,26 @@ public:
      * project path
      *
      * \param type
-     * Can be Project::EXECUTABLE, Project::STATIC_LIBRARY or Project::DYNAMIC_LIBRARY
+     * Can be PROJECT_TYPE_EXECUTABLE, PROJECT_TYPE_STATIC_LIBRARY or PROJECT_TYPE_DYNAMIC_LIBRARY
      * \returns
      * true on success false otherwise
      */
-    bool CreateProject(const wxString& name, const wxString& path, const wxString& type,
-        const wxString& workspaceFolder, bool addToBuildMatrix, wxString& errMsg);
+    bool CreateProject(const wxString& name,
+                       const wxString& path,
+                       const wxString& type,
+                       const wxString& workspaceFolder,
+                       bool addToBuildMatrix,
+                       wxString& errMsg);
 
     /**
      * @brief rename a project
      * @param oldname current name
-     * @param newname new name for the proejct
+     * @param newname new name for the project
      */
     void RenameProject(const wxString& oldname, const wxString& newname);
 
     /**
-     * \brief get a string property from the worksapce file
+     * \brief get a string property from the workspace file
      * \returns property value or wxEmptyString
      */
     wxString GetStringProperty(const wxString& propName, wxString& errMsg);
@@ -270,7 +294,10 @@ public:
      * \param errMsg [output] incase an error, report the error to the caller
      */
     bool AddProject(const wxString& path, wxString& errMsg);
-
+    /**
+     * @brief add project to the workspace into a given workspace folder
+     */
+    bool AddProject(const wxString& path, const wxString& workspaceFolder, wxString& errMsg);
     /**
      * Remove project from the workspace. This function does not delete
      * any file related to the project but simply removes it from the workspace
@@ -278,17 +305,12 @@ public:
      * \param errMsg [output] incase an error, report the error to the caller
      * \return true on success false otherwise
      */
-    bool RemoveProject(const wxString& name, wxString& errMsg);
+    bool RemoveProject(const wxString& name, wxString& errMsg, const wxString& workspaceFolder);
 
     /**
      * \return The active project name or wxEmptyString
      */
-    wxString GetActiveProjectName() const;
-
-    /**
-     * @brief return the paths of all projects in the workspace (full paths)
-     */
-    wxArrayString GetAllProjectPaths();
+    wxString GetActiveProjectName() const override;
 
     /**
      * Set project as active
@@ -297,7 +319,7 @@ public:
     void SetActiveProject(const wxString& name);
 
     /**
-     * Add new virtual directoy to workspace
+     * Add new virtual directory to workspace
      * \param vdFullPath virtual directory full path
      * \param errMsg [output] incase an error, report the error to the caller
      * \return true on success false otherwise
@@ -310,7 +332,7 @@ public:
     bool IsVirtualDirectoryExists(const wxString& vdFullPath);
 
     /**
-     * Remove virtual directoy to workspace
+     * Remove virtual directory to workspace
      * \param vdFullPath virtual directory full path
      * \param errMsg [output] incase an error, report the error to the caller
      * \return true on success false otherwise
@@ -319,7 +341,7 @@ public:
 
     /**
      * Add new file to project. The project name is taken from the virtual directory full path
-     * \param vdFullPath vritual directory full path including project
+     * \param vdFullPath virtual directory full path including project
      * \param fileName file name to add
      * \param errMsg output
      * \return true on success, false otherwise
@@ -328,7 +350,7 @@ public:
 
     /**
      * Remove file from a project. The project name is taken from the virtual directory full path
-     * \param vdFullPath vritual directory full path including project
+     * \param vdFullPath virtual directory full path including project
      * \param fileName file name to remove
      * \param errMsg output
      * \return true on success, false otherwise
@@ -340,16 +362,6 @@ public:
      */
     void Save();
 
-    /**
-     * Return a node pointing to any workspace-wide editor preferences
-     */
-    wxXmlNode* GetWorkspaceEditorOptions() const;
-
-    /**
-     * Add or update local workspace options
-     */
-    void SetWorkspaceEditorOptions(LocalOptionsConfigPtr opts);
-
     /**
      * Return the configuration mapping for the workspace. 'Configuration Mapping' is
      * the build matrix that should be used for this workspace, it contains all possible
@@ -367,7 +379,7 @@ public:
     /**
      * Return the workspace name
      */
-    wxString GetName() const;
+    wxString GetName() const override;
 
     /**
      * return the project build configuration that matches the
@@ -397,13 +409,13 @@ public:
     /**
      * @brief return the workspace environment variables
      */
-    wxString GetEnvironmentVariabels();
+    wxString GetEnvironmentVariables();
 
     /**
      * @brief set the workspace environment variables. These environment variables
      * will be kept in the workspace file (i.e. they are portable)
      */
-    void SetEnvironmentVariabels(const wxString& envvars);
+    void SetEnvironmentVariables(const wxString& envvars);
 
     /**
      * @brief return the selected workspace configuration
@@ -456,6 +468,26 @@ public:
      */
     void ClearIncludePathCache();
 
+    /**
+     * @brief return the underlying file for a given project name
+     */
+    wxFileName GetProjectFileName(const wxString& projectName) const override;
+
+    /**
+     * @brief return list of projects for this workspace
+     */
+    wxArrayString GetWorkspaceProjects() const override;
+
+    /**
+     * @brief return list of files that are excluded for a given workspace configuration
+     */
+    size_t GetExcludeFilesForConfig(std::vector<wxString>& files, const wxString& workspaceConfigName = "");
+
+    /**
+     * @brief return the workspace environment
+     */
+    clEnvList_t GetEnvironment() const override;
+
 private:
     /**
      * Do the actual add project
