@@ -26,18 +26,20 @@
 #ifndef WXCODECOMPLETIONBOX_H
 #define WXCODECOMPLETIONBOX_H
 
+#include "LSP/CompletionItem.h"
+#include "database/entry.h"
 #include "wxCodeCompletionBoxBase.h"
-#include "wxCodeCompletionBoxEntry.h"
-#include <wx/arrstr.h>
-#include <wx/sharedptr.h>
+#include "wxCodeCompletionBoxEntry.hpp"
+#include "wxStringHash.h"
+
 #include <vector>
-#include <list>
+#include <wx/arrstr.h>
 #include <wx/bitmap.h>
-#include <wx/stc/stc.h>
-#include <wx/font.h>
-#include "entry.h"
 #include <wx/event.h>
-#include <wx/bitmap.h>
+#include <wx/font.h>
+#include <wx/sharedptr.h>
+#include <wx/stc/stc.h>
+#include <wx/timer.h>
 
 class CCBoxTipWindow;
 class wxCodeCompletionBox;
@@ -54,71 +56,57 @@ public:
         kNone = 0,
         kInsertSingleMatch = (1 << 0),
         kRefreshOnKeyType = (1 << 1),
+        kNoShowingEvent = (1 << 2), // Don't send the wxEVT_CCBOX_SHOWING event
+        kAlwaysShow = (1 << 3),    // internally, the CC box does some checking to see if the box can be shown. Use this
+                                   // flag to force it to show
+        kTriggerUser = (1 << 4), // CC box was invoked by user typing Ctrl-Space
     };
 
 protected:
+    virtual void OnSelectionActivated(wxDataViewEvent& event);
+    virtual void OnSelectionChanged(wxDataViewEvent& event);
     wxCodeCompletionBoxEntry::Vec_t m_allEntries;
     wxCodeCompletionBoxEntry::Vec_t m_entries;
     wxCodeCompletionBox::BmpVec_t m_bitmaps;
     static wxCodeCompletionBox::BmpVec_t m_defaultBitmaps;
-    
-    int m_index;
+    std::unordered_map<int, int> m_lspCompletionItemImageIndexMap;
     wxString m_displayedTip;
-    wxStyledTextCtrl* m_stc;
+    wxStyledTextCtrl* m_stc = nullptr;
     wxFont m_ccFont;
-    int m_startPos;
-    bool m_useLightColours;
+    int m_startPos = wxNOT_FOUND;
 
     /// When firing the various "clCodeCompletionEvent"s, set the event object
     /// to this member. This help distinguish the real trigger of the code completion
     /// box
-    wxEvtHandler* m_eventObject;
+    wxEvtHandler* m_eventObject = nullptr;
 
     /// Code completion tooltip that is shown next to the code completion box
-    CCBoxTipWindow* m_tipWindow;
+    CCBoxTipWindow* m_tipWindow = nullptr;
 
     /// The code completion box flags, see above enum for possible values
-    size_t m_flags;
+    size_t m_flags = 0;
 
-    /// Contains the scrollbar rectangle
-    wxRect m_scrollArea;
-    wxRect m_scrollTopRect;
-    wxRect m_scrollBottomRect;
-
-    /// Colours used by this class
-    wxColour m_lightBorder;
-    wxColour m_darkBorder;
-    wxColour m_bgColour;
-    wxColour m_textColour;
-    wxColour m_selectedTextColour;
-    wxColour m_selection;
-    wxColour m_penColour;
-    wxColour m_scrollBgColour;
     /// Scrollbar bitmaps
     wxBitmap m_bmpUp;
     wxBitmap m_bmpDown;
     wxBitmap m_bmpUpEnabled;
     wxBitmap m_bmpDownEnabled;
+    wxTimer* m_tooltipTimer = nullptr;
 
 protected:
-    void StcKeyDown(wxKeyEvent& event);
-    void StcLeftDown(wxMouseEvent& event);
     void StcModified(wxStyledTextEvent& event);
     void StcCharAdded(wxStyledTextEvent& event);
-
-    // Event handlers
-    void OnLeftDClick(wxMouseEvent& event);
-    void OnEraseBackground(wxEraseEvent& event);
-    void OnPaint(wxPaintEvent& event);
-    
+    void StcLeftDown(wxMouseEvent& event);
+    void StcKeyDown(wxKeyEvent& event);
     static void InitializeDefaultBitmaps();
-    
+    void DoPopulateList();
+
 public:
     /**
-     * @brief return the bitamp associated with this tag entry
+     * @brief return the bitmap associated with this tag entry
      */
     static wxBitmap GetBitmap(TagEntryPtr tag);
-    
+
     virtual ~wxCodeCompletionBox();
     /**
      * @brief construct a code completion box
@@ -129,14 +117,28 @@ public:
     wxCodeCompletionBox(wxWindow* parent, wxEvtHandler* eventObject = NULL, size_t flags = 0);
 
     /**
-     * @brief show the completion box
+     * @brief reset the code completion box clearing it from all its content and preparing it
+     * for a new usage
      */
-    void ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries);
+    void Reset(wxEvtHandler* eventObject = NULL, size_t flags = 0);
 
     /**
      * @brief show the completion box
      */
-    void ShowCompletionBox(wxStyledTextCtrl* ctrl, const TagEntryPtrVector_t& tags);
+    void ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries,
+                           const wxSize& control_size = wxDefaultSize);
+
+    /**
+     * @brief show the completion box
+     */
+    void ShowCompletionBox(wxStyledTextCtrl* ctrl, const TagEntryPtrVector_t& tags,
+                           const wxSize& control_size = wxDefaultSize);
+
+    /**
+     * @brief show the completion box  (Language Server Protocol support)
+     */
+    void ShowCompletionBox(wxStyledTextCtrl* ctrl, const LSP::CompletionItem::Vec_t& completions,
+                           const wxSize& control_size = wxDefaultSize);
 
     void SetBitmaps(const wxCodeCompletionBox::BmpVec_t& bitmaps) { this->m_bitmaps = bitmaps; }
     const wxCodeCompletionBox::BmpVec_t& GetBitmaps() const { return m_bitmaps; }
@@ -153,31 +155,38 @@ public:
     void SetStartPos(int startPos) { this->m_startPos = startPos; }
     int GetStartPos() const { return m_startPos; }
 
+    /**
+     * @brief strip HTML tags before showing the tooltip
+     */
+    static void SetStripHtmlTags(bool strip);
+
 protected:
-    int GetSingleLineHeight() const;
     /**
      * @brief filter the results based on what the user typed in the editor
+     * @param [output] startsWithCount number of entries that 'starts with' the filter (case-I)
+     * @param [output] containsCount number of entries that 'starts with' the filter
      * @return Should we refresh the content of the CC box (based on number of "Exact matches" / "Starts with" found)
      */
-    bool FilterResults();
+    bool FilterResults(bool updateEntries, size_t& startsWithCount, size_t& containsCount, size_t& exactMatchCount);
     void RemoveDuplicateEntries();
-    void InsertSelection();
+    void InsertSelection(wxCodeCompletionBoxEntry::Ptr_t entry = wxCodeCompletionBoxEntry::Ptr_t(nullptr));
+    wxString GetFilter();
 
-    // For backward compatability, we support initializing the list with TagEntryPtrVector_t
+    // For backward compatibility, we support initializing the list with TagEntryPtrVector_t
     // These 2 functions provide conversion between wxCodeCompletionBoxEntry and TagEntryPtr
     wxCodeCompletionBoxEntry::Vec_t TagsToEntries(const TagEntryPtrVector_t& tags);
+    wxCodeCompletionBoxEntry::Vec_t LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& completions);
     static int GetImageId(TagEntryPtr entry);
-    void DoDisplayTipWindow();
+    int GetImageId(LSP::CompletionItem::Ptr_t entry) const;
+
+    /// Starts a tooltip timer
+    void StartTooltipWindowTimer();
+    void OnTooltipWindowTimer(wxTimerEvent& event);
+
     void DoDestroyTipWindow();
 
     void DoUpdateList();
-    void DoScrollDown();
-    void DoScrollUp();
     void DoDestroy();
-    void DoDrawBottomScrollButton(wxDC& dc);
-    void DoDrawTopScrollButton(wxDC& dc);
-    bool CanScrollDown();
-    bool CanScrollUp();
-    void DoShowCompletionBox();
+    void DoShowCompletionBox(const wxSize& control_size);
 };
 #endif // WXCODECOMPLETIONBOX_H
