@@ -1,9 +1,13 @@
 #include "wxCustomStatusBar.h"
+
+#include "drawingutils.h"
+
 #include <wx/dcbuffer.h>
-#include <wx/msgdlg.h>
-#include <wx/dcmemory.h>
-#include <wx/settings.h>
 #include <wx/dcclient.h>
+#include <wx/dcgraph.h>
+#include <wx/dcmemory.h>
+#include <wx/msgdlg.h>
+#include <wx/settings.h>
 
 //========================------------------------------------
 //========================------------------------------------
@@ -13,18 +17,10 @@ wxDEFINE_EVENT(wxEVT_STATUSBAR_CLICKED, clCommandEvent);
 wxCustomStatusBarArt::wxCustomStatusBarArt(const wxString& name)
     : m_name(name)
 {
-    m_penColour = wxColour(125, 125, 125);
-    m_bgColour = wxColour(86, 86, 86);
-    m_separatorColour = wxColour(50, 50, 50);
-    m_textColour = *wxWHITE;
-    m_textShadowColour = *wxBLACK;
 }
 
 void wxCustomStatusBarArt::DrawText(wxDC& dc, wxCoord x, wxCoord y, const wxString& text)
 {
-    dc.SetTextForeground(GetTextShadowColour());
-    dc.DrawText(text, x, y - 1);
-
     dc.SetTextForeground(GetTextColour());
     dc.DrawText(text, x, y);
 }
@@ -43,6 +39,27 @@ void wxCustomStatusBarArt::DrawFieldSeparator(wxDC& dc, const wxRect& fieldRect)
     dc.DrawLine(topPt, bottomPt);
 }
 
+wxColour wxCustomStatusBarArt::GetBgColour() const
+{
+    wxColour c = clSystemSettings::GetDefaultPanelColour();
+    return c;
+}
+
+wxColour wxCustomStatusBarArt::GetPenColour() const { return GetBgColour(); }
+wxColour wxCustomStatusBarArt::GetTextColour() const { return clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT); }
+wxColour wxCustomStatusBarArt::GetSeparatorColour() const { return GetBgColour(); }
+
+//========================------------------------------------
+//========================------------------------------------
+
+void wxCustomStatusBarSpacerField::Render(wxDC& dc, const wxRect& rect, wxCustomStatusBarArt::Ptr_t art)
+{
+    m_rect = rect;
+
+    // draw border line
+    art->DrawFieldSeparator(dc, rect);
+}
+
 //========================------------------------------------
 //========================------------------------------------
 
@@ -54,7 +71,7 @@ void wxCustomStatusBarFieldText::Render(wxDC& dc, const wxRect& rect, wxCustomSt
     // Center text
     wxCoord textY = (rect.GetHeight() - textSize.GetHeight()) / 2 + rect.y;
     wxCoord textX;
-    if(m_textAlign == wxALIGN_CENTER) {
+    if (m_textAlign == wxALIGN_CENTER) {
         textX = (rect.GetWidth() - textSize.GetWidth()) / 2 + rect.x;
     } else {
         // left
@@ -72,63 +89,48 @@ void wxCustomStatusBarFieldText::SetText(const wxString& text)
 {
     m_text = text;
     // Render the new text
-    if((m_rect != wxRect()) && m_parent) {
+    if ((m_rect != wxRect()) && m_parent) {
         // valid rect
         wxCustomStatusBarArt::Ptr_t art = m_parent->GetArt();
-        if(art->GetName() == m_parent->GetLastArtNameUsedForPaint()) {
-#if defined(__WXOSX__) || defined(__WXMSW__)
+        if (art->GetName() == m_parent->GetLastArtNameUsedForPaint()) {
             m_parent->Refresh();
             return;
-#endif
-            // Make sure we draw only when the "art" objects are in sync with the field
-            // and with the bar itself
-            wxBitmap bmp(m_rect.GetSize());
-            wxMemoryDC memDc;
-            m_parent->PrepareDC(memDc);
-
-            memDc.SelectObject(bmp);
-            wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-            font.SetPointSize(10);
-            memDc.SetFont(font);
-            wxRect rect(m_rect.GetSize()); // Create the same rect size, but on 0,0
-
-            // Draw the field background
-            memDc.SetBrush(art->GetBgColour());
-            memDc.SetPen(art->GetBgColour());
-            memDc.DrawRectangle(rect);
-
-            // Draw top separator line
-            wxPoint topLeft = rect.GetTopLeft();
-            wxPoint topRight = rect.GetTopRight();
-            topRight.x += 1;
-            memDc.SetPen(art->GetSeparatorColour());
-            memDc.DrawLine(topLeft, topRight);
-
-            // Draw the bottom separator using the pen colour
-            // this will give a "sink" look to the status bar
-            topLeft.y += 1;
-            topRight.y += 1;
-            memDc.SetPen(art->GetPenColour());
-            memDc.DrawLine(topLeft, topRight);
-
-            // Render will override m_rect, we so keep a copy
-            wxRect origRect = m_rect;
-            Render(memDc, rect, art);
-            m_rect = origRect;
-            memDc.SelectObject(wxNullBitmap);
-            // bmp contains the field content, draw it
-            wxClientDC dc(m_parent);
-            m_parent->PrepareDC(dc);
-            dc.DrawBitmap(bmp, m_rect.GetTopLeft());
         }
     }
 }
 
 //========================------------------------------------
+// wxCustomStatusBarControlField
 //========================------------------------------------
 
-wxCustomStatusBarAnimationField::wxCustomStatusBarAnimationField(
-    wxCustomStatusBar* parent, const wxBitmap& sprite, wxOrientation spriteOrientation, const wxSize& animSize)
+wxCustomStatusBarControlField::wxCustomStatusBarControlField(wxCustomStatusBar* parent, wxControl* control)
+    : wxCustomStatusBarField(parent)
+    , m_control(control)
+{
+}
+
+void wxCustomStatusBarControlField::Render(wxDC& dc, const wxRect& rect, wxCustomStatusBarArt::Ptr_t art)
+{
+    CHECK_PTR_RET(m_control);
+    wxUnusedVar(dc);
+    m_rect = rect;
+
+    // Draw the left side border
+    art->DrawFieldSeparator(dc, rect);
+
+    // Position the animation
+    wxRect control_rect = m_control->GetRect();
+    control_rect = control_rect.CenterIn(m_rect);
+    m_control->Move(control_rect.GetTopLeft());
+}
+
+//========================------------------------------------
+//========================------------------------------------
+
+wxCustomStatusBarAnimationField::wxCustomStatusBarAnimationField(wxCustomStatusBar* parent,
+                                                                 const wxBitmap& sprite,
+                                                                 wxOrientation spriteOrientation,
+                                                                 const wxSize& animSize)
     : wxCustomStatusBarField(parent)
 {
     m_animation = new wxPNGAnimation(parent, sprite, spriteOrientation, animSize);
@@ -139,8 +141,6 @@ wxCustomStatusBarAnimationField::wxCustomStatusBarAnimationField(
     m_animation->Bind(wxEVT_LEFT_DOWN, &wxCustomStatusBarAnimationField::OnAnimationClicked, this);
 }
 
-wxCustomStatusBarAnimationField::~wxCustomStatusBarAnimationField() {}
-
 void wxCustomStatusBarAnimationField::Render(wxDC& dc, const wxRect& rect, wxCustomStatusBarArt::Ptr_t art)
 {
     m_rect = rect;
@@ -164,7 +164,7 @@ void wxCustomStatusBarAnimationField::OnAnimationClicked(wxMouseEvent& event)
 {
     event.Skip();
     wxCustomStatusBar* bar = dynamic_cast<wxCustomStatusBar*>(m_animation->GetParent());
-    if(bar) {
+    if (bar) {
         // Notify the bar that the animation owned by this field was clicked
         bar->AnimationClicked(this);
     }
@@ -180,14 +180,29 @@ void wxCustomStatusBarBitmapField::Render(wxDC& dc, const wxRect& rect, wxCustom
     // draw border line
     art->DrawFieldSeparator(dc, rect);
 
+    constexpr int X_SPACER = 5;
+
     // Center bitmap
-    if(m_bitmap.IsOk()) {
-        int bmpHeight = m_bitmap.GetScaledHeight();
-        int bmpWidth = m_bitmap.GetScaledWidth();
-        wxCoord bmpY = (rect.GetHeight() - bmpHeight) / 2 + rect.y;
-        wxCoord bmpX = (rect.GetWidth() - bmpWidth) / 2 + rect.x;
+    int remaining_width = m_width;
+    int xx = rect.GetTopLeft().x;
+    if (m_bitmap.IsOk()) {
+        wxRect rr{wxPoint(xx, rect.GetTopLeft().y), m_bitmap.GetScaledSize()};
+        rr = rr.CenterIn(rect, wxVERTICAL);
         // Draw the bitmap
-        dc.DrawBitmap(m_bitmap, bmpX, bmpY + 1);
+        dc.DrawBitmap(m_bitmap, rr.GetTopLeft());
+        xx += m_bitmap.GetScaledSize().GetWidth();
+        remaining_width -= m_bitmap.GetScaledSize().GetWidth();
+    }
+
+    if (!m_label.empty()) {
+        xx += X_SPACER;
+        remaining_width -= X_SPACER;
+        wxString fixed_text;
+        DrawingUtils::TruncateText(m_label, remaining_width, dc, fixed_text);
+        wxRect text_rect = dc.GetTextExtent(fixed_text);
+        text_rect = text_rect.CenterIn(rect, wxVERTICAL);
+        text_rect.SetX(xx);
+        dc.DrawText(fixed_text, text_rect.GetTopLeft());
     }
 }
 
@@ -198,103 +213,83 @@ wxCustomStatusBar::wxCustomStatusBar(wxWindow* parent, wxWindowID id, long style
     : wxStatusBar(parent, id, style)
     , m_art(new wxCustomStatusBarArt("Dark"))
     , m_mainText(new wxCustomStatusBarFieldText(this, 0))
-    , m_timer(NULL)
 {
+    m_mainText->SetAutoWidth(true);
+
     SetBackgroundStyle(wxBG_STYLE_PAINT);
     m_mainText->Cast<wxCustomStatusBarFieldText>()->SetTextAlignment(wxALIGN_LEFT);
 
     Bind(wxEVT_PAINT, &wxCustomStatusBar::OnPaint, this);
-    Bind(wxEVT_ERASE_BACKGROUND, &wxCustomStatusBar::OnEraseBackround, this);
+    Bind(wxEVT_ERASE_BACKGROUND, &wxCustomStatusBar::OnEraseBackground, this);
     Bind(wxEVT_LEFT_DOWN, &wxCustomStatusBar::OnLeftDown, this);
     Bind(wxEVT_MOTION, &wxCustomStatusBar::OnMouseMotion, this);
     m_timer = new wxTimer(this);
     Bind(wxEVT_TIMER, &wxCustomStatusBar::OnTimer, this, m_timer->GetId());
+
+    m_fields.push_back(m_mainText);
+    // 1 second event interval
+    m_timer->Start(1000);
 }
 
 wxCustomStatusBar::~wxCustomStatusBar()
 {
+    // unbind the timer before we delete it
+    Unbind(wxEVT_TIMER, &wxCustomStatusBar::OnTimer, this, m_timer->GetId());
+
     m_timer->Stop();
     wxDELETE(m_timer);
 
     Unbind(wxEVT_PAINT, &wxCustomStatusBar::OnPaint, this);
-    Unbind(wxEVT_ERASE_BACKGROUND, &wxCustomStatusBar::OnEraseBackround, this);
+    Unbind(wxEVT_ERASE_BACKGROUND, &wxCustomStatusBar::OnEraseBackground, this);
     Unbind(wxEVT_LEFT_DOWN, &wxCustomStatusBar::OnLeftDown, this);
     Unbind(wxEVT_MOTION, &wxCustomStatusBar::OnMouseMotion, this);
 }
 
 void wxCustomStatusBar::OnPaint(wxPaintEvent& event)
 {
-    wxAutoBufferedPaintDC dc(this);
-    PrepareDC(dc);
+    wxPaintDC abdc(this);
+    wxGCDC gcdc;
+    wxDC& dc = DrawingUtils::GetGCDC(abdc, gcdc);
 
+    PrepareDC(dc);
     wxRect rect = GetClientRect();
+    rect.Inflate(1);
+
+    dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
 
     // Remember which art name used for painting
     SetLastArtNameUsedForPaint(m_art->GetName());
 
     // Fill the background
-    dc.SetBrush(m_art->GetBgColour());
-    dc.SetPen(m_art->GetBgColour());
-
+    wxColour bgColour = m_art->GetBgColour();
+    dc.SetBrush(bgColour);
+    dc.SetPen(bgColour);
     dc.DrawRectangle(rect);
 
-    // Draw top separator line
-    wxPoint topLeft = rect.GetTopLeft();
-    wxPoint topRight = rect.GetTopRight();
-    dc.SetPen(m_art->GetSeparatorColour());
-    dc.DrawLine(topLeft, topRight);
-
-    // Draw the bottom separator using the pen colour
-    // this will give a "sink" look to the status bar
-    topLeft.y += 1;
-    topRight.y += 1;
-    dc.SetPen(m_art->GetPenColour());
-    dc.DrawLine(topLeft, topRight);
-
-    // Calculate the fields length
-    size_t totalLength = rect.GetWidth();
-    size_t fieldsLength = DoGetFieldsWidth();
-
-    // sanity
-    size_t offsetX = 0;
-    if(totalLength <= fieldsLength) {
-        offsetX = 0;
-    } else {
-        offsetX = totalLength - fieldsLength;
-    }
-
-    //===----------------------
-    // Draw the main field
-    //===----------------------
-    // update the rect
-
-    wxRect mainRect(0, rect.y, offsetX, rect.height);
-    dc.SetClippingRegion(mainRect);
-    m_mainText->SetRect(mainRect);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->Render(dc, mainRect, m_art);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetTooltip(m_text);
-    dc.DestroyClippingRegion();
+    // Update the fields width
+    Finalize();
 
     //===----------------------
     // Draw the fields
     //===----------------------
-
-    for(size_t i = 0; i < m_fields.size(); ++i) {
+    size_t offset_x = 0;
+    for (auto field : m_fields) {
         // Prepare the rect
-        wxRect fieldRect(offsetX, rect.y, m_fields.at(i)->GetWidth(), rect.height);
+        size_t width = field->IsAutoWidth() ? field->GetAutoWidth() : field->GetWidth();
+        wxRect fieldRect(offset_x, rect.y, width, rect.height);
         dc.SetClippingRegion(fieldRect);
-        m_fields.at(i)->Render(dc, fieldRect, m_art);
+        field->Render(dc, fieldRect, m_art);
         dc.DestroyClippingRegion();
-        offsetX += m_fields.at(i)->GetWidth();
+        offset_x += width;
     }
 }
 
-void wxCustomStatusBar::OnEraseBackround(wxEraseEvent& event) { wxUnusedVar(event); }
+void wxCustomStatusBar::OnEraseBackground(wxEraseEvent& event) { wxUnusedVar(event); }
 
 size_t wxCustomStatusBar::DoGetFieldsWidth()
 {
     size_t width(0);
-    for(size_t i = 0; i < m_fields.size(); ++i) {
+    for (size_t i = 0; i < m_fields.size(); ++i) {
         width += m_fields.at(i)->GetWidth();
     }
     return width;
@@ -302,17 +297,16 @@ size_t wxCustomStatusBar::DoGetFieldsWidth()
 
 wxCustomStatusBarField::Ptr_t wxCustomStatusBar::GetField(size_t index)
 {
-    if(index >= m_fields.size()) return wxCustomStatusBarField::Ptr_t(NULL);
+    if (index >= m_fields.size())
+        return wxCustomStatusBarField::Ptr_t(NULL);
     return m_fields.at(index);
 }
 
 void wxCustomStatusBar::RemoveField(size_t index)
 {
-    if(index >= m_fields.size()) return;
+    if (index >= m_fields.size())
+        return;
     m_fields.erase(m_fields.begin() + index);
-    if(m_timer->IsRunning()) {
-        m_timer->Stop();
-    }
     Refresh();
 }
 
@@ -320,8 +314,8 @@ void wxCustomStatusBar::OnLeftDown(wxMouseEvent& event)
 {
     event.Skip();
     wxPoint point = event.GetPosition();
-    for(size_t i = 0; i < m_fields.size(); ++i) {
-        if(m_fields.at(i)->HitTest(point)) {
+    for (size_t i = 0; i < m_fields.size(); ++i) {
+        if (m_fields.at(i)->HitTest(point)) {
             // fire an event
             clCommandEvent event(wxEVT_STATUSBAR_CLICKED);
             event.SetEventObject(this);
@@ -334,55 +328,89 @@ void wxCustomStatusBar::OnLeftDown(wxMouseEvent& event)
 
 void wxCustomStatusBar::ClearText()
 {
-    m_text.Clear();
-    if(m_timer->IsRunning()) {
-        m_timer->Stop();
-    }
+    m_text.clear();
     Refresh();
 }
 
-void wxCustomStatusBar::SetText(const wxString& message, int secondsToLive)
+void wxCustomStatusBar::UpdateMainTextField()
 {
-    // Stop any timer
-    if(m_timer->IsRunning()) {
-        m_timer->Stop();
-    }
-
-    m_text = message;
-    SetToolTip(message);
-
     // Make sure we draw only when the "art" objects are in sync with the field
     // and with the bar itself
     wxRect mainRect = DoGetMainFieldRect();
 
     // update the rect
     m_mainText->SetRect(mainRect);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetText(m_text);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetTooltip(m_text);
+    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetText(GetText());
+    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetTooltip(GetText());
+}
 
-    if(secondsToLive != wxNOT_FOUND) {
-        m_timer->Start(secondsToLive * 1000, true);
+void wxCustomStatusBar::Finalize()
+{
+    decltype(m_fields) dyn_width_fields;
+    size_t fixed_field_width = 0;
+    for (auto field : m_fields) {
+        if (field->IsAutoWidth()) {
+            dyn_width_fields.push_back(field);
+        } else {
+            fixed_field_width += field->GetWidth();
+        }
     }
+
+    if (dyn_width_fields.empty())
+        return; // nothing to be done here
+
+    size_t dyn_width = (GetClientRect().GetWidth() - fixed_field_width) / dyn_width_fields.size();
+    for (auto field : dyn_width_fields) {
+        field->SetAutoWidth(dyn_width);
+    }
+}
+
+void wxCustomStatusBar::SetText(const wxString& message, int secondsToLive)
+{
+    if (message.empty()) {
+        // passing an empty string suggests that we want to clear the text field completely
+        ClearText();
+        return;
+    }
+
+    if (secondsToLive < 0) {
+        secondsToLive = 1; // default to 1 second message
+    } else if (secondsToLive == 0) {
+        secondsToLive = 5; // this is how forever looks like
+    }
+
+    m_text.push_back({message, time(nullptr) + secondsToLive});
+
+#ifndef __WXMAC__
+    // for some reason, macos tooltips are shown in the middle of the screen :)
+    SetToolTip(message);
+#endif
+
+    UpdateMainTextField();
 }
 
 void wxCustomStatusBar::OnMouseMotion(wxMouseEvent& event)
 {
     event.Skip();
-    SetToolTip(wxEmptyString);
+    wxString current_tip = GetToolTipText();
+    wxString tip_text;
     wxPoint point = event.GetPosition();
-    for(size_t i = 0; i < m_fields.size(); ++i) {
-        if(m_fields.at(i)->HitTest(point)) {
-            SetToolTip(m_fields.at(i)->GetTooltip());
-            return;
+    for (size_t i = 0; i < m_fields.size(); ++i) {
+        if (m_fields.at(i)->HitTest(point)) {
+            tip_text = m_fields.at(i)->GetTooltip();
+            break;
         }
     }
-    SetToolTip(m_text);
+
+    if (current_tip != tip_text) {
+        SetToolTip(tip_text);
+    }
 }
 
 void wxCustomStatusBar::AnimationClicked(wxCustomStatusBarField* field)
 {
-    for(size_t i = 0; i < m_fields.size(); ++i) {
-        if(m_fields.at(i).get() == field) {
+    for (size_t i = 0; i < m_fields.size(); ++i) {
+        if (m_fields.at(i).get() == field) {
             // fire an event
             clCommandEvent event(wxEVT_STATUSBAR_CLICKED);
             event.SetEventObject(this);
@@ -401,21 +429,52 @@ void wxCustomStatusBar::SetArt(wxCustomStatusBarArt::Ptr_t art)
 
 wxRect wxCustomStatusBar::DoGetMainFieldRect()
 {
-    // Calculate the fields length
     wxRect rect = GetClientRect();
-    size_t totalLength = rect.GetWidth();
-    size_t fieldsLength = DoGetFieldsWidth();
-
-    size_t offsetX = 0;
-    if(totalLength <= fieldsLength) {
-        offsetX = 0;
-    } else {
-        offsetX = totalLength - fieldsLength;
+    size_t offset_x = 0;
+    for (auto field : m_fields) {
+        // Prepare the rect
+        if (field.get() == m_mainText.get()) {
+            // found the main text field
+            break;
+        }
+        size_t width = field->IsAutoWidth() ? field->GetAutoWidth() : field->GetWidth();
+        offset_x += width;
     }
-    wxRect mainRect(0, rect.y, offsetX, rect.height);
+
+    // Calculate the fields length
+    wxRect mainRect(
+        offset_x, rect.y, m_mainText->IsAutoWidth() ? m_mainText->GetAutoWidth() : m_mainText->GetWidth(), rect.height);
     return mainRect;
 }
 
-void wxCustomStatusBar::OnTimer(wxTimerEvent& event) { SetText(""); }
+void wxCustomStatusBar::OnTimer(wxTimerEvent& event)
+{
+    event.Skip();
+
+    time_t current_timestamp = time(nullptr);
+
+    // filter expired items from the list and display the back() of the queue
+    // find the best text to display
+    decltype(m_text) filtered_queue;
+    for (const auto& entry : m_text) {
+        if (entry.second > current_timestamp) {
+            // we keep this entry
+            filtered_queue.push_back(entry);
+        }
+    }
+    m_text.swap(filtered_queue);
+
+    // this will use the back of the stack as the display item
+    UpdateMainTextField();
+}
 
 bool wxCustomStatusBarField::HitTest(const wxPoint& point) const { return m_rect.Contains(point); }
+
+thread_local wxString EMPTY_STRING;
+const wxString& wxCustomStatusBar::GetText() const
+{
+    if (m_text.empty()) {
+        return EMPTY_STRING;
+    }
+    return m_text.back().first;
+}
