@@ -23,43 +23,35 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include <wx/app.h>
-#include <wx/stdpaths.h>
-#include "environmentconfig.h"
-#include <wx/msgdlg.h>
-#include <wx/xrc/xmlres.h>
-#include "event_notifier.h"
-#include <wx/mimetype.h>
-#include "globals.h"
-#include "dirsaver.h"
-#include "newqtprojdlg.h"
-#include "procutils.h"
-#include "project.h"
-#include "workspace.h"
-#include "build_settings_config.h"
-#include "qmakegenerator.h"
-#include <wx/log.h>
-#include <wx/menu.h>
 #include "qmakeplugin.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "StringUtils.h"
+#include "cl_standard_paths.h"
+#include "dirsaver.h"
+#include "environmentconfig.h"
+#include "event_notifier.h"
+#include "globals.h"
+#include "macros.h"
+#include "newqtprojdlg.h"
+#include "project.h"
+#include "qmakeconf.h"
+#include "qmakegenerator.h"
 #include "qmakesettingsdlg.h"
 #include "qmaketab.h"
-#include "qmakeconf.h"
-#include "build_system.h"
-#include "cl_standard_paths.h"
-#include "macros.h"
-#include <wx/msgdlg.h>
-#include "processreaderthread.h"
-#include "asyncprocess.h"
+#include "workspace.h"
 
-static QMakePlugin* thePlugin = NULL;
+#include <wx/app.h>
+#include <wx/menu.h>
+#include <wx/mimetype.h>
+#include <wx/msgdlg.h>
+#include <wx/xrc/xmlres.h>
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new QMakePlugin(manager);
-    }
-    return thePlugin;
+    return new QMakePlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -86,49 +78,28 @@ QMakePlugin::QMakePlugin(IManager* manager)
     Bind(wxEVT_ASYNC_PROCESS_OUTPUT, &QMakePlugin::OnQmakeOutput, this);
     Bind(wxEVT_ASYNC_PROCESS_TERMINATED, &QMakePlugin::OnQmakeTerminated, this);
     // Connect items
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_PROJ_SETTINGS_SAVED, clProjectSettingsEventHandler(QMakePlugin::OnSaveConfig), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_PROJ_SETTINGS_SAVED,
+                                  clProjectSettingsEventHandler(QMakePlugin::OnSaveConfig), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_BUILD_STARTING, clBuildEventHandler(QMakePlugin::OnBuildStarting), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_GET_PROJECT_BUILD_CMD, clBuildEventHandler(QMakePlugin::OnGetBuildCommand), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_GET_PROJECT_CLEAN_CMD, clBuildEventHandler(QMakePlugin::OnGetCleanCommand), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_GET_IS_PLUGIN_MAKEFILE, clBuildEventHandler(QMakePlugin::OnGetIsPluginMakefile), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_TREE_ITEM_FILE_ACTIVATED, clCommandEventHandler(QMakePlugin::OnOpenFile), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_GET_PROJECT_BUILD_CMD, clBuildEventHandler(QMakePlugin::OnGetBuildCommand),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_GET_PROJECT_CLEAN_CMD, clBuildEventHandler(QMakePlugin::OnGetCleanCommand),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_GET_IS_PLUGIN_MAKEFILE, clBuildEventHandler(QMakePlugin::OnGetIsPluginMakefile),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_TREE_ITEM_FILE_ACTIVATED, clCommandEventHandler(QMakePlugin::OnOpenFile), NULL,
+                                  this);
 }
 
 QMakePlugin::~QMakePlugin() { delete m_conf; }
 
-clToolBar* QMakePlugin::CreateToolBar(wxWindow* parent)
+void QMakePlugin::CreateToolBar(clToolBarGeneric* toolbar)
 {
-    // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-
-    // You can use the below code a snippet:
-    // First, check that CodeLite allows plugin to register plugins
-    if(m_mgr->AllowToolbar()) {
-
-        // Support both toolbars icon size
-        int size = m_mgr->GetToolbarIconSize();
-
-        // Allocate new toolbar, which will be freed later by CodeLite
-        tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE_PLUGIN);
-
-        // Set the toolbar size
-        tb->SetToolBitmapSize(wxSize(size, size));
-        tb->AddTool(XRCID("new_qmake_project"),
-                    _("Create new qmake based project"),
-                    m_mgr->GetStdIcons()->LoadBitmap("qt", size),
-                    _("Create new qmake based project"));
-        // And finally, we must call 'Realize()'
-        tb->Realize();
-    }
-
-    // return the toolbar, it can be NULL if CodeLite does not allow plugins to register toolbars
-    // or in case the plugin simply does not require toolbar
-    return tb;
+    // Support both toolbars icon size
+    int size = m_mgr->GetToolbarIconSize();
+    auto images = toolbar->GetBitmapsCreateIfNeeded();
+    toolbar->AddTool(XRCID("new_qmake_project"), _("Create new qmake based project"), images->Add("qt", size),
+                     _("Create new qmake based project"));
 }
 
 void QMakePlugin::CreatePluginMenu(wxMenu* pluginsMenu)
@@ -143,23 +114,14 @@ void QMakePlugin::CreatePluginMenu(wxMenu* pluginsMenu)
     item = new wxMenuItem(menu, XRCID("qmake_settings"), _("Settings..."), wxEmptyString, wxITEM_NORMAL);
     menu->Append(item);
 
-    pluginsMenu->Append(wxID_ANY, wxT("QMake"), menu);
+    pluginsMenu->Append(wxID_ANY, _("QMake"), menu);
 
-    wxTheApp->Connect(XRCID("new_qmake_project"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(QMakePlugin::OnNewQmakeBasedProject),
-                      NULL,
-                      (wxEvtHandler*)this);
-    wxTheApp->Connect(XRCID("qmake_settings"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(QMakePlugin::OnSettings),
-                      NULL,
-                      (wxEvtHandler*)this);
-    wxTheApp->Connect(XRCID("qmake_run_qmake"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(QMakePlugin::OnExportMakefile),
-                      NULL,
-                      this);
+    wxTheApp->Connect(XRCID("new_qmake_project"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(QMakePlugin::OnNewQmakeBasedProject), NULL, (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("qmake_settings"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(QMakePlugin::OnSettings), NULL, (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("qmake_run_qmake"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(QMakePlugin::OnExportMakefile), NULL, this);
 }
 
 void QMakePlugin::HookPopupMenu(wxMenu* menu, MenuType type)
@@ -174,38 +136,30 @@ void QMakePlugin::HookPopupMenu(wxMenu* menu, MenuType type)
 
 void QMakePlugin::UnPlug()
 {
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_PROJ_SETTINGS_SAVED, clProjectSettingsEventHandler(QMakePlugin::OnSaveConfig), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_BUILD_STARTING, clBuildEventHandler(QMakePlugin::OnBuildStarting), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_GET_PROJECT_BUILD_CMD, clBuildEventHandler(QMakePlugin::OnGetBuildCommand), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_GET_PROJECT_CLEAN_CMD, clBuildEventHandler(QMakePlugin::OnGetCleanCommand), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_GET_IS_PLUGIN_MAKEFILE, clBuildEventHandler(QMakePlugin::OnGetIsPluginMakefile), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_TREE_ITEM_FILE_ACTIVATED, clCommandEventHandler(QMakePlugin::OnOpenFile), NULL, this);
-    wxTheApp->Disconnect(XRCID("new_qmake_project"),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(QMakePlugin::OnNewQmakeBasedProject),
-                         NULL,
-                         (wxEvtHandler*)this);
-    wxTheApp->Disconnect(XRCID("qmake_settings"),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(QMakePlugin::OnSettings),
-                         NULL,
-                         (wxEvtHandler*)this);
-    wxTheApp->Disconnect(XRCID("qmake_run_qmake"),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(QMakePlugin::OnExportMakefile),
-                         NULL,
-                         this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_PROJ_SETTINGS_SAVED,
+                                     clProjectSettingsEventHandler(QMakePlugin::OnSaveConfig), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_BUILD_STARTING, clBuildEventHandler(QMakePlugin::OnBuildStarting), NULL,
+                                     this);
+    EventNotifier::Get()->Disconnect(wxEVT_GET_PROJECT_BUILD_CMD, clBuildEventHandler(QMakePlugin::OnGetBuildCommand),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_GET_PROJECT_CLEAN_CMD, clBuildEventHandler(QMakePlugin::OnGetCleanCommand),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_GET_IS_PLUGIN_MAKEFILE,
+                                     clBuildEventHandler(QMakePlugin::OnGetIsPluginMakefile), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_TREE_ITEM_FILE_ACTIVATED, clCommandEventHandler(QMakePlugin::OnOpenFile),
+                                     NULL, this);
+    wxTheApp->Disconnect(XRCID("new_qmake_project"), wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(QMakePlugin::OnNewQmakeBasedProject), NULL, (wxEvtHandler*)this);
+    wxTheApp->Disconnect(XRCID("qmake_settings"), wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(QMakePlugin::OnSettings), NULL, (wxEvtHandler*)this);
+    wxTheApp->Disconnect(XRCID("qmake_run_qmake"), wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(QMakePlugin::OnExportMakefile), NULL, this);
 }
 
 void QMakePlugin::HookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName)
 {
-    if(!book) return;
+    if(!book)
+        return;
 
     DoUnHookAllTabs(book);
 
@@ -218,8 +172,8 @@ void QMakePlugin::HookProjectSettingsTab(wxBookCtrlBase* book, const wxString& p
     book->AddPage(page, wxT("QMake"), true, wxNOT_FOUND);
 }
 
-void
-QMakePlugin::UnHookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName)
+void QMakePlugin::UnHookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName,
+                                           const wxString& configName)
 {
     wxUnusedVar(configName);
     DoUnHookAllTabs(book);
@@ -303,9 +257,8 @@ void QMakePlugin::OnBuildStarting(clBuildEvent& event)
     QMakeProFileGenerator generator(m_mgr, project, config);
     if(!wxFileName::Exists(generator.GetProFileName())) {
         // alert and return
-        ::wxMessageBox(_("Could not locate pro file.\nDid you remember to run qmake? (right click on the project"),
-                       "QMake",
-                       wxICON_WARNING | wxCENTER);
+        ::wxMessageBox(_("Could not locate pro file.\nDid you remember to run qmake? (right click on the project)"),
+                       "QMake", wxICON_WARNING | wxCENTER);
         return;
     } else {
         event.Skip();
@@ -400,7 +353,7 @@ wxString QMakePlugin::DoGetBuildCommand(const wxString& project, const wxString&
 
     wxString projectMakefile;
     projectMakefile << p->GetName() << ".mk";
-    ::WrapWithQuotes(projectMakefile);
+    StringUtils::WrapWithQuotes(projectMakefile);
     projectMakefile.Replace("\\", "/");
 
     if(!projectOnly) {
@@ -423,9 +376,7 @@ void QMakePlugin::OnNewQmakeBasedProject(wxCommandEvent& event)
     wxUnusedVar(event);
     if(m_conf->GetAllConfigurations().IsEmpty()) {
         wxMessageBox(_("There is no qmake defined, please define one from 'Plugins -> Qmake -> Settings'"),
-                     _("CodeLite"),
-                     wxOK | wxICON_WARNING | wxCENTER,
-                     m_mgr->GetTheApp()->GetTopWindow());
+                     wxT("CodeLite"), wxOK | wxICON_WARNING | wxCENTER, m_mgr->GetTheApp()->GetTopWindow());
         return;
     }
 
@@ -444,21 +395,21 @@ void QMakePlugin::OnNewQmakeBasedProject(wxCommandEvent& event)
 
         if(kind == wxT("Static Library")) {
 
-            type = Project::STATIC_LIBRARY;
+            type = PROJECT_TYPE_STATIC_LIBRARY;
 
         } else if(kind == wxT("Dynamic Library")) {
 
-            type = Project::DYNAMIC_LIBRARY;
+            type = PROJECT_TYPE_DYNAMIC_LIBRARY;
 
         } else if(kind == wxT("Console")) {
 
-            type = Project::EXECUTABLE;
+            type = PROJECT_TYPE_EXECUTABLE;
             configRelease = wxT("0017CONFIG += console");
             config = wxT("0023CONFIG += console debug");
 
         } else {
 
-            type = Project::EXECUTABLE;
+            type = PROJECT_TYPE_EXECUTABLE;
             config = wxT("0015CONFIG += debug");
             configRelease = wxT("0000");
         }
@@ -468,7 +419,7 @@ void QMakePlugin::OnNewQmakeBasedProject(wxCommandEvent& event)
             return;
         }
 
-        // prepend the string lenght
+        // prepend the string length
         qmake = wxString::Format(wxT("%04d%s"), qmakeSettings.Length(), qmakeSettings.c_str());
 
         content.Replace(wxT("$(TYPE)"), type);
@@ -481,7 +432,7 @@ void QMakePlugin::OnNewQmakeBasedProject(wxCommandEvent& event)
         {
             DirSaver ds;
             if(!wxSetWorkingDirectory(path)) {
-                wxMessageBox(_("Invalid project path!"), _("CodeLite"), wxOK | wxCENTER | wxICON_WARNING);
+                wxMessageBox(_("Invalid project path!"), wxT("CodeLite"), wxOK | wxCENTER | wxICON_WARNING);
                 return;
             }
 
@@ -493,8 +444,7 @@ void QMakePlugin::OnNewQmakeBasedProject(wxCommandEvent& event)
             if(!WriteFileWithBackup(name + wxT(".project"), content, false)) {
                 wxMessageBox(wxString::Format(_("Failed to create .project file '%s'"),
                                               wxString(name + wxT(".project")).c_str()),
-                             _("CodeLite"),
-                             wxOK | wxCENTER | wxICON_WARNING);
+                             wxT("CodeLite"), wxOK | wxCENTER | wxICON_WARNING);
                 return;
             }
 
@@ -531,7 +481,8 @@ void QMakePlugin::OnOpenFile(clCommandEvent& event)
 
 void QMakePlugin::OnExportMakefile(wxCommandEvent& event)
 {
-    if(m_qmakeProcess) return;
+    if(m_qmakeProcess)
+        return;
 
     QmakePluginData::BuildConfPluginData bcpd;
 
@@ -557,9 +508,9 @@ void QMakePlugin::OnExportMakefile(wxCommandEvent& event)
         generator.Generate();
 
         // run qmake
-        wxString qmake_exe = m_conf->Read(wxString::Format(wxT("%s/qmake"), bcpd.m_qmakeConfig.c_str()));
-        wxString qmakespec = m_conf->Read(wxString::Format(wxT("%s/qmakespec"), bcpd.m_qmakeConfig.c_str()));
-        wxString qtdir = m_conf->Read(wxString::Format(wxT("%s/qtdir"), bcpd.m_qmakeConfig.c_str()));
+        wxString qmake_exe = m_conf->Read(wxString::Format(wxT("%s/qmake"), bcpd.m_qmakeConfig));
+        wxString qmakespec = m_conf->Read(wxString::Format(wxT("%s/qmakespec"), bcpd.m_qmakeConfig));
+        wxString qtdir = m_conf->Read(wxString::Format(wxT("%s/qtdir"), bcpd.m_qmakeConfig));
 
         // Create qmake comand
         wxString qmake_exe_line;
@@ -569,19 +520,29 @@ void QMakePlugin::OnExportMakefile(wxCommandEvent& event)
         // Set QTDIR
         DirSaver ds;
         {
-
             wxString errMsg;
             ProjectPtr p = m_mgr->GetWorkspace()->FindProjectByName(project, errMsg);
             if(!p) {
                 return;
             }
-
-            qmake_exe_line << wxT("\"") << qmake_exe << wxT("\" -spec ") << qmakespec << wxT(" ")
-                           << generator.GetProFileName();
+            StringUtils::WrapWithQuotes(qmake_exe);
+            qmake_exe_line << qmake_exe << wxT(" -spec ") << qmakespec << wxT(" ") << generator.GetProFileName();
             wxStringMap_t om;
-            om.insert(std::make_pair("QTDIR", qtdir));
+            om.insert({ "QTDIR", qtdir });
+
+            // Add the bin folder of the compiler (so qmakw will be able to find g++ or whatever compiler)
+            wxString cxx = bldConf->GetCompiler()->GetTool("CXX");
+            wxFileName fnCxx(cxx);
+            wxString curpath;
+            wxString updatedPath = fnCxx.GetPath();
+            if(::wxGetEnv("PATH", &curpath)) {
+                updatedPath << clPATH_SEPARATOR << curpath;
+            }
+            om.insert({ "PATH", updatedPath });
+
             EnvSetter envGuard(NULL, &om, project, config);
             m_mgr->ClearOutputTab(kOutputTab_Build);
+            m_mgr->ShowOutputPane(_("Build"));
             m_mgr->AppendOutputTabText(kOutputTab_Build, wxString() << "-- " << qmake_exe_line << "\n");
             m_qmakeProcess =
                 ::CreateAsyncProcess(this, qmake_exe_line, IProcessCreateDefault, p->GetFileName().GetPath());
