@@ -26,9 +26,9 @@
 #ifndef __QMakePlugin__
 #define __QMakePlugin__
 
+#include "cl_command_event.h"
 #include "plugin.h"
 #include "qmakeplugindata.h"
-#include "cl_command_event.h"
 
 class QMakeTab;
 class QmakeConf;
@@ -47,18 +47,17 @@ protected:
 
 public:
     QMakePlugin(IManager* manager);
-    ~QMakePlugin();
+    ~QMakePlugin() override;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void HookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void HookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName);
-    virtual void
-    UnHookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void HookPopupMenu(wxMenu* menu, MenuType type) override;
+    void HookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName) override;
+    void UnHookProjectSettingsTab(wxBookCtrlBase* book, const wxString& projectName, const wxString& configName) override;
+    void UnPlug() override;
 
     // event handlers
     void OnSaveConfig(clProjectSettingsEvent& event);
