@@ -26,31 +26,38 @@
 #ifndef REMOTEFILEINFO_H
 #define REMOTEFILEINFO_H
 
-#include "ssh_account_info.h"
-#include <wx/filename.h>
+#include "ssh/ssh_account_info.h"
+#include "wxStringHash.h"
+
 #include <map>
 #include <wx/clntdata.h>
+#include <wx/filename.h>
 
 class RemoteFileInfo : public wxClientData
 {
     SSHAccountInfo m_account; // the account for which this file belongs to
     wxString m_localFile;
     wxString m_remoteFile;
+    size_t m_premissions;
+    int m_lineNumber = 0;
 
 public:
-    typedef std::map<wxString, RemoteFileInfo> Map_t;
+    typedef std::unordered_map<wxString, RemoteFileInfo> Map_t;
 
 public:
     RemoteFileInfo();
-    virtual ~RemoteFileInfo();
+    virtual ~RemoteFileInfo() = default;
 
     void SetAccount(const SSHAccountInfo& account) { this->m_account = account; }
     const SSHAccountInfo& GetAccount() const { return m_account; }
     const wxString& GetLocalFile() const { return m_localFile; }
     void SetRemoteFile(const wxString& remoteFile);
     const wxString& GetRemoteFile() const { return m_remoteFile; }
+    void SetPremissions(size_t premissions) { this->m_premissions = premissions; }
+    size_t GetPremissions() const { return m_premissions; }
 
-    static wxString GetTempFolder();
+    void SetLineNumber(int lineNumber) { this->m_lineNumber = lineNumber; }
+    int GetLineNumber() const { return m_lineNumber; }
 };
 
 #endif // REMOTEFILEINFO_H
