@@ -24,54 +24,44 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "sftp.h"
-#include <wx/xrc/xmlres.h>
-#include <wx/menu.h>
-#include <wx/msgdlg.h>
-#include "SSHAccountManagerDlg.h"
-#include "sftp_settings.h"
+
+#include "JSON.h"
 #include "SFTPBrowserDlg.h"
-#include "event_notifier.h"
-#include "sftp_workspace_settings.h"
-#include "sftp_worker_thread.h"
-#include <wx/xrc/xmlres.h>
-#include "cl_command_event.h"
-#include "json_node.h"
+#include "SFTPSettingsDialog.h"
 #include "SFTPStatusPage.h"
 #include "SFTPTreeView.h"
-#include <wx/log.h>
-#include "sftp_settings.h"
-#include "SFTPSettingsDialog.h"
-#include "fileutils.h"
-#include "dockablepane.h"
+#include "SSHAccountManagerDlg.h"
+#include "clFilesCollector.h"
+#include "cl_command_event.h"
+#include "cl_standard_paths.h"
 #include "detachedpanesinfo.h"
+#include "dockablepane.h"
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "fileutils.h"
+#include "globals.h"
+#include "procutils.h"
+#include "sftp_settings.h"
+#include "sftp_worker_thread.h"
+#include "sftp_workspace_settings.h"
+
+#include <algorithm>
+#include <wx/log.h>
+#include <wx/menu.h>
+#include <wx/msgdlg.h>
+#include <wx/xrc/xmlres.h>
 
-static SFTP* thePlugin = NULL;
 const wxEventType wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER = ::wxNewEventType();
 const wxEventType wxEVT_SFTP_SETTINGS = ::wxNewEventType();
 const wxEventType wxEVT_SFTP_SETUP_WORKSPACE_MIRRORING = ::wxNewEventType();
 const wxEventType wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING = ::wxNewEventType();
 
-class SFTPClientData : public wxClientData
-{
-    wxString localPath;
-    wxString remotePath;
-
-public:
-    SFTPClientData() {}
-    virtual ~SFTPClientData() {}
-
-    void SetLocalPath(const wxString& localPath) { this->localPath = localPath; }
-    void SetRemotePath(const wxString& remotePath) { this->remotePath = remotePath; }
-    const wxString& GetLocalPath() const { return localPath; }
-    const wxString& GetRemotePath() const { return remotePath; }
-};
-
 // Exposed API (via events)
-// SFTP plugin provides SFTP functionality for codelite based on events
-// It uses the event type clCommandEvent to accept requests from codelite's code
+// SFTP plugin provides SFTP functionality for CodeLite based on events
+// It uses the event type clCommandEvent to accept requests from CodeLite's code
 // the SFTP uses the event GetString() method to read a string in the form of JSON format
 // For example, to instruct the plugin to connect over SSH to a remote server and save a remote file:
-// the GetString() should retrun this JSON string:
+// the GetString() should return this JSON string:
 //  {
 //      account : "account-name-to-use",
 //      local_file : "/path/to/local/file",
@@ -81,10 +71,7 @@ public:
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new SFTP(manager);
-    }
-    return thePlugin;
+    return new SFTP(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -105,72 +92,67 @@ SFTP::SFTP(IManager* manager)
     m_longName = _("SFTP plugin for codelite IDE");
     m_shortName = wxT("SFTP");
 
-    wxTheApp->Connect(
-        wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER, wxEVT_MENU, wxCommandEventHandler(SFTP::OnAccountManager), NULL, this);
+    wxTheApp->Connect(wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER, wxEVT_MENU, wxCommandEventHandler(SFTP::OnAccountManager),
+                      NULL, this);
     wxTheApp->Connect(wxEVT_SFTP_SETTINGS, wxEVT_MENU, wxCommandEventHandler(SFTP::OnSettings), NULL, this);
     wxTheApp->Connect(wxEVT_SFTP_SETUP_WORKSPACE_MIRRORING, wxEVT_MENU,
-        wxCommandEventHandler(SFTP::OnSetupWorkspaceMirroring), NULL, this);
+                      wxCommandEventHandler(SFTP::OnSetupWorkspaceMirroring), NULL, this);
     wxTheApp->Connect(wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, wxEVT_MENU,
-        wxCommandEventHandler(SFTP::OnDisableWorkspaceMirroring), NULL, this);
+                      wxCommandEventHandler(SFTP::OnDisableWorkspaceMirroring), NULL, this);
     wxTheApp->Connect(wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(SFTP::OnDisableWorkspaceMirroringUI), NULL, this);
+                      wxUpdateUIEventHandler(SFTP::OnDisableWorkspaceMirroringUI), NULL, this);
 
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(SFTP::OnWorkspaceOpened), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(SFTP::OnWorkspaceClosed), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_FILE_SAVED, clCommandEventHandler(SFTP::OnFileSaved), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_LOADED, &SFTP::OnWorkspaceOpened, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &SFTP::OnWorkspaceClosed, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_SAVED, &SFTP::OnFileSaved, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_RENAMED, &SFTP::OnFileRenamed, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_DELETED, &SFTP::OnFileDeleted, this);
     EventNotifier::Get()->Bind(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, &SFTP::OnReplaceInFiles, this);
-    EventNotifier::Get()->Connect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(SFTP::OnEditorClosed), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_EDITOR_CLOSING, &SFTP::OnEditorClosed, this);
 
     // API support
     EventNotifier::Get()->Bind(wxEVT_SFTP_SAVE_FILE, &SFTP::OnSaveFile, this);
-
-    SFTPImages images;
+    EventNotifier::Get()->Bind(wxEVT_SFTP_RENAME_FILE, &SFTP::OnRenameFile, this);
+    EventNotifier::Get()->Bind(wxEVT_SFTP_DELETE_FILE, &SFTP::OnDeleteFile, this);
+    EventNotifier::Get()->Bind(wxEVT_SFTP_OPEN_FILE, &SFTP::OnOpenFile, this);
 
     // Add the "SFTP" page to the workspace pane
-    Notebook* book = m_mgr->GetWorkspacePaneNotebook();
-    if(IsPaneDetached(_("SFTP"))) {
+    if (IsPaneDetached(_("SFTP"))) {
         // Make the window child of the main panel (which is the grand parent of the notebook)
         DockablePane* cp =
-            new DockablePane(book->GetParent()->GetParent(), book, _("SFTP"), false, wxNullBitmap, wxSize(200, 200));
-        m_treeView = new SFTPTreeView(cp, this);
-        cp->SetChildNoReparent(m_treeView);
+            new DockablePane(m_mgr->GetMainPanel(), PaneId::SIDE_BAR, _("SFTP"), false, wxSize(200, 200));
+        m_browserView = new SFTPTreeView(cp, this);
+        cp->SetChildNoReparent(m_browserView);
 
     } else {
-        m_treeView = new SFTPTreeView(book, this);
-        book->AddPage(m_treeView, _("SFTP"), false);
+        m_browserView = new SFTPTreeView(m_mgr->BookGet(PaneId::SIDE_BAR), this);
+        m_mgr->BookAddPage(PaneId::SIDE_BAR, m_browserView, _("SFTP"), "sftp-button");
     }
 
     // Add the "SFTP Log" page to the output pane
-    book = m_mgr->GetOutputPaneNotebook();
-    if(IsPaneDetached(_("SFTP Log"))) {
+    if (IsPaneDetached(_("SFTP Log"))) {
         // Make the window child of the main panel (which is the grand parent of the notebook)
-        DockablePane* cp = new DockablePane(
-            book->GetParent()->GetParent(), book, _("SFTP Log"), false, images.Bitmap("sftp_tab"), wxSize(200, 200));
-        m_outputPane = new SFTPStatusPage(cp, this);
-        cp->SetChildNoReparent(m_outputPane);
+        DockablePane* cp =
+            new DockablePane(m_mgr->GetMainPanel(), PaneId::BOTTOM_BAR, _("SFTP Log"), false, wxSize(200, 200));
+        m_logView = new SFTPStatusPage(cp, this);
+        cp->SetChildNoReparent(m_logView);
 
     } else {
-        m_outputPane = new SFTPStatusPage(book, this);
-        book->AddPage(m_outputPane, _("SFTP Log"), false, images.Bitmap("sftp_tab"));
+        m_logView = new SFTPStatusPage(m_mgr->BookGet(PaneId::BOTTOM_BAR), this);
+        m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_logView, _("SFTP Log"));
     }
 
     // Create the helper for adding our tabs in the "more" menu
-    m_tabToggler.reset(new clTabTogglerHelper(_("SFTP Log"), m_outputPane, _("SFTP"), m_treeView));
-    m_tabToggler->SetOutputTabBmp(m_mgr->GetStdIcons()->LoadBitmap("remote-folder"));
+    m_tabToggler.reset(new clTabTogglerHelper(_("SFTP Log"), m_logView, _("SFTP"), m_browserView));
 
-    SFTPWorkerThread::Instance()->SetNotifyWindow(m_outputPane);
+    SFTPWorkerThread::Instance()->SetNotifyWindow(m_logView);
     SFTPWorkerThread::Instance()->SetSftpPlugin(this);
     SFTPWorkerThread::Instance()->Start();
+
+    EventNotifier::Get()->Bind(wxEVT_INIT_DONE, &SFTP::OnInitDone, this);
 }
 
-SFTP::~SFTP() {}
-
-clToolBar* SFTP::CreateToolBar(wxWindow* parent)
-{
-    // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-    return tb;
-}
+void SFTP::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void SFTP::CreatePluginMenu(wxMenu* pluginsMenu)
 {
@@ -178,7 +160,7 @@ void SFTP::CreatePluginMenu(wxMenu* pluginsMenu)
     wxMenuItem* item(NULL);
 
     item = new wxMenuItem(menu, wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER, _("Open SSH Account Manager"),
-        _("Open SSH Account Manager"), wxITEM_NORMAL);
+                          _("Open SSH Account Manager"), wxITEM_NORMAL);
     menu->Append(item);
     menu->AppendSeparator();
     item = new wxMenuItem(menu, wxEVT_SFTP_SETTINGS, _("Settings..."), _("Settings..."), wxITEM_NORMAL);
@@ -188,17 +170,17 @@ void SFTP::CreatePluginMenu(wxMenu* pluginsMenu)
 
 void SFTP::HookPopupMenu(wxMenu* menu, MenuType type)
 {
-    if(type == MenuTypeFileView_Workspace) {
+    if (type == MenuTypeFileView_Workspace) {
         // Create the popup menu for the virtual folders
         wxMenuItem* item(NULL);
 
         wxMenu* sftpMenu = new wxMenu();
-        item = new wxMenuItem(
-            sftpMenu, wxEVT_SFTP_SETUP_WORKSPACE_MIRRORING, _("&Setup..."), wxEmptyString, wxITEM_NORMAL);
+        item = new wxMenuItem(sftpMenu, wxEVT_SFTP_SETUP_WORKSPACE_MIRRORING, _("&Setup..."), wxEmptyString,
+                              wxITEM_NORMAL);
         sftpMenu->Append(item);
 
-        item = new wxMenuItem(
-            sftpMenu, wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, _("&Disable"), wxEmptyString, wxITEM_NORMAL);
+        item = new wxMenuItem(sftpMenu, wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, _("&Disable"), wxEmptyString,
+                              wxITEM_NORMAL);
         sftpMenu->Append(item);
 
         item = new wxMenuItem(menu, wxID_SEPARATOR);
@@ -211,91 +193,82 @@ bool SFTP::IsPaneDetached(const wxString& name) const
 {
     DetachedPanesInfo dpi;
     m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    const wxArrayString& detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(name) != wxNOT_FOUND;
-}
-
-void SFTP::UnHookPopupMenu(wxMenu* menu, MenuType type)
-{
-    wxUnusedVar(menu);
-    wxUnusedVar(type);
+    return dpi.GetPanes().Index(name) != wxNOT_FOUND;
 }
 
 void SFTP::UnPlug()
 {
-    // Find our page and release it
-    // before this plugin is un-plugged we must remove the tab we added
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); ++i) {
-        if(m_outputPane == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            break;
-        }
+    if (!m_mgr->BookDeletePage(PaneId::SIDE_BAR, m_browserView)) {
+        m_browserView->Destroy();
     }
-    m_outputPane->Destroy();
+    m_browserView = nullptr;
 
-    for(size_t i = 0; i < m_mgr->GetWorkspacePaneNotebook()->GetPageCount(); ++i) {
-        if(m_treeView == m_mgr->GetWorkspacePaneNotebook()->GetPage(i)) {
-            m_mgr->GetWorkspacePaneNotebook()->RemovePage(i);
-            break;
-        }
+    if (!m_mgr->BookDeletePage(PaneId::BOTTOM_BAR, m_logView)) {
+        m_logView->Destroy();
     }
-    m_treeView->Destroy();
+    m_logView = nullptr;
 
     SFTPWorkerThread::Release();
-    wxTheApp->Disconnect(
-        wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER, wxEVT_MENU, wxCommandEventHandler(SFTP::OnAccountManager), NULL, this);
+    wxTheApp->Disconnect(wxEVT_SFTP_OPEN_SSH_ACCOUNT_MANAGER, wxEVT_MENU, wxCommandEventHandler(SFTP::OnAccountManager),
+                         NULL, this);
     wxTheApp->Disconnect(wxEVT_SFTP_SETTINGS, wxEVT_MENU, wxCommandEventHandler(SFTP::OnSettings), NULL, this);
     wxTheApp->Disconnect(wxEVT_SFTP_SETUP_WORKSPACE_MIRRORING, wxEVT_MENU,
-        wxCommandEventHandler(SFTP::OnSetupWorkspaceMirroring), NULL, this);
+                         wxCommandEventHandler(SFTP::OnSetupWorkspaceMirroring), NULL, this);
     wxTheApp->Disconnect(wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, wxEVT_MENU,
-        wxCommandEventHandler(SFTP::OnDisableWorkspaceMirroring), NULL, this);
+                         wxCommandEventHandler(SFTP::OnDisableWorkspaceMirroring), NULL, this);
     wxTheApp->Disconnect(wxEVT_SFTP_DISABLE_WORKSPACE_MIRRORING, wxEVT_UPDATE_UI,
-        wxUpdateUIEventHandler(SFTP::OnDisableWorkspaceMirroringUI), NULL, this);
+                         wxUpdateUIEventHandler(SFTP::OnDisableWorkspaceMirroringUI), NULL, this);
 
-    EventNotifier::Get()->Disconnect(
-        wxEVT_WORKSPACE_LOADED, wxCommandEventHandler(SFTP::OnWorkspaceOpened), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_WORKSPACE_CLOSED, wxCommandEventHandler(SFTP::OnWorkspaceClosed), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(SFTP::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_EDITOR_CLOSING, wxCommandEventHandler(SFTP::OnEditorClosed), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_LOADED, &SFTP::OnWorkspaceOpened, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &SFTP::OnWorkspaceClosed, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &SFTP::OnFileSaved, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_RENAMED, &SFTP::OnFileRenamed, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_DELETED, &SFTP::OnFileDeleted, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, &SFTP::OnReplaceInFiles, this);
+    EventNotifier::Get()->Unbind(wxEVT_EDITOR_CLOSING, &SFTP::OnEditorClosed, this);
 
     EventNotifier::Get()->Unbind(wxEVT_SFTP_SAVE_FILE, &SFTP::OnSaveFile, this);
-    EventNotifier::Get()->Unbind(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, &SFTP::OnReplaceInFiles, this);
-    m_tabToggler.reset(NULL);
+    EventNotifier::Get()->Unbind(wxEVT_SFTP_RENAME_FILE, &SFTP::OnRenameFile, this);
+    EventNotifier::Get()->Unbind(wxEVT_SFTP_DELETE_FILE, &SFTP::OnDeleteFile, this);
+    EventNotifier::Get()->Unbind(wxEVT_SFTP_OPEN_FILE, &SFTP::OnOpenFile, this);
+    EventNotifier::Get()->Unbind(wxEVT_INIT_DONE, &SFTP::OnInitDone, this);
+    m_tabToggler.reset();
+
+    // Delete the temporary files
+    wxFileName::Rmdir(clSFTP::GetDefaultDownloadFolder({}), wxPATH_RMDIR_RECURSIVE);
 }
 
 void SFTP::OnAccountManager(wxCommandEvent& e)
 {
     wxUnusedVar(e);
     SSHAccountManagerDlg dlg(wxTheApp->GetTopWindow());
-    if(dlg.ShowModal() == wxID_OK) {
-
-        SFTPSettings settings;
-        settings.Load();
-        settings.SetAccounts(dlg.GetAccounts());
-        settings.Save();
-    }
+    dlg.ShowModal();
 }
 
 void SFTP::OnSetupWorkspaceMirroring(wxCommandEvent& e)
 {
     SFTPBrowserDlg dlg(wxTheApp->GetTopWindow(), _("Select the remote workspace"), "*.workspace");
     dlg.Initialize(m_workspaceSettings.GetAccount(), m_workspaceSettings.GetRemoteWorkspacePath());
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         m_workspaceSettings.SetRemoteWorkspacePath(dlg.GetPath());
         m_workspaceSettings.SetAccount(dlg.GetAccount());
         SFTPWorkspaceSettings::Save(m_workspaceSettings, m_workspaceFile);
     }
 }
 
-void SFTP::OnWorkspaceOpened(wxCommandEvent& e)
+void SFTP::OnWorkspaceOpened(clWorkspaceEvent& e)
 {
     e.Skip();
-    m_workspaceFile = e.GetString();
-    SFTPWorkspaceSettings::Load(m_workspaceSettings, m_workspaceFile);
+    if (e.IsRemote()) {
+        m_workspaceFile.Clear();
+        m_workspaceSettings.Clear();
+    } else {
+        m_workspaceFile = e.GetString();
+        SFTPWorkspaceSettings::Load(m_workspaceSettings, m_workspaceFile);
+    }
 }
 
-void SFTP::OnWorkspaceClosed(wxCommandEvent& e)
+void SFTP::OnWorkspaceClosed(clWorkspaceEvent& e)
 {
     e.Skip();
     m_workspaceFile.Clear();
@@ -314,9 +287,9 @@ void SFTP::OnFileSaved(clCommandEvent& e)
     DoFileSaved(local_file);
 }
 
-void SFTP::OnFileWriteOK(const wxString& message) { wxLogMessage(message); }
+void SFTP::OnFileWriteOK(const wxString& message) { clLogMessage(message); }
 
-void SFTP::OnFileWriteError(const wxString& errorMessage) { wxLogMessage(errorMessage); }
+void SFTP::OnFileWriteError(const wxString& errorMessage) { clLogMessage(errorMessage); }
 
 void SFTP::OnDisableWorkspaceMirroring(wxCommandEvent& e)
 {
@@ -339,37 +312,43 @@ void SFTP::OnSaveFile(clSFTPEvent& e)
     wxString remoteFile = e.GetRemoteFile();
 
     SSHAccountInfo account;
-    if(settings.GetAccount(accName, account)) {
-        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile, localFile));
+    if (settings.GetAccount(accName, account)) {
+        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile, localFile, 0));
 
     } else {
         wxString msg;
-        msg << _("Failed to synchronize file '") << localFile << "'\n" << _("with remote server\n")
-            << _("Could not locate account: ") << accName;
+        msg << _("Failed to synchronize file '") << localFile << "'\n"
+            << _("with remote server\n") << _("Could not locate account: ") << accName;
         ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
     }
 }
 
 void SFTP::DoSaveRemoteFile(const RemoteFileInfo& remoteFile)
 {
-    SFTPWorkerThread::Instance()->Add(
-        new SFTPThreadRequet(remoteFile.GetAccount(), remoteFile.GetRemoteFile(), remoteFile.GetLocalFile()));
+    SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(remoteFile.GetAccount(), remoteFile.GetRemoteFile(),
+                                                           remoteFile.GetLocalFile(), remoteFile.GetPremissions()));
 }
 
-void SFTP::FileDownloadedSuccessfully(const wxString& localFileName, const wxString& remotePath)
+void SFTP::FileDownloadedSuccessfully(const SFTPClientData& cd)
 {
     wxString tooltip;
-    tooltip << "Local: " << localFileName << "\n"
-            << "Remote: " << remotePath;
-    
-    wxBitmap bmp = m_mgr->GetStdIcons()->LoadBitmap("download");
-    IEditor* editor = m_mgr->OpenFile(localFileName, bmp, tooltip);
-    if(editor) {
+    tooltip << "Local: " << cd.GetLocalPath() << "\n"
+            << "Remote: " << cd.GetRemotePath();
+
+    IEditor* editor = m_mgr->OpenFile(cd.GetLocalPath(), "download", tooltip);
+    if (editor) {
         // Tag this editor as a remote file
-        SFTPClientData* cd = new SFTPClientData();
-        cd->SetLocalPath(localFileName);
-        cd->SetRemotePath(remotePath);
-        editor->SetClientData("sftp", cd);
+        editor->SetClientData("sftp", std::make_unique<SFTPClientData>(cd));
+        // set the line number
+        if (cd.GetLineNumber() != wxNOT_FOUND) {
+            editor->GetCtrl()->GotoLine(cd.GetLineNumber());
+        }
+    }
+
+    // Now that the file was downloaded, update the file permissions
+    if (m_remoteFiles.count(cd.GetLocalPath())) {
+        RemoteFileInfo& info = m_remoteFiles[cd.GetLocalPath()];
+        info.SetPremissions(cd.GetPermissions());
     }
 }
 
@@ -377,7 +356,7 @@ void SFTP::OpenWithDefaultApp(const wxString& localFileName) { ::wxLaunchDefault
 
 void SFTP::AddRemoteFile(const RemoteFileInfo& remoteFile)
 {
-    if(m_remoteFiles.count(remoteFile.GetLocalFile())) {
+    if (m_remoteFiles.count(remoteFile.GetLocalFile())) {
         m_remoteFiles.erase(remoteFile.GetLocalFile());
     }
     m_remoteFiles.insert(std::make_pair(remoteFile.GetLocalFile(), remoteFile));
@@ -387,14 +366,14 @@ void SFTP::OnEditorClosed(wxCommandEvent& e)
 {
     e.Skip();
     IEditor* editor = (IEditor*)e.GetClientData();
-    if(editor) {
+    if (editor) {
         wxString localFile = editor->GetFileName().GetFullPath();
-        if(m_remoteFiles.count(localFile)) {
+        if (m_remoteFiles.count(localFile)) {
 
             wxLogNull noLog;
 
             // Remove the file from our cache
-            ::wxRemoveFile(localFile);
+            clRemoveFile(localFile);
             m_remoteFiles.erase(localFile);
         }
     }
@@ -409,7 +388,8 @@ void SFTP::MSWInitiateConnection()
     SFTPSettings settings;
     settings.Load();
     const SSHAccountInfo::Vect_t& accounts = settings.GetAccounts();
-    if(accounts.empty()) return;
+    if (accounts.empty())
+        return;
     const SSHAccountInfo& account = accounts.at(0);
     SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account));
 #endif
@@ -424,10 +404,11 @@ void SFTP::OnSettings(wxCommandEvent& e)
 
 void SFTP::DoFileSaved(const wxString& filename)
 {
-    if(filename.IsEmpty()) return;
+    if (filename.IsEmpty())
+        return;
 
     // Check to see if this file is part of a remote files managed by our plugin
-    if(m_remoteFiles.count(filename)) {
+    if (m_remoteFiles.count(filename)) {
         // ----------------------------------------------------------------------------------------------
         // this file was opened by the SFTP explorer
         // ----------------------------------------------------------------------------------------------
@@ -438,29 +419,23 @@ void SFTP::DoFileSaved(const wxString& filename)
         // Not a remote file, see if have a sychronization setup between this workspace and a remote one
         // ----------------------------------------------------------------------------------------------
 
-        // check if we got a workspace file opened
-        if(!m_workspaceFile.IsOk()) return;
-
-        // check if mirroring is setup for this workspace
-        if(!m_workspaceSettings.IsOk()) return;
-
-        wxFileName file(filename);
-        file.MakeRelativeTo(m_workspaceFile.GetPath());
-        file.MakeAbsolute(wxFileName(m_workspaceSettings.GetRemoteWorkspacePath(), wxPATH_UNIX).GetPath());
-        wxString remoteFile = file.GetFullPath(wxPATH_UNIX);
+        wxString remoteFile = GetRemotePath(filename);
+        if (remoteFile.IsEmpty()) {
+            return;
+        }
 
         SFTPSettings settings;
         settings.Load();
 
         SSHAccountInfo account;
-        if(settings.GetAccount(m_workspaceSettings.GetAccount(), account)) {
-            SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile, filename));
+        if (settings.GetAccount(m_workspaceSettings.GetAccount(), account)) {
+            SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile, filename, 0));
 
         } else {
 
             wxString msg;
-            msg << _("Failed to synchronize file '") << filename << "'\n" << _("with remote server\n")
-                << _("Could not locate account: ") << m_workspaceSettings.GetAccount();
+            msg << _("Failed to synchronize file '") << filename << "'\n"
+                << _("with remote server\n") << _("Could not locate account: ") << m_workspaceSettings.GetAccount();
             ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
 
             // Disable the workspace mirroring for this workspace
@@ -473,10 +448,157 @@ void SFTP::DoFileSaved(const wxString& filename)
 void SFTP::OnReplaceInFiles(clFileSystemEvent& e)
 {
     e.Skip();
-    const wxArrayString& files = e.GetStrings();
-    for(size_t i = 0; i < files.size(); ++i) {
-        DoFileSaved(files.Item(i));
+    for (const auto& file : e.GetStrings()) {
+        DoFileSaved(file);
     }
 }
 
 void SFTP::OpenContainingFolder(const wxString& localFileName) { FileUtils::OpenFileExplorerAndSelect(localFileName); }
+
+void SFTP::OnFileRenamed(clFileSystemEvent& e)
+{
+    e.Skip();
+
+    // Convert local paths to remote paths
+    wxString remoteFile = GetRemotePath(e.GetPath());
+    wxString remoteNew = GetRemotePath(e.GetNewpath());
+    if (remoteFile.IsEmpty() || remoteNew.IsEmpty()) {
+        return;
+    }
+
+    SFTPSettings settings;
+    settings.Load();
+
+    SSHAccountInfo account;
+    if (settings.GetAccount(m_workspaceSettings.GetAccount(), account)) {
+        clDEBUG() << "SFTP: Renaming remote file:" << remoteFile << "->" << remoteNew;
+        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile, remoteNew));
+
+    } else {
+
+        wxString msg;
+        msg << _("Failed to rename file '") << e.GetPath() << "'\n"
+            << _("with remote server\n") << _("Could not locate account: ") << m_workspaceSettings.GetAccount();
+        ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
+
+        // Disable the workspace mirroring for this workspace
+        m_workspaceSettings.Clear();
+        SFTPWorkspaceSettings::Save(m_workspaceSettings, m_workspaceFile);
+    }
+}
+
+void SFTP::OnFileDeleted(clFileSystemEvent& e)
+{
+    e.Skip();
+    for (const auto& file : e.GetPaths()) {
+        DoFileDeleted(file);
+    }
+}
+
+bool SFTP::IsCxxWorkspaceMirrorEnabled() const { return m_workspaceFile.IsOk() && m_workspaceSettings.IsOk(); }
+
+void SFTP::OnRenameFile(clSFTPEvent& e)
+{
+    SFTPSettings settings;
+    settings.Load();
+
+    wxString accName = e.GetAccount();
+    wxString remoteOld = e.GetRemoteFile();
+    wxString remoteNew = e.GetNewRemoteFile();
+
+    SSHAccountInfo account;
+    if (settings.GetAccount(accName, account)) {
+        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteOld, remoteNew));
+
+    } else {
+        wxString msg;
+        msg << _("Failed to rename file '") << remoteOld << "'\n"
+            << _("with remote server\n") << _("Could not locate account: ") << accName;
+        ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
+    }
+}
+
+void SFTP::OnDeleteFile(clSFTPEvent& e)
+{
+    SFTPSettings settings;
+    settings.Load();
+
+    wxString accName = e.GetAccount();
+    wxString path = e.GetRemoteFile();
+
+    SSHAccountInfo account;
+    if (settings.GetAccount(accName, account)) {
+        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, path));
+
+    } else {
+        wxString msg;
+        msg << _("Failed to delete remote file '") << path << _("'\nCould not locate account: ") << accName;
+        ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
+    }
+}
+
+void SFTP::DoFileDeleted(const wxString& filepath)
+{
+    wxString remoteFile = GetRemotePath(filepath);
+    if (remoteFile.IsEmpty()) {
+        return;
+    }
+
+    SFTPSettings settings;
+    settings.Load();
+
+    SSHAccountInfo account;
+    if (settings.GetAccount(m_workspaceSettings.GetAccount(), account)) {
+        SFTPWorkerThread::Instance()->Add(new SFTPThreadRequet(account, remoteFile));
+
+    } else {
+
+        wxString msg;
+        msg << _("Failed to delete remote file: ") << remoteFile << "'\n"
+            << _("Could not locate account: ") << m_workspaceSettings.GetAccount();
+        ::wxMessageBox(msg, _("SFTP"), wxOK | wxICON_ERROR);
+
+        // Disable the workspace mirroring for this workspace
+        m_workspaceSettings.Clear();
+        SFTPWorkspaceSettings::Save(m_workspaceSettings, m_workspaceFile);
+    }
+}
+
+wxString SFTP::GetRemotePath(const wxString& localpath) const
+{
+    if (!IsCxxWorkspaceMirrorEnabled()) {
+        return "";
+    }
+    wxFileName file(localpath);
+    file.MakeRelativeTo(m_workspaceFile.GetPath());
+    file.MakeAbsolute(wxFileName(m_workspaceSettings.GetRemoteWorkspacePath(), wxPATH_UNIX).GetPath());
+    return file.GetFullPath(wxPATH_UNIX);
+}
+
+void SFTP::OpenFile(const wxString& remotePath, int lineNumber)
+{
+    RemoteFileInfo::Map_t::iterator iter =
+        std::find_if(m_remoteFiles.begin(), m_remoteFiles.end(), [&](const RemoteFileInfo::Map_t::value_type& vt) {
+            return vt.second.GetRemoteFile() == remotePath;
+        });
+    if (iter != m_remoteFiles.end()) {
+        m_mgr->OpenFile(iter->second.GetLocalFile(), "", lineNumber);
+    } else {
+        RemoteFileInfo remoteFile;
+        remoteFile.SetAccount(GetTreeView()->GetAccount());
+        remoteFile.SetRemoteFile(remotePath);
+        remoteFile.SetLineNumber(lineNumber);
+
+        SFTPThreadRequet* req = new SFTPThreadRequet(remoteFile);
+        SFTPWorkerThread::Instance()->Add(req);
+        AddRemoteFile(remoteFile);
+    }
+}
+
+void SFTP::OnInitDone(wxCommandEvent& event) { event.Skip(); }
+
+void SFTP::OnOpenFile(clSFTPEvent& e)
+{
+    e.Skip();
+    OpenFile(e.GetRemoteFile(), e.GetLineNumber());
+}
