@@ -23,10 +23,13 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include "SFTPStatusPage.h"
-#include "cl_ssh.h"
-#include "sftp.h"
 #include "sftp_worker_thread.h"
+
+#include "SFTPStatusPage.h"
+#include "environmentconfig.h"
+#include "sftp.h"
+#include "ssh/cl_ssh.h"
+
 #include <libssh/sftp.h>
 #include <wx/ffile.h>
 
@@ -38,11 +41,9 @@ SFTPWorkerThread::SFTPWorkerThread()
 {
 }
 
-SFTPWorkerThread::~SFTPWorkerThread() {}
-
 SFTPWorkerThread* SFTPWorkerThread::Instance()
 {
-    if(ms_instance == 0) {
+    if (ms_instance == 0) {
         ms_instance = new SFTPWorkerThread();
     }
     return ms_instance;
@@ -50,7 +51,7 @@ SFTPWorkerThread* SFTPWorkerThread::Instance()
 
 void SFTPWorkerThread::Release()
 {
-    if(ms_instance) {
+    if (ms_instance) {
         ms_instance->Stop();
         delete ms_instance;
     }
@@ -64,24 +65,24 @@ void SFTPWorkerThread::ProcessRequest(ThreadRequest* request)
     wxString currentAccout = m_sftp ? m_sftp->GetAccount() : "";
     wxString requestAccount = req->GetAccount().GetAccountName();
 
-    if(currentAccout.IsEmpty() || currentAccout != requestAccount) {
-        m_sftp.reset(NULL);
+    if (currentAccout.IsEmpty() || currentAccout != requestAccount) {
+        m_sftp.reset();
         DoConnect(req);
     }
 
-    if(req->GetAction() == eSFTPActions::kConnect) {
+    if (req->GetAction() == eSFTPActions::kConnect) {
         // Nothing more to be done here
         // Disconnect
-        m_sftp.reset(NULL);
+        m_sftp.reset();
         return;
     }
 
     wxString msg;
     wxString accountName = req->GetAccount().GetAccountName();
-    if(m_sftp && m_sftp->IsConnected()) {
+    if (m_sftp && m_sftp->IsConnected()) {
         msg.Clear();
         try {
-            switch(req->GetAction()) {
+            switch (req->GetAction()) {
             case eSFTPActions::kConnect:
                 // We don't really need this case. Just make the compiler silence
                 return;
@@ -100,7 +101,7 @@ void SFTPWorkerThread::ProcessRequest(ThreadRequest* request)
                 wxMemoryBuffer buffer;
                 SFTPAttribute::Ptr_t fileAttr = m_sftp->Read(req->GetRemoteFile(), buffer);
                 wxFFile fp(req->GetLocalFile(), "w+b");
-                if(fp.IsOpened()) {
+                if (fp.IsOpened()) {
                     fp.Write(buffer.GetData(), buffer.GetDataLen());
                     fp.Close();
                 }
@@ -110,7 +111,7 @@ void SFTPWorkerThread::ProcessRequest(ThreadRequest* request)
                 DoReportStatusBarMessage("");
 
                 // We should also notify the parent window about download completed
-                if(req->GetAction() == eSFTPActions::kDownload) {
+                if (req->GetAction() == eSFTPActions::kDownload) {
                     SFTPClientData cd;
                     cd.SetLocalPath(req->GetLocalFile());
                     cd.SetRemotePath(req->GetRemoteFile());
@@ -119,7 +120,7 @@ void SFTPWorkerThread::ProcessRequest(ThreadRequest* request)
                     cd.SetAccountName(req->GetAccount().GetAccountName());
                     m_plugin->CallAfter(&SFTP::FileDownloadedSuccessfully, cd);
 
-                } else if(req->GetAction() == eSFTPActions::kDownloadAndOpenContainingFolder) {
+                } else if (req->GetAction() == eSFTPActions::kDownloadAndOpenContainingFolder) {
                     m_plugin->CallAfter(&SFTP::OpenContainingFolder, req->GetLocalFile());
 
                 } else {
@@ -145,16 +146,16 @@ void SFTPWorkerThread::ProcessRequest(ThreadRequest* request)
                 break;
             }
             }
-        } catch(clException& e) {
+        } catch (const clException& e) {
 
             msg.Clear();
             msg << "SFTP error: " << e.What();
             DoReportMessage(accountName, msg, SFTPThreadMessage::STATUS_ERROR);
             DoReportStatusBarMessage(msg);
-            m_sftp.reset(NULL);
+            m_sftp.reset();
 
             // Requeue our request
-            if(req->GetRetryCounter() == 0) {
+            if (req->GetRetryCounter() == 0) {
                 msg.Clear();
                 msg << "Retrying to upload file: " << req->GetRemoteFile();
                 DoReportMessage(req->GetAccount().GetAccountName(), msg, SFTPThreadMessage::STATUS_NONE);
@@ -172,13 +173,15 @@ void SFTPWorkerThread::DoConnect(SFTPThreadRequet* req)
 {
     wxString accountName = req->GetAccount().GetAccountName();
     clSSH::Ptr_t ssh(new clSSH(req->GetAccount().GetHost(), req->GetAccount().GetUsername(),
-                               req->GetAccount().GetPassword(), req->GetAccount().GetPort()));
+                               req->GetAccount().GetPassword(), req->GetAccount().GetKeyFiles(),
+                               req->GetAccount().GetPort()));
     try {
         wxString message;
         DoReportStatusBarMessage(wxString() << _("Connecting to ") << accountName);
         DoReportMessage(accountName, "Connecting...", SFTPThreadMessage::STATUS_NONE);
-        ssh->Connect();
-        if(!ssh->AuthenticateServer(message)) {
+        EnvSetter env;
+        ssh->Open();
+        if (!ssh->AuthenticateServer(message)) {
             ssh->AcceptServerAuthentication();
         }
 
@@ -193,11 +196,11 @@ void SFTPWorkerThread::DoConnect(SFTPThreadRequet* req)
         msg << "Successfully connected to " << accountName;
         DoReportMessage(accountName, msg, SFTPThreadMessage::STATUS_OK);
 
-    } catch(clException& e) {
+    } catch (const clException& e) {
         wxString msg;
         msg << "Connect error. " << e.What();
         DoReportMessage(accountName, msg, SFTPThreadMessage::STATUS_ERROR);
-        m_sftp.reset(NULL);
+        m_sftp.reset();
     }
 }
 
@@ -263,7 +266,7 @@ SFTPThreadRequet::SFTPThreadRequet(const SSHAccountInfo& accountInfo, const wxSt
 
 SFTPThreadRequet::SFTPThreadRequet(const SFTPThreadRequet& other)
 {
-    if(this == &other)
+    if (this == &other)
         return;
     *this = other;
 }
@@ -280,8 +283,6 @@ SFTPThreadRequet& SFTPThreadRequet::operator=(const SFTPThreadRequet& other)
     return *this;
 }
 
-SFTPThreadRequet::~SFTPThreadRequet() {}
-
 ThreadRequest* SFTPThreadRequet::Clone() const { return new SFTPThreadRequet(*this); }
 
 // -----------------------------------------
@@ -292,5 +293,3 @@ SFTPThreadMessage::SFTPThreadMessage()
     : m_status(STATUS_NONE)
 {
 }
-
-SFTPThreadMessage::~SFTPThreadMessage() {}
