@@ -30,19 +30,15 @@ SFTPWorkspaceSettings::SFTPWorkspaceSettings()
 {
 }
 
-SFTPWorkspaceSettings::~SFTPWorkspaceSettings()
-{
-}
-
-void SFTPWorkspaceSettings::FromJSON(const JSONElement& json)
+void SFTPWorkspaceSettings::FromJSON(const JSONItem& json)
 {
     m_remoteWorkspacePath = json.namedObject("m_remoteWorkspacePath").toString();
     m_account = json.namedObject("m_account").toString();
 }
 
-JSONElement SFTPWorkspaceSettings::ToJSON() const
+JSONItem SFTPWorkspaceSettings::ToJSON() const
 {
-    JSONElement element = JSONElement::createObject(GetName());
+    JSONItem element = JSONItem::createObject(GetName());
     element.addProperty("m_account", m_account);
     element.addProperty("m_remoteWorkspacePath", m_remoteWorkspacePath);
     return element;
@@ -51,11 +47,13 @@ JSONElement SFTPWorkspaceSettings::ToJSON() const
 void SFTPWorkspaceSettings::Load(SFTPWorkspaceSettings& settings, const wxFileName& workspaceFile)
 {
     wxFileName fn(workspaceFile);
-    fn.SetName("sftp-workspace-settings");
-    fn.SetExt("conf");
-    fn.AppendDir(".codelite");
-    clConfig config( fn.GetFullPath() );
-    config.ReadItem( &settings );
+    if(fn.IsOk() && fn.FileExists()) {
+        fn.SetName("sftp-workspace-settings");
+        fn.SetExt("conf");
+        fn.AppendDir(".codelite");
+        clConfig config(fn.GetFullPath());
+        config.ReadItem(&settings);
+    }
 }
 
 void SFTPWorkspaceSettings::Save(const SFTPWorkspaceSettings& settings, const wxFileName& workspaceFile)
@@ -64,8 +62,8 @@ void SFTPWorkspaceSettings::Save(const SFTPWorkspaceSettings& settings, const wx
     fn.SetName("sftp-workspace-settings");
     fn.SetExt("conf");
     fn.AppendDir(".codelite");
-    clConfig config( fn.GetFullPath() );
-    config.WriteItem( &settings );
+    clConfig config(fn.GetFullPath());
+    config.WriteItem(&settings);
 }
 
 void SFTPWorkspaceSettings::Clear()
