@@ -24,15 +24,16 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "editsnippetsdlg.h"
-#include "snipwiz.h"
-#include <wx/msgdlg.h>
+
 #include "AboutHtml.h"
-#include "clKeyboardManager.h"
+#include "Keyboard/clKeyboardManager.h"
+#include "snipwiz.h"
+
+#include <wx/msgdlg.h>
 
 EditSnippetsDlg::EditSnippetsDlg(wxWindow* parent, SnipWiz* plugin, IManager* manager)
     : EditSnippetsBaseDlg(parent)
     , m_pPlugin(plugin)
-    , m_manager(manager)
 {
     Initialize();
     m_listBox1->SetFocus();
@@ -58,23 +59,21 @@ void EditSnippetsDlg::DoItemSelected(const wxString& text)
     m_textCtrlSnippet->SetValue(GetStringDb()->GetSnippetString(text));
     MenuItemDataMap_t accelMap;
     clKeyboardManager::Get()->GetAllAccelerators(accelMap);
-    if(text.IsEmpty()) {
+    if (text.IsEmpty()) {
         return;
     }
 
-    m_textCtrlAccelerator->SetValue(wxT(""));
-    MenuItemDataMap_t::iterator iter = accelMap.begin();
-    for(; iter != accelMap.end(); ++iter) {
-        MenuItemData mid = iter->second;
-        if(mid.action == text) {
-            m_textCtrlAccelerator->SetValue(mid.accel);
+    m_textCtrlAccelerator->SetValue("");
+    for (const auto& [_, mid] : accelMap) {
+        if (mid.parentMenu == _("SnipWiz") && mid.action == text) {
+            m_textCtrlAccelerator->SetValue(mid.accel.ToString());
         }
     }
 }
 
 void EditSnippetsDlg::OnAddSnippet(wxCommandEvent& event)
 {
-    if(GetStringDb()->IsSnippetKey(m_textCtrlMenuEntry->GetValue())) {
+    if (GetStringDb()->IsSnippetKey(m_textCtrlMenuEntry->GetValue())) {
         wxMessageBox(_("Menu entry is not unique!"));
         return;
     }
@@ -86,10 +85,7 @@ void EditSnippetsDlg::OnAddSnippet(wxCommandEvent& event)
 
 void EditSnippetsDlg::OnAddSnippetUI(wxUpdateUIEvent& event)
 {
-    if(m_textCtrlMenuEntry->GetValue().IsEmpty() || m_textCtrlSnippet->GetValue().IsEmpty())
-        event.Enable(false);
-    else
-        event.Enable(true);
+    event.Enable(!m_textCtrlMenuEntry->GetValue().IsEmpty() && !m_textCtrlSnippet->GetValue().IsEmpty());
 }
 
 void EditSnippetsDlg::OnChangeSnippet(wxCommandEvent& event)
@@ -98,14 +94,16 @@ void EditSnippetsDlg::OnChangeSnippet(wxCommandEvent& event)
     int index = m_listBox1->GetSelection();
 
     // check if list key is not equal new menu entry and if it is an used key
-    if(curListKey.Cmp(m_textCtrlMenuEntry->GetValue()) != 0 &&
-       GetStringDb()->IsSnippetKey(m_textCtrlMenuEntry->GetValue())) {
+    if (curListKey.Cmp(m_textCtrlMenuEntry->GetValue()) != 0 &&
+        GetStringDb()->IsSnippetKey(m_textCtrlMenuEntry->GetValue())) {
         ::wxMessageBox(_("Menu entry is not unique!"));
         return;
     }
 
     // if menu entry has changed, delete old entry in list
-    if(curListKey.Cmp(m_textCtrlMenuEntry->GetValue()) != 0) GetStringDb()->DeleteSnippetKey(curListKey);
+    if (curListKey.Cmp(m_textCtrlMenuEntry->GetValue()) != 0) {
+        GetStringDb()->DeleteSnippetKey(curListKey);
+    }
 
     GetStringDb()->SetSnippetString(m_textCtrlMenuEntry->GetValue(), m_textCtrlSnippet->GetValue());
     m_listBox1->SetString(index, m_textCtrlMenuEntry->GetValue());
@@ -114,10 +112,7 @@ void EditSnippetsDlg::OnChangeSnippet(wxCommandEvent& event)
 
 void EditSnippetsDlg::OnChangeSnippetUI(wxUpdateUIEvent& event)
 {
-    if(m_textCtrlMenuEntry->GetValue().IsEmpty() || m_textCtrlSnippet->GetValue().IsEmpty())
-        event.Enable(false);
-    else
-        event.Enable(true);
+    event.Enable(!m_textCtrlMenuEntry->GetValue().IsEmpty() && !m_textCtrlSnippet->GetValue().IsEmpty());
 }
 
 void EditSnippetsDlg::OnRemoveSnippet(wxCommandEvent& event)
@@ -128,16 +123,15 @@ void EditSnippetsDlg::OnRemoveSnippet(wxCommandEvent& event)
     GetStringDb()->DeleteSnippetKey(key);
     m_listBox1->Delete(index);
 
-    if(m_listBox1->GetCount()) SelectItem(0);
+    if (m_listBox1->GetCount()) {
+        SelectItem(0);
+    }
     m_modified = true;
 }
 
 void EditSnippetsDlg::OnRemoveSnippetUI(wxUpdateUIEvent& event)
 {
-    if(m_listBox1->GetSelection() != wxNOT_FOUND)
-        event.Enable(true);
-    else
-        event.Enable(false);
+    event.Enable(m_listBox1->GetSelection() != wxNOT_FOUND);
 }
 
 void EditSnippetsDlg::Initialize()
@@ -145,7 +139,7 @@ void EditSnippetsDlg::Initialize()
     wxTextAttr attribs = m_textCtrlSnippet->GetDefaultStyle();
     wxArrayInt tabs = attribs.GetTabs();
     int tab = 70;
-    for(int i = 1; i < 20; i++) {
+    for (int i = 1; i < 20; i++) {
         tabs.Add(tab * i);
     }
 
@@ -156,7 +150,7 @@ void EditSnippetsDlg::Initialize()
     GetStringDb()->GetAllSnippetKeys(keys);
     m_listBox1->Append(keys);
 
-    if(m_listBox1->IsEmpty() == false) {
+    if (m_listBox1->IsEmpty() == false) {
         SelectItem(0);
     }
     m_htmlWinAbout->SetPage(wxString::FromUTF8(snipwizhtml_txt));
@@ -171,23 +165,24 @@ void EditSnippetsDlg::OnButtonKeyShortcut(wxCommandEvent& e)
     keys.Sort();
 
     int index = keys.Index(m_textCtrlMenuEntry->GetValue());
-    if(index != wxNOT_FOUND) {
+    if (index != wxNOT_FOUND) {
         int id = 20050 + index;
 
         MenuItemData mid;
         mid.resourceID << id;
+        mid.parentMenu = _("SnipWiz");
         mid.action = m_textCtrlMenuEntry->GetValue();
-        
-        if(clKeyboardManager::Get()->PopupNewKeyboardShortcutDlg(this, mid) == wxID_OK) {
 
-            if(clKeyboardManager::Get()->Exists(mid.accel) && mid.accel.IsEmpty() == false) {
-                wxMessageBox(_("That accelerator already exists"), _("CodeLite"), wxOK | wxCENTRE, this);
+        if (clKeyboardManager::Get()->PopupNewKeyboardShortcutDlg(this, mid) == wxID_OK) {
+
+            if (clKeyboardManager::Get()->Exists(mid.accel)) {
+                wxMessageBox(_("That accelerator already exists"), wxT("CodeLite"), wxOK | wxCENTRE, this);
                 return;
             }
 
-            clKeyboardManager::Get()->AddGlobalAccelerator(mid.resourceID, mid.accel, mid.action);
+            clKeyboardManager::Get()->AddAccelerator(mid.resourceID, mid.parentMenu, mid.action, mid.accel);
             clKeyboardManager::Get()->Update();
-            m_textCtrlAccelerator->ChangeValue(mid.accel);
+            m_textCtrlAccelerator->ChangeValue(mid.accel.ToString());
         }
     }
 }
