@@ -62,6 +62,8 @@ protected:
     bool       m_scanC;
     bool       m_scanD1;
     bool       m_scanD2;
+    bool       m_caseSensitiveUserDictionary;
+    bool       m_ignoreSymbolsInTagsDatabase;
 
 public:
     const wxString& GetDictionaryPath() const {
@@ -77,20 +79,18 @@ public:
     void            SetHunspell( IHunSpell* pHunspell ) {
         this->m_pHunspell = pHunspell;
     }
-    void            SetScanC( const bool& scanC ) {
-        this->m_scanC = scanC;
+    void SetScanC(bool scanC) { this->m_scanC = scanC; }
+    void SetScanCPP(bool scanCPP) { this->m_scanCPP = scanCPP; }
+    void SetScanD1(bool scanD1) { this->m_scanD1 = scanD1; }
+    void SetScanD2(bool scanD2) { this->m_scanD2 = scanD2; }
+    void SetScanStrings(bool scanStrings) { this->m_scanStrings = scanStrings; }
+    void SetCaseSensitiveUserDictionary(bool caseSensitiveUserDictionary)
+    {
+        this->m_caseSensitiveUserDictionary = caseSensitiveUserDictionary;
     }
-    void            SetScanCPP( const bool& scanCPP ) {
-        this->m_scanCPP = scanCPP;
-    }
-    void            SetScanD1( const bool& scanD1 ) {
-        this->m_scanD1 = scanD1;
-    }
-    void            SetScanD2( const bool& scanD2 ) {
-        this->m_scanD2 = scanD2;
-    }
-    void            SetScanStrings( const bool& scanStrings ) {
-        this->m_scanStrings = scanStrings;
+    void SetIgnoreSymbolsInTagsDatabase(bool ignoreSymbolsInTagsDatabase)
+    {
+        this->m_ignoreSymbolsInTagsDatabase = ignoreSymbolsInTagsDatabase;
     }
 
     bool GetScanC() const {
@@ -108,9 +108,15 @@ public:
     bool GetScanStrings() const {
         return m_scanStrings;
     }
+    bool GetCaseSensitiveUserDictionary() const {
+        return m_caseSensitiveUserDictionary;
+	}
+    bool GetIgnoreSymbolsInTagsDatabase() const {
+        return m_ignoreSymbolsInTagsDatabase;
+    }
     /** Constructor */
     SpellCheckerSettings( wxWindow* parent );
-    virtual ~SpellCheckerSettings();
+    virtual ~SpellCheckerSettings() = default;
 };
 
 #endif // __SpellCheckerSettings__
