@@ -42,18 +42,27 @@ class SpellCheckerOptions : public SerializedObject
 {
 public:
 	SpellCheckerOptions();
-	virtual ~SpellCheckerOptions();
+	virtual ~SpellCheckerOptions() = default;
 
 	void DeSerialize( Archive& arch );
 	void Serialize( Archive& arch );
 
 	void            SetDictionaryPath( const wxString& dictionaryPath ) { this->m_dictionaryPath = dictionaryPath; }
 	void            SetDictionaryFileName( const wxString& dictionary ) { this->m_dictionary = dictionary; }
-	void            SetScanC( const bool& scanC ) { this->m_scanC = scanC; }
-	void            SetScanCPP( const bool& scanCPP ) { this->m_scanCPP = scanCPP; }
-	void            SetScanD1( const bool& scanD1 ) { this->m_scanD1 = scanD1; }
-	void            SetScanD2( const bool& scanD2 ) { this->m_scanD2 = scanD2; }
-	void            SetScanStr( const bool& scanStr ) { this->m_scanStr = scanStr; }
+    void SetScanC(bool scanC) { this->m_scanC = scanC; }
+    void SetScanCPP(bool scanCPP) { this->m_scanCPP = scanCPP; }
+    void SetScanD1(bool scanD1) { this->m_scanD1 = scanD1; }
+    void SetScanD2(bool scanD2) { this->m_scanD2 = scanD2; }
+    void SetScanStr(bool scanStr) { this->m_scanStr = scanStr; }
+    void SetCheckContinuous(bool checkContinuous) { this->m_checkContinuous = checkContinuous; }
+    void SetCaseSensitiveUserDictionary(bool caseSensitiveUserDictionary)
+    {
+        this->m_caseSensitiveUserDictionary = caseSensitiveUserDictionary;
+    }
+    void SetIgnoreSymbolsInTagsDatabase(bool ignoreSymbolsInTagsDatabase)
+    {
+        this->m_ignoreSymbolsInTagsDatabase = ignoreSymbolsInTagsDatabase;
+    }
 	bool            GetScanC() const { return m_scanC; }
 	bool            GetScanCPP() const { return m_scanCPP; }
 	bool            GetScanD1() const { return m_scanD1; }
@@ -61,6 +70,9 @@ public:
 	bool            GetScanStr() const { return m_scanStr; }
 	const wxString& GetDictionaryPath() const { return m_dictionaryPath; }
 	const wxString& GetDictionaryFileName() const { return m_dictionary; }
+    bool            GetCheckContinuous() const { return m_checkContinuous; }
+    bool            GetCaseSensitiveUserDictionary() const { return m_caseSensitiveUserDictionary; }
+    bool            GetIgnoreSymbolsInTagsDatabase() const { return m_ignoreSymbolsInTagsDatabase; }
 
 protected:
 	wxString m_dictionary;
@@ -70,6 +82,9 @@ protected:
 	bool     m_scanC;
 	bool     m_scanD1;
 	bool     m_scanD2;
+    bool     m_checkContinuous;
+    bool     m_caseSensitiveUserDictionary;
+    bool     m_ignoreSymbolsInTagsDatabase;
 };
 //------------------------------------------------------------
 #endif // __spellcheckeroptions__
