@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : SvnBlameFrame.cpp
 //
 // -------------------------------------------------------------------------
@@ -24,9 +24,10 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "SvnBlameFrame.h"
-#include <windowattrmanager.h>
-#include <lexer_configuration.h>
-#include <editor_config.h>
+
+#include "editor_config.h"
+#include "lexer_configuration.h"
+#include "windowattrmanager.h"
 
 SvnBlameFrame::SvnBlameFrame(wxWindow* parent, const wxFileName& filename, const wxString& content)
     : SvnBlameFrameBase(parent)
@@ -45,5 +46,3 @@ SvnBlameFrame::SvnBlameFrame(wxWindow* parent, const wxFileName& filename, const
     SetName("SvnBlameFrame");
     WindowAttrManager::Load(this);
 }
-
-SvnBlameFrame::~SvnBlameFrame() {}
