@@ -24,18 +24,20 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "SvnCommitDialog.h"
-#include "asyncprocess.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "bitmap_loader.h"
 #include "clSingleChoiceDialog.h"
 #include "editor_config.h"
 #include "globals.h"
 #include "imanager.h"
 #include "lexer_configuration.h"
-#include "processreaderthread.h"
 #include "subversion2.h"
 #include "svn_local_properties.h"
 #include "svnsettingsdata.h"
 #include "windowattrmanager.h"
+
 #include <wx/msgdlg.h>
 #include <wx/tokenzr.h>
 
@@ -48,7 +50,7 @@ public:
         : m_data(data.c_str())
     {
     }
-    virtual ~CommitMessageStringData() {}
+    virtual ~CommitMessageStringData() = default;
 
     const wxString& GetData() const { return m_data; }
 };
@@ -106,8 +108,8 @@ void SvnCommitDialog::DoCommonInit()
     m_checkListFiles->Clear();
 
     // These two classes will allow copy / paste etc using the keyboard on the STC classes
-    m_stcMessageHelper.Reset(new clEditEventsHandler(m_stcMessage));
-    m_stcDiffHelper.Reset(new clEditEventsHandler(m_stcDiff));
+    m_stcMessageHelper = std::make_unique<clEditEventsHandler>(m_stcMessage);
+    m_stcDiffHelper = std::make_unique<clEditEventsHandler>(m_stcDiff);
     DoCreateToolbar();
     int sashPos = m_plugin->GetSettings().GetCommitDlgSashPos();
     if(sashPos != wxNOT_FOUND) {
@@ -163,18 +165,18 @@ wxString SvnCommitDialog::GetMesasge()
         if(bugId.IsEmpty() == false) {
             // Loop over the bug IDs and append message for each bug
             wxArrayString bugs = wxStringTokenize(bugId, wxT(","), wxTOKEN_STRTOK);
-            for(size_t i = 0; i < bugs.size(); i++) {
+            for (auto& bug : bugs) {
 
-                bugs[i].Trim().Trim(false);
-                if(bugs[i].IsEmpty())
+                bug.Trim().Trim(false);
+                if (bug.IsEmpty())
                     continue;
 
                 wxString tmpMsg = bugTrackerMsg;
                 wxString tmpUrl = bugTrackerUrl;
 
-                tmpUrl.Replace(wxT("$(BUGID)"), bugs[i]);
+                tmpUrl.Replace(wxT("$(BUGID)"), bug);
                 tmpMsg.Replace(wxT("$(BUG_URL)"), tmpUrl);
-                tmpMsg.Replace(wxT("$(BUGID)"), bugs[i]);
+                tmpMsg.Replace(wxT("$(BUGID)"), bug);
                 msg << tmpMsg << wxT("\n");
             }
         }
@@ -308,9 +310,9 @@ void SvnCommitDialog::OnClearHistoryUI(wxUpdateUIEvent& event)
 
 void SvnCommitDialog::DoCreateToolbar()
 {
-    m_toolbar->AddTool(XRCID("commit-history"), _("Commit History"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("history"), "", wxITEM_DROPDOWN);
-    m_toolbar->AddTool(wxID_CLEAR, _("Clear History"), clGetManager()->GetStdIcons()->LoadBitmap("clear"));
+    auto images = m_toolbar->GetBitmapsCreateIfNeeded();
+    m_toolbar->AddTool(XRCID("commit-history"), _("Commit History"), images->Add("history"), "", wxITEM_DROPDOWN);
+    m_toolbar->AddTool(wxID_CLEAR, _("Clear History"), images->Add("clear"));
     m_toolbar->Realize();
 
     m_toolbar->Bind(wxEVT_TOOL, &SvnCommitDialog::OnShowCommitHistory, this, XRCID("commit-history"));
