@@ -28,9 +28,6 @@
 SvnInfoDialog::SvnInfoDialog(wxWindow* parent)
     : SvnInfoDialogBase(parent)
 {
+    GetSizer()->Fit(this);
+    CenterOnParent();
 }
-
-SvnInfoDialog::~SvnInfoDialog()
-{
-}
-
