@@ -23,15 +23,15 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include "svncommand.h"
 #include "environmentconfig.h"
+#include "file_logger.h"
+#include "globals.h"
+#include "imanager.h"
+#include "subversion2.h"
 #include "subversion_strings.h"
 #include "svn_console.h"
-#include "globals.h"
-#include "subversion2.h"
+#include "svncommand.h"
 #include <wx/aui/framemanager.h>
-#include "imanager.h"
-#include "file_logger.h"
 
 SvnCommand::SvnCommand(Subversion2* plugin)
     : m_process(NULL)
@@ -44,26 +44,17 @@ SvnCommand::SvnCommand(Subversion2* plugin)
 
 SvnCommand::~SvnCommand() { ClearAll(); }
 
-bool SvnCommand::Execute(const wxString& command,
-                         const wxString& workingDirectory,
-                         SvnCommandHandler* handler,
+bool SvnCommand::Execute(const wxString& command, const wxString& workingDirectory, SvnCommandHandler* handler,
                          Subversion2* plugin)
 {
-    // Dont run 2 commands at the same time
+    // Don't run 2 commands at the same time
     if(m_process) {
-        if(handler) {
-            // handler->GetPlugin()->GetShell()->AppendText(svnANOTHER_PROCESS_RUNNING);
-            delete handler;
-        }
+        wxDELETE(handler);
         return false;
     }
 
     ClearAll();
 
-    // Wrap the command in the OS Shell
-    wxString cmdShell(command);
-    WrapInShell(cmdShell);
-
     // Apply the environment variables before executing the command
     wxStringMap_t om;
     om.insert(std::make_pair("LC_ALL", "C"));
@@ -71,7 +62,7 @@ bool SvnCommand::Execute(const wxString& command,
     bool useOverrideMap = m_plugin->GetSettings().GetFlags() & SvnUsePosixLocale;
     EnvSetter env(m_plugin->GetManager()->GetEnv(), useOverrideMap ? &om : NULL);
 
-    m_process = CreateAsyncProcess(this, command, IProcessCreateDefault, workingDirectory);
+    m_process = CreateAsyncProcess(this, command, IProcessCreateDefault | IProcessWrapInShell, workingDirectory);
     if(!m_process) {
         return false;
     }
@@ -84,13 +75,13 @@ bool SvnCommand::Execute(const wxString& command,
 void SvnCommand::OnProcessOutput(clProcessEvent& event)
 {
     m_output.Append(event.GetOutput());
-    CL_DEBUG("Subversion:\n%s", m_output);
+    LOG_IF_TRACE { clDEBUG1() << "Subversion:" << m_output << clEndl; }
 }
 
 void SvnCommand::OnProcessTerminated(clProcessEvent& event)
 {
     if(m_handler) {
-        CL_DEBUG("Subversion output:\n%s", m_output);
+        LOG_IF_TRACE { clDEBUG1() << "Subversion:" << m_output << clEndl; }
         if(m_handler->TestLoginRequired(m_output)) {
             // re-issue the last command but this time with login dialog
             m_handler->GetPlugin()->GetConsole()->AppendText(_("Authentication failed. Retrying...\n"));
@@ -105,15 +96,9 @@ void SvnCommand::OnProcessTerminated(clProcessEvent& event)
             // command ended successfully, invoke the "success" callback
             m_handler->Process(m_output);
         }
-
-        delete m_handler;
-        m_handler = NULL;
-    }
-
-    if(m_process) {
-        delete m_process;
-        m_process = NULL;
+        wxDELETE(m_handler);
     }
+    wxDELETE(m_process);
 }
 
 void SvnCommand::ClearAll()
