@@ -51,7 +51,7 @@ class SvnSettingsData : public SerializedObject
     wxArrayString m_urls;
     wxString m_revisionMacroName;
     int m_svnTabIndex;
-    std::map<wxString, wxString> m_workspaceRepoPath;
+    wxStringMap_t m_workspaceRepoPath;
     wxArrayString m_repos;
     int m_commitDlgSashPos;
     int m_commitDlgHSashPos;
@@ -73,7 +73,7 @@ public:
     {
     }
 
-    virtual ~SvnSettingsData() {}
+    virtual ~SvnSettingsData() = default;
 
 public:
     virtual void DeSerialize(Archive& arch)
@@ -123,22 +123,19 @@ public:
     void SetExecutable(const wxString& executable) { this->m_executable = executable; }
     const wxString& GetExecutable() const { return m_executable; }
     void SetExternalDiffViewer(const wxString& externalDiffViewer) { this->m_externalDiffViewer = externalDiffViewer; }
-    void SetFlags(const size_t& flags) { this->m_flags = flags; }
+    void SetFlags(size_t flags) { this->m_flags = flags; }
     void SetIgnoreFilePattern(const wxString& ignoreFilePattern) { this->m_ignoreFilePattern = ignoreFilePattern; }
     void SetSshClient(const wxString& sshClient) { this->m_sshClient = sshClient; }
     void SetSshClientArgs(const wxString& sshClientArgs) { this->m_sshClientArgs = sshClientArgs; }
     const wxString& GetExternalDiffViewer() const { return m_externalDiffViewer; }
-    const size_t& GetFlags() const { return m_flags; }
+    size_t GetFlags() const { return m_flags; }
     const wxString& GetIgnoreFilePattern() const { return m_ignoreFilePattern; }
     const wxString& GetSshClient() const { return m_sshClient; }
     const wxString& GetSshClientArgs() const { return m_sshClientArgs; }
     void SetUrls(const wxArrayString& urls) { this->m_urls = urls; }
     const wxArrayString& GetUrls() const { return m_urls; }
-    void SetWorkspaceRepoPath(const std::map<wxString, wxString>& workspaceRepoPath)
-    {
-        this->m_workspaceRepoPath = workspaceRepoPath;
-    }
-    std::map<wxString, wxString>& GetWorkspaceRepoPath() { return m_workspaceRepoPath; }
+    void SetWorkspaceRepoPath(const wxStringMap_t& workspaceRepoPath) { this->m_workspaceRepoPath = workspaceRepoPath; }
+    wxStringMap_t& GetWorkspaceRepoPath() { return m_workspaceRepoPath; }
 };
 
 #endif // SVNSETTINGSDATA_H
