@@ -36,11 +36,11 @@ class WorkspaceSvnSettings : public clConfigItem
 public:
     WorkspaceSvnSettings(const wxFileName& fn);
     WorkspaceSvnSettings();
-    virtual ~WorkspaceSvnSettings();
+    virtual ~WorkspaceSvnSettings() = default;
 
 public:
-    virtual void FromJSON(const JSONElement& json);
-    virtual JSONElement ToJSON() const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON() const;
 
     WorkspaceSvnSettings& Load();
     void Save();
