@@ -1,6 +1,8 @@
 #include "TailFrame.h"
-#include "tail.h"
 #include "TailPanel.h"
+#include "codelite_events.h"
+#include "event_notifier.h"
+#include "tail.h"
 
 TailFrame::TailFrame(wxWindow* parent, Tail* plugin)
     : TailFrameBase(parent)
@@ -8,10 +10,12 @@ TailFrame::TailFrame(wxWindow* parent, Tail* plugin)
 {
 }
 
-TailFrame::~TailFrame() {}
-
 void TailFrame::OnClose(wxCloseEvent& event)
 {
+    // Remove us from the view
+    m_plugin->GetView()->SetFrame(NULL);
+
+    // Redock the view
     TailData d = m_plugin->GetView()->GetTailData();
     m_plugin->CallAfter(&Tail::DockTailWindow, d);
     m_plugin->m_view = NULL;
