@@ -6,10 +6,11 @@ class Tail;
 class TailFrame : public TailFrameBase
 {
     Tail* m_plugin;
-    
+
 public:
     TailFrame(wxWindow* parent, Tail* plugin);
-    virtual ~TailFrame();
+    virtual ~TailFrame() = default;
+
 protected:
     virtual void OnClose(wxCloseEvent& event);
 };
