@@ -23,42 +23,39 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
+#include "ctags_manager.h"
+#include "globals.h"
+#include "imanager.h"
+#include "open_resource_dialog.h"
+#include "testclassdlg.h"
+#include "unittestpp.h"
+#include "windowattrmanager.h"
+#include <algorithm>
 #include <wx/app.h>
 #include <wx/choicdlg.h>
-#include "unittestpp.h"
-#include "open_resource_dialog.h"
 #include <wx/msgdlg.h>
-#include "testclassdlg.h"
-#include "imanager.h"
-#include "ctags_manager.h"
-#include "windowattrmanager.h"
 
 TestClassDlg::TestClassDlg(wxWindow* parent, IManager* mgr, UnitTestPP* plugin)
     : TestClassBaseDlg(parent)
     , m_manager(mgr)
     , m_plugin(plugin)
 {
-    m_manager->GetTagsManager()->GetClasses(m_tags);
+    TagEntryPtrVector_t tags;
+    m_manager->GetTagsManager()->GetClasses(tags);
+    for(auto tag : tags) {
+        m_tags[tag->GetName()].push_back(tag);
+    }
 
     // populate the unit tests project list
     std::vector<ProjectPtr> projects = m_plugin->GetUnitTestProjects();
-    for(size_t i = 0; i < projects.size(); i++) {
-        m_choiceProjects->Append(projects.at(i)->GetName());
+    for (const auto& project : projects) {
+        m_choiceProjects->Append(project->GetName());
     }
 
     if(m_choiceProjects->IsEmpty() == false) {
         m_choiceProjects->SetSelection(0);
     }
-    SetName("TestClassDlg");
-    WindowAttrManager::Load(this);
-}
-
-TestClassDlg::~TestClassDlg() {  }
-
-void TestClassDlg::OnRefreshFunctions(wxCommandEvent& event)
-{
-    wxUnusedVar(event);
-    DoRefreshFunctions();
+    ::clSetSmallDialogBestSizeAndPosition(this);
 }
 
 void TestClassDlg::OnUseActiveEditor(wxCommandEvent& event)
@@ -74,11 +71,6 @@ void TestClassDlg::OnUseActiveEditor(wxCommandEvent& event)
     }
 }
 
-void TestClassDlg::OnRefreshButtonUI(wxUpdateUIEvent& e)
-{
-    e.Enable(m_textCtrlClassName->GetValue().IsEmpty() ? false : true);
-}
-
 void TestClassDlg::OnCheckAll(wxCommandEvent& e)
 {
     // check all items
@@ -116,7 +108,7 @@ void TestClassDlg::OnButtonOk(wxCommandEvent& e)
 {
     // validate the class name
     if(m_checkListMethods->GetCount() == 0) {
-        wxMessageBox(_("There are no tests to generate"), _("CodeLite"), wxICON_WARNING | wxOK);
+        wxMessageBox(_("There are no tests to generate"), wxT("CodeLite"), wxICON_WARNING | wxOK);
         return;
     }
     EndModal(wxID_OK);
@@ -126,10 +118,10 @@ void TestClassDlg::OnShowClassListDialog(wxCommandEvent& e)
 {
     m_textCtrlClassName->SetFocus();
     OpenResourceDialog dlg(m_manager->GetTheApp()->GetTopWindow(), m_manager, "");
-    if(dlg.ShowModal() == wxID_OK) {
-
+    if(dlg.ShowModal() == wxID_OK && !dlg.GetSelections().empty()) {
+        OpenResourceDialogItemData* item = dlg.GetSelections().at(0);
         // do something with the selected text
-        m_textCtrlClassName->SetValue(dlg.GetSelection().m_name);
+        m_textCtrlClassName->SetValue(item->m_name);
 
         // display the class methods
         DoRefreshFunctions();
@@ -138,25 +130,16 @@ void TestClassDlg::OnShowClassListDialog(wxCommandEvent& e)
 
 void TestClassDlg::DoRefreshFunctions(bool repportError)
 {
-    std::vector<TagEntryPtr> matches;
-
-    // search m_tags for suitable name
-    for(size_t i = 0; i < m_tags.size(); i++) {
-        TagEntryPtr tag = m_tags.at(i);
-        if(tag->GetName() == m_textCtrlClassName->GetValue()) {
-            matches.push_back(tag);
-        }
-    }
-
-    if(matches.empty()) {
+    if(m_tags.count(m_textCtrlClassName->GetValue()) == 0) {
         if(repportError) {
             wxMessageBox(_("Could not find match for class '") + m_textCtrlClassName->GetValue() + wxT("'"),
-                         _("CodeLite"),
-                         wxICON_WARNING | wxOK);
+                         wxT("CodeLite"), wxICON_WARNING | wxOK);
         }
+        m_checkListMethods->Clear();
         return;
     }
 
+    std::vector<TagEntryPtr> matches = m_tags[m_textCtrlClassName->GetValue()];
     wxString theClass;
     if(matches.size() == 1) {
         // single match we are good
@@ -165,9 +148,7 @@ void TestClassDlg::DoRefreshFunctions(bool repportError)
         // suggest the user a multiple choice
         wxArrayString choices;
 
-        for(size_t i = 0; i < matches.size(); i++) {
-            wxString option;
-            TagEntryPtr t = matches.at(i);
+        for (const auto& t : matches) {
             choices.Add(t->GetPath());
         }
 
@@ -180,19 +161,25 @@ void TestClassDlg::DoRefreshFunctions(bool repportError)
 
     // get list of methods for the given path
     matches.clear();
-    m_manager->GetTagsManager()->TagsByScope(theClass, wxT("prototype"), matches, false, true);
+    wxArrayString kind;
+    kind.push_back("prototype");
+    kind.push_back("function");
+    m_manager->GetTagsManager()->TagsByScope(theClass, kind, matches);
 
-    // populate the list control
+    wxStringSet_t uniqueNames;
     wxArrayString methods;
-    for(size_t i = 0; i < matches.size(); i++) {
-        TagEntryPtr t = matches.at(i);
-        methods.Add(t->GetName() + t->GetSignature());
+    for (const auto& m : matches) {
+        if(uniqueNames.count(m->GetName()) == 0) {
+            methods.push_back(m->GetName());
+            uniqueNames.insert(m->GetName());
+        }
     }
+
     m_checkListMethods->Clear();
     m_checkListMethods->Append(methods);
 
     // check all items
-    for(unsigned int idx = 0; idx < m_checkListMethods->GetCount(); idx++) {
+    for(unsigned int idx = 0; idx < m_checkListMethods->GetCount(); ++idx) {
         m_checkListMethods->Check(idx, true);
     }
 }
@@ -211,3 +198,8 @@ void TestClassDlg::EscapeName(wxString& name)
     name.Replace(wxT(">"), wxT("Gadol"));
     name.Replace(wxT("<"), wxT("Katan"));
 }
+void TestClassDlg::OnClassNameUpdated(wxCommandEvent& event)
+{
+    wxUnusedVar(event);
+    DoRefreshFunctions(false);
+}
