@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : unittestdata.h
 //
 // -------------------------------------------------------------------------
@@ -31,8 +31,8 @@
 class UnitTestData : public SerializedObject {
 
 public:
-	UnitTestData();
-	~UnitTestData();
+	UnitTestData() = default;
+	~UnitTestData() = default;
 
 public:
 	virtual void DeSerialize(Archive &arch);
