@@ -22,57 +22,52 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include <wx/app.h>
+#include "unittestpp.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "Keyboard/clKeyboardManager.h"
 #include "bitmap_loader.h"
-#include "unittestspage.h"
-#include "macros.h"
-#include "unittestdata.h"
-#include "event_notifier.h"
-#include "asyncprocess.h"
-#include "processreaderthread.h"
+#include "codelite_events.h"
 #include "ctags_manager.h"
-#include "unittestcppoutputparser.h"
-#include <wx/tokenzr.h>
-#include "environmentconfig.h"
-#include "pipedprocess.h"
 #include "dirsaver.h"
-#include "procutils.h"
-#include "workspace.h"
+#include "environmentconfig.h"
+#include "event_notifier.h"
+#include "newunittestdlg.h"
 #include "project.h"
 #include "testclassdlg.h"
-#include "newunittestdlg.h"
+#include "unittestcppoutputparser.h"
+#include "unittestspage.h"
+#include "workspace.h"
+
+#include <wx/app.h>
 #include <wx/ffile.h>
-#include <wx/msgdlg.h>
-#include "unittestpp.h"
-#include <wx/xrc/xmlres.h>
-#include <wx/menuitem.h>
 #include <wx/menu.h>
-#include "codelite_events.h"
 #include <wx/msgdlg.h>
+#include <wx/tokenzr.h>
+#include <wx/xrc/xmlres.h>
 
-#ifdef __WXMSW__
-#include <wx/msw/registry.h>
-#include "evnvarlist.h"
-#endif
-
-static UnitTestPP* thePlugin = NULL;
+namespace
+{
+bool IsSourceFile(const wxString& ext)
+{
+    return ext == wxT("cpp") || ext == wxT("cxx") || ext == wxT("c") || ext == wxT("c++") || ext == wxT("cc");
+}
+}
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new UnitTestPP(manager);
-    }
-    return thePlugin;
+    return new UnitTestPP(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
     static PluginInfo info;
-    info.SetAuthor(wxT("Eran Ifrah"));
-    info.SetName(wxT("UnitTestPP"));
+    info.SetAuthor("Eran Ifrah");
+    info.SetName("UnitTestPP");
     info.SetDescription(_("A Unit test plugin based on the UnitTest++ framework"));
-    info.SetVersion(wxT("v1.0"));
+    info.SetVersion("v1.0");
     return &info;
 }
 
@@ -83,70 +78,54 @@ UnitTestPP::UnitTestPP(IManager* manager)
     , m_proc(NULL)
 {
     // Connect the events to us
-    wxTheApp->Connect(XRCID("run_unit_tests"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(UnitTestPP::OnRunUnitTests),
-                      NULL,
-                      (wxEvtHandler*)this);
-    wxTheApp->Connect(XRCID("run_unit_tests"),
-                      wxEVT_UPDATE_UI,
-                      wxUpdateUIEventHandler(UnitTestPP::OnRunUnitTestsUI),
-                      NULL,
-                      (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("run_unit_tests"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(UnitTestPP::OnRunUnitTests), NULL, (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("run_unit_tests"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(UnitTestPP::OnRunUnitTestsUI),
+                      NULL, (wxEvtHandler*)this);
 
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, clExecuteEventHandler(UnitTestPP::OnRunProject), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, clExecuteEventHandler(UnitTestPP::OnRunProject),
+                                  NULL, this);
 
-    m_outputPage = new UnitTestsPage(m_mgr->GetOutputPaneNotebook(), m_mgr);
-    m_mgr->GetOutputPaneNotebook()->AddPage(
-        m_outputPage, _("UnitTest++"), false, m_mgr->GetStdIcons()->LoadBitmap("ok"));
+    m_outputPage = new UnitTestsPage(m_mgr->BookGet(PaneId::BOTTOM_BAR), m_mgr);
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_outputPage, _("UnitTest++"));
     m_tabHelper.reset(new clTabTogglerHelper(_("UnitTest++"), m_outputPage, "", NULL));
-    m_tabHelper->SetOutputTabBmp(m_mgr->GetStdIcons()->LoadBitmap("ok"));
 
     m_longName = _("A Unit test plugin based on the UnitTest++ framework");
-    m_shortName = wxT("UnitTestPP");
+    m_shortName = "UnitTestPP";
     m_topWindow = m_mgr->GetTheApp();
 
     Bind(wxEVT_ASYNC_PROCESS_OUTPUT, &UnitTestPP::OnProcessRead, this);
     Bind(wxEVT_ASYNC_PROCESS_TERMINATED, &UnitTestPP::OnProcessTerminated, this);
+
+    clKeyboardManager::Get()->AddAccelerator(_("UnitTest++"),
+                                             { { "unittestpp_new_simple_test", _("Create new test...") },
+                                               { "unittestpp_new_class_test", _("Create tests for class...") },
+                                               { "mark_project_as_ut", _("Mark this project as UnitTest++ project") },
+                                               { "run_unit_tests", _("Run Project as UnitTest++ and report") } });
 }
 
-UnitTestPP::~UnitTestPP() {}
-
-clToolBar* UnitTestPP::CreateToolBar(wxWindow* parent)
+void UnitTestPP::CreateToolBar(clToolBarGeneric* toolbar)
 {
-    // support both toolbars icon size
-    clToolBar* tb(NULL);
+    int size = m_mgr->GetToolbarIconSize();
 
-    if(m_mgr->AllowToolbar()) {
-        int size = m_mgr->GetToolbarIconSize();
-
-        tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE_PLUGIN);
-        tb->SetToolBitmapSize(wxSize(size, size));
-
-        BitmapLoader& bitmapLoader = *m_mgr->GetStdIcons();
-        tb->AddTool(XRCID("run_unit_tests"),
-                    _("Run Unit tests..."),
-                    bitmapLoader.LoadBitmap("ok", size),
-                    _("Run project as unit test project..."));
-        tb->Realize();
-    }
-    return tb;
+    auto images = toolbar->GetBitmapsCreateIfNeeded();
+    toolbar->AddTool(XRCID("run_unit_tests"), _("Run Unit tests..."), images->Add("ok", size),
+                     _("Run project as unit test project..."));
 }
 
 void UnitTestPP::CreatePluginMenu(wxMenu* pluginsMenu)
 {
     // Create the popup menu for the file explorer
-    // The only menu that we are interseted is the file explorer menu
+    // The only menu that we are interested is the file explorer menu
     wxMenu* menu = new wxMenu();
     wxMenuItem* item(NULL);
 
-    item = new wxMenuItem(
-        menu, XRCID("unittestpp_new_simple_test"), _("Create new &test..."), wxEmptyString, wxITEM_NORMAL);
+    item = new wxMenuItem(menu, XRCID("unittestpp_new_simple_test"), _("Create new &test..."), wxEmptyString,
+                          wxITEM_NORMAL);
     menu->Append(item);
 
-    item = new wxMenuItem(
-        menu, XRCID("unittestpp_new_class_test"), _("Create tests for &class..."), wxEmptyString, wxITEM_NORMAL);
+    item = new wxMenuItem(menu, XRCID("unittestpp_new_class_test"), _("Create tests for &class..."), wxEmptyString,
+                          wxITEM_NORMAL);
     menu->Append(item);
 
     menu->AppendSeparator();
@@ -154,28 +133,19 @@ void UnitTestPP::CreatePluginMenu(wxMenu* pluginsMenu)
     item = new wxMenuItem(menu, XRCID("mark_project_as_ut"), _("Mark this project as UnitTest++ project"));
     menu->Append(item);
 
-    item = new wxMenuItem(
-        menu, XRCID("run_unit_tests"), _("Run Project as UnitTest++ and report"), wxEmptyString, wxITEM_NORMAL);
+    item = new wxMenuItem(menu, XRCID("run_unit_tests"), _("Run Project as UnitTest++ and report"), wxEmptyString,
+                          wxITEM_NORMAL);
     menu->Append(item);
 
-    pluginsMenu->Append(wxID_ANY, wxT("UnitTest++"), menu);
+    pluginsMenu->Append(wxID_ANY, _("UnitTest++"), menu);
 
     // connect the events
-    wxTheApp->Connect(XRCID("unittestpp_new_simple_test"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(UnitTestPP::OnNewSimpleTest),
-                      NULL,
-                      (wxEvtHandler*)this);
-    wxTheApp->Connect(XRCID("unittestpp_new_class_test"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(UnitTestPP::OnNewClassTest),
-                      NULL,
-                      (wxEvtHandler*)this);
-    wxTheApp->Connect(XRCID("mark_project_as_ut"),
-                      wxEVT_COMMAND_MENU_SELECTED,
-                      wxCommandEventHandler(UnitTestPP::OnMarkProjectAsUT),
-                      NULL,
-                      (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("unittestpp_new_simple_test"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(UnitTestPP::OnNewSimpleTest), NULL, (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("unittestpp_new_class_test"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(UnitTestPP::OnNewClassTest), NULL, (wxEvtHandler*)this);
+    wxTheApp->Connect(XRCID("mark_project_as_ut"), wxEVT_COMMAND_MENU_SELECTED,
+                      wxCommandEventHandler(UnitTestPP::OnMarkProjectAsUT), NULL, (wxEvtHandler*)this);
     EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_EDITOR, &UnitTestPP::OnEditorContextMenu, this);
 }
 
@@ -184,17 +154,11 @@ void UnitTestPP::UnPlug()
     m_tabHelper.reset(NULL);
 
     // Connect the events to us
-    wxTheApp->Disconnect(XRCID("run_unit_tests"),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(UnitTestPP::OnRunUnitTests),
-                         NULL,
-                         (wxEvtHandler*)this);
+    wxTheApp->Disconnect(XRCID("run_unit_tests"), wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(UnitTestPP::OnRunUnitTests), NULL, (wxEvtHandler*)this);
 
-    wxTheApp->Disconnect(XRCID("run_unit_tests"),
-                         wxEVT_UPDATE_UI,
-                         wxUpdateUIEventHandler(UnitTestPP::OnRunUnitTestsUI),
-                         NULL,
-                         (wxEvtHandler*)this);
+    wxTheApp->Disconnect(XRCID("run_unit_tests"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(UnitTestPP::OnRunUnitTestsUI),
+                         NULL, (wxEvtHandler*)this);
 
     Unbind(wxEVT_ASYNC_PROCESS_OUTPUT, &UnitTestPP::OnProcessRead, this);
     Unbind(wxEVT_ASYNC_PROCESS_TERMINATED, &UnitTestPP::OnProcessTerminated, this);
@@ -207,16 +171,16 @@ void UnitTestPP::UnPlug()
 wxMenu* UnitTestPP::CreateEditorPopMenu()
 {
     // Create the popup menu for the file explorer
-    // The only menu that we are interseted is the file explorer menu
+    // The only menu that we are interested is the file explorer menu
     wxMenu* menu = new wxMenu();
     wxMenuItem* item(NULL);
 
-    item = new wxMenuItem(
-        menu, XRCID("unittestpp_new_simple_test"), _("Create new &test..."), wxEmptyString, wxITEM_NORMAL);
+    item = new wxMenuItem(menu, XRCID("unittestpp_new_simple_test"), _("Create new &test..."), wxEmptyString,
+                          wxITEM_NORMAL);
     menu->Append(item);
 
-    item = new wxMenuItem(
-        menu, XRCID("unittestpp_new_class_test"), _("Create tests for &class..."), wxEmptyString, wxITEM_NORMAL);
+    item = new wxMenuItem(menu, XRCID("unittestpp_new_class_test"), _("Create tests for &class..."), wxEmptyString,
+                          wxITEM_NORMAL);
     menu->Append(item);
 
     return menu;
@@ -230,8 +194,7 @@ void UnitTestPP::OnNewClassTest(wxCommandEvent& e)
         if(wxMessageBox(
                wxString::Format(
                    _("There are currently no UnitTest project in your workspace\nWould you like to create one now?")),
-               _("CodeLite"),
-               wxYES_NO | wxCANCEL) == wxYES) {
+               wxT("CodeLite"), wxYES_NO | wxCANCEL) == wxYES) {
             // add new UnitTest project
             wxCommandEvent event(wxEVT_COMMAND_MENU_SELECTED, XRCID("new_project"));
             m_mgr->GetTheApp()->GetTopWindow()->GetEventHandler()->AddPendingEvent(event);
@@ -245,7 +208,7 @@ void UnitTestPP::OnNewClassTest(wxCommandEvent& e)
     if(editor) {
         int line = editor->GetCurrentLine();
         TagEntryPtr tag = m_mgr->GetTagsManager()->FunctionFromFileLine(editor->GetFileName(), line + 1);
-        if(tag && tag->GetScope().IsEmpty() == false && tag->GetScope() != wxT("<global>")) {
+        if(tag && tag->GetScope().IsEmpty() == false && tag->GetScope() != "<global>") {
             clsName = tag->GetScope();
         }
     }
@@ -279,7 +242,7 @@ void UnitTestPP::OnNewClassTest(wxCommandEvent& e)
                 prefix << name;
 
                 wxString testName;
-                testName << wxT("Test") << prefix;
+                testName << "Test" << prefix;
 
                 if(!fixture.IsEmpty()) {
                     DoCreateFixtureTest(testName, fixture, projectName, fn.GetFullPath());
@@ -299,8 +262,7 @@ void UnitTestPP::OnNewSimpleTest(wxCommandEvent& e)
         if(wxMessageBox(
                wxString::Format(
                    _("There are currently no UnitTest project in your workspace\nWould you like to create one now?")),
-               _("CodeLite"),
-               wxYES_NO | wxCANCEL) == wxYES) {
+               wxT("CodeLite"), wxYES_NO | wxCANCEL) == wxYES) {
             // add new UnitTest project
             wxCommandEvent event(wxEVT_COMMAND_MENU_SELECTED, XRCID("new_project"));
             m_mgr->GetTheApp()->GetTopWindow()->GetEventHandler()->AddPendingEvent(event);
@@ -332,16 +294,14 @@ void UnitTestPP::OnNewSimpleTest(wxCommandEvent& e)
     }
 }
 
-void UnitTestPP::DoCreateFixtureTest(const wxString& name,
-                                     const wxString& fixture,
-                                     const wxString& projectName,
+void UnitTestPP::DoCreateFixtureTest(const wxString& name, const wxString& fixture, const wxString& projectName,
                                      const wxString& filename)
 {
     wxString text;
 
-    text << wxT("\nTEST_FIXTURE(") << fixture << wxT(", ") << name << wxT(")\n");
-    text << wxT("{\n");
-    text << wxT("}\n");
+    text << "\nTEST_FIXTURE(" << fixture << ", " << name << ")\n";
+    text << "{\n";
+    text << "}\n";
 
     IEditor* editor = DoAddTestFile(filename, projectName);
     if(editor) {
@@ -356,16 +316,16 @@ void UnitTestPP::DoCreateSimpleTest(const wxString& name, const wxString& projec
     ProjectPtr proj = m_mgr->GetWorkspace()->FindProjectByName(projectName, errMsg);
     if(!proj) {
         // no such project!
-        wxMessageBox(_("Could not find the target project"), _("CodeLite"), wxOK | wxICON_ERROR);
+        wxMessageBox(_("Could not find the target project"), wxT("CodeLite"), wxOK | wxICON_ERROR);
         return;
     }
 
     IEditor* editor = DoAddTestFile(filename, projectName);
     wxString text;
 
-    text << wxT("\nTEST(") << name << wxT(")\n");
-    text << wxT("{\n");
-    text << wxT("}\n");
+    text << "\nTEST(" << name << ")\n";
+    text << "{\n";
+    text << "}\n";
 
     if(editor) {
         editor->AppendText(text);
@@ -375,7 +335,9 @@ void UnitTestPP::DoCreateSimpleTest(const wxString& name, const wxString& projec
 void UnitTestPP::OnRunUnitTests(wxCommandEvent& e)
 {
     ProjectPtr p = m_mgr->GetSelectedProject();
-    if(!p) return;
+    if(!p) {
+        return;
+    }
     DoRunProject(p);
 }
 
@@ -386,8 +348,8 @@ void UnitTestPP::OnRunUnitTestsUI(wxUpdateUIEvent& e)
         e.Enable(false);
 
     } else {
-        ProjectPtr p = m_mgr->GetSelectedProject();
-        e.Enable(p && p->GetProjectInternalType() == wxT("UnitTest++"));
+        e.Enable(clCxxWorkspaceST::Get()->IsOpen() && clCxxWorkspaceST::Get()->GetActiveProject() &&
+                 clCxxWorkspaceST::Get()->GetActiveProject()->GetProjectInternalType() == "UnitTest++");
     }
 }
 
@@ -411,7 +373,7 @@ bool UnitTestPP::IsUnitTestProject(ProjectPtr p)
     if(!p) {
         return false;
     }
-    return p->GetProjectInternalType() == wxT("UnitTest++");
+    return p->GetProjectInternalType() == "UnitTest++";
 }
 
 IEditor* UnitTestPP::DoAddTestFile(const wxString& filename, const wxString& projectName)
@@ -420,16 +382,15 @@ IEditor* UnitTestPP::DoAddTestFile(const wxString& filename, const wxString& pro
     wxFileName fn(filename);
     if(wxFileName::FileExists(filename) == false) {
         // the file does not exist!
-        wxFFile file(filename, wxT("wb"));
+        wxFFile file(filename, "wb");
         if(!file.IsOpened()) {
-            wxMessageBox(wxString::Format(_("Could not create target file '%s'"), filename.c_str()),
-                         _("CodeLite"),
+            wxMessageBox(wxString::Format(_("Could not create target file '%s'"), filename.c_str()), wxT("CodeLite"),
                          wxICON_WARNING | wxOK);
             return NULL;
         }
 
         // since this is a new file, it will most probably will need the include file
-        file.Write(wxT("#include <UnitTest++.h>\n"));
+        file.Write("#include <UnitTest++.h>\n");
         file.Close();
     }
 
@@ -440,12 +401,12 @@ IEditor* UnitTestPP::DoAddTestFile(const wxString& filename, const wxString& pro
     ProjectPtr proj = m_mgr->GetWorkspace()->FindProjectByName(projectName, errMsg);
     if(proj) {
         std::vector<wxFileName> files;
-        proj->GetFiles(files, true);
+        proj->GetFilesAsVectorOfFileName(files);
 
         // Search the target file, if it is already exist in the project, open the file
         // and return
-        for(size_t i = 0; i < files.size(); i++) {
-            if(files.at(i) == fn) {
+        for (const auto& file : files) {
+            if (file == fn) {
                 m_mgr->OpenFile(fn.GetFullPath());
                 editor = m_mgr->GetActiveEditor();
                 if(editor && editor->GetFileName() == fn) {
@@ -459,8 +420,8 @@ IEditor* UnitTestPP::DoAddTestFile(const wxString& filename, const wxString& pro
         // add it to the project
         wxArrayString paths;
         paths.Add(filename);
-        m_mgr->CreateVirtualDirectory(proj->GetName(), wxT("tests"));
-        m_mgr->AddFilesToVirtualFolder(proj->GetName() + wxT(":tests"), paths);
+        m_mgr->CreateVirtualDirectory(proj->GetName(), "tests");
+        m_mgr->AddFilesToVirtualFolder(proj->GetName() + ":tests", paths);
 
         // open the file
         m_mgr->OpenFile(fn.GetFullPath());
@@ -477,21 +438,20 @@ wxFileName UnitTestPP::FindBestSourceFile(ProjectPtr proj, const wxFileName& fil
     if(filename.IsOk() == false) {
         // no such file
         std::vector<wxFileName> files;
-        proj->GetFiles(files, true);
+        proj->GetFilesAsVectorOfFileName(files);
 
         // Search the target file, if it is already exist in the project, open the file
         // and return
-        for(size_t i = 0; i < files.size(); i++) {
-            wxFileName fn = files.at(i);
-            if(IsSourceFile(fn.GetExt())) {
+        for (const auto& fn : files) {
+            if (IsSourceFile(fn.GetExt())) {
                 return fn;
             }
         }
         // no source file were found in the project
         // create a path name of the file which will be located
-        // under the selected project path (we dont create it here)
+        // under the selected project path (we don't create it here)
         wxFileName fn(proj->GetFileName());
-        fn.SetFullName(wxT("unit_tests.cpp"));
+        fn.SetFullName("unit_tests.cpp");
         return fn;
     } else if(filename.IsAbsolute() == false) {
         // relative path was given, set the path to the project path
@@ -510,7 +470,7 @@ void UnitTestPP::OnMarkProjectAsUT(wxCommandEvent& e)
         return;
     }
 
-    p->SetProjectInternalType(wxT("UnitTest++"));
+    p->SetProjectInternalType("UnitTest++");
     p->Save();
 }
 
@@ -520,7 +480,7 @@ void UnitTestPP::OnProcessTerminated(clProcessEvent& e)
 {
     wxDELETE(m_proc);
 
-    wxArrayString arr = wxStringTokenize(m_output, wxT("\r\n"));
+    wxArrayString arr = wxStringTokenize(m_output, "\r\n");
     UnitTestCppOutputParser parser(arr);
 
     // parse the results
@@ -540,33 +500,28 @@ void UnitTestPP::OnProcessTerminated(clProcessEvent& e)
 
     double err_percent = (errCount / totalTests) * 100;
     double pass_percent = ((totalTests - errCount) / totalTests) * 100;
-    msg << err_percent << wxT("%");
+    msg << err_percent << "%";
     m_outputPage->UpdateFailedBar((size_t)summary.errorCount, msg);
 
     msg.clear();
-    msg << pass_percent << wxT("%");
+    msg << pass_percent << "%";
     m_outputPage->UpdatePassedBar((size_t)(summary.totalTests - summary.errorCount), msg);
 
     SelectUTPage();
 }
 
-void UnitTestPP::SelectUTPage()
-{
-    size_t pageCount = m_mgr->GetOutputPaneNotebook()->GetPageCount();
-    for(size_t i = 0; i < pageCount; ++i) {
-        if(m_mgr->GetOutputPaneNotebook()->GetPage(i) == m_outputPage) {
-            m_mgr->GetOutputPaneNotebook()->SetSelection(i);
-            break;
-        }
-    }
-}
+void UnitTestPP::SelectUTPage() { m_mgr->BookSelectPage(PaneId::BOTTOM_BAR, m_outputPage); }
 
 void UnitTestPP::OnRunProject(clExecuteEvent& e)
 {
     e.Skip();
     // Sanity
-    if(!clCxxWorkspaceST::Get()->IsOpen()) return;
-    if(e.GetTargetName().IsEmpty()) return;
+    if(!clCxxWorkspaceST::Get()->IsOpen()) {
+        return;
+    }
+    if(e.GetTargetName().IsEmpty()) {
+        return;
+    }
 
     ProjectPtr pProj = clCxxWorkspaceST::Get()->GetProject(e.GetTargetName());
     CHECK_PTR_RET(pProj);
@@ -586,10 +541,10 @@ void UnitTestPP::DoRunProject(ProjectPtr project)
     wxString wd;
     wxString cmd = m_mgr->GetProjectExecutionCommand(project->GetName(), wd);
     DirSaver ds;
-    
+
     // Ensure that the ut++ page is shown and selected
-    m_mgr->ShowOutputPane("UnitTest++");
-    
+    m_mgr->ShowOutputPane(_("UnitTest++"));
+
     // first we need to CD to the project directory
     ::wxSetWorkingDirectory(project->GetFileName().GetPath());
 
