@@ -31,6 +31,7 @@
 #include "project.h"
 #include <vector>
 #include "cl_command_event.h"
+#include "clTabTogglerHelper.h"
 
 class wxMenuItem;
 class IProcess;
@@ -42,17 +43,18 @@ class UnitTestPP : public IPlugin
     IProcess* m_proc;
     wxString m_output;
     UnitTestsPage* m_outputPage;
-
+    clTabTogglerHelper::Ptr_t m_tabHelper;
+    
 public:
     UnitTestPP(IManager* manager);
-    ~UnitTestPP();
+    ~UnitTestPP() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void UnPlug() override;
     bool IsUnitTestProject(ProjectPtr p);
     /**
      * @brief return list of the projects which are identified as UnitTests project
