@@ -1,18 +1,21 @@
 #include "NodeJSDebuggerDlg.h"
-#include <wx/filename.h>
-#include "cl_config.h"
-#include "clTernServer.h"
-#include "globals.h"
-#include "imanager.h"
+
+#include "ColoursAndFontsManager.h"
 #include "NodeJSWorkspaceUserConfiguration.h"
 #include "NoteJSWorkspace.h"
-#include "ColoursAndFontsManager.h"
+#include "StringUtils.h"
+#include "clNodeJS.h"
+#include "cl_config.h"
+#include "globals.h"
+#include "imanager.h"
+
+#include <wx/filename.h>
 
 NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent, eDialogType type)
     : NodeJSDebuggerDlgBase(parent)
     , m_type(type)
 {
-    if(m_type == kDebug) {
+    if(m_type == kDebug || m_type == kDebugCLI) {
         SetLabel(_("Debug script"));
         m_staticTextScript->SetLabel(_("Script to debug:"));
     } else {
@@ -24,12 +27,7 @@ NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent, eDialogType type)
 
     m_stcCommandLineArguments->SetEOLMode(wxSTC_EOL_LF);
     wxFileName fnNodejs;
-    wxString nodejs = clConfig::Get().Read("webtools/nodejs/debugger/executable", wxString());
-    if(nodejs.IsEmpty()) {
-        if(clTernServer::LocateNodeJS(fnNodejs)) {
-            nodejs = fnNodejs.GetFullPath();
-        }
-    }
+    wxString nodejs = clNodeJS::Get().GetNode().GetFullPath();
 
     NodeJSWorkspaceUser userConf(NodeJSWorkspace::Get()->GetFilename().GetFullPath());
     userConf.Load();
@@ -43,24 +41,22 @@ NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent, eDialogType type)
     m_filePickerNodeJS->SetPath(nodejs);
     m_filePickerScript->SetPath(script);
     m_textCtrlPort->ChangeValue(wxString() << userConf.GetDebuggerPort());
-    m_dirPickerWorkingDirectory->SetPath(userConf.GetWorkingDirectory());
-    
+    m_dirPickerWorkingDirectory->SetPath(userConf.GetWorkingDirectory().IsEmpty()
+                                             ? NodeJSWorkspace::Get()->GetFilename().GetPath()
+                                             : userConf.GetWorkingDirectory());
+
     m_stcCommandLineArguments->SetText(::wxJoin(userConf.GetCommandLineArgs(), '\n'));
     LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("javascript");
-    if(lexer) {
-        lexer->Apply(m_stcCommandLineArguments);
-    }
+    if(lexer) { lexer->Apply(m_stcCommandLineArguments); }
     CenterOnParent();
 }
 
-NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent,
-                                     eDialogType type,
-                                     const wxFileName& script,
+NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent, eDialogType type, const wxFileName& script,
                                      const wxArrayString& args)
     : NodeJSDebuggerDlgBase(parent)
     , m_type(type)
 {
-    if(m_type == kDebug) {
+    if(m_type == kDebug || m_type == kDebugCLI) {
         SetLabel(_("Debug script"));
         m_staticTextScript->SetLabel(_("Script to debug:"));
     } else {
@@ -72,12 +68,7 @@ NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent,
 
     m_stcCommandLineArguments->SetEOLMode(wxSTC_EOL_LF);
     wxFileName fnNodejs;
-    wxString nodejs = clConfig::Get().Read("webtools/nodejs/debugger/executable", wxString());
-    if(nodejs.IsEmpty()) {
-        if(clTernServer::LocateNodeJS(fnNodejs)) {
-            nodejs = fnNodejs.GetFullPath();
-        }
-    }
+    wxString nodejs = clNodeJS::Get().GetNode().GetFullPath();
 
     NodeJSWorkspaceUser userConf(NodeJSWorkspace::Get()->GetFilename().GetFullPath());
     userConf.Load();
@@ -86,12 +77,12 @@ NodeJSDebuggerDlg::NodeJSDebuggerDlg(wxWindow* parent,
     m_filePickerScript->SetPath(script.GetFullPath());
     m_textCtrlPort->ChangeValue(wxString() << userConf.GetDebuggerPort());
     m_stcCommandLineArguments->SetText(::wxJoin(args, '\n'));
-    m_dirPickerWorkingDirectory->SetPath(userConf.GetWorkingDirectory());
-    
+    m_dirPickerWorkingDirectory->SetPath(userConf.GetWorkingDirectory().IsEmpty()
+                                             ? NodeJSWorkspace::Get()->GetFilename().GetPath()
+                                             : userConf.GetWorkingDirectory());
+
     LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("javascript");
-    if(lexer) {
-        lexer->Apply(m_stcCommandLineArguments);
-    }
+    if(lexer) { lexer->Apply(m_stcCommandLineArguments); }
     CenterOnParent();
 }
 
@@ -117,31 +108,32 @@ void NodeJSDebuggerDlg::OnOKUI(wxUpdateUIEvent& event)
                  wxFileName::Exists(m_filePickerScript->GetPath()));
 }
 
-wxString NodeJSDebuggerDlg::GetCommand()
+void NodeJSDebuggerDlg::GetCommand(wxString& command, wxString& command_args)
 {
-    wxString command, nodejs, script;
-    nodejs << m_filePickerNodeJS->GetPath();
+    wxString script;
+    command << m_filePickerNodeJS->GetPath();
     script << m_filePickerScript->GetPath();
-    ::WrapWithQuotes(nodejs);
-    ::WrapWithQuotes(script);
-
+    StringUtils::WrapWithQuotes(script);
+    wxString sport = m_textCtrlPort->GetValue();
+    long port = 5858;
+    if(!sport.Trim().ToCLong(&port)) { port = 5858; }
+    
     if(m_type == kDebug) {
-        wxString sport = m_textCtrlPort->GetValue();
-        long port = 5858;
-        if(!sport.Trim().ToCLong(&port)) {
-            port = 5858;
-        }
-        command << nodejs << " --debug-brk=" << port << " " << script;
+        command_args << "--debug-brk=" << port << " " << script;
+    } else if(m_type == kDebugCLI) {
+        command_args << "--inspect-brk=" << port << " " << script;
     } else {
-        command << nodejs << " " << script;
+        command_args << script;
     }
 
     wxArrayString args = ::wxStringTokenize(m_stcCommandLineArguments->GetText(), "\n", wxTOKEN_STRTOK);
-    if(!args.IsEmpty()) {
-        command << " ";
+    for (auto& arg : args) {
+        command_args << " " << StringUtils::WrapWithQuotes(arg);
     }
-    for(size_t i = 0; i < args.size(); ++i) {
-        command << ::WrapWithQuotes(args.Item(i)) << " ";
-    }
-    return command;
+}
+
+wxString NodeJSDebuggerDlg::GetWorkingDirectory() const
+{
+    return m_dirPickerWorkingDirectory->GetPath().IsEmpty() ? NodeJSWorkspace::Get()->GetFilename().GetPath()
+                                                            : m_dirPickerWorkingDirectory->GetPath();
 }
