@@ -1,6 +1,7 @@
 #include "NodeJSWorkspaceUserConfiguration.h"
-#include <globals.h>
-#include <json_node.h>
+
+#include "JSON.h"
+#include "globals.h"
 
 NodeJSWorkspaceUser::NodeJSWorkspaceUser(const wxString& workspacePath)
     : m_workspacePath(workspacePath)
@@ -9,8 +10,6 @@ NodeJSWorkspaceUser::NodeJSWorkspaceUser(const wxString& workspacePath)
 {
 }
 
-NodeJSWorkspaceUser::~NodeJSWorkspaceUser() {}
-
 wxFileName NodeJSWorkspaceUser::GetFileName() const
 {
     wxFileName workspaceFile(m_workspacePath);
@@ -25,8 +24,8 @@ wxFileName NodeJSWorkspaceUser::GetFileName() const
 NodeJSWorkspaceUser& NodeJSWorkspaceUser::Load()
 {
     wxFileName fn = GetFileName();
-    JSONRoot root(fn);
-    JSONElement element = root.toElement();
+    JSON root(fn);
+    JSONItem element = root.toElement();
 
     m_debuggerPort = element.namedObject("m_debuggerPort").toInt(m_debuggerPort);
     m_debuggerHost = element.namedObject("m_debuggerHost").toString(m_debuggerHost);
@@ -35,7 +34,7 @@ NodeJSWorkspaceUser& NodeJSWorkspaceUser::Load()
     m_workingDirectory = element.namedObject("m_workingDirectory").toString();
 
     m_breakpoints.clear();
-    JSONElement bpArr = element.namedObject("m_breakpoints");
+    JSONItem bpArr = element.namedObject("m_breakpoints");
     int bpcount = bpArr.arraySize();
     for(int i = 0; i < bpcount; ++i) {
         NodeJSBreakpoint bp;
@@ -48,19 +47,18 @@ NodeJSWorkspaceUser& NodeJSWorkspaceUser::Load()
 NodeJSWorkspaceUser& NodeJSWorkspaceUser::Save()
 {
     // Serialize the breakpoints
-    JSONRoot root(cJSON_Object);
-    JSONElement json = root.toElement();
+    JSON root(cJSON_Object);
+    JSONItem json = root.toElement();
     json.addProperty("m_debuggerPort", m_debuggerPort);
     json.addProperty("m_debuggerHost", m_debuggerHost);
     json.addProperty("m_scriptToExecute", m_scriptToExecute);
     json.addProperty("m_commandLineArgs", m_commandLineArgs);
     json.addProperty("m_workingDirectory", m_workingDirectory);
-    JSONElement bpArr = JSONElement::createArray("m_breakpoints");
+    JSONItem bpArr = JSONItem::createArray("m_breakpoints");
     json.append(bpArr);
 
-    NodeJSBreakpoint::List_t::const_iterator iter = m_breakpoints.begin();
-    for(; iter != m_breakpoints.end(); ++iter) {
-        bpArr.arrayAppend(iter->ToJSON());
+    for (const auto& breakpoint : m_breakpoints) {
+        bpArr.arrayAppend(breakpoint.ToJSON(""));
     }
     root.save(GetFileName());
     return *this;
