@@ -1,22 +1,25 @@
 #include "NoteJSWorkspace.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "NodeDebugger.h"
+#include "NodeJSDebuggerDlg.h"
+#include "NodeJSExecutable.h"
+#include "NodeJSNewWorkspaceDlg.h"
 #include "NodeJSWorkspaceConfiguration.h"
-#include "event_notifier.h"
-#include "codelite_events.h"
 #include "NodeJSWorkspaceView.h"
+#include "clWorkspaceManager.h"
+#include "clWorkspaceView.h"
+#include "codelite_events.h"
+#include "ctags_manager.h"
+#include "event_notifier.h"
+#include "file_logger.h"
 #include "globals.h"
 #include "imanager.h"
-#include "clWorkspaceView.h"
-#include "event_notifier.h"
-#include "codelite_events.h"
-#include <wx/dirdlg.h>
-#include "ctags_manager.h"
-#include "clWorkspaceManager.h"
-#include <wx/msgdlg.h>
-#include "NodeJSDebuggerDlg.h"
-#include "asyncprocess.h"
-#include "processreaderthread.h"
-#include "NodeJSNewWorkspaceDlg.h"
+
 #include <wx/dir.h>
+#include <wx/dirdlg.h>
+#include <wx/msgdlg.h>
 
 NodeJSWorkspace* NodeJSWorkspace::ms_workspace = NULL;
 
@@ -31,7 +34,6 @@ NodeJSWorkspace::NodeJSWorkspace()
     , m_showWelcomePage(false)
 {
     SetWorkspaceType("Node.js");
-    m_debugger.Reset(new NodeJSDebugger());
 
     m_view = new NodeJSWorkspaceView(clGetManager()->GetWorkspaceView()->GetBook(), GetWorkspaceType());
     clGetManager()->GetWorkspaceView()->AddPage(m_view, GetWorkspaceType());
@@ -44,6 +46,7 @@ NodeJSWorkspace::NodeJSWorkspace()
     EventNotifier::Get()->Bind(wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, &NodeJSWorkspace::OnExecute, this);
     EventNotifier::Get()->Bind(wxEVT_CMD_STOP_EXECUTED_PROGRAM, &NodeJSWorkspace::OnStopExecute, this);
     EventNotifier::Get()->Bind(wxEVT_CMD_IS_PROGRAM_RUNNING, &NodeJSWorkspace::OnIsExecuteInProgress, this);
+    EventNotifier::Get()->Bind(wxEVT_DBG_UI_START, &NodeJSWorkspace::OnDebugStart, this);
 
     m_terminal.Bind(wxEVT_TERMINAL_COMMAND_EXIT, &NodeJSWorkspace::OnProcessTerminated, this);
     m_terminal.Bind(wxEVT_TERMINAL_COMMAND_OUTPUT, &NodeJSWorkspace::OnProcessOutput, this);
@@ -51,7 +54,7 @@ NodeJSWorkspace::NodeJSWorkspace()
 
 NodeJSWorkspace::~NodeJSWorkspace()
 {
-    if(!m_dummy) {
+    if (!m_dummy) {
         EventNotifier::Get()->Unbind(wxEVT_CMD_CLOSE_WORKSPACE, &NodeJSWorkspace::OnCloseWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_CREATE_NEW_WORKSPACE, &NodeJSWorkspace::OnNewWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_OPEN_WORKSPACE, &NodeJSWorkspace::OnOpenWorkspace, this);
@@ -60,7 +63,8 @@ NodeJSWorkspace::~NodeJSWorkspace()
         EventNotifier::Get()->Unbind(wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, &NodeJSWorkspace::OnExecute, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_STOP_EXECUTED_PROGRAM, &NodeJSWorkspace::OnStopExecute, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_IS_PROGRAM_RUNNING, &NodeJSWorkspace::OnIsExecuteInProgress, this);
-        m_debugger.Reset(NULL);
+        EventNotifier::Get()->Unbind(wxEVT_DBG_UI_START, &NodeJSWorkspace::OnDebugStart, this);
+        m_debugger.reset(NULL);
         m_terminal.Unbind(wxEVT_TERMINAL_COMMAND_EXIT, &NodeJSWorkspace::OnProcessTerminated, this);
         m_terminal.Unbind(wxEVT_TERMINAL_COMMAND_OUTPUT, &NodeJSWorkspace::OnProcessOutput, this);
 
@@ -73,7 +77,7 @@ bool NodeJSWorkspace::IsProjectSupported() const { return false; }
 
 void NodeJSWorkspace::Free()
 {
-    if(ms_workspace) {
+    if (ms_workspace) {
         delete ms_workspace;
     }
     ms_workspace = NULL;
@@ -81,7 +85,7 @@ void NodeJSWorkspace::Free()
 
 NodeJSWorkspace* NodeJSWorkspace::Get()
 {
-    if(!ms_workspace) {
+    if (!ms_workspace) {
         ms_workspace = new NodeJSWorkspace();
     }
     return ms_workspace;
@@ -91,8 +95,10 @@ bool NodeJSWorkspace::IsOpen() const { return m_filename.IsOk() && m_filename.Ex
 
 bool NodeJSWorkspace::Create(const wxFileName& filename)
 {
-    if(IsOpen()) return false;
-    if(filename.Exists()) return false;
+    if (IsOpen())
+        return false;
+    if (filename.Exists())
+        return false;
     DoClear();
     m_filename = filename;
 
@@ -100,21 +106,23 @@ bool NodeJSWorkspace::Create(const wxFileName& filename)
     m_folders.Add(m_filename.GetPath());
     Save();
 
-    // We dont load the workspace
+    // We don't load the workspace
     DoClear();
     return true;
 }
 
 bool NodeJSWorkspace::Open(const wxFileName& filename)
 {
-    if(IsOpen()) return false;
+    if (IsOpen())
+        return false;
     m_filename = filename;
     return DoOpen(m_filename);
 }
 
 void NodeJSWorkspace::Close()
 {
-    if(!IsOpen()) return;
+    if (!IsOpen())
+        return;
 
     // Store the session
     clGetManager()->StoreWorkspaceSession(m_filename);
@@ -129,12 +137,12 @@ void NodeJSWorkspace::Close()
     GetView()->Clear();
 
     // Notify workspace closed event
-    wxCommandEvent event(wxEVT_WORKSPACE_CLOSED);
+    clWorkspaceEvent event(wxEVT_WORKSPACE_CLOSED);
     EventNotifier::Get()->ProcessEvent(event);
 
-    m_debugger.Reset(NULL);
+    m_debugger.reset(NULL);
 
-    // notify codelite to close the currently opened workspace
+    // notify CodeLite to close the currently opened workspace
     wxCommandEvent eventClose(wxEVT_MENU, wxID_CLOSE_ALL);
     eventClose.SetEventObject(EventNotifier::Get()->TopFrame());
     EventNotifier::Get()->TopFrame()->GetEventHandler()->ProcessEvent(eventClose);
@@ -149,15 +157,15 @@ void NodeJSWorkspace::DoClear()
 
 void NodeJSWorkspace::Save()
 {
-    NodeJSWorkspaceConfiguration conf;
+    NodeJSWorkspaceConfiguration conf(GetFileName());
     conf.SetFolders(m_folders);
-    conf.Save(m_filename);
+    conf.Save();
 }
 
 void NodeJSWorkspace::OnCloseWorkspace(clCommandEvent& e)
 {
     e.Skip();
-    if(IsOpen()) {
+    if (IsOpen()) {
         e.Skip(false);
         Close();
     }
@@ -166,14 +174,15 @@ void NodeJSWorkspace::OnCloseWorkspace(clCommandEvent& e)
 void NodeJSWorkspace::OnNewWorkspace(clCommandEvent& e)
 {
     e.Skip();
-    if(e.GetString() == GetWorkspaceType()) {
+    if (e.GetString() == GetWorkspaceType()) {
         e.Skip(false);
         // Create a new NodeJS workspace
         NodeJSNewWorkspaceDlg dlg(NULL);
-        if(dlg.ShowModal() != wxID_OK) return;
+        if (dlg.ShowModal() != wxID_OK)
+            return;
 
         wxFileName workspaceFile = dlg.GetWorkspaceFilename();
-        if(!workspaceFile.GetDirCount()) {
+        if (!workspaceFile.GetDirCount()) {
             ::wxMessageBox(
                 _("Can not create workspace in the root folder"), _("New Workspace"), wxICON_ERROR | wxOK | wxCENTER);
             return;
@@ -182,7 +191,7 @@ void NodeJSWorkspace::OnNewWorkspace(clCommandEvent& e)
         // Ensure that the path the workspace exists
         workspaceFile.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
 
-        if(!Create(workspaceFile)) {
+        if (!Create(workspaceFile)) {
             ::wxMessageBox(_("Failed to create workspace\nWorkspace already exists"),
                            _("New Workspace"),
                            wxICON_ERROR | wxOK | wxCENTER);
@@ -194,9 +203,9 @@ void NodeJSWorkspace::OnNewWorkspace(clCommandEvent& e)
 
 bool NodeJSWorkspace::DoOpen(const wxFileName& filename)
 {
-    NodeJSWorkspaceConfiguration conf;
-    conf.Load(m_filename);
-    if(!conf.IsOk()) {
+    NodeJSWorkspaceConfiguration conf(filename);
+    conf.Load();
+    if (!conf.IsOk()) {
         DoClear();
         return false;
     }
@@ -206,11 +215,11 @@ bool NodeJSWorkspace::DoOpen(const wxFileName& filename)
     GetView()->ShowHiddenFiles(conf.IsShowHiddenFiles());
 
     const wxArrayString& folders = GetFolders();
-    for(size_t i = 0; i < folders.size(); ++i) {
-        GetView()->AddFolder(folders.Item(i));
+    for (const auto& folder : folders) {
+        GetView()->AddFolder(folder);
     }
 
-    // Notify codelite that NodeJS workspace is opened
+    // Notify CodeLite that NodeJS workspace is opened
     clGetManager()->GetWorkspaceView()->SelectPage(GetWorkspaceType());
     clWorkspaceManager::Get().SetWorkspace(this);
 
@@ -221,18 +230,20 @@ bool NodeJSWorkspace::DoOpen(const wxFileName& filename)
     clGetManager()->EnableClangCodeCompletion(false);
 
     // Notify that the a new workspace is loaded
-    wxCommandEvent event(wxEVT_WORKSPACE_LOADED);
+    clWorkspaceEvent event(wxEVT_WORKSPACE_LOADED);
     event.SetString(filename.GetFullPath());
+    event.SetWorkspaceType(GetWorkspaceType());
+    event.SetFileName(filename.GetFullPath());
     EventNotifier::Get()->AddPendingEvent(event);
 
-    // and finally, request codelite to keep this workspace in the recently opened workspace list
+    // and finally, request CodeLite to keep this workspace in the recently opened workspace list
     clGetManager()->AddWorkspaceToRecentlyUsedList(m_filename);
 
     // Load the workspace session (if any)
     CallAfter(&NodeJSWorkspace::RestoreSession);
 
     // Create new debugger for this workspace
-    m_debugger.Reset(new NodeJSDebugger());
+    DoAllocateDebugger();
     return true;
 }
 
@@ -242,9 +253,9 @@ void NodeJSWorkspace::OnOpenWorkspace(clCommandEvent& event)
     wxFileName workspaceFile(event.GetFileName());
 
     // Test that this is our workspace
-    NodeJSWorkspaceConfiguration conf;
-    conf.Load(workspaceFile);
-    if(!conf.IsOk()) {
+    NodeJSWorkspaceConfiguration conf(workspaceFile);
+    conf.Load();
+    if (!conf.IsOk()) {
         return;
     }
     // This is a NodeJS workspace, stop event processing by calling
@@ -252,7 +263,7 @@ void NodeJSWorkspace::OnOpenWorkspace(clCommandEvent& event)
     event.Skip(false);
 
     // Check if this is a PHP workspace
-    if(IsOpen()) {
+    if (IsOpen()) {
         Close();
     }
     Open(workspaceFile);
@@ -261,7 +272,7 @@ void NodeJSWorkspace::OnOpenWorkspace(clCommandEvent& event)
 void NodeJSWorkspace::OnAllEditorsClosed(wxCommandEvent& event)
 {
     event.Skip();
-    if(m_showWelcomePage) {
+    if (m_showWelcomePage) {
         m_showWelcomePage = false;
         // Show the 'Welcome Page'
         wxFrame* frame = EventNotifier::Get()->TopFrame();
@@ -273,7 +284,7 @@ void NodeJSWorkspace::OnAllEditorsClosed(wxCommandEvent& event)
 
 void NodeJSWorkspace::RestoreSession()
 {
-    if(IsOpen()) {
+    if (IsOpen()) {
         clGetManager()->LoadWorkspaceSession(m_filename);
     }
 }
@@ -281,7 +292,7 @@ void NodeJSWorkspace::RestoreSession()
 void NodeJSWorkspace::OnSaveSession(clCommandEvent& event)
 {
     event.Skip();
-    if(IsOpen()) {
+    if (IsOpen()) {
         // Call event.Skip(false) so no other session are kept beside ours
         event.Skip(false);
         clGetManager()->StoreWorkspaceSession(m_filename);
@@ -296,8 +307,8 @@ wxString NodeJSWorkspace::GetFilesMask() const
 void NodeJSWorkspace::OnExecute(clExecuteEvent& event)
 {
     event.Skip();
-    if(IsOpen()) {
-        if(m_terminal.IsRunning()) {
+    if (IsOpen()) {
+        if (m_terminal.IsRunning()) {
             ::wxMessageBox(_("Another instance is already running. Please stop it before executing another one"),
                            "CodeLite",
                            wxICON_WARNING | wxCENTER | wxOK);
@@ -305,11 +316,14 @@ void NodeJSWorkspace::OnExecute(clExecuteEvent& event)
         }
         event.Skip(false);
         NodeJSDebuggerDlg dlg(EventNotifier::Get()->TopFrame(), NodeJSDebuggerDlg::kExecute);
-        if(dlg.ShowModal() != wxID_OK) {
+        if (dlg.ShowModal() != wxID_OK) {
             return;
         }
-        wxString cmd = dlg.GetCommand();
-        m_terminal.ExecuteConsole(cmd, dlg.GetWorkingDirectory(), true, cmd);
+
+        wxString command;
+        wxString command_args;
+        dlg.GetCommand(command, command_args);
+        m_terminal.ExecuteConsole(command, true, command_args, dlg.GetWorkingDirectory(), command + " " + command_args);
     }
 }
 
@@ -327,7 +341,7 @@ void NodeJSWorkspace::OnProcessTerminated(clCommandEvent& event)
 void NodeJSWorkspace::OnIsExecuteInProgress(clExecuteEvent& event)
 {
     event.Skip();
-    if(IsOpen()) {
+    if (IsOpen()) {
         event.Skip(false);
         event.SetAnswer(m_terminal.IsRunning());
     }
@@ -336,7 +350,7 @@ void NodeJSWorkspace::OnIsExecuteInProgress(clExecuteEvent& event)
 void NodeJSWorkspace::OnStopExecute(clExecuteEvent& event)
 {
     event.Skip();
-    if(IsOpen()) {
+    if (IsOpen()) {
         event.Skip(false);
         m_terminal.Terminate();
     }
@@ -358,3 +372,55 @@ void NodeJSWorkspace::GetWorkspaceFiles(wxArrayString& files) const
     // Return all the files
     wxDir::GetAllFiles(GetFilename().GetPath(), &files);
 }
+wxString NodeJSWorkspace::GetActiveProjectName() const { return wxEmptyString; }
+
+wxFileName NodeJSWorkspace::GetProjectFileName(const wxString& projectName) const
+{
+    wxUnusedVar(projectName);
+    return wxFileName();
+}
+
+wxArrayString NodeJSWorkspace::GetWorkspaceProjects() const { return wxArrayString(); }
+
+int NodeJSWorkspace::GetNodeJSMajorVersion() const
+{
+    NodeJSExecutable nodeJS;
+    int nodeVersion = nodeJS.GetMajorVersion();
+    clDEBUG() << "NodeJS major version is:" << nodeVersion;
+    return nodeVersion;
+}
+
+void NodeJSWorkspace::DoAllocateDebugger()
+{
+    if ((GetNodeJSMajorVersion() >= 8)) {
+        clDEBUG() << "Successfully allocated new JS debugger";
+        m_debugger.reset(new NodeDebugger());
+    } else {
+        m_debugger.reset();
+        clWARNING() << "Your Nodejs version is lower than v8, unable to allocate debugger";
+    }
+}
+
+void NodeJSWorkspace::OnDebugStart(clDebugEvent& event)
+{
+    if (IsOpen()) {
+        if (m_debugger) {
+            // let our debugger handle it
+            event.Skip();
+        } else {
+            // We don't have a proper debugger, however, we don't want CodeLite to start the wrong debugger
+            ::wxMessageBox(_("Could not instantiate a debugger for your NodeJS version!"), "CodeLite", wxICON_WARNING);
+            event.Skip(false);
+        }
+    } else {
+        event.Skip();
+    }
+}
+
+NodeDebugger::Ptr_t NodeJSWorkspace::GetDebugger() { return m_debugger; }
+
+void NodeJSWorkspace::AllocateDebugger() { DoAllocateDebugger(); }
+
+void NodeJSWorkspace::SetProjectActive(const wxString& project) { wxUnusedVar(project); }
+
+wxString NodeJSWorkspace::GetDebuggerName() const { return NodeDebugger::NODE_CLI_DEBUGGER_NAME; }
\ No newline at end of file
