@@ -26,30 +26,37 @@
 #ifndef NOTEJSWORKSPACE_H
 #define NOTEJSWORKSPACE_H
 
-#include "IWorkspace.h"
-#include <wx/filename.h>
+#include "AsyncProcess/TerminalEmulator.h"
+#include "NodeDebugger.h"
+#include "clWorkspaceManager.h"
 #include "cl_command_event.h"
-#include "NodeJSDebugger.h"
-#include "TerminalEmulator.h"
 
+#include <wx/filename.h>
+
+class NodeDebugger;
 class NodeJSWorkspaceView;
-class NodeJSWorkspace : public IWorkspace
+class NodeJSWorkspace : public LocalWorkspaceCommon
 {
 protected:
     wxFileName m_filename;
     wxArrayString m_folders;
     NodeJSWorkspaceView* m_view;
     bool m_clangOldFlag;
-    bool m_dummy;
+    bool m_dummy = false;
     bool m_showWelcomePage;
-    NodeJSDebugger::Ptr_t m_debugger;
+    NodeDebugger::Ptr_t m_debugger;
     TerminalEmulator m_terminal;
     static NodeJSWorkspace* ms_workspace;
 
 protected:
+    int GetNodeJSMajorVersion() const;
+    void DoAllocateDebugger();
     void DoClear();
     bool DoOpen(const wxFileName& filename);
 
+    // Fallback, incase we fail to allocate a proper debugger
+    void OnDebugStart(clDebugEvent& event);
+
     //--------------------------------------------------
     // Event handlers
     //--------------------------------------------------
@@ -95,22 +102,35 @@ protected:
     NodeJSWorkspace(); // default ctor is private
 
 public:
-    virtual void GetProjectFiles(const wxString& projectName, wxArrayString& files) const;
-    virtual void GetWorkspaceFiles(wxArrayString& files) const;
-    virtual wxString GetProjectFromFile(const wxFileName& filename) const;
-    virtual wxString GetFilesMask() const;
+    wxString GetActiveProjectName() const override;
+    wxFileName GetProjectFileName(const wxString& projectName) const override;
+    wxArrayString GetWorkspaceProjects() const override;
+    void GetProjectFiles(const wxString& projectName, wxArrayString& files) const override;
+    void GetWorkspaceFiles(wxArrayString& files) const override;
+    wxString GetProjectFromFile(const wxFileName& filename) const override;
+    wxString GetFilesMask() const override;
+    void SetProjectActive(const wxString& project) override;
+    wxString GetDebuggerName() const override;
+
     NodeJSWorkspace(bool dummy);
     virtual ~NodeJSWorkspace();
 
+    /**
+     * @brief create a debugger instance for this workspace
+     */
+    void AllocateDebugger();
     static NodeJSWorkspace* Get();
     static void Free();
 
 public:
-    virtual bool IsBuildSupported() const;
-    virtual bool IsProjectSupported() const;
+    bool IsBuildSupported() const override;
+    bool IsProjectSupported() const override;
+
+    wxString GetName() const override { return m_filename.GetName(); }
 
     NodeJSWorkspaceView* GetView() { return m_view; }
-    NodeJSDebugger::Ptr_t GetDebugger() { return m_debugger; }
+    NodeDebugger::Ptr_t GetDebugger();
+
     /**
      * @brief is this workspace opened?
      */
@@ -142,7 +162,8 @@ public:
     /**
      * @brief as defined by IWorkspace
      */
-    wxFileName GetFileName() const { return GetFilename(); }
+    wxString GetFileName() const override { return GetFilename().GetFullPath(); }
+    wxString GetDir() const override { return GetFilename().GetPath(); }
     void SetFolders(const wxArrayString& folders) { this->m_folders = folders; }
     const wxArrayString& GetFolders() const { return m_folders; }
     wxArrayString& GetFolders() { return m_folders; }
