@@ -1,32 +1,36 @@
 #include "XMLCodeCompletion.h"
-#include "ieditor.h"
-#include <wx/stc/stc.h>
-#include <wx/xrc/xmlres.h>
-#include <wx/app.h>
+
+#include "WebToolsConfig.h"
 #include "XMLBuffer.h"
-#include "wxCodeCompletionBoxManager.h"
-#include "event_notifier.h"
 #include "codelite_events.h"
+#include "event_notifier.h"
 #include "globals.h"
 #include "ieditor.h"
 #include "imanager.h"
-#include <wx/xrc/xmlres.h>
-#include "WebToolsConfig.h"
+#include "webtools.h"
+#include "wxCodeCompletionBoxManager.h"
 
-XMLCodeCompletion::XMLCodeCompletion()
+#include <wx/app.h>
+#include <wx/stc/stc.h>
+#include <wx/xrc/xmlres.h>
+
+XMLCodeCompletion::XMLCodeCompletion(WebTools* plugin)
     : m_completeReason(kNone)
+    , m_plugin(plugin)
 {
     PrepareHtmlCompletions();
     EventNotifier::Get()->Bind(wxEVT_CCBOX_SELECTION_MADE, &XMLCodeCompletion::OnCodeCompleted, this);
 
-    WebToolsConfig conf;
-    m_htmlCcEnabeld = conf.Load().HasHtmlFlag(WebToolsConfig::kHtmlEnableCC);
-    m_xmlCcEnabled = conf.Load().HasXmlFlag(WebToolsConfig::kXmlEnableCC);
+    WebToolsConfig& conf = WebToolsConfig::Get();
+    m_htmlCcEnabeld = conf.HasHtmlFlag(WebToolsConfig::kHtmlEnableCC);
+    m_xmlCcEnabled = conf.HasXmlFlag(WebToolsConfig::kXmlEnableCC);
+    EventNotifier::Get()->Bind(wxEVT_CC_CODE_COMPLETE, &XMLCodeCompletion::OnCodeComplete, this);
 }
 
 XMLCodeCompletion::~XMLCodeCompletion()
 {
     EventNotifier::Get()->Unbind(wxEVT_CCBOX_SELECTION_MADE, &XMLCodeCompletion::OnCodeCompleted, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_CODE_COMPLETE, &XMLCodeCompletion::OnCodeComplete, this);
 }
 
 void XMLCodeCompletion::SuggestClosingTag(IEditor* editor, bool html)
@@ -37,12 +41,13 @@ void XMLCodeCompletion::SuggestClosingTag(IEditor* editor, bool html)
     XMLBuffer buffer(ctrl->GetTextRange(0, ctrl->GetCurrentPos()), html);
     buffer.Parse();
     if(buffer.InCData() || buffer.InComment()) {
-        // dont offer code completion when inside CDATA or COMMENT blocks
+        // don't offer code completion when inside CDATA or COMMENT blocks
         return;
     }
 
     XMLBuffer::Scope currentScope = buffer.GetCurrentScope();
-    if(!currentScope.IsOk()) return;
+    if(!currentScope.IsOk())
+        return;
 
     wxCodeCompletionBox::BmpVec_t bitmaps;
     bitmaps.push_back(wxXmlResource::Get()->LoadBitmap("code-tags"));
@@ -52,13 +57,14 @@ void XMLCodeCompletion::SuggestClosingTag(IEditor* editor, bool html)
     entries.push_back(entry);
 
     m_completeReason = kCloseSequence;
-    wxCodeCompletionBoxManager::Get().ShowCompletionBox(
-        editor->GetCtrl(), entries, bitmaps, 0, GetWordStartPos(editor), this);
+    wxCodeCompletionBoxManager::Get().ShowCompletionBox(editor->GetCtrl(), entries, bitmaps, 0, GetWordStartPos(editor),
+                                                        this);
 }
 
 void XMLCodeCompletion::XmlCodeComplete(IEditor* editor)
 {
-    if(!m_xmlCcEnabled) return;
+    if(!m_xmlCcEnabled)
+        return;
 
     // Perform XML code completion
     wxStyledTextCtrl* ctrl = editor->GetCtrl();
@@ -70,14 +76,15 @@ void XMLCodeCompletion::XmlCodeComplete(IEditor* editor)
     } else {
         // CC was triggered by "<"
         // In this case, we simply trigger the word completion
-        wxCommandEvent event(wxEVT_MENU, XRCID("word_complete_no_single_insert"));
-        wxTheApp->AddPendingEvent(event);
+        wxCommandEvent event(wxEVT_MENU, XRCID("simple_word_completion"));
+        EventNotifier::Get()->TopFrame()->GetEventHandler()->AddPendingEvent(event);
     }
 }
 
 void XMLCodeCompletion::HtmlCodeComplete(IEditor* editor)
 {
-    if(!m_htmlCcEnabeld) return;
+    if(!m_htmlCcEnabeld)
+        return;
 
     // Perform HTML code completion
     wxStyledTextCtrl* ctrl = editor->GetCtrl();
@@ -91,14 +98,14 @@ void XMLCodeCompletion::HtmlCodeComplete(IEditor* editor)
         bitmaps.push_back(wxXmlResource::Get()->LoadBitmap("code-tags"));
 
         wxCodeCompletionBoxEntry::Vec_t entries;
-        for(size_t i = 0; i < m_htmlCompletions.size(); ++i) {
-            wxCodeCompletionBoxEntry::Ptr_t entry = wxCodeCompletionBoxEntry::New(m_htmlCompletions.at(i).m_tag, 0);
-            entry->SetComment(m_htmlCompletions.at(i).m_comment);
+        for (const auto& htmlCompletion : m_htmlCompletions) {
+            wxCodeCompletionBoxEntry::Ptr_t entry = wxCodeCompletionBoxEntry::New(htmlCompletion.m_tag, 0);
+            entry->SetComment(htmlCompletion.m_comment);
             entries.push_back(entry);
         }
         m_completeReason = kHtmlOpenSequence;
-        wxCodeCompletionBoxManager::Get().ShowCompletionBox(
-            editor->GetCtrl(), entries, bitmaps, 0, GetWordStartPos(editor), this);
+        wxCodeCompletionBoxManager::Get().ShowCompletionBox(editor->GetCtrl(), entries, bitmaps, 0,
+                                                            GetWordStartPos(editor), this);
     }
 }
 
@@ -130,8 +137,8 @@ void XMLCodeCompletion::PrepareHtmlCompletions()
     m_htmlCompletions.push_back(
         HtmlCompletion("<base", "Specifies the base URL/target for all relative URLs in a document"));
     m_htmlCompletions.push_back(HtmlCompletion("<basefont",
-        "Not supported in HTML5. Use CSS instead. Specifies a "
-        "default color, size, and font for all text in a document"));
+                                               "Not supported in HTML5. Use CSS instead. Specifies a "
+                                               "default color, size, and font for all text in a document"));
     m_htmlCompletions.push_back(HtmlCompletion(
         "bdi", "Isolates a part of text that might be formatted in a different direction from other text outside it"));
     m_htmlCompletions.push_back(HtmlCompletion("<bdo", "Overrides the current text direction"));
@@ -196,7 +203,8 @@ void XMLCodeCompletion::PrepareHtmlCompletions()
     m_htmlCompletions.push_back(HtmlCompletion("<label", "Defines a label for an <input> element"));
     m_htmlCompletions.push_back(HtmlCompletion("<legend", "Defines a caption for a <fieldset> element"));
     m_htmlCompletions.push_back(HtmlCompletion("<li", "Defines a list item"));
-    m_htmlCompletions.push_back(HtmlCompletion("link",
+    m_htmlCompletions.push_back(HtmlCompletion(
+        "link",
         "Defines the relationship between a document and an external resource (most used to link to style sheets)"));
     m_htmlCompletions.push_back(HtmlCompletion("<main", "Specifies the main content of a document"));
     m_htmlCompletions.push_back(HtmlCompletion("<map", "Defines a client-side image-map"));
@@ -274,7 +282,8 @@ void XMLCodeCompletion::OnCodeCompleted(clCodeCompletionEvent& event)
 
     // sanity
     IEditor* editor = clGetManager()->GetActiveEditor();
-    if(!editor) return;
+    if(!editor)
+        return;
 
     // HTML triggered the code complete?
     if(m_completeReason == kHtmlOpenSequence) {
@@ -344,14 +353,14 @@ bool XMLCodeCompletion::HasSpecialInsertPattern(const wxString& tag) const
 
 void XMLCodeCompletion::Reload()
 {
-    WebToolsConfig conf;
-    m_htmlCcEnabeld = conf.Load().HasHtmlFlag(WebToolsConfig::kHtmlEnableCC);
-    m_xmlCcEnabled = conf.Load().HasXmlFlag(WebToolsConfig::kXmlEnableCC);
+    WebToolsConfig& conf = WebToolsConfig::Get();
+    m_htmlCcEnabeld = conf.HasHtmlFlag(WebToolsConfig::kHtmlEnableCC);
+    m_xmlCcEnabled = conf.HasXmlFlag(WebToolsConfig::kXmlEnableCC);
 }
 
 int XMLCodeCompletion::GetWordStartPos(IEditor* editor)
 {
-    // Dont use WordStartPos / WordEndPos, instead, search for the first "<"
+    // Don't use WordStartPos / WordEndPos, instead, search for the first "<"
     // from this line backward and use that as the first insert position
     int minPos = editor->PosFromLine(editor->GetCurrentLine());
     int curpos = editor->GetCurrentPosition() - 1;
@@ -362,3 +371,27 @@ int XMLCodeCompletion::GetWordStartPos(IEditor* editor)
     }
     return editor->WordStartPos(editor->GetCurrentPosition(), true);
 }
+
+void XMLCodeCompletion::OnCodeComplete(clCodeCompletionEvent& event)
+{
+    event.Skip();
+    IEditor* editor = GetEditor(event.GetFileName());
+    if(editor && wxWindow::FindFocus() == editor->GetCtrl() && editor->GetCtrl()->GetLexer() == wxSTC_LEX_XML) {
+        // an XML file
+        event.Skip(false);
+        XmlCodeComplete(editor);
+    } else if(editor && m_plugin->IsHTMLFile(editor)) {
+        // Html code completion
+        event.Skip(false);
+        HtmlCodeComplete(editor);
+    }
+}
+
+IEditor* XMLCodeCompletion::GetEditor(const wxString& filename) const
+{
+    auto editor = clGetManager()->FindEditor(filename);
+    if(editor && editor == clGetManager()->GetActiveEditor()) {
+        return editor;
+    }
+    return nullptr;
+}
