@@ -2,24 +2,22 @@
 
 WordCompletionSettings::WordCompletionSettings()
     : clConfigItem("WordCompletionSettings")
-    , m_completeTypes(kCompleteWords)
     , m_comparisonMethod(kComparisonStartsWith)
+    , m_enabled(true)
 {
 }
 
-WordCompletionSettings::~WordCompletionSettings() {}
-
-void WordCompletionSettings::FromJSON(const JSONElement& json)
+void WordCompletionSettings::FromJSON(const JSONItem& json)
 {
-    m_completeTypes = json.namedObject("m_completeTypes").toSize_t(m_completeTypes);
     m_comparisonMethod = json.namedObject("m_comparisonMethod").toInt(m_comparisonMethod);
+    m_enabled = json.namedObject("m_enabled").toBool(m_enabled);
 }
 
-JSONElement WordCompletionSettings::ToJSON() const
+JSONItem WordCompletionSettings::ToJSON() const
 {
-    JSONElement element = JSONElement::createObject(GetName());
-    element.addProperty("m_completeTypes", m_completeTypes);
+    JSONItem element = JSONItem::createObject(GetName());
     element.addProperty("m_comparisonMethod", m_comparisonMethod);
+    element.addProperty("m_enabled", m_enabled);
     return element;
 }
 
