@@ -4,24 +4,32 @@
 
 WordCompletionSettingsDlg::WordCompletionSettingsDlg(wxWindow* parent)
     : WordCompletionSettingsBaseDlg(parent)
+    , m_modified(false)
 {
     ::wxPGPropertyBooleanUseCheckbox(m_pgMgr->GetGrid());
     WordCompletionSettings settings;
-    size_t completeTypes = settings.Load().GetCompleteTypes();
-    m_pgPropTypes->SetValueFromInt(completeTypes);
+    settings.Load();
     m_pgPropComparisonMethod->SetChoiceSelection(settings.GetComparisonMethod());
-    
-    WindowAttrManager::Load(this, "WordCompletionSettingsDlg");
+    m_pgPropEnabled->SetValue(settings.IsEnabled());
+    SetName("WordCompletionSettingsDlg");
+    WindowAttrManager::Load(this);
 }
 
-WordCompletionSettingsDlg::~WordCompletionSettingsDlg() { WindowAttrManager::Save(this, "WordCompletionSettingsDlg"); }
-
 void WordCompletionSettingsDlg::OnValueChanged(wxPropertyGridEvent& event)
+{
+    event.Skip();
+    m_modified = true;
+}
+
+void WordCompletionSettingsDlg::OnOk(wxCommandEvent& event)
 {
     event.Skip();
     WordCompletionSettings settings;
     settings.Load();
-    settings.SetCompleteTypes(m_pgPropTypes->GetValue().GetInteger());
     settings.SetComparisonMethod(m_pgPropComparisonMethod->GetChoiceSelection());
+    settings.SetEnabled(m_pgPropEnabled->GetValue().GetBool());
     settings.Save();
+    EndModal(wxID_OK);
 }
+
+void WordCompletionSettingsDlg::OnOkUI(wxUpdateUIEvent& event) { event.Enable(m_modified); }
