@@ -30,32 +30,29 @@
 //  the Free Software Foundation; either version 2 of the License, or
 //  (at your option) any later version.
 
-#include <wx/menu.h>
-#include <wx/xrc/xmlres.h>
-#include <wx/stc/stc.h>
-#include "dockablepane.h"
-#include "detachedpanesinfo.h"
 #include "zoomnavigator.h"
+
+#include "bookmark_manager.h"
 #include "event_notifier.h"
+#include "zoomtext.h"
 #include "znSettingsDlg.h"
 #include "zn_config_item.h"
+
+#include <wx/menu.h>
 #include <wx/msgdlg.h>
+#include <wx/stc/stc.h>
+#include <wx/timer.h>
 #include <wx/wupdlock.h>
+#include <wx/xrc/xmlres.h>
 
-static ZoomNavigator* thePlugin = NULL;
 #define CHECK_CONDITION(cond) \
-    if(!cond) return;
+    if (!cond)                \
+        return;
 
-const wxString ZOOM_PANE_TITLE(_("Zoom Navigator"));
+static const wxString ZOOM_PANE_TITLE(_("Zoom"));
 
 // Define the plugin entry point
-CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
-{
-    if(thePlugin == 0) {
-        thePlugin = new ZoomNavigator(manager);
-    }
-    return thePlugin;
-}
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager) { return new ZoomNavigator(manager); }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
@@ -69,76 +66,76 @@ CL_PLUGIN_API PluginInfo* GetPluginInfo()
 
 CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
+namespace
+{
+/// @[param]in ctrl the control
+/// @[param]in marker_mask marker type to check
+std::vector<int> GetMarkers(wxStyledTextCtrl& ctrl, marker_mask_type marker_mask)
+{
+    std::vector<int> lines;
+    int nFoundLine = 0;
+    while (true) {
+        nFoundLine = ctrl.MarkerNext(nFoundLine, marker_mask);
+        if (nFoundLine == wxNOT_FOUND) {
+            break;
+        }
+        lines.push_back(nFoundLine);
+        ++nFoundLine;
+    }
+    return lines;
+}
+} // namespace
+
 ZoomNavigator::ZoomNavigator(IManager* manager)
     : IPlugin(manager)
-    , mgr(manager)
-    , zoompane(NULL)
-    , m_topWindow(NULL)
-    , m_text(NULL)
-    , m_markerFirstLine(wxNOT_FOUND)
-    , m_markerLastLine(wxNOT_FOUND)
-    , m_enabled(false)
-    , m_lastLine(wxNOT_FOUND)
-    , m_startupCompleted(false)
+    , m_config(new clConfig("zoom-navigator.conf"))
 {
-    m_config = new clConfig("zoom-navigator.conf");
     m_longName = _("Zoom Navigator");
     m_shortName = wxT("ZoomNavigator");
     m_topWindow = m_mgr->GetTheApp();
 
-    m_topWindow->Connect(wxEVT_IDLE, wxIdleEventHandler(ZoomNavigator::OnIdle), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_INIT_DONE, wxCommandEventHandler(ZoomNavigator::OnInitDone), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_FILE_SAVED, clCommandEventHandler(ZoomNavigator::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_ZN_SETTINGS_UPDATED, wxCommandEventHandler(ZoomNavigator::OnSettingsChanged), NULL, this);
-    m_topWindow->Connect(XRCID("zn_settings"),
-                         wxEVT_COMMAND_MENU_SELECTED,
-                         wxCommandEventHandler(ZoomNavigator::OnSettings),
-                         NULL,
-                         this);
-    EventNotifier::Get()->Bind(wxEVT_SHOW_WORKSPACE_TAB, &ZoomNavigator::OnToggleTab, this);
+    m_topWindow->Connect(wxEVT_IDLE, wxIdleEventHandler(ZoomNavigator::OnIdle), nullptr, this);
+    EventNotifier::Get()->Bind(wxEVT_INIT_DONE, &ZoomNavigator::OnInitDone, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_SAVED, &ZoomNavigator::OnFileSaved, this);
+    EventNotifier::Get()->Bind(wxEVT_ZN_SETTINGS_UPDATED, &ZoomNavigator::OnSettingsChanged, this);
+
+    m_topWindow->Connect(XRCID("zn_settings"), wxEVT_COMMAND_MENU_SELECTED,
+                         wxCommandEventHandler(ZoomNavigator::OnSettings), nullptr, this);
+
+    m_timer = new wxTimer(this);
+    Bind(wxEVT_TIMER, &ZoomNavigator::OnTimer, this, m_timer->GetId());
+    m_timer->Start(100);
+
     DoInitialize();
 }
 
-ZoomNavigator::~ZoomNavigator() {}
-
 void ZoomNavigator::UnPlug()
 {
-    EventNotifier::Get()->Disconnect(wxEVT_INIT_DONE, wxCommandEventHandler(ZoomNavigator::OnInitDone), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_ZN_SETTINGS_UPDATED, wxCommandEventHandler(ZoomNavigator::OnSettingsChanged), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(ZoomNavigator::OnFileSaved), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_ZN_SETTINGS_UPDATED, &ZoomNavigator::OnSettingsChanged, this);
+    EventNotifier::Get()->Unbind(wxEVT_INIT_DONE, &ZoomNavigator::OnInitDone, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &ZoomNavigator::OnFileSaved, this);
 
-    m_topWindow->Disconnect(wxEVT_IDLE, wxIdleEventHandler(ZoomNavigator::OnIdle), NULL, this);
-    m_topWindow->Disconnect(XRCID("zn_settings"),
-                            wxEVT_COMMAND_MENU_SELECTED,
-                            wxCommandEventHandler(ZoomNavigator::OnSettings),
-                            NULL,
-                            this);
-    EventNotifier::Get()->Unbind(wxEVT_SHOW_WORKSPACE_TAB, &ZoomNavigator::OnToggleTab, this);
+    m_topWindow->Disconnect(wxEVT_IDLE, wxIdleEventHandler(ZoomNavigator::OnIdle), nullptr, this);
+    m_topWindow->Disconnect(XRCID("zn_settings"), wxEVT_COMMAND_MENU_SELECTED,
+                            wxCommandEventHandler(ZoomNavigator::OnSettings), nullptr, this);
+    // cancel the timer
+    Unbind(wxEVT_TIMER, &ZoomNavigator::OnTimer, this, m_timer->GetId());
+    m_timer->Stop();
+    wxDELETE(m_timer);
 
     // Remove the tab if it's actually docked in the workspace pane
-    int index(wxNOT_FOUND);
-    index = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(zoompane);
-    if(index != wxNOT_FOUND) {
-        m_mgr->GetWorkspacePaneNotebook()->RemovePage(index);
+    if (!m_mgr->BookDeletePage(PaneId::SIDE_BAR, m_zoompane)) {
+        m_zoompane->Destroy();
     }
-    zoompane->Destroy();
+    m_zoompane = nullptr;
 }
 
-clToolBar* ZoomNavigator::CreateToolBar(wxWindow* parent)
-{
-    // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-    return tb;
-}
+void ZoomNavigator::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void ZoomNavigator::CreatePluginMenu(wxMenu* pluginsMenu)
 {
     wxMenu* menu = new wxMenu();
-    wxMenuItem* item(NULL);
-    item = new wxMenuItem(menu, XRCID("zn_settings"), _("Settings"), _("Settings"), wxITEM_NORMAL);
-    menu->Append(item);
+    menu->Append(new wxMenuItem(menu, XRCID("zn_settings"), _("Settings"), _("Settings"), wxITEM_NORMAL));
     pluginsMenu->Append(wxID_ANY, _("Zoom Navigator"), menu);
 }
 
@@ -147,47 +144,23 @@ void ZoomNavigator::OnShowHideClick(wxCommandEvent& e) {}
 void ZoomNavigator::DoInitialize()
 {
     znConfigItem data;
-    if(m_config->ReadItem(&data)) {
+    if (m_config->ReadItem(&data)) {
         m_enabled = data.IsEnabled();
     }
 
     // create tab (possibly detached)
-    Notebook* book = m_mgr->GetWorkspacePaneNotebook();
-    if(IsZoomPaneDetached()) {
-        // Make the window child of the main panel (which is the grand parent of the notebook)
-        DockablePane* cp = new DockablePane(
-            book->GetParent()->GetParent(), book, ZOOM_PANE_TITLE, false, wxNullBitmap, wxSize(200, 200));
-        zoompane = new wxPanel(cp);
-        cp->SetChildNoReparent(zoompane);
-
-    } else {
-        zoompane = new wxPanel(book);
-        book->AddPage(zoompane, ZOOM_PANE_TITLE, false);
-    }
+    auto book = m_mgr->BookGet(PaneId::SIDE_BAR);
+    m_zoompane = new wxPanel(book);
+    m_mgr->BookAddPage(PaneId::SIDE_BAR, m_zoompane, ZOOM_PANE_TITLE, "zoom-button");
     m_mgr->AddWorkspaceTab(ZOOM_PANE_TITLE);
 
-    m_text = new ZoomText(zoompane);
-    m_text->Connect(wxEVT_LEFT_DOWN, wxMouseEventHandler(ZoomNavigator::OnPreviewClicked), NULL, this);
-    m_text->Connect(wxEVT_LEFT_DCLICK, wxMouseEventHandler(ZoomNavigator::OnPreviewClicked), NULL, this);
+    m_text = new ZoomText(m_zoompane);
+    m_text->Bind(wxEVT_LEFT_DOWN, &ZoomNavigator::OnPreviewClicked, this);
+    m_text->Bind(wxEVT_LEFT_DCLICK, &ZoomNavigator::OnPreviewClicked, this);
     m_text->SetCursor(wxCURSOR_POINT_LEFT);
-
     wxBoxSizer* bs = new wxBoxSizer(wxVERTICAL);
     bs->Add(m_text, 1, wxEXPAND, 0);
-    wxCheckBox* cbEnablePlugin = new wxCheckBox(zoompane, wxID_ANY, _("Enable plugin"));
-    cbEnablePlugin->SetValue(data.IsEnabled());
-    bs->Add(cbEnablePlugin, 0, wxEXPAND);
-
-    cbEnablePlugin->Connect(
-        wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(ZoomNavigator::OnEnablePlugin), NULL, this);
-    zoompane->SetSizer(bs);
-}
-
-bool ZoomNavigator::IsZoomPaneDetached()
-{
-    DetachedPanesInfo dpi;
-    m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    wxArrayString detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(ZOOM_PANE_TITLE) != wxNOT_FOUND;
+    m_zoompane->SetSizer(bs);
 }
 
 void ZoomNavigator::DoUpdate()
@@ -197,24 +170,29 @@ void ZoomNavigator::DoUpdate()
     CHECK_CONDITION(!m_mgr->IsShutdownInProgress());
 
     IEditor* curEditor = m_mgr->GetActiveEditor();
-    if(!curEditor && !m_text->IsEmpty()) {
+    if (!curEditor && !m_text->IsEmpty()) {
         DoCleanup();
     }
     CHECK_CONDITION(curEditor);
 
     wxStyledTextCtrl* stc = curEditor->GetCtrl();
     CHECK_CONDITION(stc);
+    CHECK_CONDITION(stc->IsShown());
 
-    if(curEditor->GetFileName().GetFullPath() != m_curfile) {
+    // locate any error and warning markers in the main editor and duplicate then into the zoomed view
+    m_text->UpdateMarkers(GetMarkers(*stc, mmt_error), ZoomText::MarkerType::Error);
+    m_text->UpdateMarkers(GetMarkers(*stc, mmt_warning), ZoomText::MarkerType::Warning);
+
+    if (curEditor->GetFileName().GetFullPath() != m_curfile) {
         SetEditorText(curEditor);
     }
 
-    int first = stc->GetFirstVisibleLine();
-    int last = stc->LinesOnScreen() + first;
+    const int first = stc->GetFirstVisibleLine();
+    const int last = stc->LinesOnScreen() + first;
 
-    if(m_markerFirstLine != first || m_markerLastLine != last) {
+    if (m_markerFirstLine != first || m_markerLastLine != last) {
         PatchUpHighlights(first, last);
-        SetZoomTextScrollPosToMiddle(stc);
+        SetZoomTextScrollPosToMiddle(*stc);
     }
 }
 
@@ -222,23 +200,24 @@ void ZoomNavigator::SetEditorText(IEditor* editor)
 {
     m_curfile.Clear();
     m_text->UpdateText(editor);
-    if(editor) {
+    if (editor) {
         m_curfile = editor->GetFileName().GetFullPath();
         m_text->UpdateLexer(editor);
     }
 }
 
-void ZoomNavigator::SetZoomTextScrollPosToMiddle(wxStyledTextCtrl* stc)
+void ZoomNavigator::SetZoomTextScrollPosToMiddle(wxStyledTextCtrl& stc)
 {
-    int first;
-    first = stc->GetFirstVisibleLine();
+    // make the middle line of editor text centered in the zoomview
+    int first = stc.GetFirstVisibleLine() + (stc.LinesOnScreen() / 2);
 
     // we want to make 'first' centered
-    int numLinesOnScreen = m_text->LinesOnScreen();
-    int linesAboveIt = numLinesOnScreen / 2;
+    const int numLinesOnScreen = m_text->LinesOnScreen();
+    const int linesAboveIt = numLinesOnScreen / 2;
 
     first = first - linesAboveIt;
-    if(first < 0) first = 0;
+    if (first < 0)
+        first = 0;
 
     m_text->SetFirstVisibleLine(first);
     m_text->ClearSelections();
@@ -253,8 +232,6 @@ void ZoomNavigator::PatchUpHighlights(const int first, const int last)
 
 void ZoomNavigator::HookPopupMenu(wxMenu* menu, MenuType type) {}
 
-void ZoomNavigator::UnHookPopupMenu(wxMenu* menu, MenuType type) {}
-
 void ZoomNavigator::OnPreviewClicked(wxMouseEvent& e)
 {
     IEditor* curEditor = m_mgr->GetActiveEditor();
@@ -265,17 +242,18 @@ void ZoomNavigator::OnPreviewClicked(wxMouseEvent& e)
     CHECK_CONDITION(m_enabled);
 
     // the first line is taken from the preview
-    int pos = m_text->PositionFromPoint(e.GetPosition());
-    if(pos == wxSTC_INVALID_POSITION) {
+    const int pos = m_text->PositionFromPoint(e.GetPosition());
+    if (pos == wxSTC_INVALID_POSITION) {
         return;
     }
     int first = m_text->LineFromPosition(pos);
-    int nLinesOnScreen = curEditor->GetCtrl()->LinesOnScreen();
+    const int nLinesOnScreen = curEditor->GetCtrl()->LinesOnScreen();
     first -= (nLinesOnScreen / 2);
-    if(first < 0) first = 0;
+    if (first < 0)
+        first = 0;
 
     // however, the last line is set according to the actual editor
-    int last = nLinesOnScreen + first;
+    const int last = nLinesOnScreen + first;
 
     PatchUpHighlights(first, last);
     curEditor->GetCtrl()->SetFirstVisibleLine(first);
@@ -288,10 +266,10 @@ void ZoomNavigator::OnPreviewClicked(wxMouseEvent& e)
 
 void ZoomNavigator::DoCleanup()
 {
-    SetEditorText(NULL);
+    SetEditorText(nullptr);
     m_markerFirstLine = wxNOT_FOUND;
     m_markerLastLine = wxNOT_FOUND;
-    m_text->UpdateLexer(NULL);
+    m_text->UpdateLexer(nullptr);
 }
 
 void ZoomNavigator::OnSettings(wxCommandEvent& e)
@@ -305,12 +283,12 @@ void ZoomNavigator::OnSettingsChanged(wxCommandEvent& e)
     e.Skip();
     m_config->Reload();
     znConfigItem data;
-    if(m_config->ReadItem(&data)) {
+    if (m_config->ReadItem(&data)) {
         m_enabled = data.IsEnabled();
 
-        if(!m_enabled) {
+        if (!m_enabled) {
             // Clear selection
-            m_text->UpdateText(NULL);
+            m_text->UpdateText(nullptr);
 
         } else {
             DoCleanup();
@@ -323,9 +301,10 @@ void ZoomNavigator::OnFileSaved(clCommandEvent& e)
 {
     e.Skip();
 
-    if(e.GetString() == m_curfile) {
+    if (e.GetString() == m_curfile) {
         // Update the file content
         m_curfile.Clear();
+        m_markerFirstLine = m_markerLastLine = wxNOT_FOUND; // forces a scrolling
         DoUpdate();
     }
 }
@@ -353,28 +332,13 @@ void ZoomNavigator::OnInitDone(wxCommandEvent& e)
 {
     e.Skip();
     m_startupCompleted = true;
+    m_text->Startup();
 }
 
-void ZoomNavigator::OnIdle(wxIdleEvent& e)
+void ZoomNavigator::OnIdle(wxIdleEvent& e) { e.Skip(); }
+
+void ZoomNavigator::OnTimer(wxTimerEvent& event)
 {
-    e.Skip();
+    wxUnusedVar(event);
     DoUpdate();
 }
-
-void ZoomNavigator::OnToggleTab(clCommandEvent& event)
-{
-    if(event.GetString() != ZOOM_PANE_TITLE) {
-        event.Skip();
-        return;
-    }
-
-    if(event.IsSelected()) {
-        // show it
-        m_mgr->GetWorkspacePaneNotebook()->InsertPage(0, zoompane, ZOOM_PANE_TITLE, true);
-    } else {
-        int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(ZOOM_PANE_TITLE);
-        if(where != wxNOT_FOUND) {
-            m_mgr->GetWorkspacePaneNotebook()->RemovePage(where);
-        }
-    }
-}
