@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : zoomnavigator.h
 //
 // -------------------------------------------------------------------------
@@ -33,54 +33,47 @@
 #ifndef __ZoomNavigator__
 #define __ZoomNavigator__
 
-#include "plugin.h"
-#include "zoomtext.h"
-#include <wx/timer.h>
-#include <set>
 #include "cl_command_event.h"
+#include "plugin.h"
 
-extern const wxString ZOOM_PANE_TITLE;
-
-class ZoomNavUpdateTimer;
+class wxTimer;
+class ZoomText;
 
 class ZoomNavigator : public IPlugin
 {
-    IManager* mgr;
-    wxPanel* zoompane;
-    wxEvtHandler* m_topWindow;
-    ZoomText* m_text;
-    int m_markerFirstLine;
-    int m_markerLastLine;
-    bool m_enabled;
-    clConfig* m_config;
-    int m_lastLine;
-    bool m_startupCompleted;
+    wxPanel* m_zoompane = nullptr;
+    wxEvtHandler* m_topWindow = nullptr;
+    ZoomText* m_text = nullptr;
+    int m_markerFirstLine = wxNOT_FOUND;
+    int m_markerLastLine = wxNOT_FOUND;
+    bool m_enabled = false;
+    clConfig* m_config = nullptr;
+    bool m_startupCompleted = false;
     wxString m_curfile;
+    wxTimer* m_timer = nullptr;
 
 protected:
     void DoInitialize();
-    bool IsZoomPaneDetached();
     void PatchUpHighlights(const int first, const int last);
     void SetEditorText(IEditor* editor);
-    void SetZoomTextScrollPosToMiddle(wxStyledTextCtrl* stc);
+    void SetZoomTextScrollPosToMiddle(wxStyledTextCtrl& stc);
     void DoUpdate();
     void DoCleanup();
+    void OnTimer(wxTimerEvent& event);
 
 public:
-    ZoomNavigator(IManager* manager);
-    ~ZoomNavigator();
+    explicit ZoomNavigator(IManager* manager);
+    ~ZoomNavigator() override = default;
 
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void HookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnHookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void HookPopupMenu(wxMenu* menu, MenuType type) override;
+    void UnPlug() override;
 
     void OnIdle(wxIdleEvent& e);
-
     void OnShowHideClick(wxCommandEvent& e);
     void OnPreviewClicked(wxMouseEvent& e);
     void OnSettings(wxCommandEvent& e);
@@ -89,7 +82,6 @@ public:
     void OnWorkspaceClosed(wxCommandEvent& e);
     void OnEnablePlugin(wxCommandEvent& e);
     void OnInitDone(wxCommandEvent& e);
-    void OnToggleTab(clCommandEvent& event);
 };
 
 #endif // ZoomNavigator
