@@ -20,19 +20,22 @@ protected:
     int m_exitCode;
     eCommandType m_commandType;
     wxString m_buildSettingsXml;
+    bool m_generateCompileCommands;
+	bool m_generateCompilerFlags = false;
 
 protected:
     bool DoParseCommandLine(wxCmdLineParser& parser);
     void DoExecCommand(const wxString& command);
-
+    void DoGenerateCompileCommands();
     void Notice(const wxString& msg);
     void Error(const wxString& msg);
     void Info(const wxString& msg);
     void Out(const wxString& msg);
-
+    void Bye();
+    
 public:
     clMakeGeneratorApp();
-    virtual ~clMakeGeneratorApp();
+    virtual ~clMakeGeneratorApp() = default;
 
     void DoExitApp();
     virtual bool OnInit();
