@@ -1,20 +1,15 @@
-#include <wx/stc/stc.h>
-#include <wx/treectrl.h>
-#include <wx/filename.h>
-#include <wx/tokenzr.h>
-#include <lexer_configuration.h>
-#include <editor_config.h>
 #include "php_utils.h"
-#include <wx/uri.h>
-#include <wx/base64.h>
-#include <map>
+
+#include "PHP/PHPSourceFile.h"
+#include "StringUtils.h"
+#include "fileextmanager.h"
 #include "php_project.h"
 #include "php_workspace.h"
-#include "json_node.h"
-#include "file_logger.h"
-#include "fileutils.h"
-#include "PHPSourceFile.h"
-#include "fileextmanager.h"
+
+#include <wx/base64.h>
+#include <wx/filename.h>
+#include <wx/stc/stc.h>
+#include <wx/uri.h>
 
 bool IsPHPCommentOrString(int styleAtPos)
 {
@@ -75,25 +70,6 @@ bool IsPHPFileByExt(const wxString& filename)
     // return false;
 }
 
-wxString GetResourceDirectory()
-{
-    wxFileName fn;
-#ifdef __WXGTK__
-    fn = wxFileName(PLUGINS_DIR, "");
-    fn.AppendDir("resources");
-#else
-#ifdef USE_POSIX_LAYOUT
-    fn = wxFileName(clStandardPaths::Get().GetPluginsDirectory());
-#else
-    fn = wxFileName(clStandardPaths::Get().GetExecutablePath());
-    fn.AppendDir("plugins");
-#endif
-    fn.AppendDir("resources");
-#endif
-    fn.AppendDir("php");
-    return fn.GetPath();
-}
-
 wxString URIToFileName(const wxString& uriFileName)
 {
     wxString filename = wxURI::Unescape(uriFileName);
@@ -107,7 +83,7 @@ wxString URIToFileName(const wxString& uriFileName)
     return wxFileName(filename).GetFullPath();
 }
 
-static wxString URIEncode(const wxString& inputStr) { return FileUtils::EncodeURI(inputStr); }
+static wxString URIEncode(const wxString& inputStr) { return StringUtils::EncodeURI(inputStr); }
 
 wxString FileNameToURI(const wxString& filename)
 {
@@ -116,8 +92,7 @@ wxString FileNameToURI(const wxString& filename)
         sourceFullPath.Prepend(FILE_SCHEME);
     }
     sourceFullPath.Replace("\\", "/");
-    while(sourceFullPath.Replace("//", "/")) {
-    }
+    while(sourceFullPath.Replace("//", "/")) {}
     //    wxURI uri(sourceFullPath);
     sourceFullPath = URIEncode(sourceFullPath);
     sourceFullPath.Replace("file:", FILE_SCHEME);
@@ -130,36 +105,35 @@ wxString Base64Encode(const wxString& str)
     return encodedString;
 }
 
-static void DecodeFileName(wxString& filename) { filename = FileUtils::DecodeURI(filename); }
+static void DecodeFileName(wxString& filename) { filename = StringUtils::DecodeURI(filename); }
 
 wxString MapRemoteFileToLocalFile(const wxString& remoteFile)
 {
     // Check that a workspace is opened
-    if(!PHPWorkspace::Get()->IsOpen()) return remoteFile;
+    if(!PHPWorkspace::Get()->IsOpen())
+        return remoteFile;
 
     // Sanity
     PHPProject::Ptr_t pProject = PHPWorkspace::Get()->GetActiveProject();
-    if(!pProject) return remoteFile;
+    if(!pProject)
+        return remoteFile;
 
     // Map filename file attribute returned by xdebug to local filename
     wxString filename = remoteFile;
 
     // Remote the "file://" from the file path
     filename.StartsWith(FILE_SCHEME, &filename);
-    CL_DEBUG("filename => %s", filename);
 
     // On Windows, the file is returned like (after removing the file://)
     // /C:/Http/htdocs/file.php - remote the leading "/"
     wxRegEx reMSWPrefix("/[a-zA-Z]{1}:/");
     if(reMSWPrefix.IsValid() && reMSWPrefix.Matches(filename)) {
         // Windows file
-        CL_DEBUG("filename => %s", filename);
         filename.Remove(0, 1);
     }
 
     // Remove URI encoding ("%20"=>" " etc)
     DecodeFileName(filename);
-    CL_DEBUG("filename => %s", filename);
 
     // First check if the remote file exists locally
     if(wxFileName(filename).Exists()) {
@@ -167,13 +141,8 @@ wxString MapRemoteFileToLocalFile(const wxString& remoteFile)
     }
 
     // Use the active project file mapping
-    const PHPProjectSettingsData& settings = pProject->GetSettings();
-    const JSONElement::wxStringMap_t& mapping = settings.GetFileMapping();
-    JSONElement::wxStringMap_t::const_iterator iter = mapping.begin();
-    for(; iter != mapping.end(); ++iter) {
-        const wxString& localFolder = iter->first;
-        const wxString& remoteFolder = iter->second;
-        if(filename.StartsWith(remoteFolder)) {
+    for (const auto& [localFolder, remoteFolder] : pProject->GetSettings().GetFileMapping()) {
+        if (filename.StartsWith(remoteFolder)) {
             filename.Replace(remoteFolder, localFolder);
             return wxFileName(filename).GetFullPath();
         }
