@@ -1,25 +1,24 @@
 #include "php_workspace.h"
+
+#include "clWorkspaceManager.h"
+#include "cl_command_event.h"
+#include "dirtraverser.h"
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "globals.h"
+#include "macros.h"
+#include "php_code_completion.h"
+#include "php_configuration_data.h"
+#include "php_event.h"
+#include "php_parser_thread.h"
 #include "php_strings.h"
-#include <dirtraverser.h>
-#include <plugin.h>
-#include <globals.h>
+#include "plugin.h"
+#include "wxCodeCompletionBox.h"
+
+#include <algorithm>
 #include <wx/busyinfo.h>
 #include <wx/msgdlg.h>
-#include <event_notifier.h>
-#include <macros.h>
-#include "php_event.h"
-#include <cl_command_event.h>
-#include <wx/msgdlg.h>
-#include "php_code_completion.h"
-#include "php_strings.h"
-#include <wx/msgdlg.h>
-#include "php_parser_thread.h"
 #include <wx/progdlg.h>
-#include "cl_command_event.h"
-#include "php_strings.h"
-#include "php_configuration_data.h"
-#include "clWorkspaceManager.h"
-#include <algorithm>
 
 #ifndef __WXMSW__
 #include <errno.h>
@@ -27,13 +26,22 @@
 
 PHPWorkspace* PHPWorkspace::ms_instance = 0;
 
+wxDEFINE_EVENT(wxEVT_PHP_WORKSPACE_FILES_SYNC_START, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_PHP_WORKSPACE_FILES_SYNC_END, clCommandEvent);
+
 PHPWorkspace::PHPWorkspace()
     : m_manager(NULL)
+    , m_projectSyncOwner(NULL)
 {
     SetWorkspaceType(PHPStrings::PHP_WORKSPACE_VIEW_LABEL);
+    Bind(wxEVT_PHP_PROJECT_FILES_SYNC_END, &PHPWorkspace::OnProjectSyncEnd, this);
 }
 
-PHPWorkspace::~PHPWorkspace() { m_workspaceFile.Clear(); }
+PHPWorkspace::~PHPWorkspace()
+{
+    m_workspaceFile.Clear();
+    Unbind(wxEVT_PHP_PROJECT_FILES_SYNC_END, &PHPWorkspace::OnProjectSyncEnd, this);
+}
 
 PHPWorkspace* PHPWorkspace::Get()
 {
@@ -53,7 +61,8 @@ void PHPWorkspace::Release()
 
 bool PHPWorkspace::Close(bool saveBeforeClose, bool saveSession)
 {
-    SendCmdEvent(wxEVT_WORKSPACE_CLOSING);
+    clWorkspaceEvent closing_event(wxEVT_WORKSPACE_CLOSING);
+    EventNotifier::Get()->ProcessEvent(closing_event);
 
     if(IsOpen()) {
         if(m_manager && saveSession) {
@@ -70,16 +79,20 @@ bool PHPWorkspace::Close(bool saveBeforeClose, bool saveSession)
 
     // Close the code completion lookup table
     PHPCodeCompletion::Instance()->Close();
+    PHPParserThread::Clear();
 
     PHPEvent phpEvent(wxEVT_PHP_WORKSPACE_CLOSED);
     EventNotifier::Get()->AddPendingEvent(phpEvent);
 
     // Notify that workspace has been opened to the plugins
-    SendCmdEvent(wxEVT_WORKSPACE_CLOSED);
+    clWorkspaceEvent closed_event(wxEVT_WORKSPACE_CLOSED);
+    EventNotifier::Get()->ProcessEvent(closed_event);
+
+    wxCodeCompletionBox::SetStripHtmlTags(false);
     return true;
 }
 
-bool PHPWorkspace::Open(const wxString& filename, bool createIfMissing)
+bool PHPWorkspace::Open(const wxString& filename, wxEvtHandler* view, bool createIfMissing)
 {
     // Close the currently opened workspace
     if(IsOpen()) {
@@ -124,7 +137,7 @@ bool PHPWorkspace::Open(const wxString& filename, bool createIfMissing)
     // set the working directory to the workspace path
     ::wxSetWorkingDirectory(m_workspaceFile.GetPath());
 
-    JSONRoot root(m_workspaceFile);
+    JSON root(m_workspaceFile);
     FromJSON(root.toElement());
 
     // We open the symbols database manually here and _not_ via an event
@@ -137,22 +150,21 @@ bool PHPWorkspace::Open(const wxString& filename, bool createIfMissing)
     EventNotifier::Get()->AddPendingEvent(phpEvent);
 
     // Notify that the a new workspace is loaded
-    // This time send the standard codelite event
+    // This time send the standard CodeLite event
     // this is important so other plugins such as Svn, Git
     // want to adjust their paths according to the new workspace
     {
-        wxCommandEvent event(wxEVT_WORKSPACE_LOADED);
+        clWorkspaceEvent event(wxEVT_WORKSPACE_LOADED);
+        event.SetFileName(GetFilename().GetFullPath());
         event.SetString(GetFilename().GetFullPath());
+        event.SetWorkspaceType(GetWorkspaceType());
         EventNotifier::Get()->AddPendingEvent(event);
     }
 
-    wxBusyInfo busy(_("Scanning for workspace files..."), EventNotifier::Get()->TopFrame());
-    wxYieldIfNeeded();
-
-    wxArrayString dummy;
-    GetWorkspaceFiles(dummy);
-
-    // progress->Destroy();
+    // wxBusyInfo busy(_("Scanning for workspace files..."), EventNotifier::Get()->TopFrame());
+    // wxYieldIfNeeded();
+    wxBusyCursor bc;
+    SyncWithFileSystemAsync(view);
 
     // Perform a quick re-parse of the workspace
     ParseWorkspace(false);
@@ -160,10 +172,12 @@ bool PHPWorkspace::Open(const wxString& filename, bool createIfMissing)
     // set this workspace as the active one
     clWorkspaceManager::Get().SetWorkspace(this);
 
-    // and finally, request codelite to keep this workspace in the recently opened workspace list
+    // and finally, request CodeLite to keep this workspace in the recently opened workspace list
     clGetManager()->AddWorkspaceToRecentlyUsedList(GetFilename());
 
     CallAfter(&PHPWorkspace::RestoreWorkspaceSession);
+
+    wxCodeCompletionBox::SetStripHtmlTags(true);
     // Change the workspace extension
     return true;
 }
@@ -177,7 +191,8 @@ void PHPWorkspace::CreateProject(const PHPProject::CreateData& createData)
     projectName << createData.name << ".phprj";
     fnProjectFileName.SetFullName(projectName);
 
-    if(HasProject(projectName)) return;
+    if(HasProject(projectName))
+        return;
 
     // Ensure that the path to the file exists
     fnProjectFileName.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
@@ -203,8 +218,6 @@ void PHPWorkspace::CreateProject(const PHPProject::CreateData& createData)
     ParseWorkspace(false);
 }
 
-bool PHPWorkspace::IsProjectExists(const wxString& project) { return HasProject(project); }
-
 const PHPProject::Map_t& PHPWorkspace::GetProjects() const { return m_projects; }
 
 void PHPWorkspace::DeleteProject(const wxString& project)
@@ -223,17 +236,17 @@ void PHPWorkspace::DeleteProject(const wxString& project)
 
 void PHPWorkspace::SetProjectActive(const wxString& project)
 {
-    PHPProject::Map_t::iterator iter = m_projects.begin();
     PHPProject::Ptr_t activeProject;
-    for(; iter != m_projects.end(); ++iter) {
-        if(iter->first == project) {
-            activeProject = iter->second;
+
+    for (auto& p : m_projects) {
+        if (p.first == project) {
+            activeProject = p.second;
         }
-        bool newState = (iter->first == project);
-        if(iter->second->IsActive() != newState) {
-            iter->second->SetIsActive(newState);
+        bool newState = (p.first == project);
+        if (p.second->IsActive() != newState) {
+            p.second->SetIsActive(newState);
             // Save the change to the file system
-            iter->second->Save();
+            p.second->Save();
         }
     }
 
@@ -248,65 +261,23 @@ void PHPWorkspace::SetProjectActive(const wxString& project)
 
 void PHPWorkspace::GetWorkspaceFiles(wxStringSet_t& workspaceFiles, wxProgressDialog* progress) const
 {
-    PHPProject::Map_t::const_iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); ++iter) {
-        const wxArrayString& files = iter->second->GetFiles(progress);
+    for (const auto& [_, project] : m_projects) {
+        const wxArrayString& files = project->GetFiles(progress);
         workspaceFiles.insert(files.begin(), files.end());
     }
 }
 
-void PHPWorkspace::GetWorkspaceFiles(wxStringSet_t& workspaceFiles, const wxString& filter) const
-{
-    wxStringSet_t all_files;
-    GetWorkspaceFiles(all_files);
-    if(filter.IsEmpty()) {
-        workspaceFiles.swap(all_files);
-
-    } else {
-        wxStringSet_t::iterator iter = all_files.begin();
-        for(; iter != all_files.end(); ++iter) {
-            wxFileName fn(*iter);
-            if(fn.GetName().Contains(filter)) {
-                workspaceFiles.insert(*iter);
-            }
-        }
-    }
-}
-
-void PHPWorkspace::DoNotifyFilesRemoved(const wxArrayString& files)
-{
-    if(!files.IsEmpty()) {
-
-        wxBusyInfo info(_("Updating workspace..."));
-        wxYieldIfNeeded();
-        EventNotifier::Get()->PostFileRemovedEvent(files);
-    }
-}
-
 wxString PHPWorkspace::GetActiveProjectName() const
 {
-    PHPProject::Map_t::const_iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); ++iter) {
-        if(iter->second->IsActive()) {
-            return iter->second->GetName();
+    for (const auto& [_, project] : m_projects) {
+        if (project->IsActive()) {
+            return project->GetName();
         }
     }
     return "";
 }
 
-void PHPWorkspace::DelFile(const wxString& project, const wxString& filename)
-{
-    PHPProject::Ptr_t proj = GetProject(project);
-    CHECK_PTR_RET(proj);
-
-    wxArrayString files;
-    files.Add(filename);
-    proj->FilesDeleted(files, true);
-}
-
-bool PHPWorkspace::RunProject(bool debugging,
-                              const wxString& urlOrFilePath,
-                              const wxString& projectName,
+bool PHPWorkspace::RunProject(bool debugging, const wxString& urlOrFilePath, const wxString& projectName,
                               const wxString& xdebugSessionName)
 {
     wxString projectToRun = projectName;
@@ -328,12 +299,12 @@ bool PHPWorkspace::HasProject(const wxString& projectname) const
     return m_projects.count(projectname);
 }
 
-void PHPWorkspace::FromJSON(const JSONElement& e)
+void PHPWorkspace::FromJSON(const JSONItem& e)
 {
     m_projects.clear();
     if(e.hasNamedObject("projects")) {
         PHPProject::Ptr_t firstProject;
-        JSONElement projects = e.namedObject("projects");
+        JSONItem projects = e.namedObject("projects");
         int count = projects.arraySize();
         for(int i = 0; i < count; ++i) {
             PHPProject::Ptr_t p(new PHPProject());
@@ -367,9 +338,9 @@ void PHPWorkspace::FromJSON(const JSONElement& e)
 #define PHP_WORKSPACE_VERSION wxString("1.0")
 #define PHP_WORKSPACE_IDE wxString("CodeLite")
 
-JSONElement PHPWorkspace::ToJSON(JSONElement& e) const
+JSONItem PHPWorkspace::ToJSON(JSONItem& e) const
 {
-    JSONElement metadata = JSONElement::createObject("metadata");
+    JSONItem metadata = JSONItem::createObject("metadata");
     e.append(metadata);
 
     metadata.addProperty("version", PHP_WORKSPACE_VERSION);
@@ -377,12 +348,11 @@ JSONElement PHPWorkspace::ToJSON(JSONElement& e) const
     metadata.addProperty("type", wxString("php"));
 
     // Store the list of files
-    JSONElement projectsArr = JSONElement::createArray("projects");
+    JSONItem projectsArr = JSONItem::createArray("projects");
     e.append(projectsArr);
 
-    PHPProject::Map_t::const_iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); ++iter) {
-        wxFileName projectFile = iter->second->GetFilename();
+    for (const auto& [_, project] : m_projects) {
+        wxFileName projectFile = project->GetFilename();
         projectFile.MakeRelativeTo(m_workspaceFile.GetPath());
         projectsArr.arrayAppend(projectFile.GetFullPath(wxPATH_UNIX));
     }
@@ -406,8 +376,8 @@ void PHPWorkspace::Save()
         return;
     }
     // serialize the workspace and store it to disk
-    JSONRoot root(cJSON_Object);
-    JSONElement ele = root.toElement();
+    JSON root(cJSON_Object);
+    JSONItem ele = root.toElement();
     ToJSON(ele);
     root.save(m_workspaceFile);
 }
@@ -428,8 +398,8 @@ bool PHPWorkspace::Create(const wxString& filename)
     }
 
     // create it
-    JSONRoot root(cJSON_Object);
-    JSONElement ele = root.toElement();
+    JSON root(cJSON_Object);
+    JSONItem ele = root.toElement();
     ToJSON(ele);
     root.save(fn);
     return true;
@@ -450,7 +420,8 @@ void PHPWorkspace::Rename(const wxString& newname)
     if(!::wxRenameFile(m_workspaceFile.GetFullPath(), new_path.GetFullPath())) {
         wxString msg;
         msg << _("Failed to rename workspace file:\n'") << m_workspaceFile.GetFullName() << _("'\nto:\n'")
-            << new_path.GetFullName() << "'\n" << strerror(errno);
+            << new_path.GetFullName() << "'\n"
+            << strerror(errno);
         ::wxMessageBox(msg, "CodeLite", wxOK | wxCENTER | wxICON_ERROR, EventNotifier::Get()->TopFrame());
         return;
     }
@@ -468,39 +439,14 @@ void PHPWorkspace::Rename(const wxString& newname)
     EventNotifier::Get()->AddPendingEvent(evtRetag);
 }
 
-void PHPWorkspace::DoPromptWorkspaceModifiedDialog()
-{
-    wxMessageDialog dlg(FRAME,
-                        _("Workspace file modified externally. Would you like to reload the workspace?"),
-                        "CodeLite",
-                        wxYES_NO | wxCENTER);
-    dlg.SetYesNoLabels(_("Reload Workspace"), _("Ignore"));
-
-    int answer = dlg.ShowModal();
-    if(answer == wxID_YES) {
-        wxCommandEvent evtReload(wxEVT_COMMAND_MENU_SELECTED, XRCID("reload_workspace"));
-        FRAME->GetEventHandler()->AddPendingEvent(evtReload);
-    }
-}
-
-void PHPWorkspace::GetWorkspaceFiles(wxArrayString& workspaceFiles, wxProgressDialog* progress) const
-{
-    wxStringSet_t files;
-    GetWorkspaceFiles(files, progress);
-    workspaceFiles.clear();
-    wxStringSet_t::const_iterator iter = files.begin();
-    for(; iter != files.end(); ++iter) {
-        workspaceFiles.Add(*iter);
-    }
-}
-
 void PHPWorkspace::ParseWorkspace(bool full)
 {
     // Request for parsing
     if(full) {
-        // a full parsing is needed, stop the paser thread
+        // a full parsing is needed, stop the parser thread
         // close the database, delete it and recreate it
         // then, restart the parser thread
+        PHPParserThread::Clear();
         PHPParserThread::Release(); // Stop and wait the thread terminates
 
         // Close the CC manager
@@ -511,7 +457,7 @@ void PHPWorkspace::ParseWorkspace(bool full)
         fnDatabaseFile.AppendDir(".codelite");
 
         wxLogNull noLog;
-        bool bRemoved = ::wxRemoveFile(fnDatabaseFile.GetFullPath());
+        bool bRemoved = clRemoveFile(fnDatabaseFile.GetFullPath());
         wxUnusedVar(bRemoved);
 
         // Start the managers again
@@ -541,19 +487,11 @@ void PHPWorkspace::RestoreWorkspaceSession()
     }
 }
 
-void PHPWorkspace::SyncWithFileSystem()
-{
-    PHPProject::Map_t::const_iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); ++iter) {
-        iter->second->SynchWithFileSystem();
-    }
-}
-
 PHPProject::Ptr_t PHPWorkspace::GetProjectForFile(const wxFileName& filename) const
 {
-    PHPProject::Map_t::const_iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); ++iter) {
-        if(iter->second->HasFile(filename)) return iter->second;
+    for (auto& [_, project] : m_projects) {
+        if (project->HasFile(filename))
+            return project;
     }
     return PHPProject::Ptr_t(NULL);
 }
@@ -600,25 +538,23 @@ bool PHPWorkspace::AddProject(const wxFileName& projectFile, wxString& errmsg)
 bool PHPWorkspace::CanCreateProjectAtPath(const wxFileName& projectFileName, bool prompt) const
 {
     wxString newpath = projectFileName.GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME);
-    const PHPProject::Map_t& projects = GetProjects();
-    PHPProject::Map_t::const_iterator iter = projects.begin();
-    for(; iter != projects.end(); ++iter) {
-        if(newpath.StartsWith(iter->second->GetFilename().GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME))) {
+    for (const auto& [_, project] : GetProjects()) {
+        if (newpath.StartsWith(project->GetFilename().GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME))) {
             // The new path is a sub folder of a project
-            if(prompt) {
+            if (prompt) {
                 wxString message;
                 message << _("Unable to create a project at the selected path\n") << _("Path '") << newpath
-                        << _("' is already part of project '") << iter->second->GetName() << "'";
+                        << _("' is already part of project '") << project->GetName() << "'";
                 ::wxMessageBox(message, "CodeLite", wxOK | wxICON_ERROR | wxCENTER);
             }
             return false;
 
-        } else if(iter->second->GetFilename().GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME).StartsWith(newpath)) {
+        } else if (project->GetFilename().GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME).StartsWith(newpath)) {
             // The new project is a parent of an existing project
-            if(prompt) {
+            if (prompt) {
                 wxString message;
                 message << _("Unable to create a project at the selected path\n") << _("Project '")
-                        << iter->second->GetName() << _("' is located under this path");
+                        << project->GetName() << _("' is located under this path");
                 ::wxMessageBox(message, "CodeLite", wxOK | wxICON_ERROR | wxCENTER);
             }
             return false;
@@ -661,7 +597,81 @@ void PHPWorkspace::GetProjectFiles(const wxString& projectName, wxArrayString& f
 
 void PHPWorkspace::GetWorkspaceFiles(wxArrayString& files) const
 {
-    std::for_each(m_projects.begin(), m_projects.end(), [&](const PHPProject::Map_t::value_type& v) {
-        v.second->GetFilesArray(files);
-    });
+    for (const auto& p : m_projects) {
+        p.second->GetFilesArray(files);
+    }
 }
+
+void PHPWorkspace::SyncWithFileSystemAsync(wxEvtHandler* owner)
+{
+    m_inSyncProjects.clear();
+    m_projectSyncOwner = owner;
+
+    if(owner) {
+        clCommandEvent event(wxEVT_PHP_WORKSPACE_FILES_SYNC_START);
+        owner->AddPendingEvent(event);
+    }
+
+    if(!m_projects.empty()) {
+        for (auto& [projectName, project] : m_projects) {
+            m_inSyncProjects.insert(projectName);
+            project->SyncWithFileSystemAsync(this);
+        }
+    } else {
+        if(owner) {
+            // Fire sync-ended event
+            clCommandEvent endEvent(wxEVT_PHP_WORKSPACE_FILES_SYNC_END);
+            owner->AddPendingEvent(endEvent);
+        }
+    }
+}
+
+void PHPWorkspace::OnProjectSyncEnd(clCommandEvent& event)
+{
+    const wxString& name = event.GetString();
+    if(m_inSyncProjects.count(name) == 0) {
+        clWARNING() << "PHPWorkspace::OnProjectSyncEnd: unable to find project '" << name << "' in the workspace..."
+                    << clEndl;
+        return;
+    }
+
+    clDEBUG() << "PHPWorkspace::OnProjectSyncEnd: project" << name << "completed sync" << clEndl;
+    m_inSyncProjects.erase(name);
+
+    // Load the project
+    PHPProject::Ptr_t pProj = GetProject(name);
+    CHECK_PTR_RET(pProj);
+
+    // Update the project files
+    pProj->SetFiles(event.GetStrings());
+
+    if(m_inSyncProjects.empty()) {
+        clDEBUG() << "PHPWorkspace::OnProjectSyncEnd: all projects completed sync" << clEndl;
+        if(m_projectSyncOwner) {
+            clCommandEvent endEvent(wxEVT_PHP_WORKSPACE_FILES_SYNC_END);
+            m_projectSyncOwner->AddPendingEvent(endEvent);
+        }
+    }
+}
+wxFileName PHPWorkspace::GetProjectFileName(const wxString& projectName) const
+{
+    PHPProject::Ptr_t p = GetProject(projectName);
+    if(!p) {
+        return wxFileName();
+    }
+    return p->GetFilename();
+}
+
+wxArrayString PHPWorkspace::GetWorkspaceProjects() const
+{
+    wxArrayString projectArr;
+    PHPProject::Map_t projects = GetProjects();
+    for (const auto& p : projects) {
+        projectArr.Add(p.second->GetName());
+    }
+    return projectArr;
+}
+
+wxString PHPWorkspace::GetName() const { return m_workspaceFile.GetName(); }
+
+wxString PHPWorkspace::GetDebuggerName() const { return "xdebug"; }
\ No newline at end of file
