@@ -1,15 +1,13 @@
 #include "XDebugTester.h"
+
+#include "JSON.h"
+#include "Zip/clZipReader.h"
 #include "cl_standard_paths.h"
-#include <wx/filename.h>
-#include "clZipReader.h"
-#include "phpexecutor.h"
-#include <wx/msgdlg.h>
-#include "json_node.h"
 #include "php_configuration_data.h"
+#include "phpexecutor.h"
 
-XDebugTester::XDebugTester() {}
-
-XDebugTester::~XDebugTester() {}
+#include <wx/filename.h>
+#include <wx/msgdlg.h>
 
 bool XDebugTester::RunTest()
 {
@@ -27,8 +25,8 @@ bool XDebugTester::RunTest()
         PHPExecutor executor;
         wxString php_output;
         if(executor.RunScript(xdebugTesterScript.GetFullPath(), php_output)) {
-            JSONRoot root(php_output);
-            JSONElement rootElement = root.toElement();
+            JSON root(php_output);
+            JSONItem rootElement = root.toElement();
 
             //////////////////////////////////////////////////
             // Directives
