@@ -1,56 +1,52 @@
 #include "php.h"
-#include "php_utils.h"
-#include "php_open_resource_dlg.h"
-#include <wx/xrc/xmlres.h>
+
+#include "NewPHPProjectWizard.h"
+#include "PHPDebugPane.h"
+#include "PHPXDebugSetupWizard.h"
+#include "XDebugTester.h"
+#include "Zip/clZipReader.h"
+#include "bookmark_manager.h"
+#include "clSFTPEvent.h"
+#include "clWorkspaceManager.h"
+#include "clWorkspaceView.h"
+#include "cl_config.h"
+#include "cl_standard_paths.h"
+#include "ctags_manager.h"
+#include "detachedpanesinfo.h"
+#include "dockablepane.h"
 #include "editor_config.h"
-#include "php_settings_dlg.h"
-#include <detachedpanesinfo.h>
-#include <dockablepane.h>
-#include "php_code_completion.h"
-#include "quick_outline_dlg.h"
-#include <wx/app.h>
-#include <wx/filedlg.h>
+#include "evalpane.h"
+#include "event_notifier.h"
+#include "file_logger.h"
+#include "globals.h"
+#include "localsview.h"
 #include "new_php_workspace_dlg.h"
+#include "php_code_completion.h"
+#include "php_configuration_data.h"
+#include "php_editor_context_menu.h"
+#include "php_open_resource_dlg.h"
+#include "php_parser_thread.h"
+#include "php_settings_dlg.h"
+#include "php_strings.h"
+#include "php_utils.h"
 #include "php_workspace.h"
 #include "php_workspace_view.h"
-#include "php_strings.h"
-#include "php_editor_context_menu.h"
-#include <event_notifier.h>
-#include <plugin.h>
-#include <wx/richmsgdlg.h>
-#include <cl_config.h>
-#include <ctags_manager.h>
+#include "plugin.h"
+#include "quick_outline_dlg.h"
 #include "ssh_workspace_settings.h"
-#include "php_parser_thread.h"
-#include <file_logger.h>
-#include "PHPDebugPane.h"
-#include <cl_standard_paths.h>
+#include "wxCodeCompletionBox.h"
 #include "xdebugevent.h"
-#include "localsview.h"
-#include "evalpane.h"
-#include "XDebugTester.h"
-#include "clZipReader.h"
-#include "cl_standard_paths.h"
-#include "php_configuration_data.h"
-#include "PHPLocator.h"
-#include <wx/regex.h>
-#include "bookmark_manager.h"
-#include "NewPHPProjectWizard.h"
-#include "PHPXDebugSetupWizard.h"
-#include "globals.h"
-#include "clWorkspaceView.h"
-#include "clWorkspaceManager.h"
-#include "clSFTPEvent.h"
 
-static PhpPlugin* thePlugin = NULL;
+#include <wx/app.h>
+#include <wx/filedlg.h>
+#include <wx/regex.h>
+#include <wx/richmsgdlg.h>
+#include <wx/xrc/xmlres.h>
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new PhpPlugin(manager);
-    }
-    return thePlugin;
+    return new PhpPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -73,10 +69,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
     , m_xdebugLocalsView(NULL)
     , m_xdebugEvalPane(NULL)
     , m_showWelcomePage(false)
-    , m_toggleToolbar(false)
 {
-    m_lint.Reset(new PHPLint(this));
-
     // Add new workspace type
     clWorkspaceManager::Get().RegisterWorkspace(new PHPWorkspace());
 
@@ -88,8 +81,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
     PHPWorkspace::Get()->SetPluginManager(m_mgr);
     XDebugManager::Initialize(this);
 
-    // BitmapLoader::RegisterImage(FileExtManager::TypeWorkspacePHP, images.Bitmap("m_bmpPhpWorkspace"));
-
     // Add our UI
     // create tab (possibly detached)
     m_workspaceView = new PHPWorkspaceView(m_mgr->GetWorkspaceView()->GetBook(), m_mgr);
@@ -103,42 +94,35 @@ PhpPlugin::PhpPlugin(IManager* manager)
     PHPEditorContextMenu::Instance()->SetManager(m_mgr);
 
     // Connect events
-    EventNotifier::Get()->Connect(
-        wxEVT_CC_SHOW_QUICK_OUTLINE, clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_DBG_UI_DELTE_ALL_BREAKPOINTS, clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEventHandler(PhpPlugin::OnNewWorkspace), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_NEW_PROJECT_WIZARD_SHOWING, clNewProjectEventHandler(PhpPlugin::OnNewProject), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_NEW_PROJECT_WIZARD_FINISHED, clNewProjectEventHandler(PhpPlugin::OnNewProjectFinish), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_IS_WORKSPACE_OPEN, clCommandEventHandler(PhpPlugin::OnIsWorkspaceOpen), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_CLOSE_WORKSPACE, clCommandEventHandler(PhpPlugin::OnCloseWorkspace), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_OPEN_WORKSPACE, clCommandEventHandler(PhpPlugin::OnOpenWorkspace), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_RELOAD_WORKSPACE, clCommandEventHandler(PhpPlugin::OnReloadWorkspace), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_OPEN_RESOURCE, wxCommandEventHandler(PhpPlugin::OnOpenResource), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_GET_WORKSPACE_FILES, wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-                                  wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
-                                  NULL,
+    EventNotifier::Get()->Connect(wxEVT_CC_SHOW_QUICK_OUTLINE,
+                                  clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS,
+                                  clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEventHandler(PhpPlugin::OnNewWorkspace),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_NEW_PROJECT_WIZARD_SHOWING, clNewProjectEventHandler(PhpPlugin::OnNewProject),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_NEW_PROJECT_WIZARD_FINISHED,
+                                  clNewProjectEventHandler(PhpPlugin::OnNewProjectFinish), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_IS_WORKSPACE_OPEN, clCommandEventHandler(PhpPlugin::OnIsWorkspaceOpen),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_CLOSE_WORKSPACE, clCommandEventHandler(PhpPlugin::OnCloseWorkspace), NULL,
                                   this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_CMD_FIND_IN_FILES_DISMISSED, clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
-
-    EventNotifier::Get()->Connect(wxEVT_FILE_SAVED, clCommandEventHandler(PhpPlugin::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Bind(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, &PhpPlugin::OnReplaceInFiles, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_OPEN_WORKSPACE, clCommandEventHandler(PhpPlugin::OnOpenWorkspace), NULL,
+                                  this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_RELOAD_WORKSPACE, clCommandEventHandler(PhpPlugin::OnReloadWorkspace), NULL,
+                                  this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_OPEN_RESOURCE, wxCommandEventHandler(PhpPlugin::OnOpenResource), NULL,
+                                  this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_GET_WORKSPACE_FILES, wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles),
+                                  NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
+                                  wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_CMD_GET_ACTIVE_PROJECT_FILES,
+                                  wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_PHP_LOAD_URL, PHPEventHandler(PhpPlugin::OnLoadURL), NULL, this);
-    EventNotifier::Get()->Connect(
-        wxEVT_ALL_EDITORS_CLOSED, wxCommandEventHandler(PhpPlugin::OnAllEditorsClosed), NULL, this);
+    EventNotifier::Get()->Connect(wxEVT_ALL_EDITORS_CLOSED, wxCommandEventHandler(PhpPlugin::OnAllEditorsClosed), NULL,
+                                  this);
 
     EventNotifier::Get()->Bind(wxEVT_XDEBUG_SESSION_STARTED, &PhpPlugin::OnDebugStarted, this);
     EventNotifier::Get()->Bind(wxEVT_XDEBUG_SESSION_ENDED, &PhpPlugin::OnDebugEnded, this);
@@ -146,6 +130,11 @@ PhpPlugin::PhpPlugin(IManager* manager)
     EventNotifier::Get()->Connect(wxEVT_GOING_DOWN, clCommandEventHandler(PhpPlugin::OnGoingDown), NULL, this);
     EventNotifier::Get()->Bind(wxEVT_FILE_SYSTEM_UPDATED, &PhpPlugin::OnFileSysetmUpdated, this);
     EventNotifier::Get()->Bind(wxEVT_SAVE_SESSION_NEEDED, &PhpPlugin::OnSaveSession, this);
+
+    // Menu bar actions
+    wxTheApp->Bind(wxEVT_MENU, &PhpPlugin::OnRunXDebugDiagnostics, this, wxID_PHP_RUN_XDEBUG_DIAGNOSTICS);
+    wxTheApp->Bind(wxEVT_MENU, &PhpPlugin::OnMenuCommand, this, wxID_PHP_SETTINGS);
+
     CallAfter(&PhpPlugin::FinalizeStartup);
 
     // Extract all CC files from PHP.zip into the folder ~/.codelite/php-plugin/cc
@@ -157,13 +146,15 @@ PhpPlugin::PhpPlugin(IManager* manager)
         targetDir.AppendDir("php-plugin");
 
         // Don't extract the zip if one of the files on disk is newer or equal to the zip timestamp
-        wxFileName fnSampleFile(targetDir.GetPath(), "basic.php");
+        wxFileName fnSampleFile(targetDir.GetPath(), "version");
         fnSampleFile.AppendDir("cc");
         PHPConfigurationData config;
         if(!fnSampleFile.Exists() || // the sample file does not exists
                                      // Or the resource file (PHP.zip) is newer than the sample file
            (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
-
+            if(targetDir.DirExists()) {
+                targetDir.Rmdir(wxPATH_RMDIR_RECURSIVE);
+            }
             targetDir.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             zipReader.Extract("*", targetDir.GetPath());
 
@@ -182,31 +173,21 @@ PhpPlugin::PhpPlugin(IManager* manager)
             }
         }
     } else {
-        CL_WARNING("PHP: Could not locate PHP resources 'PHP.zip' => '%s'", phpResources.GetFullPath());
+        clWARNING() << "PHP: Could not locate PHP resources 'PHP.zip' =>" << phpResources.GetFullPath();
     }
+
+#if USE_SFTP
+    // Allocate SFTP handler
+    m_sftpHandler.reset(new PhpSFTPHandler());
+#endif // USE_SFTP
 }
 
-PhpPlugin::~PhpPlugin() {}
-
-bool PhpPlugin::IsWorkspaceViewDetached()
-{
-    DetachedPanesInfo dpi;
-    m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    wxArrayString detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(PHPStrings::PHP_WORKSPACE_VIEW_TITLE) != wxNOT_FOUND;
-}
-
-clToolBar* PhpPlugin::CreateToolBar(wxWindow* parent)
-{
-    // Create the toolbar to be used by the plugin
-    clToolBar* tb(NULL);
-    return tb;
-}
+void PhpPlugin::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void PhpPlugin::CreatePluginMenu(wxMenu* pluginsMenu)
 {
-    if(pluginsMenu->GetMenuBar()) {
-        DoPlaceMenuBar(pluginsMenu->GetMenuBar());
+    if(clGetManager()->GetMenuBar()) {
+        DoPlaceMenuBar(clGetManager()->GetMenuBar());
     }
 }
 
@@ -216,50 +197,41 @@ void PhpPlugin::HookPopupMenu(wxMenu* menu, MenuType type)
     wxUnusedVar(type);
 }
 
-void PhpPlugin::UnHookPopupMenu(wxMenu* menu, MenuType type)
-{
-    wxUnusedVar(menu);
-    wxUnusedVar(type);
-}
-
 void PhpPlugin::UnPlug()
 {
+#if USE_SFTP
+    m_sftpHandler.reset(nullptr);
+#endif // USE_SFTP
     XDebugManager::Free();
-    EventNotifier::Get()->Disconnect(
-        wxEVT_DBG_UI_DELTE_ALL_BREAKPOINTS, clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CC_SHOW_QUICK_OUTLINE, clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEventHandler(PhpPlugin::OnNewWorkspace), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_NEW_PROJECT_WIZARD_SHOWING, clNewProjectEventHandler(PhpPlugin::OnNewProject), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_NEW_PROJECT_WIZARD_FINISHED, clNewProjectEventHandler(PhpPlugin::OnNewProjectFinish), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_IS_WORKSPACE_OPEN, clCommandEventHandler(PhpPlugin::OnIsWorkspaceOpen), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_CLOSE_WORKSPACE, clCommandEventHandler(PhpPlugin::OnCloseWorkspace), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_OPEN_WORKSPACE, clCommandEventHandler(PhpPlugin::OnOpenWorkspace), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_RELOAD_WORKSPACE, clCommandEventHandler(PhpPlugin::OnReloadWorkspace), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_OPEN_RESOURCE, wxCommandEventHandler(PhpPlugin::OnOpenResource), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_GET_WORKSPACE_FILES, wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_FIND_IN_FILES_DISMISSED, clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-                                     wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
-                                     NULL,
+    EventNotifier::Get()->Disconnect(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS,
+                                     clDebugEventHandler(PhpPlugin::OnXDebugDeleteAllBreakpoints), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CC_SHOW_QUICK_OUTLINE,
+                                     clCodeCompletionEventHandler(PhpPlugin::OnShowQuickOutline), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEventHandler(PhpPlugin::OnNewWorkspace),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_NEW_PROJECT_WIZARD_SHOWING,
+                                     clNewProjectEventHandler(PhpPlugin::OnNewProject), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_NEW_PROJECT_WIZARD_FINISHED,
+                                     clNewProjectEventHandler(PhpPlugin::OnNewProjectFinish), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_IS_WORKSPACE_OPEN, clCommandEventHandler(PhpPlugin::OnIsWorkspaceOpen),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_CLOSE_WORKSPACE, clCommandEventHandler(PhpPlugin::OnCloseWorkspace),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_OPEN_WORKSPACE, clCommandEventHandler(PhpPlugin::OnOpenWorkspace), NULL,
                                      this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(PhpPlugin::OnFileSaved), NULL, this);
-    EventNotifier::Get()->Unbind(wxEVT_FILES_MODIFIED_REPLACE_IN_FILES, &PhpPlugin::OnReplaceInFiles, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_RELOAD_WORKSPACE, clCommandEventHandler(PhpPlugin::OnReloadWorkspace),
+                                     NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_OPEN_RESOURCE, wxCommandEventHandler(PhpPlugin::OnOpenResource), NULL,
+                                     this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_WORKSPACE_FILES,
+                                     wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
+                                     wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_ACTIVE_PROJECT_FILES,
+                                     wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_PHP_LOAD_URL, PHPEventHandler(PhpPlugin::OnLoadURL), NULL, this);
-    EventNotifier::Get()->Disconnect(
-        wxEVT_ALL_EDITORS_CLOSED, wxCommandEventHandler(PhpPlugin::OnAllEditorsClosed), NULL, this);
+    EventNotifier::Get()->Disconnect(wxEVT_ALL_EDITORS_CLOSED, wxCommandEventHandler(PhpPlugin::OnAllEditorsClosed),
+                                     NULL, this);
 
     EventNotifier::Get()->Unbind(wxEVT_XDEBUG_SESSION_STARTED, &PhpPlugin::OnDebugStarted, this);
     EventNotifier::Get()->Unbind(wxEVT_XDEBUG_SESSION_ENDED, &PhpPlugin::OnDebugEnded, this);
@@ -267,6 +239,10 @@ void PhpPlugin::UnPlug()
     EventNotifier::Get()->Unbind(wxEVT_FILE_SYSTEM_UPDATED, &PhpPlugin::OnFileSysetmUpdated, this);
     EventNotifier::Get()->Unbind(wxEVT_SAVE_SESSION_NEEDED, &PhpPlugin::OnSaveSession, this);
 
+    // Menu bar actions
+    wxTheApp->Unbind(wxEVT_MENU, &PhpPlugin::OnRunXDebugDiagnostics, this, wxID_PHP_RUN_XDEBUG_DIAGNOSTICS);
+    wxTheApp->Unbind(wxEVT_MENU, &PhpPlugin::OnMenuCommand, this, wxID_PHP_SETTINGS);
+
     SafelyDetachAndDestroyPane(m_debuggerPane, "XDebug");
     SafelyDetachAndDestroyPane(m_xdebugLocalsView, "XDebugLocals");
     SafelyDetachAndDestroyPane(m_xdebugEvalPane, "XDebugEval");
@@ -291,18 +267,19 @@ void PhpPlugin::UnPlug()
 
 void PhpPlugin::OnShowQuickOutline(clCodeCompletionEvent& e)
 {
-    IEditor* editor = dynamic_cast<IEditor*>(e.GetEditor());
-    if(editor) {
-        // we handle only .php files
-        if(!IsPHPFile(editor)) {
-            // get the position
-            e.Skip();
-            return;
-        }
-        PHPQuickOutlineDlg dlg(m_mgr->GetTheApp()->GetTopWindow(), editor, m_mgr);
-        dlg.ShowModal();
-        CallAfter(&PhpPlugin::SetEditorActive, editor);
+    e.Skip();
+    IEditor* editor = clGetManager()->FindEditor(e.GetFileName());
+    CHECK_PTR_RET(editor);
+
+    // we handle only .php files
+    if(!IsPHPFile(editor)) {
+        return;
     }
+    e.Skip(false);
+
+    PHPQuickOutlineDlg dlg(m_mgr->GetTheApp()->GetTopWindow(), editor, m_mgr);
+    dlg.ShowModal();
+    CallAfter(&PhpPlugin::SetEditorActive, editor);
 }
 
 void PhpPlugin::OnNewWorkspace(clCommandEvent& e)
@@ -317,12 +294,11 @@ void PhpPlugin::OnNewWorkspace(clCommandEvent& e)
             wxFileName workspaceFile(newWspDlg.GetWorkspacePath());
             if(!workspaceFile.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL)) {
                 ::wxMessageBox(wxString::Format(_("Could not create workspace folder:\n%s"), workspaceFile.GetPath()),
-                               "CodeLite",
-                               wxICON_ERROR | wxOK | wxCENTER);
+                               "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
                 return;
             }
             PHPWorkspace::Get()->Create(newWspDlg.GetWorkspacePath());
-            DoOpenWorkspace(newWspDlg.GetWorkspacePath(), false /* create if missing */, newWspDlg.IsCreateProject());
+            DoOpenWorkspace(newWspDlg.GetWorkspacePath(), false /* create if missing */, false);
         }
     }
 }
@@ -346,7 +322,7 @@ void PhpPlugin::OnCloseWorkspace(clCommandEvent& e)
         PHPWorkspace::Get()->Close(true, true);
         m_workspaceView->UnLoadWorkspaceView();
 
-        // notify codelite to close the currently opened workspace
+        // notify CodeLite to close the currently opened workspace
         wxCommandEvent eventClose(wxEVT_COMMAND_MENU_SELECTED, wxID_CLOSE_ALL);
         eventClose.SetEventObject(FRAME);
         FRAME->GetEventHandler()->ProcessEvent(eventClose);
@@ -369,8 +345,9 @@ void PhpPlugin::OnOpenWorkspace(clCommandEvent& e)
 {
     e.Skip();
     wxFileName workspaceFile(e.GetFileName());
-    JSONRoot root(workspaceFile);
-    if(!root.isOk()) return;
+    JSON root(workspaceFile);
+    if(!root.isOk())
+        return;
 
     wxString type = root.toElement().namedObject("metadata").namedObject("type").toString();
     bool hasProjects = root.toElement().hasNamedObject("projects");
@@ -390,17 +367,15 @@ void PhpPlugin::OnOpenWorkspace(clCommandEvent& e)
 
 void PhpPlugin::DoOpenWorkspace(const wxString& filename, bool createIfMissing, bool createProjectFromSources)
 {
-    // notify codelite to close the currently opened workspace
+    // notify CodeLite to close the currently opened workspace
     wxCommandEvent eventClose(wxEVT_COMMAND_MENU_SELECTED, XRCID("close_workspace"));
     eventClose.SetEventObject(FRAME);
     FRAME->GetEventHandler()->ProcessEvent(eventClose);
 
     // Open the PHP workspace
     if(!PHPWorkspace::Get()->Open(filename, m_workspaceView, createIfMissing)) {
-        wxMessageBox(_("Failed to open workspace: corrupted workspace file"),
-                     wxT("CodeLite"),
-                     wxOK | wxICON_WARNING | wxCENTER,
-                     FRAME);
+        wxMessageBox(_("Failed to open workspace: corrupted workspace file"), wxT("CodeLite"),
+                     wxOK | wxICON_WARNING | wxCENTER, FRAME);
         return;
     }
 
@@ -437,10 +412,8 @@ void PhpPlugin::OnOpenResource(wxCommandEvent& e)
                 IEditor* editor = m_mgr->OpenFile(itemData->filename.GetFullPath());
                 if(editor) {
                     if(itemData->line != wxNOT_FOUND) {
-                        if(!editor->FindAndSelect(itemData->displayName,
-                                                  itemData->displayName,
-                                                  editor->PosFromLine(itemData->line),
-                                                  NULL)) {
+                        if(!editor->FindAndSelect(itemData->displayName, itemData->displayName,
+                                                  editor->PosFromLine(itemData->line), NULL)) {
                             editor->CenterLine(itemData->line);
                         }
                     }
@@ -486,11 +459,10 @@ void PhpPlugin::OnGetWorkspaceFiles(wxCommandEvent& e)
     if(PHPWorkspace::Get()->IsOpen()) {
         wxArrayString* pfiles = (wxArrayString*)e.GetClientData();
         if(pfiles) {
-            std::set<wxString> files;
+            wxStringSet_t files;
             PHPWorkspace::Get()->GetWorkspaceFiles(files);
-            std::set<wxString>::iterator iter = files.begin();
-            for(; iter != files.end(); iter++) {
-                pfiles->Add(*iter);
+            for (const auto& file : files) {
+                pfiles->Add(file);
             }
         }
 
@@ -502,19 +474,6 @@ void PhpPlugin::OnNewProject(clNewProjectEvent& e)
 {
     if(!PHPWorkspace::Get()->IsOpen()) {
         e.Skip();
-#if 0
-        // No workspace is opened yet, let codelite process this event normally
-        e.Skip();
-        clNewProjectEvent::Template phpTemplate;
-        phpTemplate.m_category = "PHP";
-        phpTemplate.m_categoryPng = "m_bmpElephant";
-        phpTemplate.m_template = "PHP Project";
-        phpTemplate.m_templatePng = "m_bmpPhpFile";
-        phpTemplate.m_debugger = "XDebug";
-        phpTemplate.m_toolchain = "PHP Tools";
-        phpTemplate.m_allowSeparateFolder = true;
-        e.GetTemplates().push_back(phpTemplate);
-#endif
     } else {
         // we have a PHP workspace opened - handle it ourself
         NewPHPProjectWizard wiz(EventNotifier::Get()->TopFrame());
@@ -528,25 +487,14 @@ void PhpPlugin::DoPlaceMenuBar(wxMenuBar* menuBar)
 {
     // Add our menu bar
     wxMenu* phpMenuBarMenu = new wxMenu();
-    phpMenuBarMenu->Append(wxID_PHP_SETTINGS, _("Settings..."), _("Settings..."));
-    phpMenuBarMenu->Append(
-        wxID_PHP_RUN_XDEBUG_DIAGNOSTICS, _("Run XDebug Setup Wizard..."), _("Run XDebug Setup Wizard..."));
+    phpMenuBarMenu->Append(wxID_PHP_SETTINGS, _("PHP Settings..."), _("PHP Settings..."));
+    phpMenuBarMenu->Append(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS, _("Run XDebug Setup Wizard..."),
+                           _("Run XDebug Setup Wizard..."));
 
     int helpLoc = menuBar->FindMenu(_("Help"));
     if(helpLoc != wxNOT_FOUND) {
         menuBar->Insert(helpLoc, phpMenuBarMenu, _("P&HP"));
     }
-
-    phpMenuBarMenu->Connect(wxID_PHP_SETTINGS,
-                            wxEVT_COMMAND_MENU_SELECTED,
-                            wxCommandEventHandler(PhpPlugin::OnMenuCommand),
-                            NULL,
-                            (wxEvtHandler*)this);
-    phpMenuBarMenu->Connect(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS,
-                            wxEVT_COMMAND_MENU_SELECTED,
-                            wxCommandEventHandler(PhpPlugin::OnRunXDebugDiagnostics),
-                            NULL,
-                            (wxEvtHandler*)this);
 }
 
 void PhpPlugin::OnMenuCommand(wxCommandEvent& e)
@@ -562,28 +510,6 @@ void PhpPlugin::OnMenuCommand(wxCommandEvent& e)
     }
 }
 
-void PhpPlugin::OnFileSaved(clCommandEvent& e)
-{
-    e.Skip();
-
-    if(PHPWorkspace::Get()->IsOpen()) {
-        DoSyncFileWithRemote(e.GetString());
-    }
-
-    // Run php lint
-    IEditor* editor = m_mgr->GetActiveEditor();
-    CHECK_PTR_RET(editor);
-
-    PHPConfigurationData conf;
-    conf.Load();
-    if(::IsPHPFile(editor) && conf.IsRunLint()) {
-        if(m_mgr->GetActiveEditor()) {
-            m_mgr->GetActiveEditor()->DelAllCompilerMarkers();
-        }
-        m_lint->CheckCode(e.GetFileName());
-    }
-}
-
 void PhpPlugin::OnReloadWorkspace(clCommandEvent& e)
 {
     if(PHPWorkspace::Get()->IsOpen()) {
@@ -597,7 +523,6 @@ void PhpPlugin::OnReloadWorkspace(clCommandEvent& e)
 void PhpPlugin::OnLoadURL(PHPEvent& e)
 {
     e.Skip();
-    CL_DEBUG("Loading URL: " + e.GetUrl());
     ::wxLaunchDefaultBrowser(e.GetUrl());
 }
 
@@ -620,22 +545,12 @@ void PhpPlugin::OnDebugEnded(XDebugEvent& e)
         m_mgr->GetDockingManager()->LoadPerspective(m_savedPerspective);
         m_savedPerspective.Clear();
     }
-
-    if(m_toggleToolbar) {
-        m_mgr->ShowToolBar(false);
-        m_toggleToolbar = false;
-    }
 }
 
 void PhpPlugin::OnDebugStarted(XDebugEvent& e)
 {
     e.Skip();
     DoEnsureXDebugPanesVisible();
-    m_toggleToolbar = !m_mgr->IsToolBarShown();
-    if(m_toggleToolbar) {
-        // toolbar not shown
-        m_mgr->ShowToolBar();
-    }
 }
 
 void PhpPlugin::OnXDebugDeleteAllBreakpoints(clDebugEvent& e)
@@ -645,8 +560,6 @@ void PhpPlugin::OnXDebugDeleteAllBreakpoints(clDebugEvent& e)
     EventNotifier::Get()->AddPendingEvent(eventDelAllBP);
 }
 
-void PhpPlugin::OnXDebugShowBreakpointsWindow(wxCommandEvent& e) { DoEnsureXDebugPanesVisible(_("Breakpoints")); }
-
 void PhpPlugin::DoEnsureXDebugPanesVisible(const wxString& selectWindow)
 {
     // Save the current layout to be the normal layout
@@ -702,8 +615,8 @@ void PhpPlugin::OnNewProjectFinish(clNewProjectEvent& e)
     }
 
     if(m_mgr->IsWorkspaceOpen()) {
-        ::wxMessageBox(
-            _("Can't create PHP project. Close your current workspace first"), "PHP", wxOK | wxICON_ERROR | wxCENTER);
+        ::wxMessageBox(_("Can't create PHP project. Close your current workspace first"), "PHP",
+                       wxOK | wxICON_ERROR | wxCENTER);
         return;
     }
 
@@ -723,8 +636,6 @@ void PhpPlugin::OnNewProjectFinish(clNewProjectEvent& e)
     }
 }
 
-void PhpPlugin::OnXDebugSettings(wxCommandEvent& e) {}
-
 void PhpPlugin::OnAllEditorsClosed(wxCommandEvent& e)
 {
     e.Skip();
@@ -746,8 +657,7 @@ void PhpPlugin::SetEditorActive(IEditor* editor) { editor->SetActive(); }
 void PhpPlugin::RunXDebugDiagnostics()
 {
     PHPXDebugSetupWizard wiz(EventNotifier::Get()->TopFrame());
-    if(wiz.RunWizard(wiz.GetFirstPage())) {
-    }
+    if(wiz.RunWizard(wiz.GetFirstPage())) {}
 #if 0
     XDebugTester xdebugTester;
     if(xdebugTester.RunTest()) {
@@ -757,13 +667,11 @@ void PhpPlugin::RunXDebugDiagnostics()
         html << "<table>";
 
         html << "<tr valign=\"top\" align=\"left\"><th>What?</th><th>Result</th><th>Description</th></tr>";
-        const XDebugTester::ResultMap_t& result = xdebugTester.GetResults();
-        XDebugTester::ResultMap_t::const_iterator iter = result.begin();
-        for(; iter != result.end(); ++iter) {
+        for (const auto& p : xdebugTester.GetResults()) {
             html << "<tr valign=\"top\" align=\"left\">";
-            html << "<td>" << iter->first << "</td>";
-            html << "<td>" << iter->second.first << "</td>";
-            html << "<td>" << iter->second.second << "</td>";
+            html << "<td>" << p.first << "</td>";
+            html << "<td>" << p.second.first << "</td>";
+            html << "<td>" << p.second.second << "</td>";
             html << "</tr>";
         }
 
@@ -787,15 +695,14 @@ void PhpPlugin::FinalizeStartup()
     // Create the debugger windows (hidden)
     wxWindow* parent = m_mgr->GetDockingManager()->GetManagedWindow();
     m_debuggerPane = new PHPDebugPane(parent);
-    m_mgr->GetDockingManager()->AddPane(m_debuggerPane,
-                                        wxAuiPaneInfo()
-                                            .Name("XDebug")
-                                            .Caption("Call Stack & Breakpoints")
-                                            .Hide()
-                                            .CloseButton()
-                                            .MaximizeButton()
-                                            .Bottom()
-                                            .Position(3));
+    m_mgr->GetDockingManager()->AddPane(m_debuggerPane, wxAuiPaneInfo()
+                                                            .Name("XDebug")
+                                                            .Caption("Call Stack & Breakpoints")
+                                                            .Hide()
+                                                            .CloseButton()
+                                                            .MaximizeButton()
+                                                            .Bottom()
+                                                            .Position(3));
 
     m_xdebugLocalsView = new LocalsView(parent);
     m_mgr->GetDockingManager()->AddPane(
@@ -811,59 +718,10 @@ void PhpPlugin::FinalizeStartup()
     // if not - update it
     PHPConfigurationData data;
     data.Load();
-
-    PHPLocator locator;
-    if(locator.Locate()) {
-        // update a PHP executable in the settings
-        if(data.GetPhpExe().IsEmpty()) {
-            data.SetPhpExe(locator.GetPhpExe().GetFullPath());
-        }
-        data.Save();
-    }
 }
 
 void PhpPlugin::OnGoingDown(clCommandEvent& event) { event.Skip(); }
 
-void PhpPlugin::PhpLintDone(const wxString& lintOutput, const wxString& filename)
-{
-    // Find the editor
-    CL_DEBUG("PHPLint: searching editor for file: %s", filename);
-    IEditor* editor = m_mgr->FindEditor(filename);
-    CHECK_PTR_RET(editor);
-
-    wxRegEx reLine("[ \t]*on line ([0-9]+)");
-    wxArrayString lines = ::wxStringTokenize(lintOutput, "\n", wxTOKEN_STRTOK);
-    for(size_t i = 0; i < lines.GetCount(); ++i) {
-        wxString errorString = lines.Item(i);
-        errorString.Trim().Trim(false);
-        if(errorString.Contains("syntax error")) {
-            // get the line number
-            if(reLine.Matches(errorString)) {
-                wxString strLine = reLine.GetMatch(errorString, 1);
-                int where = errorString.Find(" in ");
-                if(where != wxNOT_FOUND) {
-                    errorString.Truncate(where);
-                }
-                long nLine(wxNOT_FOUND);
-                if(strLine.ToCLong(&nLine)) {
-                    CL_DEBUG("PHPLint: adding error marker @%d", (int)nLine - 1);
-                    editor->SetErrorMarker(nLine - 1, errorString);
-                }
-            }
-        }
-    }
-}
-
-void PhpPlugin::OnFindInFilesDismissed(clCommandEvent& e)
-{
-    e.Skip();
-    if(PHPWorkspace::Get()->IsOpen()) {
-        // store the find in files mask
-        PHPConfigurationData conf;
-        conf.Load().SetFindInFilesMask(e.GetString()).Save();
-    }
-}
-
 void PhpPlugin::OnFileSysetmUpdated(clFileSystemEvent& event)
 {
     event.Skip();
@@ -882,45 +740,3 @@ void PhpPlugin::OnSaveSession(clCommandEvent& event)
         event.Skip();
     }
 }
-
-void PhpPlugin::DoSyncFileWithRemote(const wxFileName& localFile)
-{
-    // Check to see if we got a remote-upload setup
-    PHPProject::Ptr_t pProject = PHPWorkspace::Get()->GetProjectForFile(localFile);
-    if(!pProject) {
-        // Not a workspace file
-        clDEBUG() << localFile << "is not a PHP workspace file, will not sync it with remote" << clEndl;
-        return;
-    }
-    
-    SSHWorkspaceSettings settings;
-    settings.Load();
-
-    if(settings.IsRemoteUploadSet() && settings.IsRemoteUploadEnabled()) {
-        // Post an event to the SFTP plugin and ask it to save our file
-        wxFileName fnLocalFile = localFile;
-
-        fnLocalFile.MakeRelativeTo(PHPWorkspace::Get()->GetFilename().GetPath());
-        fnLocalFile.MakeAbsolute(wxFileName(settings.GetRemoteFolder(), "", wxPATH_UNIX).GetPath());
-
-        wxString remoteFile = fnLocalFile.GetFullPath(wxPATH_UNIX);
-
-        // Fire this event, if the sftp plugin is ON, it will handle it
-        clSFTPEvent eventSave(wxEVT_SFTP_SAVE_FILE);
-        eventSave.SetAccount(settings.GetAccount());
-        eventSave.SetLocalFile(localFile.GetFullPath());
-        eventSave.SetRemoteFile(remoteFile);
-        EventNotifier::Get()->AddPendingEvent(eventSave);
-    }
-}
-
-void PhpPlugin::OnReplaceInFiles(clFileSystemEvent& e)
-{
-    e.Skip();
-    if(PHPWorkspace::Get()->IsOpen()) {
-        const wxArrayString& files = e.GetStrings();
-        for(size_t i = 0; i < files.size(); ++i) {
-            DoSyncFileWithRemote(files.Item(i));
-        }
-    }
-}
