@@ -26,14 +26,14 @@
 #ifndef __PHP__
 #define __PHP__
 
-#include "plugin.h"
-#include <wx/filename.h>
-#include <cl_command_event.h>
-#include "plugin_settings.h"
-#include "php_event.h"
-#include <wx/sharedptr.h>
+#include "PhpSFTPHandler.h"
 #include "XDebugManager.h"
-#include "PHPLint.h"
+#include "cl_command_event.h"
+#include "php_event.h"
+#include "plugin.h"
+
+#include <wx/filename.h>
+#include <wx/sharedptr.h>
 
 class EvalPane;
 class LocalsView;
@@ -55,8 +55,9 @@ protected:
     LocalsView* m_xdebugLocalsView;
     EvalPane* m_xdebugEvalPane;
     bool m_showWelcomePage;
-    PHPLint::Ptr_t m_lint;
-    bool m_toggleToolbar;
+#if USE_SFTP
+    PhpSFTPHandler::Ptr_t m_sftpHandler;
+#endif // USE_SFTP
 
 public:
     enum {
@@ -69,30 +70,26 @@ public:
 
 public:
     PhpPlugin(IManager* manager);
-    ~PhpPlugin();
+    ~PhpPlugin() override = default;
     void SafelyDetachAndDestroyPane(wxWindow* pane, const wxString& name);
     void EnsureAuiPaneIsVisible(const wxString& paneName, bool update = false);
     void FinalizeStartup();
-    void PhpLintDone(const wxString& lintOutput, const wxString& filename);
 
     PHPDebugPane* GetDebuggerPane() { return m_debuggerPane; }
 
 protected:
-    bool IsWorkspaceViewDetached();
     void DoOpenWorkspace(const wxString& filename, bool createIfMissing = false, bool createProjectFromSources = false);
     void DoPlaceMenuBar(wxMenuBar* menuBar);
     void DoEnsureXDebugPanesVisible(const wxString& selectWindow = "");
-    void DoSyncFileWithRemote(const wxFileName& localFile);
 
 public:
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void HookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnHookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void HookPopupMenu(wxMenu* menu, MenuType type) override;
+    void UnPlug() override;
     void RunXDebugDiagnostics();
 
     IManager* GetManager() { return m_mgr; }
@@ -106,7 +103,7 @@ public:
     void OnShowQuickOutline(clCodeCompletionEvent& e);
 
     //////////////////////////////////////////////
-    // Other common codelite events
+    // Other common CodeLite events
     //////////////////////////////////////////////
     void OnNewWorkspace(clCommandEvent& e);
     void OnIsWorkspaceOpen(clCommandEvent& e);
@@ -119,13 +116,9 @@ public:
     void OnGetActiveProjectFiles(wxCommandEvent& e);
     void OnNewProject(clNewProjectEvent& e);
     void OnNewProjectFinish(clNewProjectEvent& e);
-    void OnFindInFilesDismissed(clCommandEvent& e);
     void OnRunXDebugDiagnostics(wxCommandEvent& e);
     void OnMenuCommand(wxCommandEvent& e);
-    void OnFileSaved(clCommandEvent& e);
-    void OnXDebugShowBreakpointsWindow(wxCommandEvent& e);
     void OnXDebugDeleteAllBreakpoints(clDebugEvent& e);
-    void OnXDebugSettings(wxCommandEvent& e);
     void OnLoadURL(PHPEvent& e);
     void OnAllEditorsClosed(wxCommandEvent& e);
     void OnGoingDown(clCommandEvent& event);
@@ -133,7 +126,6 @@ public:
     void OnDebugEnded(XDebugEvent& e);
     void OnFileSysetmUpdated(clFileSystemEvent& event);
     void OnSaveSession(clCommandEvent& event);
-    void OnReplaceInFiles(clFileSystemEvent& e);
 };
 
 #endif // PHP
