@@ -1,12 +1,14 @@
 #include "php_file_layout_tree.h"
-#include <imanager.h>
-#include <ieditor.h>
-#include <algorithm>
-#include <globals.h>
-#include "PHPEntityFunction.h"
-#include "PHPEntityVariable.h"
-#include "PHPSourceFile.h"
+
+#include "PHP/PHPEntityFunction.h"
+#include "PHP/PHPEntityVariable.h"
+#include "PHP/PHPSourceFile.h"
 #include "fileutils.h"
+#include "globals.h"
+#include "ieditor.h"
+#include "imanager.h"
+
+#include <algorithm>
 
 #ifndef __WXMSW__
 #include <wx/imaglist.h>
@@ -14,33 +16,28 @@
 
 PHPFileLayoutTree::PHPFileLayoutTree(wxWindow* parent, IEditor* editor, IManager* manager)
     : wxTreeCtrl(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize,
-          wxTR_DEFAULT_STYLE | wxTR_FULL_ROW_HIGHLIGHT | wxTR_HIDE_ROOT | wxTR_NO_LINES | wxTR_SINGLE)
+          wxTR_DEFAULT_STYLE | wxTR_HIDE_ROOT | wxTR_NO_LINES | wxTR_SINGLE)
     , m_editor(editor)
     , m_manager(manager)
 {
-    MSWSetNativeTheme(this);
-    m_keyboard.reset(new clTreeKeyboardInput(this));
 }
 
 PHPFileLayoutTree::PHPFileLayoutTree(wxWindow* parent)
     : wxTreeCtrl(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize,
-          wxTR_DEFAULT_STYLE | wxTR_FULL_ROW_HIGHLIGHT | wxTR_HIDE_ROOT | wxTR_NO_LINES | wxTR_SINGLE)
+          wxTR_DEFAULT_STYLE | wxTR_HIDE_ROOT | wxTR_NO_LINES | wxTR_SINGLE)
     , m_editor(NULL)
     , m_manager(NULL)
 {
     MSWSetNativeTheme(this);
-    m_keyboard.reset(new clTreeKeyboardInput(this));
 }
 
-PHPFileLayoutTree::~PHPFileLayoutTree() { m_keyboard.reset(nullptr); }
-
 void PHPFileLayoutTree::Construct()
 {
     // Sanity
     if(!m_editor || !m_manager) return;
 
     wxString text = m_editor->GetTextRange(0, m_editor->GetLength());
-    PHPSourceFile source(text);
+    PHPSourceFile source(text, NULL);
     source.SetParseFunctionBody(false);
     source.SetFilename(m_editor->GetFileName());
     source.Parse();
@@ -91,7 +88,7 @@ int PHPFileLayoutTree::GetImageId(PHPEntityBase::Ptr_t entry)
     } else if(entry->Is(kEntityTypeVariable)) {
         PHPEntityVariable* var = entry->Cast<PHPEntityVariable>();
         if(!var->IsMember() && !var->IsConst()) {
-            // A global variale
+            // A global variable
             return 6;
 
         } else if(var->IsMember()) {
@@ -120,27 +117,6 @@ int PHPFileLayoutTree::GetImageId(PHPEntityBase::Ptr_t entry)
     return -1; // Unknown
 }
 
-wxTreeItemId PHPFileLayoutTree::FindItemIdByName(const wxTreeItemId& parent, const wxString& name)
-{
-    if(parent.IsOk() == false) return wxTreeItemId();
-
-    if(!ItemHasChildren(parent)) {
-        return AppendItem(parent, name, 7, 7, NULL);
-    }
-
-    wxTreeItemIdValue cookie;
-    wxTreeItemId child = GetFirstChild(parent, cookie);
-    while(child.IsOk()) {
-        if(GetItemText(child) == name) {
-            return child;
-        }
-        child = GetNextChild(parent, cookie);
-    }
-
-    // No match? add it
-    return AppendItem(parent, name, 7, 7, NULL);
-}
-
 wxTreeItemId PHPFileLayoutTree::RecurseSearch(const wxTreeItemId& item, const wxString& word)
 {
     if(!item.IsOk()) return wxTreeItemId();
@@ -165,41 +141,6 @@ wxTreeItemId PHPFileLayoutTree::RecurseSearch(const wxTreeItemId& item, const wx
     return wxTreeItemId();
 }
 
-void PHPFileLayoutTree::FindWord(const wxString& word)
-{
-    wxString lcword = word;
-    lcword.MakeLower();
-
-    wxTreeItemId item = RecurseSearch(GetRootItem(), lcword);
-    if(item.IsOk()) {
-        SelectItem(item);
-        EnsureVisible(item);
-        ScrollTo(item);
-    }
-}
-
-void PHPFileLayoutTree::AdvanceSelection(bool forward)
-{
-    wxTreeItemId item = GetSelection();
-    if(!item.IsOk()) {
-        return;
-    }
-
-    wxTreeItemId nextItem;
-    if(forward) {
-        // Item is visible, scroll to it to make sure GetNextVisible() wont
-        // fail
-        ScrollTo(item);
-        nextItem = GetNextVisible(item);
-    } else {
-        nextItem = TryGetPrevItem(item);
-    }
-
-    if(nextItem.IsOk()) {
-        SelectItem(nextItem);
-    }
-}
-
 wxTreeItemId PHPFileLayoutTree::TryGetPrevItem(wxTreeItemId item)
 {
     wxCHECK_MSG(item.IsOk(), wxTreeItemId(), wxT("invalid tree item"));
@@ -235,13 +176,10 @@ void PHPFileLayoutTree::BuildTree(wxTreeItemId parentTreeItem, PHPEntityBase::Pt
 {
     int imgID = GetImageId(entity);
     wxTreeItemId parent = AppendItem(parentTreeItem, entity->GetDisplayName(), imgID, imgID, new QItemData(entity));
-    // dont add the children of the function (i.e. function arguments)
-    if(entity->Is(kEntityTypeFunction)) return;
-    const PHPEntityBase::List_t& children = entity->GetChildren();
-    if(!children.empty()) {
-        PHPEntityBase::List_t::const_iterator iter = children.begin();
-        for(; iter != children.end(); ++iter) {
-            BuildTree(parent, *iter);
-        }
+    // don't add the children of the function (i.e. function arguments)
+    if (entity->Is(kEntityTypeFunction)) return;
+
+    for (const auto& child : entity->GetChildren()) {
+        BuildTree(parent, child);
     }
 }
