@@ -1,36 +1,36 @@
+#include "php_workspace_view.h"
+
 #include "FilesCollector.h"
 #include "NewPHPClass.h"
+#include "PHP/PHPLookupTable.h"
 #include "PHPDebugStartDlg.h"
-#include "PHPLookupTable.h"
+#include "SFTPBrowserDlg.h"
+#include "SSHAccountManagerDlg.h"
 #include "XDebugManager.h"
+#include "bitmap_loader.h"
 #include "clFileOrFolderDropTarget.h"
 #include "clFileSystemEvent.h"
 #include "clWorkspaceView.h"
 #include "cl_aui_tool_stickness.h"
+#include "cl_command_event.h"
+#include "editor_config.h"
 #include "event_notifier.h"
 #include "file_logger.h"
+#include "fileextmanager.h"
 #include "fileutils.h"
-#include "new_file_dlg.h"
+#include "globals.h"
+#include "imanager.h"
+#include "macros.h"
 #include "php_configuration_data.h"
 #include "php_project_settings_dlg.h"
 #include "php_strings.h"
 #include "php_workspace.h"
-#include "php_workspace_view.h"
+#include "plugin.h"
+#include "sftp_settings.h"
+#include "ssh/ssh_account_info.h"
 #include "ssh_workspace_settings.h"
 #include "tree_item_data.h"
-#include <SFTPBrowserDlg.h>
-#include <SSHAccountManagerDlg.h>
-#include <bitmap_loader.h>
-#include <cl_command_event.h>
-#include <editor_config.h>
-#include <event_notifier.h>
-#include <fileextmanager.h>
-#include <globals.h>
-#include <imanager.h>
-#include <macros.h>
-#include <plugin.h>
-#include <sftp_settings.h>
-#include <ssh_account_info.h>
+
 #include <wx/busyinfo.h>
 #include <wx/filedlg.h>
 #include <wx/imaglist.h>
@@ -98,9 +98,14 @@ PHPWorkspaceView::PHPWorkspaceView(wxWindow* parent, IManager* mgr)
     Bind(wxEVT_PHP_PROJECT_FILES_SYNC_END, &PHPWorkspaceView::OnProjectSyncCompleted, this);
     EventNotifier::Get()->Bind(wxEVT_FOLDER_CREATED, &PHPWorkspaceView::OnFolderChanged, this);
     EventNotifier::Get()->Bind(wxEVT_FOLDER_DELETED, &PHPWorkspaceView::OnFolderChanged, this);
+    EventNotifier::Get()->Bind(wxEVT_ACTIVE_PROJECT_CHANGED, &PHPWorkspaceView::OnActiveProjectChanged, this);
+    m_treeCtrlView->SetBitmaps(&m_mgr->GetStdIcons()->GetMimeBitmaps().GetBitmaps());
 
-    BitmapLoader* bl = m_mgr->GetStdIcons();
-    m_treeCtrlView->SetBitmaps(&bl->GetMimeBitmaps().GetBitmaps());
+    // respond to bitmaps-updated event
+    EventNotifier::Get()->Bind(wxEVT_BITMAPS_UPDATED, [this](clCommandEvent& event) {
+        event.Skip();
+        m_treeCtrlView->SetBitmaps(&m_mgr->GetStdIcons()->GetMimeBitmaps().GetBitmaps());
+    });
 
     // Allow the PHP view to accepts folders
     m_treeCtrlView->SetDropTarget(new clFileOrFolderDropTarget(this));
@@ -109,20 +114,21 @@ PHPWorkspaceView::PHPWorkspaceView(wxWindow* parent, IManager* mgr)
     Bind(wxEVT_DND_FOLDER_DROPPED, &PHPWorkspaceView::OnFolderDropped, this);
 
     // Build the toolbar
-    m_toolbar->AddTool(XRCID("ID_PHP_PROJECT_SETTINGS"), _("Open active project settings"), bl->LoadBitmap("cog"),
+    auto images = m_toolbar->GetBitmapsCreateIfNeeded();
+    m_toolbar->AddTool(XRCID("ID_PHP_PROJECT_SETTINGS"), _("Open active project settings"), images->Add("cog"),
                        _("Open active project settings"), wxITEM_NORMAL);
 #if USE_SFTP
-    m_toolbar->AddTool(XRCID("ID_PHP_PROJECT_REMOTE_SAVE"), _("Setup automatic upload"), bl->LoadBitmap("file_open"),
+    m_toolbar->AddTool(XRCID("ID_PHP_PROJECT_REMOTE_SAVE"), _("Setup automatic upload"), images->Add("file_open"),
                        _("Setup automatic upload"), wxITEM_DROPDOWN);
 #endif
     m_toolbar->AddSeparator();
-    m_toolbar->AddTool(XRCID("ID_TOOL_COLLAPSE"), _("Collapse All"), bl->LoadBitmap("fold"), _("Collapse All"),
+    m_toolbar->AddTool(XRCID("ID_TOOL_COLLAPSE"), _("Collapse All"), images->Add("fold"), _("Collapse All"),
                        wxITEM_NORMAL);
     m_toolbar->AddTool(XRCID("ID_TOOL_SYNC_WORKSPACE"), _("Sync workspace with file system"),
-                       bl->LoadBitmap("debugger_restart"), _("Sync workspace with file system..."), wxITEM_NORMAL);
+                       images->Add("debugger_restart"), _("Sync workspace with file system..."), wxITEM_NORMAL);
     m_toolbar->AddSeparator();
     m_toolbar->AddTool(XRCID("ID_TOOL_START_DEBUGGER_LISTENER"), _("Wait for Debugger Connection"),
-                       bl->LoadBitmap("debugger_start"), _("Wait for Debugger Connection"));
+                       images->Add("debugger_start"), _("Wait for Debugger Connection"));
     m_toolbar->Realize();
 
     // Bind events
@@ -178,6 +184,7 @@ PHPWorkspaceView::~PHPWorkspaceView()
     Unbind(wxEVT_UPDATE_UI, &PHPWorkspaceView::OnSyncWorkspaceWithFileSystemUI, this, XRCID("ID_TOOL_SYNC_WORKSPACE"));
     EventNotifier::Get()->Unbind(wxEVT_FOLDER_CREATED, &PHPWorkspaceView::OnFolderChanged, this);
     EventNotifier::Get()->Unbind(wxEVT_FOLDER_DELETED, &PHPWorkspaceView::OnFolderChanged, this);
+    EventNotifier::Get()->Unbind(wxEVT_ACTIVE_PROJECT_CHANGED, &PHPWorkspaceView::OnActiveProjectChanged, this);
 }
 
 void PHPWorkspaceView::OnFolderDropped(clCommandEvent& event)
@@ -274,7 +281,7 @@ void PHPWorkspaceView::OnFolderDropped(clCommandEvent& event)
 
 void PHPWorkspaceView::OnMenu(wxTreeEvent& event)
 {
-    wxBitmap bmpFiF = m_mgr->GetStdIcons()->LoadBitmap("find_in_files");
+    wxBitmap bmpFiF = m_mgr->GetStdIcons()->LoadBitmap("find");
     wxTreeItemId item = event.GetItem();
     if(item.IsOk()) {
         // Ensure that the item is selected
@@ -328,7 +335,7 @@ void PHPWorkspaceView::OnMenu(wxTreeEvent& event)
                 menuItem->SetBitmap(clGetManager()->GetStdIcons()->LoadBitmap("debugger_restart"));
                 menu.Append(menuItem);
                 menu.AppendSeparator();
-                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Files"));
+                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Folder..."));
                 menuItem->SetBitmap(bmpFiF);
                 menu.Append(menuItem);
                 m_treeCtrlView->PopupMenu(&menu);
@@ -344,7 +351,7 @@ void PHPWorkspaceView::OnMenu(wxTreeEvent& event)
                 menu.Append(XRCID("php_new_file"), _("New File..."));
                 menu.AppendSeparator();
 
-                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Files"));
+                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Folder..."));
                 menuItem->SetBitmap(bmpFiF);
                 menu.Append(menuItem);
                 menu.AppendSeparator();
@@ -388,7 +395,7 @@ void PHPWorkspaceView::OnMenu(wxTreeEvent& event)
                 menu.Append(XRCID("php_open_folder_in_explorer"), _("Open Containing Folder"));
                 menu.Append(XRCID("php_open_shell"), _("Open Shell"));
                 menu.AppendSeparator();
-                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Files"));
+                menuItem = new wxMenuItem(NULL, XRCID("php_folder_find_in_files"), _("Find In Folder..."));
                 menuItem->SetBitmap(bmpFiF);
                 menu.Append(menuItem);
 
@@ -427,7 +434,9 @@ void PHPWorkspaceView::LoadWorkspaceView()
     BitmapLoader* bl = m_mgr->GetStdIcons();
 
     ItemData* data = new ItemData(ItemData::Kind_Workspace);
-    data->SetFile(workspaceName);
+    data->SetFile(PHPWorkspace::Get()->GetFilename().GetFullPath());
+    data->SetFolderPath(PHPWorkspace::Get()->GetDir());
+
     wxTreeItemId root =
         m_treeCtrlView->AddRoot(workspaceName, bl->GetMimeImageId(PHPWorkspace::Get()->GetFilename().GetFullName()),
                                 bl->GetMimeImageId(PHPWorkspace::Get()->GetFilename().GetFullName()), data);
@@ -440,24 +449,25 @@ void PHPWorkspaceView::LoadWorkspaceView()
     // add projects
     wxTreeItemId activeProjectId;
     wxStringSet_t files;
-    PHPProject::Map_t::const_iterator iter_project = projects.begin();
-    for(; iter_project != projects.end(); ++iter_project) {
+    for (const auto& [projectName, project] : projects) {
         data = new ItemData(ItemData::Kind_Project);
-        data->SetProjectName(iter_project->first);
-        data->SetFolderPath(iter_project->second->GetFilename().GetPath());
-        data->SetFile(iter_project->second->GetFilename().GetFullPath());
-        data->SetActive(iter_project->second->IsActive());
+        data->SetProjectName(projectName);
+        data->SetFolderPath(project->GetFilename().GetPath());
+        data->SetFile(project->GetFilename().GetFullPath());
+        data->SetActive(project->IsActive());
 
-        wxTreeItemId projectItemId = m_treeCtrlView->AppendItem(
-            root, iter_project->second->GetName(), bl->GetMimeImageId(FileExtManager::TypeProject),
-            bl->GetMimeImageId(FileExtManager::TypeProjectExpanded), data);
+        wxTreeItemId projectItemId = m_treeCtrlView->AppendItem(root,
+                                                                project->GetName(),
+                                                                bl->GetMimeImageId(FileExtManager::TypeProject),
+                                                                bl->GetMimeImageId(FileExtManager::TypeProjectExpanded),
+                                                                data);
         if(data->IsActive()) {
             m_treeCtrlView->SetItemBold(projectItemId, true);
         }
 
         // The project is also a folder for the project folder
-        m_foldersItems.insert(std::make_pair(iter_project->second->GetFilename().GetPath(), projectItemId));
-        DoBuildProjectNode(projectItemId, iter_project->second);
+        m_foldersItems.insert(std::make_pair(project->GetFilename().GetPath(), projectItemId));
+        DoBuildProjectNode(projectItemId, project);
         if(data->IsActive()) {
             activeProjectId = projectItemId;
         }
@@ -512,7 +522,7 @@ void PHPWorkspaceView::OnDeleteProject(wxCommandEvent& e)
         if(itemData && itemData->IsProject()) {
             if(wxMessageBox(wxString() << _("Are you sure you want to remove project '") << itemData->GetProjectName()
                                        << "'?",
-                            _("CodeLite"), wxYES_NO | wxCANCEL | wxCANCEL_DEFAULT, wxTheApp->GetTopWindow()) == wxYES) {
+                            wxT("CodeLite"), wxYES_NO | wxCANCEL | wxCANCEL_DEFAULT, wxTheApp->GetTopWindow()) == wxYES) {
                 PHPWorkspace::Get()->DeleteProject(itemData->GetProjectName());
                 m_treeCtrlView->Delete(selection);
 
@@ -539,18 +549,18 @@ void PHPWorkspaceView::OnNewFolder(wxCommandEvent& e)
     wxTreeItemId parent = m_treeCtrlView->GetFocusedItem();
     CHECK_ITEM_RET(parent);
 
-    ItemData* itemData = DoGetItemData(parent);
-    CHECK_PTR_RET(itemData);
+    ItemData* parentItemData = DoGetItemData(parent);
+    CHECK_PTR_RET(parentItemData);
 
-    if(!itemData->IsFolder() && !itemData->IsProject())
+    if (!parentItemData->IsFolder() && !parentItemData->IsProject())
         return;
 
     PHPProject::Ptr_t proj = PHPWorkspace::Get()->GetProject(project);
     CHECK_PTR_RET(proj);
 
     wxString base;
-    if(itemData->IsFolder()) {
-        base = itemData->GetFolderPath();
+    if (parentItemData->IsFolder()) {
+        base = parentItemData->GetFolderPath();
     } else {
         base = proj->GetFilename().GetPath();
     }
@@ -694,7 +704,7 @@ void PHPWorkspaceView::OnDeleteFolder(wxCommandEvent& e)
 
 void PHPWorkspaceView::OnRetagWorkspace(wxCommandEvent& e)
 {
-    // notify codelite to close the currently opened workspace
+    // notify CodeLite to close the currently opened workspace
     wxCommandEvent retagEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("retag_workspace"));
     retagEvent.SetEventObject(FRAME);
     FRAME->GetEventHandler()->ProcessEvent(retagEvent);
@@ -899,7 +909,6 @@ void PHPWorkspaceView::OnProjectSettings(wxCommandEvent& event)
 void PHPWorkspaceView::OnRunActiveProject(clExecuteEvent& e)
 {
     if(PHPWorkspace::Get()->IsOpen()) {
-        CL_DEBUG("Running active project...");
         CHECK_COND_RET(PHPWorkspace::Get()->GetActiveProject());
         // Test which file we want to debug
         PHPDebugStartDlg dlg(EventNotifier::Get()->TopFrame(), PHPWorkspace::Get()->GetActiveProject(), m_mgr);
@@ -1029,8 +1038,6 @@ void PHPWorkspaceView::OnNewClass(wxCommandEvent& e)
     }
 }
 
-void PHPWorkspaceView::OnWorkspaceOpenUI(wxUpdateUIEvent& event) { event.Enable(PHPWorkspace::Get()->IsOpen()); }
-
 void PHPWorkspaceView::OnRenameWorkspace(wxCommandEvent& e)
 {
     wxString new_name = ::wxGetTextFromUser(_("New workspace name:"), _("Rename workspace"));
@@ -1112,8 +1119,8 @@ void PHPWorkspaceView::ReportParseThreadProgress(size_t curIndex, size_t total)
     }
 
     if(total) {
-        int precent = (curIndex * 100) / total;
-        m_gaugeParseProgress->SetValue(precent);
+        int percent = (curIndex * 100) / total;
+        m_gaugeParseProgress->SetValue(percent);
     }
 }
 
@@ -1151,8 +1158,6 @@ void PHPWorkspaceView::OnPhpParserProgress(clParseEvent& event)
     ReportParseThreadProgress(event.GetCurfileIndex(), event.GetTotalFiles());
 }
 
-void PHPWorkspaceView::OnPhpParserStarted(clParseEvent& event) { event.Skip(); }
-
 void PHPWorkspaceView::OnSyncWorkspaceWithFileSystem(wxCommandEvent& e)
 {
     PHPWorkspace::Get()->SyncWithFileSystemAsync(this);
@@ -1360,10 +1365,8 @@ void PHPWorkspaceView::DoGetSelectedFolders(wxArrayString& paths)
         } else if(itemData->IsWorkspace()) {
             // If the workspace is included, use the project paths and nothing more
             paths.Clear();
-            const PHPProject::Map_t& projects = PHPWorkspace::Get()->GetProjects();
-            PHPProject::Map_t::const_iterator iter = projects.begin();
-            for(; iter != projects.end(); ++iter) {
-                paths.Add(iter->second->GetFilename().GetPath());
+            for (const auto& [_, project] : PHPWorkspace::Get()->GetProjects()) {
+                paths.Add(project->GetFilename().GetPath());
             }
             break;
         }
@@ -1373,8 +1376,10 @@ void PHPWorkspaceView::DoGetSelectedFolders(wxArrayString& paths)
 void PHPWorkspaceView::OnFindInFiles(wxCommandEvent& e)
 {
     m_fifFromContextMenu = true;
-    // Open the find in files dialg for the folder path
-    m_mgr->OpenFindInFileForPaths({});
+    // Open the find in files dialog for the folder path
+    wxArrayString paths;
+    DoGetSelectedFolders(paths);
+    m_mgr->OpenFindInFileForPaths(paths);
 }
 
 void PHPWorkspaceView::OnOpenWithDefaultApp(wxCommandEvent& e)
@@ -1443,16 +1448,6 @@ void PHPWorkspaceView::OnAddExistingProject(wxCommandEvent& e)
 void PHPWorkspaceView::DoSetProjectActive(const wxString& projectName)
 {
     PHPWorkspace::Get()->SetProjectActive(projectName);
-    wxTreeItemIdValue cookie;
-    wxTreeItemId child = m_treeCtrlView->GetFirstChild(m_treeCtrlView->GetRootItem(), cookie);
-    while(child.IsOk()) {
-        ItemData* id = DoGetItemData(child);
-        if(id && id->IsProject()) {
-            id->SetActive(id->GetProjectName() == projectName);
-            m_treeCtrlView->SetItemBold(child, id->IsActive());
-        }
-        child = m_treeCtrlView->GetNextChild(m_treeCtrlView->GetRootItem(), cookie);
-    }
 }
 
 void PHPWorkspaceView::OnWorkspaceLoaded(PHPEvent& event)
@@ -1503,74 +1498,21 @@ void PHPWorkspaceView::OnRenameFolder(wxCommandEvent& e)
     }
 }
 
-void PHPWorkspaceView::OnFindInFilesDismissed(clFindInFilesEvent& e)
-{
-    e.Skip();
-    if(PHPWorkspace::Get()->IsOpen()) {
-        // store the find in files mask
-        clConfig::Get().Write("FindInFiles/PHP/LookIn", e.GetPaths());
-        clConfig::Get().Write("FindInFiles/PHP/Mask", e.GetFileMask());
-    }
-}
+void PHPWorkspaceView::OnFindInFilesDismissed(clFindInFilesEvent& e) { e.Skip(); }
 
-void PHPWorkspaceView::OnFindInFilesShowing(clFindInFilesEvent& e)
-{
-    e.Skip();
-    if(!PHPWorkspace::Get()->IsOpen())
-        return;
-
-    // Mask is always loaded from the configuration
-    const wxString defaultMask =
-        "*.php;*.inc;*.phtml;*.js;*.html;*.css;*.scss;*.json;*.xml;*.ini;*.md;*.txt;*.text;.htaccess;*.sql";
-    const wxString defaultLookIn = "<Entire Workspace>\n-*vendor*";
-
-    wxString mask = clConfig::Get().Read("FindInFiles/PHP/Mask", wxString(""));
-    wxString lookIn = clConfig::Get().Read("FindInFiles/PHP/LookIn", wxString(""));
-    if(lookIn.empty()) {
-        // first time
-        lookIn = defaultLookIn;
-    }
-
-    if(mask.empty()) {
-        // first time
-        mask = defaultMask;
-    }
-
-    wxArrayString folders;
-    if(m_fifFromContextMenu) {
-        m_fifFromContextMenu = false;
-        // the trigger was from the context menu
-        // use the selected folders from the workspace tree view to override the 'look-in'
-        wxArrayTreeItemIds items;
-        DoGetSelectedItems(items);
-        if(!items.IsEmpty()) {
-            for(size_t i = 0; i < items.GetCount(); ++i) {
-                const wxTreeItemId& item = items.Item(i);
-                ItemData* itemData = DoGetItemData(item);
-                if(itemData->IsFolder()) {
-                    folders.Add(itemData->GetFolderPath());
-                }
-            }
-        }
-        // replace the 'look-in'
-        lookIn = wxJoin(folders, '\n');
-    }
-
-    e.SetFileMask(mask);
-    e.SetPaths(lookIn);
-}
+void PHPWorkspaceView::OnFindInFilesShowing(clFindInFilesEvent& e) { e.Skip(); }
 
 void PHPWorkspaceView::OnWorkspaceSyncStart(clCommandEvent& event)
 {
     m_scanInProgress = true;
-    CallAfter(&PHPWorkspaceView::DoSetStatusBarText, "Scanning for PHP files...", wxNOT_FOUND);
+    CallAfter(&PHPWorkspaceView::DoSetStatusBarText, _("Scanning for PHP files..."), wxNOT_FOUND);
     m_treeCtrlView->Enable(false);
 }
 
 void PHPWorkspaceView::OnWorkspaceSyncEnd(clCommandEvent& event)
 {
     m_scanInProgress = false;
-    CallAfter(&PHPWorkspaceView::DoSetStatusBarText, "Scanning for PHP files completed", 3);
+    CallAfter(&PHPWorkspaceView::DoSetStatusBarText, _("Scanning for PHP files completed"), 3);
     PHPWorkspace::Get()->ParseWorkspace(false);
     CallAfter(&PHPWorkspaceView::LoadWorkspaceView);
     m_treeCtrlView->Enable(true);
@@ -1627,17 +1569,17 @@ void PHPWorkspaceView::OnProjectSyncCompleted(clCommandEvent& event)
     DoGetFilesAndFolders(pProject->GetName(), folders, files);
 
     // Clear these items from the cache
-    std::for_each(files.begin(), files.end(), [&](const wxString& s) {
+    for (const wxString& s : files) {
         if(m_filesItems.count(s)) {
             m_filesItems.erase(s);
         }
-    });
+    }
 
-    std::for_each(folders.begin(), folders.end(), [&](const wxString& s) {
+    for (const wxString& s : folders) {
         if(m_foldersItems.count(s)) {
             m_foldersItems.erase(s);
         }
-    });
+    }
 
     wxWindowUpdateLocker locker(m_treeCtrlView);
     // Now we can delete the subtree
@@ -1822,3 +1764,24 @@ void PHPWorkspaceView::OnFolderChanged(clFileSystemEvent& event)
         }
     }
 }
+
+void PHPWorkspaceView::OnActiveProjectChanged(clProjectSettingsEvent& e)
+{
+    if(!PHPWorkspace::Get()->IsOpen()) {
+        e.Skip();
+        return;
+    }
+
+    // update the UI
+    wxString projectName = e.GetProjectName();
+    wxTreeItemIdValue cookie;
+    wxTreeItemId child = m_treeCtrlView->GetFirstChild(m_treeCtrlView->GetRootItem(), cookie);
+    while(child.IsOk()) {
+        ItemData* id = DoGetItemData(child);
+        if(id && id->IsProject()) {
+            id->SetActive(id->GetProjectName() == projectName);
+            m_treeCtrlView->SetItemBold(child, id->IsActive());
+        }
+        child = m_treeCtrlView->GetNextChild(m_treeCtrlView->GetRootItem(), cookie);
+    }
+}
