@@ -26,15 +26,16 @@
 #ifndef __php_workspace_view__
 #define __php_workspace_view__
 
+#include "bitmap_loader.h"
+#include "clFileSystemEvent.h"
+#include "cl_command_event.h"
+#include "php_event.h"
 #include "php_ui.h"
 #include "php_workspace.h"
-#include <set>
-#include <bitmap_loader.h>
-#include "php_event.h"
-#include <cl_command_event.h>
+#include "wxStringHash.h"
 #include "wx_ordered_map.h"
-#include "clTreeKeyboardInput.h"
-#include "clFileSystemEvent.h"
+
+#include <set>
 
 class IManager;
 class ItemData;
@@ -42,12 +43,12 @@ class ItemData;
 class PHPWorkspaceView : public PHPWorkspaceViewBase
 {
     IManager* m_mgr;
-    BitmapLoader::BitmapMap_t m_bitmaps;
-    wxOrderedMap<wxTreeItemId, bool> m_itemsToSort;
-    std::map<wxString, wxTreeItemId> m_filesItems;
-    std::map<wxString, wxTreeItemId> m_foldersItems;
-    clTreeKeyboardInput::Ptr_t m_keyboardHelper;
+    std::unordered_map<wxString, wxTreeItemId> m_filesItems;
+    std::unordered_map<wxString, wxTreeItemId> m_foldersItems;
     bool m_scanInProgress;
+    std::unordered_set<wxString> m_pendingSync;
+    wxArrayString m_draggedFiles;
+    bool m_fifFromContextMenu = false;
 
 private:
     enum {
@@ -56,19 +57,18 @@ private:
 
 protected:
     virtual void OnCollapse(wxCommandEvent& event);
-    virtual void DoCollapseItem(wxTreeItemId& item);
     void OnFolderDropped(clCommandEvent& event);
 
     virtual void OnCollapseUI(wxUpdateUIEvent& event);
     virtual void OnStartDebuggerListenerUI(wxUpdateUIEvent& event);
-    virtual void OnSetupRemoteUploadUI(wxUpdateUIEvent& event);
     virtual void OnItemActivated(wxTreeEvent& event);
     virtual void OnMenu(wxTreeEvent& event);
     void OnWorkspaceLoaded(PHPEvent& event);
 #if USE_SFTP
-    virtual void OnSetupRemoteUpload(wxAuiToolBarEvent& event);
+    virtual void OnSetupRemoteUploadUI(wxUpdateUIEvent& event);
+    virtual void OnSetupRemoteUpload(wxCommandEvent& event);
+    virtual void OnSetupRemoteUploadMenu(wxCommandEvent& event);
 #endif
-    virtual void OnWorkspaceOpenUI(wxUpdateUIEvent& event);
     virtual void OnActiveProjectSettings(wxCommandEvent& event);
     virtual void OnProjectSettings(wxCommandEvent& event);
     virtual void OnActiveProjectSettingsUI(wxUpdateUIEvent& event);
@@ -77,7 +77,6 @@ protected:
     void DoSetStatusBarText(const wxString& text, int timeOut);
 
     // Helpers
-    void DoSortItems();
     wxTreeItemId DoAddFolder(const wxString& project, const wxString& path);
     wxTreeItemId DoCreateFile(const wxTreeItemId& parent, const wxString& fullpath, const wxString& content = "");
     wxTreeItemId DoGetProject(const wxString& project);
@@ -90,7 +89,6 @@ protected:
     const ItemData* DoGetItemData(const wxTreeItemId& item) const;
     bool IsFolderItem(const wxTreeItemId& item);
     int DoGetItemImgIdx(const wxString& filename);
-    wxBitmap DoGetBitmapForExt(const wxString& ext) const;
     void DoDeleteSelectedFileItem();
 #if USE_SFTP
     void DoOpenSSHAccountManager();
@@ -103,6 +101,12 @@ protected:
      */
     void DoBuildProjectNode(const wxTreeItemId& projectItem, PHPProject::Ptr_t project);
 
+    /**
+     * @brief return list of files and folders for a given project
+     */
+    void DoGetFilesAndFolders(const wxString& projectName, wxArrayString& folders, wxArrayString& files);
+    void DoGetFilesAndFolders(const wxTreeItemId& parent, wxArrayString& folders, wxArrayString& files);
+
     /**
      * @brief open an item into an editor
      */
@@ -110,6 +114,11 @@ protected:
 
     void DoSetProjectActive(const wxString& projectName);
 
+    /**
+     * @brief expand the tree view to highlight the active editor
+     */
+    void DoExpandToActiveEditor();
+
 protected:
     // Handlers for PHPWorkspaceViewBase events.
 
@@ -136,7 +145,10 @@ protected:
     void OnRenameWorkspace(wxCommandEvent& e);
     void OnRunProject(wxCommandEvent& e);
     void OnMakeIndexPHP(wxCommandEvent& e);
+    void OnSyncWorkspaceWithFileSystem(wxCommandEvent& e);
+    void OnSyncWorkspaceWithFileSystemUI(wxUpdateUIEvent& e);
     void OnSyncProjectWithFileSystem(wxCommandEvent& e);
+    void OnSyncFolderWithFileSystem(wxCommandEvent& e);
     void OnOpenWithDefaultApp(wxCommandEvent& e);
     void OnRunActiveProject(clExecuteEvent& e);
     void OnStopExecutedProgram(clExecuteEvent& e);
@@ -144,12 +156,15 @@ protected:
     void OnEditorChanged(wxCommandEvent& e);
     void OnFileRenamed(PHPEvent& e);
     void OnWorkspaceRenamed(PHPEvent& e);
-    void OnFindInFilesShowing(clCommandEvent& e);
+    void OnFindInFilesShowing(clFindInFilesEvent& e);
+    void OnFindInFilesDismissed(clFindInFilesEvent& e);
     void OnToggleAutoUpload(wxCommandEvent& e);
     void OnStartDebuggerListener(wxCommandEvent& e);
-    
+    void OnProjectSyncCompleted(clCommandEvent& event);
+    void OnFolderChanged(clFileSystemEvent& event);
+    void OnActiveProjectChanged(clProjectSettingsEvent& e);
+
     // Php parser events
-    void OnPhpParserStarted(clParseEvent& event);
     void OnPhpParserProgress(clParseEvent& event);
     void OnPhpParserDone(clParseEvent& event);
 
@@ -157,7 +172,11 @@ protected:
     void OnWorkspaceSyncStart(clCommandEvent& event);
     void OnWorkspaceSyncEnd(clCommandEvent& event);
     void OnFileSaveAs(clFileSystemEvent& event);
-    
+
+    // DnD
+    void OnDragBegin(wxTreeEvent& event);
+    void OnDragEnd(wxTreeEvent& event);
+
 public:
     /** Constructor */
     PHPWorkspaceView(wxWindow* parent, IManager* mgr);
