@@ -24,20 +24,13 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "cscopestatusmessage.h"
-CScopeStatusMessage::CScopeStatusMessage()
-{
-}
-
-CScopeStatusMessage::~CScopeStatusMessage()
-{
-}
 
 void CScopeStatusMessage::SetMessage(const wxString& message)
 {
 	this->m_message = message.c_str();
 }
 
-void CScopeStatusMessage::SetPercentage(const int& percentage)
+void CScopeStatusMessage::SetPercentage(int percentage)
 {
 	this->m_percentage = percentage;
 }
@@ -47,7 +40,7 @@ const wxString& CScopeStatusMessage::GetMessage() const
 	return m_message;
 }
 
-const int& CScopeStatusMessage::GetPercentage() const
+int CScopeStatusMessage::GetPercentage() const
 {
 	return m_percentage;
 }
