@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : GitApplyPatchDlg.h
 //
 // -------------------------------------------------------------------------
@@ -31,7 +31,7 @@ class GitApplyPatchDlg : public GitApplyPatchDlgBase
 {
 public:
     GitApplyPatchDlg(wxWindow* parent);
-    virtual ~GitApplyPatchDlg();
+    virtual ~GitApplyPatchDlg() = default;
 
     wxString GetExtraFlags() const { return m_textCtrlExtraFlags->GetValue().Trim(); }
     wxString GetPatchFile() const { return m_filePickerPatchFile->GetPath().Trim(); }
