@@ -33,47 +33,51 @@
 #ifndef __git__
 #define __git__
 
-#include <wx/progdlg.h>
-
-#include "plugin.h"
-#include "asyncprocess.h"
-#include "processreaderthread.h"
-#include <queue>
-#include <set>
-#include <wx/progdlg.h>
-#include "project.h" // wxStringSet_t
-#include <map>
-#include "overlaytool.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "ai/ResponseCollector.hpp"
+#include "clCodeLiteRemoteProcess.hpp"
+#include "clResult.hpp"
+#include "clTabTogglerHelper.h"
 #include "cl_command_event.h"
 #include "gitentry.h"
-#include "cl_command_event.h"
 #include "gitui.h"
-#include <vector>
-#include "clTabTogglerHelper.h"
+#include "ieditor.h"
+#include "overlaytool.h"
+#include "plugin.h"
+#include "project.h" // wxStringSet_t
 
+#include <map>
+#include <optional>
+#include <queue>
+#include <set>
+#include <vector>
+#include <wx/progdlg.h>
+#if USE_SFTP
+#include "cl_ssh.h"
+#endif
+
+class clTreeCtrl;
 class clCommandProcessor;
-class GitBlameDlg;
+class GitCommitDlg;
+
+#define GIT_TAB_NAME "Git"
 
 class gitAction
 {
 public:
-    int action;
+    int action = 0;
     wxString arguments;
     wxString workingDirectory;
 
 public:
-    gitAction()
-        : action(0)
-        , arguments("")
-        , workingDirectory("")
-    {
-    }
+    gitAction() = default;
     gitAction(int act, const wxString& args)
         : action(act)
         , arguments(args)
     {
     }
-    ~gitAction() {}
+    ~gitAction() = default;
 };
 
 class GitConsole;
@@ -99,6 +103,7 @@ class GitPlugin : public IPlugin
 {
     friend class GitConsole;
     friend class GitCommitListDlg;
+    friend class GitCommitDlg;
 
     typedef std::map<int, int> IntMap_t;
     enum {
@@ -110,6 +115,7 @@ class GitPlugin : public IPlugin
         gitAddFile,
         gitDeleteFile,
         gitDiffFile,
+        gitDiffFileExternal,
         gitDiffRepoCommit,
         gitDiffRepoShow,
         gitResetFile,
@@ -125,6 +131,7 @@ class GitPlugin : public IPlugin
         gitBranchSwitchRemote,
         gitCommitList,
         gitBlame,
+        gitBlameSummary,
         gitRevlist,
         gitRebase,
         gitGarbageCollection,
@@ -136,6 +143,7 @@ class GitPlugin : public IPlugin
         gitRevertCommit,
         gitStash,
         gitStashPop,
+        gitConfig,
     };
 
     wxArrayString m_localBranchList;
@@ -149,6 +157,7 @@ class GitPlugin : public IPlugin
     wxString m_pathGITExecutable;
     wxString m_pathGITKExecutable;
     wxString m_repositoryDirectory;
+    wxString m_userEnteredRepositoryDirectory;
     wxString m_currentBranch;
     std::list<gitAction> m_gitActionQueue;
     wxTimer m_progressTimer;
@@ -157,78 +166,95 @@ class GitPlugin : public IPlugin
     bool m_bActionRequiresTreUpdate;
     IProcess* m_process;
     wxEvtHandler* m_eventHandler;
-    wxWindow* m_topWindow;
     clToolBar* m_pluginToolbar;
     wxMenu* m_pluginMenu;
     IntMap_t m_treeImageMapping;
     int m_baseImageCount;
     GitConsole* m_console;
-    wxFileName m_workspaceFilename;
+    wxString m_workspace_file;
     GitCommitListDlg* m_commitListDlg;
     wxArrayString m_filesSelected;
     wxString m_selectedFolder;
     clCommandProcessor* m_commandProcessor;
-    clTabTogglerHelper::Ptr_t m_tabToggler;
-    GitBlameDlg* m_gitBlameDlg;
+    std::unordered_map<wxString, std::vector<wxString>>
+        m_blameMap; // contains file: comment per line (extracted from the 'git blame' info)
+    size_t m_configFlags = 0;
+    wxString m_lastBlameMessage;
+    bool m_isRemoteWorkspace = false;
+    wxString m_remoteWorkspaceAccount;
+    clCodeLiteRemoteProcess m_remoteProcess;
+    wxString m_codeliteRemoteScriptPath;
+    bool m_isEnabled = false;
+    GitCommitDlg* m_commitDialog{nullptr};
+
+#if USE_SFTP
+    clSSH::Ptr_t m_ssh;
+#endif
 
 private:
-    void DoCreateTreeImages();
+    void StartCodeLiteRemote();
+    void ClearCodeLiteRemoteInfo();
     void DoShowDiffViewer(const wxString& headFile, const wxString& fileName);
     void DoExecuteCommands(const GitCmd::Vec_t& commands, const wxString& workingDir);
-    bool DoExecuteCommandSync(const wxString& command, const wxString& workingDir, wxString& commandOutput);
+    bool
+    DoExecuteCommandSync(const wxString& command, wxString* commandOutput, const wxString& workingDir = wxEmptyString);
 
-    void DoSetTreeItemImage(wxTreeCtrl* ctrl, const wxTreeItemId& item, OverlayTool::BmpType bmpType) const;
+    void DoSetTreeItemImage(clTreeCtrl* ctrl, const wxTreeItemId& item, OverlayTool::BmpType bmpType) const;
     void InitDefaults();
     void AddDefaultActions();
     void LoadDefaultGitCommands(GitEntry& data, bool overwrite = false);
     void ProcessGitActionQueue();
-    void ColourFileTree(wxTreeCtrl* tree, const wxStringSet_t& files, OverlayTool::BmpType bmpType) const;
+    void ColourFileTree(clTreeCtrl* tree, const wxStringSet_t& files, OverlayTool::BmpType bmpType) const;
     void CreateFilesTreeIDsMap(std::map<wxString, wxTreeItemId>& IDs, bool ifmodified = false) const;
     void DoShowCommitDialog(const wxString& diff, wxString& commitArgs);
+    void DoRefreshView(bool ensureVisible);
 
     /// Workspace management
     bool IsWorkspaceOpened() const;
-    wxString GetWorkspaceName() const;
-    wxFileName GetWorkspaceFileName() const;
-
+    wxString GetCommitMessageFile() const;
+    wxString FindRepositoryRoot(const wxString& starting_dir) const;
     void FinishGitListAction(const gitAction& ga);
     void ListBranchAction(const gitAction& ga);
     void GetCurrentBranchAction(const gitAction& ga);
     void UpdateFileTree();
 
-    void ShowProgress(const wxString& message, bool pulse = true);
+    void ShowProgress(const wxString& message);
     void HideProgress();
     void DoCleanup();
     void DoAddFiles(const wxArrayString& files);
     void DoResetFiles(const wxArrayString& files);
-    void DoGetFileViewSelectedFiles(wxArrayString& files, bool relativeToRepo);
     void DoShowDiffsForFiles(const wxArrayString& files, bool useFileAsBase = false);
-    void DoSetRepoPath(const wxString& repoPath = "", bool promptUser = true);
-    void DoRecoverFromGitCommandError();
-
+    void DoSetRepoPath(const wxString& repo_path = wxEmptyString);
+    void DoRecoverFromGitCommandError(bool clear_queue = true);
+    void DoLoadBlameInfo(bool clearCache);
+    void DoUpdateBlameInfo(const wxString& info, const wxString& fullpath);
+    void DoAnyFileModified();
     DECLARE_EVENT_TABLE()
 
     // Event handlers
-    void OnInitDone(wxCommandEvent& e);
     void OnProgressTimer(wxTimerEvent& Event);
     void OnProcessTerminated(clProcessEvent& event);
     void OnProcessOutput(clProcessEvent& event);
     void OnFileMenu(clContextMenuEvent& event);
     void OnFolderMenu(clContextMenuEvent& event);
 
+    void OnSideBarPageChanged(clCommandEvent& event);
+
+    void OnFileCreated(clFileSystemEvent& event);
+    void OnReplaceInFiles(clFileSystemEvent& event);
+    void OnEditorChanged(wxCommandEvent& event);
     void OnFileSaved(clCommandEvent& e);
+    void OnFileModifiedExternally(clFileSystemEvent& e);
     void OnFilesAddedToProject(clCommandEvent& e);
     void OnFilesRemovedFromProject(clCommandEvent& e);
-    void OnWorkspaceLoaded(wxCommandEvent& e);
-    void OnWorkspaceClosed(wxCommandEvent& e);
+    void OnWorkspaceLoaded(clWorkspaceEvent& e);
+    void OnWorkspaceClosed(clWorkspaceEvent& e);
     void OnWorkspaceConfigurationChanged(wxCommandEvent& e);
     void OnMainFrameTitle(clCommandEvent& e);
-    void OnSetGitRepoPath(wxCommandEvent& e);
     void OnSettings(wxCommandEvent& e);
     void OnFileDiffSelected(wxCommandEvent& e);
     void OnFileResetSelected(wxCommandEvent& e);
     void OnFileAddSelected(wxCommandEvent& e);
-    void OnFileDeleteSelected(wxCommandEvent& e);
     void OnSwitchLocalBranch(wxCommandEvent& e);
     void OnSwitchRemoteBranch(wxCommandEvent& e);
     void OnCreateBranch(wxCommandEvent& e);
@@ -248,14 +274,11 @@ private:
     void OnGarbageColletion(wxCommandEvent& e);
     void OnOpenMSYSGit(wxCommandEvent& e);
     void OnActiveProjectChanged(clProjectSettingsEvent& event);
+    void OnFileCommitListSelected(wxCommandEvent& e);
     void OnFileGitBlame(wxCommandEvent& event);
-
-#if 0
-    void OnBisectStart(wxCommandEvent& e);
-    void OnBisectGood(wxCommandEvent& e);
-    void OnBisectBad(wxCommandEvent& e);
-    void OnBisectReset(wxCommandEvent& e);
-#endif
+    void OnAppActivated(wxCommandEvent& event);
+    void OnUpdateNavBar(clCodeCompletionEvent& event);
+    void OnEditorClosed(wxCommandEvent& event);
     void OnEnableGitRepoExists(wxUpdateUIEvent& e);
     void OnClone(wxCommandEvent& e);
 
@@ -267,13 +290,49 @@ private:
     void OnFolderStashPop(wxCommandEvent& event);
     void OnFolderGitBash(wxCommandEvent& event);
 
+    // Respond to local events
+    void OnGitActionDone(clSourceControlEvent& event);
+    bool HandleErrorsOnRemoteRepo(const wxString& output) const;
+
+    // Remote callbacks
+    void OnFindPath(clCommandEvent& event);
+    void OpenURLInBrowser(const wxString& url);
+
 public:
     GitPlugin(IManager* manager);
-    ~GitPlugin();
+    ~GitPlugin() override = default;
 
-    void StoreWorkspaceRepoDetails();
+    const wxString& GetRepositoryPath() const { return m_repositoryDirectory; }
     void WorkspaceClosed();
 
+    bool IsRemoteWorkspace() const { return m_isRemoteWorkspace; }
+
+    /**
+     * @brief create git process and return the process handle
+     */
+    IProcess* AsyncRunGit(wxEvtHandler* handler,
+                          const wxString& git_args,
+                          size_t create_flags,
+                          const wxString& working_directory,
+                          bool logMessage = false);
+    /**
+     * @brief create a git process and direct the output to a callback
+     */
+    void AsyncRunGitWithCallback(const wxString& git_args,
+                                 std::function<void(const wxString&)> callback,
+                                 size_t create_flags,
+                                 const wxString& working_directory,
+                                 bool logMessage = false);
+    /**
+     * @brief is git enabled for the current workspace?
+     */
+    bool IsGitEnabled() const;
+
+    /**
+     * @brief open a file. The path is relative to the workspace location
+     */
+    IEditor* OpenFile(const wxString& relativePathFile);
+
     /**
      * @brief fetch the next 100 commits (skip 'skip' first commits)
      * and show them in the commit list dialog
@@ -282,13 +341,13 @@ public:
     void FetchNextCommits(int skip, const wxString& args);
 
     GitConsole* GetConsole() { return m_console; }
-    const wxString& GetRepositoryDirectory() const { return m_repositoryDirectory; }
     IProcess* GetProcess() { return m_process; }
     clCommandProcessor* GetFolderProcess() { return m_commandProcessor; }
 
     IManager* GetManager() { return m_mgr; }
 
     void ShowDiff(const wxArrayString& files) { DoShowDiffsForFiles(files); }
+    void ShowExternalDiff(const wxString& file, const wxString& tool);
 
     void ApplyPatch(const wxString& filename, const wxString& extraFlags);
     void AddFiles(const wxArrayString& files) { DoAddFiles(files); }
@@ -300,11 +359,15 @@ public:
     void UndoAddFiles(const wxArrayString& files);
 
     void RefreshFileListView();
+    /**
+     * @brief display a message in the console
+     * used by outside classes e.g. GitDiffDlg
+     * @param message to display
+     */
+    void DisplayMessage(const wxString& message) const;
 
     void DoGitBlame(const wxString& args);      // Called by OnGitBlame or the git blame dialog
     wxString GetEditorRelativeFilepath() const; // Called by OnGitBlame or the git blame dialog
-    void OnGitBlameRevList(
-        const wxString& arg, const wxString& filepath, const wxString& commit = ""); // Called by the git blame dialog
 
     /**
      * @brief simple git command executioin completed. Display its output etc
@@ -312,13 +375,22 @@ public:
     void OnCommandOutput(clCommandEvent& event);
     void OnCommandEnded(clCommandEvent& event);
 
+    bool GenerateCommitMessage(const wxString& prompt);
+
+    /// Return the commit log between range of commits. We split the log (line based), to match the `chunk_size`
+    /// argument.
+    clStatusOr<wxArrayString> FetchLogBetweenCommits(const wxString& start_commit,
+                                                     const wxString& end_commit,
+                                                     bool oneline = true,
+                                                     size_t chunk_size = wxString::npos);
+
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual clToolBar* CreateToolBar(wxWindow* parent);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void HookPopupMenu(wxMenu* menu, MenuType type);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void HookPopupMenu(wxMenu* menu, MenuType type) override;
+    void UnPlug() override;
 };
 
 #endif // git
