@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : gitCloneDlg.h
 //
 // -------------------------------------------------------------------------
@@ -32,7 +32,7 @@ class gitCloneDlg : public gitCloneDlgBaseClass
 {
 public:
     gitCloneDlg(wxWindow* parent);
-    virtual ~gitCloneDlg();
+    virtual ~gitCloneDlg() = default;
 
 protected:
     virtual void OnOKUI(wxUpdateUIEvent& event);
