@@ -33,34 +33,60 @@
 #ifndef __gitCommitDlg__
 #define __gitCommitDlg__
 
+#include "CustomControls/IndicatorPanel.hpp"
+#include "ai/ResponseCollector.hpp"
+#include "clEditorEditEventsHandler.h"
 #include "gitui.h"
+#include "macros.h"
+
 #include <map>
+#include <optional>
+#include <wx/tokenzr.h>
+
+class GitPlugin;
 
 class GitCommitDlg : public GitCommitDlgBase
 {
-    std::map<wxString, wxString> m_diffMap;
-    bool m_toggleChecks;
-    
 public:
-    GitCommitDlg(wxWindow* parent);
-    ~GitCommitDlg();
+    GitCommitDlg(wxWindow* parent, GitPlugin* plugin, const wxString& workingDir);
+    virtual ~GitCommitDlg();
+
+    void AppendCommitMessage(const wxString& message);
+    void ClearCommitMessage();
+    void SetCommitMessageGenerationCompleted();
+    void SetIndicatorMessage(const wxString& mesage);
 
     void AppendDiff(const wxString& diff);
 
     wxArrayString GetSelectedFiles();
     wxString GetCommitMessage();
+    void SetPreviousCommitMessage(const wxString& previous) { m_previousCommitMessage = previous; }
+    void SetHistory(const wxString& history) { m_history = wxStringTokenize(history, "\n"); }
     bool IsAmending() const { return m_checkBoxAmend->IsChecked(); }
-
-private:
-    void OnChangeFile(wxCommandEvent& e);
+    bool IsSignedOffBy() const { return m_checkBoxSignedOff->IsChecked(); }
 
 protected:
-    virtual void OnClearGitCommitHistoryUI(wxUpdateUIEvent& event);
+    virtual void OnAmendClicked(wxCommandEvent& event);
+    virtual void OnGenerate(wxCommandEvent& event);
+    virtual void OnGenerateUI(wxUpdateUIEvent& event);
     virtual void OnCommitHistory(wxCommandEvent& event);
-    virtual void OnCommitHistoryUI(wxUpdateUIEvent& event);
-    virtual void OnClearGitCommitHistory(wxCommandEvent& event);
     virtual void OnToggleCheckAll(wxCommandEvent& event);
     virtual void OnCommitOK(wxCommandEvent& event);
+
+private:
+    void OnChangeFile(wxDataViewEvent& e);
+
+    GitPlugin* m_plugin{nullptr};
+    wxString m_workingDir;
+    wxStringMap_t m_diffMap;
+    bool m_toggleChecks;
+    wxString m_previousCommitMessage;
+    wxArrayString m_history;
+    wxString m_stashedMessage;
+    bool m_dismissedWithOk = false;
+    wxString m_rawDiff;
+    bool m_generationInProgress{false};
+    IndicatorPanel* m_indicatorPanel{nullptr};
 };
 
 #endif
