@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : gitLogDlg.h
 //
 // -------------------------------------------------------------------------
@@ -41,9 +41,7 @@ class GitLogDlg : public wxDialog
 
 public:
     GitLogDlg(wxWindow* parent, const wxString title);
-    virtual ~GitLogDlg();
-
-    void SetLog(const wxString& log);
+    virtual ~GitLogDlg() = default;
 };
 
 #endif //__gitLogDlg__
