@@ -24,51 +24,79 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "gitSettingsDlg.h"
-#include "windowattrmanager.h"
-#include "cl_config.h"
-#include "gitentry.h"
-#include "event_notifier.h"
 
-GitSettingsDlg::GitSettingsDlg(wxWindow* parent, const wxString& localRepoPath)
+#include "cl_config.h"
+#include "event_notifier.h"
+#include "gitentry.h"
+#include "windowattrmanager.h"
+
+GitSettingsDlg::GitSettingsDlg(wxWindow* parent, const wxString& localRepoPath, const wxString& userEnteredRepoPath,
+                               const wxString& projectNameHash)
     : GitSettingsDlgBase(parent)
-    , m_localRepoPath(localRepoPath)
+    , m_userEnteredRepoPath(userEnteredRepoPath)
+    , m_projectNameHash(projectNameHash)
 {
     GitEntry data;
     data.Load();
 
     m_pathGIT->SetPath(data.GetGITExecutablePath());
     m_pathGITK->SetPath(data.GetGITKExecutablePath());
-    m_checkBoxLog->SetValue(data.GetFlags() & GitEntry::Git_Verbose_Log);
-    m_checkBoxTerminal->SetValue(data.GetFlags() & GitEntry::Git_Show_Terminal);
-    m_checkBoxTrackTree->SetValue(data.GetFlags() & GitEntry::Git_Colour_Tree_View);
+    m_textCtrlGitShell->ChangeValue(data.GetGitShellCommand());
 
-    GitEntry::GitProperties props = GitEntry::ReadGitProperties(m_localRepoPath);
+    m_checkBoxLog->SetValue(data.GetFlags() & GitEntry::VerboseLog);
+    m_checkBoxTerminal->SetValue(data.GetFlags() & GitEntry::ShowTerminal);
+    m_checkBoxShowBlameInStatusBar->SetValue(data.IsShowBlameInfoInStatusBar());
+    GitEntry::GitProperties props = GitEntry::ReadGitProperties(localRepoPath);
 
     m_textCtrlGlobalEmail->ChangeValue(props.global_email);
     m_textCtrlGlobalName->ChangeValue(props.global_username);
     m_textCtrlLocalEmail->ChangeValue(props.local_email);
     m_textCtrlLocalName->ChangeValue(props.local_username);
-    
+    m_dirPickerGitRepoPath->SetPath(m_userEnteredRepoPath);
+
+    m_choiceDiffTools->SetStringSelection(data.GetDifftool());
     SetName("GitSettingsDlg");
     WindowAttrManager::Load(this);
 }
 
-GitSettingsDlg::~GitSettingsDlg() {  }
-
 void GitSettingsDlg::OnOK(wxCommandEvent& event)
 {
     GitEntry data;
     data.Load();
 
+    wxString repopath = m_dirPickerGitRepoPath->GetPath();
+    // Sanity-check the entered path: we don't want /foo/bar/.git/, just /foo/bar
+    if(repopath.Right(1) == "/") {
+        repopath.RemoveLast();
+    }
+    if(repopath.Right(5) == "/.git") {
+        repopath.RemoveLast(5);
+    }
+
+    if(!m_projectNameHash.empty() && (repopath != m_userEnteredRepoPath)) {
+        m_userEnteredRepoPath = repopath;
+        data.SetProjectUserEnteredRepoPath(repopath, m_projectNameHash);
+        data.Save();
+
+        // The git repo path was changed, so we need to  flag a reload
+        EndModal(wxID_REFRESH);
+        return;
+    };
+
     data.SetGITExecutablePath(m_pathGIT->GetPath());
     data.SetGITKExecutablePath(m_pathGITK->GetPath());
+    data.SetGitShellCommand(m_textCtrlGitShell->GetValue());
+    data.SetDifftool(m_choiceDiffTools->GetStringSelection()); // can be an empty string
 
     size_t flags = 0;
-    if(m_checkBoxLog->IsChecked()) flags |= GitEntry::Git_Verbose_Log;
+    if(m_checkBoxLog->IsChecked())
+        flags |= GitEntry::VerboseLog;
 
-    if(m_checkBoxTerminal->IsChecked()) flags |= GitEntry::Git_Show_Terminal;
+    if(m_checkBoxTerminal->IsChecked())
+        flags |= GitEntry::ShowTerminal;
 
-    if(m_checkBoxTrackTree->IsChecked()) flags |= GitEntry::Git_Colour_Tree_View;
+    if(m_checkBoxShowBlameInStatusBar->IsChecked())
+        flags |= GitEntry::ShowCommitInfo;
 
     data.SetFlags(flags);
     data.Save();
@@ -78,7 +106,7 @@ void GitSettingsDlg::OnOK(wxCommandEvent& event)
     props.global_username = m_textCtrlGlobalName->GetValue();
     props.local_email = m_textCtrlLocalEmail->GetValue();
     props.local_username = m_textCtrlLocalName->GetValue();
-    GitEntry::WriteGitProperties(m_localRepoPath, props);
+    GitEntry::WriteGitProperties(m_userEnteredRepoPath, props);
 
     // Notify about configuration changed
     wxCommandEvent evt(wxEVT_GIT_CONFIG_CHANGED);
@@ -87,4 +115,4 @@ void GitSettingsDlg::OnOK(wxCommandEvent& event)
     EndModal(wxID_OK);
 }
 
-void GitSettingsDlg::OnLocalRepoUI(wxUpdateUIEvent& event) { event.Enable(!m_localRepoPath.IsEmpty()); }
+void GitSettingsDlg::OnLocalRepoUI(wxUpdateUIEvent& event) { event.Enable(!m_userEnteredRepoPath.IsEmpty()); }
