@@ -33,14 +33,16 @@
 #ifndef __gitentry__
 #define __gitentry__
 
+#include "cl_config.h"
+#include "wxStringHash.h"
+
+#include <map>
+#include <vector>
 #include <wx/colour.h>
 #include <wx/event.h>
-#include <vector>
-#include <map>
-#include "cl_config.h"
 
 struct GitLabelCommand {
-    GitLabelCommand() {}
+    GitLabelCommand() = default;
 
     GitLabelCommand(const wxString& l, const wxString& c)
         : label(l)
@@ -62,7 +64,7 @@ protected:
     int m_lastUsed;
 
 public:
-    GitCommandsEntries() {}
+    GitCommandsEntries() = default;
     GitCommandsEntries(const wxString& commandName)
         : m_commandName(commandName)
         , m_lastUsed(-1)
@@ -75,9 +77,9 @@ public:
     {
     }
 
-    virtual ~GitCommandsEntries() {}
-    void FromJSON(const JSONElement& json);
-    void ToJSON(JSONElement& arr) const;
+    virtual ~GitCommandsEntries() = default;
+    void FromJSON(const JSONItem& json);
+    void ToJSON(JSONItem& arr) const;
 
     const wxString& GetCommandname() const { return m_commandName; }
 
@@ -88,7 +90,7 @@ public:
     const wxString GetDefaultCommand() const
     {
         wxString str;
-        if(m_lastUsed >= 0 && m_lastUsed < (int)m_commands.size()) {
+        if (m_lastUsed >= 0 && m_lastUsed < (int)m_commands.size()) {
             str = m_commands.at(m_lastUsed).command;
         }
         return str;
@@ -99,7 +101,32 @@ public:
     void SetLastUsedCommandIndex(int index) { m_lastUsed = index; }
 };
 
-typedef std::map<wxString, GitCommandsEntries> GitCommandsEntriesMap_t;
+typedef std::unordered_map<wxString, GitCommandsEntries> GitCommandsEntriesMap_t;
+
+class GitWorkspace
+{
+public:
+    GitWorkspace() = default;
+    GitWorkspace(const wxString& name)
+        : m_name(name)
+    {
+    }
+
+    const wxString& GetWorkspaceName() const { return m_name; }
+    void SetWorkspaceName(const wxString& name) { m_name = name; }
+    const wxString GetProjectUserEnteredRepoPath(const wxString& projectName);
+    void SetProjectUserEnteredRepoPath(const wxString& projectName, const wxString& userEnteredRepoPath);
+
+    void FromJSON(const JSONItem& json);
+    void ToJSON(JSONItem& arr) const;
+
+protected:
+    wxString m_name;
+    wxStringMap_t m_projectData;
+    wxStringMap_t m_userEnteredRepoPath;
+};
+
+typedef std::unordered_map<wxString, GitWorkspace> GitWorkspaceMap_t;
 
 extern const wxEventType wxEVT_GIT_CONFIG_CHANGED;
 class GitEntry : public clConfigItem
@@ -108,23 +135,34 @@ class GitEntry : public clConfigItem
     wxColour m_colourDiffFile;
     wxString m_pathGIT;
     wxString m_pathGITK;
-    JSONElement::wxStringMap_t m_entries;
+    wxStringMap_t m_entries;
     GitCommandsEntriesMap_t m_commandsMap;
+    GitWorkspaceMap_t m_workspacesMap;
     size_t m_flags;
     int m_gitDiffDlgSashPos;
+    int m_gitDiffChooseDlgRadioSel1;
+    int m_gitDiffChooseDlgRadioSel2;
+    wxArrayString m_gitDiffChooseDlgCBoxValues1;
+    wxArrayString m_gitDiffChooseDlgCBoxValues2;
     int m_gitConsoleSashPos;
     int m_gitCommitDlgHSashPos;
     int m_gitCommitDlgVSashPos;
-    wxArrayString m_recentCommits;
     wxString m_gitShellCommand;
-	bool m_gitBlameShowLogControls;
-	bool m_gitBlameShowParentCommit;
+    bool m_gitBlameShowLogControls;
+    bool m_gitBlameShowParentCommit;
     int m_gitBlameDlgMainSashPos;
     int m_gitBlameDlgHSashPos;
     int m_gitBlameDlgVSashPos;
+    wxString m_difftool;
 
 public:
-    enum { Git_Verbose_Log = 0x00000001, Git_Show_Terminal = 0x00000002, Git_Colour_Tree_View = 0x00000004 };
+    enum {
+        VerboseLog = (1 << 0),
+        ShowTerminal = (1 << 1),
+        ColourTreeView = (1 << 2),
+        ShowCommitInfo = (1 << 4),
+        CheckSignedOffBy = (1 << 5),
+    };
 
     struct GitProperties {
         wxString global_username;
@@ -135,7 +173,7 @@ public:
 
 public:
     GitEntry();
-    virtual ~GitEntry();
+    virtual ~GitEntry() = default;
 
 public:
     static GitEntry::GitProperties ReadGitProperties(const wxString& localRepoPath = "");
@@ -143,7 +181,7 @@ public:
 
     void EnableFlag(size_t flag, bool b)
     {
-        if(b) {
+        if (b) {
             m_flags |= flag;
         } else {
             m_flags &= ~flag;
@@ -152,8 +190,6 @@ public:
 
     void Save();
     GitEntry& Load();
-    wxArrayString& GetRecentCommit() { return m_recentCommits; }
-    void AddRecentCommit(const wxString& commitMessage);
 
     void SetGitShellCommand(const wxString& gitShellCommand) { this->m_gitShellCommand = gitShellCommand; }
     const wxString& GetGitShellCommand() const { return m_gitShellCommand; }
@@ -163,12 +199,19 @@ public:
     int GetGitCommitDlgVSashPos() const { return m_gitCommitDlgVSashPos; }
     void SetGitDiffDlgSashPos(int gitDiffDlgSashPos) { this->m_gitDiffDlgSashPos = gitDiffDlgSashPos; }
     int GetGitDiffDlgSashPos() const { return m_gitDiffDlgSashPos; }
-    void SetEntries(const JSONElement::wxStringMap_t& entries) { this->m_entries = entries; }
+    void SetGitDiffChooseDlgRadioSel1(int sel) { this->m_gitDiffChooseDlgRadioSel1 = sel; }
+    int GetGitDiffChooseDlgRadioSel1() const { return m_gitDiffChooseDlgRadioSel1; }
+    void SetGitDiffChooseDlgRadioSel2(int sel) { this->m_gitDiffChooseDlgRadioSel2 = sel; }
+    int GetGitDiffChooseDlgRadioSel2() const { return m_gitDiffChooseDlgRadioSel2; }
+    void SetGitDiffChooseDlgCBoxValues1(const wxArrayString& arr) { this->m_gitDiffChooseDlgCBoxValues1 = arr; }
+    wxArrayString& GetGitDiffChooseDlgCBoxValues1() { return m_gitDiffChooseDlgCBoxValues1; }
+    void SetGitDiffChooseDlgCBoxValues2(const wxArrayString& arr) { this->m_gitDiffChooseDlgCBoxValues2 = arr; }
+    wxArrayString& GetGitDiffChooseDlgCBoxValues2() { return m_gitDiffChooseDlgCBoxValues2; }
+    void SetEntries(const wxStringMap_t& entries) { this->m_entries = entries; }
     void SetFlags(size_t flags) { this->m_flags = flags; }
-    const JSONElement::wxStringMap_t& GetEntries() const { return m_entries; }
+    const wxStringMap_t& GetEntries() const { return m_entries; }
     size_t GetFlags() const { return m_flags; }
     void SetEntry(const wxString& workspace, const wxString& repo) { this->m_entries[workspace] = repo; }
-    void DeleteEntry(const wxString& workspace);
 
     GitCommandsEntriesMap_t GetCommandsMap() const { return m_commandsMap; }
     void SetTrackedFileColour(const wxColour& colour) { this->m_colourTrackedFile = colour; }
@@ -182,9 +225,15 @@ public:
     wxString GetGITKExecutablePath() const;
     void SetGitConsoleSashPos(int gitConsoleSashPos) { this->m_gitConsoleSashPos = gitConsoleSashPos; }
     int GetGitConsoleSashPos() const { return m_gitConsoleSashPos; }
-    void SetGitBlameShowLogControls(bool gitBlameShowLogControls) { this->m_gitBlameShowLogControls = gitBlameShowLogControls; }
+    void SetGitBlameShowLogControls(bool gitBlameShowLogControls)
+    {
+        this->m_gitBlameShowLogControls = gitBlameShowLogControls;
+    }
     bool GetGitBlameShowLogControls() const { return m_gitBlameShowLogControls; }
-    void SetGitBlameShowParentCommit(bool gitBlameShowParentCommit) { this->m_gitBlameShowParentCommit = gitBlameShowParentCommit; }
+    void SetGitBlameShowParentCommit(bool gitBlameShowParentCommit)
+    {
+        this->m_gitBlameShowParentCommit = gitBlameShowParentCommit;
+    }
     bool GetGitBlameShowParentCommit() const { return m_gitBlameShowParentCommit; }
     void SetGitBlameDlgMainSashPos(int MainSashPos) { this->m_gitBlameDlgMainSashPos = MainSashPos; }
     void SetGitBlameDlgHSashPos(int HSashPos) { this->m_gitBlameDlgHSashPos = HSashPos; }
@@ -198,7 +247,14 @@ public:
     void AddGitCommandsEntry(GitCommandsEntries& entries, const wxString& entryName);
     void DeleteGitCommandsEntry(const wxString& entryName) { m_commandsMap.erase(entryName); }
 
-    virtual void FromJSON(const JSONElement& json);
-    virtual JSONElement ToJSON() const;
+    wxString GetProjectUserEnteredRepoPath(const wxString& nameHash);
+    void SetProjectUserEnteredRepoPath(const wxString& userEnteredRepoPath, const wxString& nameHash);
+
+    virtual void FromJSON(const JSONItem& json);
+    virtual JSONItem ToJSON() const;
+
+    bool IsShowBlameInfoInStatusBar() const { return m_flags & ShowCommitInfo; }
+    void SetDifftool(const wxString& difftool) { this->m_difftool = difftool; }
+    const wxString& GetDifftool() const { return m_difftool; }
 };
 #endif
