@@ -23,53 +23,42 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include <wx/app.h>
-#include "confformbuilder.h"
-#include <wx/mimetype.h>
-#include "procutils.h"
-#include "event_notifier.h"
-#include "workspace.h"
-#include "project.h"
-#include "processreaderthread.h"
-#include <wx/msgdlg.h>
-#include "asyncprocess.h"
-#include "globals.h"
-#include "formbuildsettingsdlg.h"
-#include "wxfbitemdlg.h"
-#include <wx/menu.h>
-#include <wx/xrc/xmlres.h>
 #include "wxformbuilder.h"
-#include <wx/xrc/xmlres.h>
-#include <wx/mimetype.h>
 
-static wxFormBuilder* thePlugin = NULL;
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "confformbuilder.h"
+#include "event_notifier.h"
+#include "formbuildsettingsdlg.h"
+#include "globals.h"
+#include "procutils.h"
+#include "project.h"
+#include "workspace.h"
+#include "wxfbitemdlg.h"
+
+#include <wx/app.h>
+#include <wx/menu.h>
+#include <wx/mimetype.h>
+#include <wx/msgdlg.h>
+#include <wx/xrc/xmlres.h>
 
 // Define the plugin entry point
-extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
-{
-    if(thePlugin == 0) {
-        thePlugin = new wxFormBuilder(manager);
-    }
-    return thePlugin;
-}
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager) { return new wxFormBuilder(manager); }
 
-extern "C" EXPORT PluginInfo GetPluginInfo()
+CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
-    PluginInfo info;
+    static PluginInfo info;
     info.SetAuthor(wxT("Eran Ifrah"));
     info.SetName(wxT("wxFormBuilder"));
     info.SetDescription(_("wxFormBuilder integration with CodeLite"));
     info.SetVersion(wxT("v1.0"));
-    return info;
+    return &info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
+CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
 wxFormBuilder::wxFormBuilder(IManager* manager)
     : IPlugin(manager)
-    , m_separatorItem(NULL)
-    , m_openWithWxFbItem(NULL)
-    , m_openWithWxFbSepItem(NULL)
 {
     Bind(wxEVT_ASYNC_PROCESS_TERMINATED, &wxFormBuilder::OnWxFBTerminated, this);
     m_longName = _("wxFormBuilder integration with CodeLite");
@@ -106,9 +95,7 @@ wxFormBuilder::wxFormBuilder(IManager* manager)
     EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_FILE, &wxFormBuilder::OnShowFileContextMenu, this);
 }
 
-wxFormBuilder::~wxFormBuilder() {}
-
-clToolBar* wxFormBuilder::CreateToolBar(wxWindow* parent) { return NULL; }
+void wxFormBuilder::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void wxFormBuilder::CreatePluginMenu(wxMenu* pluginsMenu)
 {
@@ -118,7 +105,7 @@ void wxFormBuilder::CreatePluginMenu(wxMenu* pluginsMenu)
     item = new wxMenuItem(menu, XRCID("wxfb_settings"), _("Settings..."), _("Settings..."), wxITEM_NORMAL);
     menu->Append(item);
 
-    pluginsMenu->Append(wxID_ANY, wxT("wxFormBuilder"), menu);
+    pluginsMenu->Append(wxID_ANY, _("wxFormBuilder"), menu);
 
     m_topWin->Connect(XRCID("wxfb_settings"),
                       wxEVT_COMMAND_MENU_SELECTED,
@@ -129,9 +116,9 @@ void wxFormBuilder::CreatePluginMenu(wxMenu* pluginsMenu)
 
 void wxFormBuilder::HookPopupMenu(wxMenu* menu, MenuType type)
 {
-    if(type == MenuTypeFileView_Folder) {
+    if (type == MenuTypeFileView_Folder) {
         menu->AppendSeparator();
-        menu->Append(XRCID("WXFB_POPUP"), wxT("wxFormBuilder"), CreatePopupMenu());
+        menu->Append(XRCID("WXFB_POPUP"), _("wxFormBuilder"), CreatePopupMenu());
     }
 }
 
@@ -149,7 +136,7 @@ void wxFormBuilder::OnSettings(wxCommandEvent& e)
 wxMenu* wxFormBuilder::CreatePopupMenu()
 {
     // Create the popup menu for the file explorer
-    // The only menu that we are interseted is the file explorer menu
+    // The only menu that we are interested is the file explorer menu
     wxMenu* menu = new wxMenu();
     wxMenuItem* item(NULL);
 
@@ -176,7 +163,7 @@ void wxFormBuilder::OnNewDialog(wxCommandEvent& e)
 {
     wxFBItemDlg dlg(m_mgr->GetTheApp()->GetTopWindow(), m_mgr);
     dlg.SetTitle(_("New wxDialog"));
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         wxFBItemInfo info;
         info = dlg.GetData();
         info.kind = wxFBItemKind_Dialog;
@@ -189,7 +176,7 @@ void wxFormBuilder::OnNewFrame(wxCommandEvent& e)
 {
     wxFBItemDlg dlg(m_mgr->GetTheApp()->GetTopWindow(), m_mgr);
     dlg.SetTitle(_("New wxFrame"));
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         wxFBItemInfo info;
         info = dlg.GetData();
         info.kind = wxFBItemKind_Frame;
@@ -205,7 +192,7 @@ void wxFormBuilder::OnNewPanel(wxCommandEvent& e)
     // no need for title in wxPanel
     dlg.DisableTitleField();
 
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         wxFBItemInfo info;
         info = dlg.GetData();
         info.kind = wxFBItemKind_Panel;
@@ -222,7 +209,7 @@ void wxFormBuilder::DoCreateWxFormBuilderProject(const wxFBItemInfo& data)
     m_mgr->CreateVirtualDirectory(formbuilderVD, wxT("formbuilder"));
     wxString templateFile(m_mgr->GetInstallDirectory() + wxT("/templates/formbuilder/"));
 
-    switch(data.kind) {
+    switch (data.kind) {
     default:
     case wxFBItemKind_Dialog:
         templateFile << wxT("DialogTemplate.fbp");
@@ -239,9 +226,9 @@ void wxFormBuilder::DoCreateWxFormBuilderProject(const wxFBItemInfo& data)
     }
 
     wxFileName tmplFile(templateFile);
-    if(!tmplFile.FileExists()) {
+    if (!tmplFile.FileExists()) {
         wxMessageBox(wxString::Format(_("Can't find wxFormBuilder template file '%s'"), tmplFile.GetFullPath().c_str()),
-                     _("CodeLite"),
+                     wxT("CodeLite"),
                      wxOK | wxCENTER | wxICON_WARNING);
         return;
     }
@@ -250,21 +237,21 @@ void wxFormBuilder::DoCreateWxFormBuilderProject(const wxFBItemInfo& data)
     wxString err_msg;
     wxString project = data.virtualFolder.BeforeFirst(wxT(':'));
     ProjectPtr proj = m_mgr->GetWorkspace()->FindProjectByName(project, err_msg);
-    if(proj) {
+    if (proj) {
         wxString files_path = proj->GetFileName().GetPath(wxPATH_GET_SEPARATOR | wxPATH_GET_VOLUME);
         // copy the file to here
         wxFileName fbpFile(files_path, data.file + wxT(".fbp"));
-        if(!wxCopyFile(tmplFile.GetFullPath(), fbpFile.GetFullPath())) {
+        if (!wxCopyFile(tmplFile.GetFullPath(), fbpFile.GetFullPath())) {
             wxMessageBox(wxString::Format(_("Failed to copy template file to '%s'"), fbpFile.GetFullPath().c_str()),
-                         _("CodeLite"),
+                         wxT("CodeLite"),
                          wxOK | wxCENTER | wxICON_WARNING);
             return;
         }
         // open the file, and replace expand its macros
         wxString content;
-        if(!ReadFileWithConversion(fbpFile.GetFullPath().c_str(), content)) {
+        if (!ReadFileWithConversion(fbpFile.GetFullPath().c_str(), content)) {
             wxMessageBox(wxString::Format(_("Failed to read file '%s'"), fbpFile.GetFullPath().c_str()),
-                         _("CodeLite"),
+                         wxT("CodeLite"),
                          wxOK | wxCENTER | wxICON_WARNING);
             return;
         }
@@ -274,9 +261,9 @@ void wxFormBuilder::DoCreateWxFormBuilderProject(const wxFBItemInfo& data)
         content.Replace(wxT("$(Title)"), data.title);
         content.Replace(wxT("$(ClassName)"), data.className);
 
-        if(!WriteFileWithBackup(fbpFile.GetFullPath().c_str(), content, false)) {
+        if (!WriteFileWithBackup(fbpFile.GetFullPath().c_str(), content, false)) {
             wxMessageBox(wxString::Format(_("Failed to write file '%s'"), fbpFile.GetFullPath().c_str()),
-                         _("CodeLite"),
+                         wxT("CodeLite"),
                          wxOK | wxCENTER | wxICON_WARNING);
             return;
         }
@@ -296,15 +283,15 @@ void wxFormBuilder::DoCreateWxFormBuilderProject(const wxFBItemInfo& data)
         wxFileName cppFile(fbpFile.GetPath(), data.file + wxT(".cpp"));
         wxFileName headerFile(fbpFile.GetPath(), data.file + wxT(".h"));
 
-        if(cppFile.FileExists()) {
+        if (cppFile.FileExists()) {
             filesToAdd.Add(cppFile.GetFullPath());
         }
 
-        if(headerFile.FileExists()) {
+        if (headerFile.FileExists()) {
             filesToAdd.Add(headerFile.GetFullPath());
         }
 
-        if(filesToAdd.GetCount()) {
+        if (filesToAdd.GetCount()) {
             m_mgr->AddFilesToVirtualFolder(data.virtualFolder, filesToAdd);
         }
 
@@ -316,12 +303,12 @@ void wxFormBuilder::OpenWithWxFb(wxCommandEvent& e)
 {
     // get the file name
     TreeItemInfo item = m_mgr->GetSelectedTreeItemInfo(TreeFileView);
-    if(item.m_item.IsOk() && item.m_itemType == ProjectItem::TypeFile) {
-        if(item.m_fileName.GetExt() == wxT("fbp")) {
+    if (item.m_item.IsOk() && item.m_itemType == ProjectItem::TypeFile) {
+        if (item.m_fileName.GetExt() == wxT("fbp")) {
             DoLaunchWxFB(item.m_fileName.GetFullPath());
         } else {
             wxMessageBox(_("Please select a 'fbp' (Form Builder Project) file only"),
-                         _("CodeLite"),
+                         wxT("CodeLite"),
                          wxOK | wxCENTER | wxICON_INFORMATION);
             return;
         }
@@ -335,7 +322,7 @@ void wxFormBuilder::DoLaunchWxFB(const wxString& file)
     //		wxMessageBox(_("Failed to launch wxFormBuilder, no path specified\nPlease set wxFormBuilder path from
     // Plugins
     //-> wxFormBuilder -> Settings..."),
-    //		             _("CodeLite"), wxOK|wxCENTER|wxICON_WARNING);
+    //		             wxT("CodeLite"), wxOK|wxCENTER|wxICON_WARNING);
     //		return;
     //	}
     ConfFormBuilder confData;
@@ -343,9 +330,7 @@ void wxFormBuilder::DoLaunchWxFB(const wxString& file)
     wxString cmd = confData.GetCommand();
     cmd.Replace(wxT("$(wxfb)"), fbpath);
     cmd.Replace(wxT("$(wxfb_project)"), wxString::Format(wxT("\"%s\""), file.c_str()));
-
-    WrapInShell(cmd);
-    CreateAsyncProcess(this, cmd, IProcessCreateWithHiddenConsole);
+    CreateAsyncProcess(this, cmd, IProcessCreateWithHiddenConsole | IProcessWrapInShell);
 }
 
 wxString wxFormBuilder::GetWxFBPath()
@@ -356,15 +341,18 @@ wxString wxFormBuilder::GetWxFBPath()
     wxString fbpath = confData.GetFbPath();
 
 #ifdef __WXGTK__
-    if(fbpath.IsEmpty()) {
+    if (fbpath.IsEmpty()) {
         // try to locate the file at '/usr/bin' or '/usr/local/bin'
-        if(wxFileName::FileExists(wxT("/usr/local/bin/wxformbuilder"))) {
+        if (wxFileName::FileExists(wxT("/usr/local/bin/wxformbuilder"))) {
             fbpath = wxT("/usr/local/bin/wxformbuilder");
-        } else if(wxFileName::FileExists(wxT("/usr/bin/wxformbuilder"))) {
+        } else if (wxFileName::FileExists(wxT("/usr/bin/wxformbuilder"))) {
             fbpath = wxT("/usr/bin/wxformbuilder");
         }
     }
 #endif
+    if (fbpath.IsEmpty()) {
+        fbpath = wxT("wxformbuilder");
+    }
     return fbpath;
 }
 
@@ -372,7 +360,7 @@ void wxFormBuilder::OnNewDialogWithButtons(wxCommandEvent& e)
 {
     wxFBItemDlg dlg(m_mgr->GetTheApp()->GetTopWindow(), m_mgr);
     dlg.SetTitle(_("New wxDialog with Default Buttons"));
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         wxFBItemInfo info;
         info = dlg.GetData();
         info.kind = wxFBItemKind_Dialog_With_Buttons;
@@ -386,7 +374,7 @@ void wxFormBuilder::OnOpenFile(clCommandEvent& e)
     e.Skip();
     // launch it with the default application
     wxFileName fullpath(e.GetFileName());
-    if(fullpath.GetExt().MakeLower() != wxT("fbp")) {
+    if (fullpath.GetExt().MakeLower() != wxT("fbp")) {
         return;
     }
 
@@ -400,10 +388,10 @@ void wxFormBuilder::OnOpenFile(clCommandEvent& e)
 #else
     wxMimeTypesManager* mgr = wxTheMimeTypesManager;
     wxFileType* type = mgr->GetFileTypeFromExtension(fullpath.GetExt());
-    if(type) {
+    if (type) {
         wxString cmd = type->GetOpenCommand(fullpath.GetFullPath());
         wxDELETE(type);
-        if(cmd.IsEmpty() == false) {
+        if (cmd.IsEmpty() == false) {
             e.Skip(false);
             wxExecute(cmd);
         }
@@ -413,7 +401,7 @@ void wxFormBuilder::OnOpenFile(clCommandEvent& e)
 
 void wxFormBuilder::OnWxFBTerminated(clProcessEvent& e)
 {
-    if(e.GetProcess()) {
+    if (e.GetProcess()) {
         delete e.GetProcess();
     }
 }
@@ -422,7 +410,7 @@ void wxFormBuilder::OnShowFileContextMenu(clContextMenuEvent& event)
 {
     event.Skip();
     wxFileName file(event.GetFileName());
-    if(file.GetExt() == "fbp") {
+    if (file.GetExt() == "fbp") {
         wxMenu* menu = event.GetMenu();
         menu->PrependSeparator();
         menu->Prepend(
